from __future__ import annotations
from win32more._prelude import *
import win32more.Microsoft.UI.Composition
import win32more.Microsoft.UI.Input
import win32more.Microsoft.UI.Text
import win32more.Microsoft.UI.Xaml
import win32more.Microsoft.UI.Xaml.Controls
import win32more.Microsoft.UI.Xaml.Controls.Primitives
import win32more.Microsoft.UI.Xaml.Data
import win32more.Microsoft.UI.Xaml.Documents
import win32more.Microsoft.UI.Xaml.Input
import win32more.Microsoft.UI.Xaml.Interop
import win32more.Microsoft.UI.Xaml.Media
import win32more.Microsoft.UI.Xaml.Media.Animation
import win32more.Microsoft.UI.Xaml.Navigation
import win32more.Microsoft.Web.WebView2.Core
import win32more.Windows.ApplicationModel.Contacts
import win32more.Windows.ApplicationModel.DataTransfer
import win32more.Windows.Devices.Geolocation
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.Foundation.Numerics
import win32more.Windows.Globalization
import win32more.Windows.Globalization.NumberFormatting
import win32more.Windows.Media.Casting
import win32more.Windows.Media.Playback
import win32more.Windows.UI
import win32more.Windows.UI.Text
import win32more.Windows.UI.Xaml.Interop
class AnchorRequestedEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IAnchorRequestedEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.AnchorRequestedEventArgs'
    @winrt_mixinmethod
    def get_Anchor(self: win32more.Microsoft.UI.Xaml.Controls.IAnchorRequestedEventArgs) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_mixinmethod
    def put_Anchor(self: win32more.Microsoft.UI.Xaml.Controls.IAnchorRequestedEventArgs, value: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    @winrt_mixinmethod
    def get_AnchorCandidates(self: win32more.Microsoft.UI.Xaml.Controls.IAnchorRequestedEventArgs) -> win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.UIElement]: ...
    Anchor = property(get_Anchor, put_Anchor)
    AnchorCandidates = property(get_AnchorCandidates, None)
class _AnimatedIcon_Meta_(ComPtr.__class__):
    pass
class AnimatedIcon(ComPtr, metaclass=_AnimatedIcon_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.IconElement
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IAnimatedIcon
    _classid_ = 'Microsoft.UI.Xaml.Controls.AnimatedIcon'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.AnimatedIcon.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IAnimatedIconFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.AnimatedIcon: ...
    @winrt_mixinmethod
    def get_Source(self: win32more.Microsoft.UI.Xaml.Controls.IAnimatedIcon) -> win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisualSource2: ...
    @winrt_mixinmethod
    def put_Source(self: win32more.Microsoft.UI.Xaml.Controls.IAnimatedIcon, value: win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisualSource2) -> Void: ...
    @winrt_mixinmethod
    def get_FallbackIconSource(self: win32more.Microsoft.UI.Xaml.Controls.IAnimatedIcon) -> win32more.Microsoft.UI.Xaml.Controls.IconSource: ...
    @winrt_mixinmethod
    def put_FallbackIconSource(self: win32more.Microsoft.UI.Xaml.Controls.IAnimatedIcon, value: win32more.Microsoft.UI.Xaml.Controls.IconSource) -> Void: ...
    @winrt_mixinmethod
    def get_MirroredWhenRightToLeft(self: win32more.Microsoft.UI.Xaml.Controls.IAnimatedIcon) -> Boolean: ...
    @winrt_mixinmethod
    def put_MirroredWhenRightToLeft(self: win32more.Microsoft.UI.Xaml.Controls.IAnimatedIcon, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_StateProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IAnimatedIconStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def SetState(cls: win32more.Microsoft.UI.Xaml.Controls.IAnimatedIconStatics, object: win32more.Microsoft.UI.Xaml.DependencyObject, value: hstr) -> Void: ...
    @winrt_classmethod
    def GetState(cls: win32more.Microsoft.UI.Xaml.Controls.IAnimatedIconStatics, object: win32more.Microsoft.UI.Xaml.DependencyObject) -> hstr: ...
    @winrt_classmethod
    def get_SourceProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IAnimatedIconStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FallbackIconSourceProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IAnimatedIconStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MirroredWhenRightToLeftProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IAnimatedIconStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    FallbackIconSource = property(get_FallbackIconSource, put_FallbackIconSource)
    MirroredWhenRightToLeft = property(get_MirroredWhenRightToLeft, put_MirroredWhenRightToLeft)
    Source = property(get_Source, put_Source)
    _AnimatedIcon_Meta_.FallbackIconSourceProperty = property(get_FallbackIconSourceProperty, None)
    _AnimatedIcon_Meta_.MirroredWhenRightToLeftProperty = property(get_MirroredWhenRightToLeftProperty, None)
    _AnimatedIcon_Meta_.SourceProperty = property(get_SourceProperty, None)
    _AnimatedIcon_Meta_.StateProperty = property(get_StateProperty, None)
class _AnimatedIconSource_Meta_(ComPtr.__class__):
    pass
class AnimatedIconSource(ComPtr, metaclass=_AnimatedIconSource_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.IconSource
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IAnimatedIconSource
    _classid_ = 'Microsoft.UI.Xaml.Controls.AnimatedIconSource'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.AnimatedIconSource.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IAnimatedIconSourceFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.AnimatedIconSource: ...
    @winrt_mixinmethod
    def get_Source(self: win32more.Microsoft.UI.Xaml.Controls.IAnimatedIconSource) -> win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisualSource2: ...
    @winrt_mixinmethod
    def put_Source(self: win32more.Microsoft.UI.Xaml.Controls.IAnimatedIconSource, value: win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisualSource2) -> Void: ...
    @winrt_mixinmethod
    def get_FallbackIconSource(self: win32more.Microsoft.UI.Xaml.Controls.IAnimatedIconSource) -> win32more.Microsoft.UI.Xaml.Controls.IconSource: ...
    @winrt_mixinmethod
    def put_FallbackIconSource(self: win32more.Microsoft.UI.Xaml.Controls.IAnimatedIconSource, value: win32more.Microsoft.UI.Xaml.Controls.IconSource) -> Void: ...
    @winrt_mixinmethod
    def get_MirroredWhenRightToLeft(self: win32more.Microsoft.UI.Xaml.Controls.IAnimatedIconSource) -> Boolean: ...
    @winrt_mixinmethod
    def put_MirroredWhenRightToLeft(self: win32more.Microsoft.UI.Xaml.Controls.IAnimatedIconSource, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_SourceProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IAnimatedIconSourceStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FallbackIconSourceProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IAnimatedIconSourceStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MirroredWhenRightToLeftProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IAnimatedIconSourceStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    FallbackIconSource = property(get_FallbackIconSource, put_FallbackIconSource)
    MirroredWhenRightToLeft = property(get_MirroredWhenRightToLeft, put_MirroredWhenRightToLeft)
    Source = property(get_Source, put_Source)
    _AnimatedIconSource_Meta_.FallbackIconSourceProperty = property(get_FallbackIconSourceProperty, None)
    _AnimatedIconSource_Meta_.MirroredWhenRightToLeftProperty = property(get_MirroredWhenRightToLeftProperty, None)
    _AnimatedIconSource_Meta_.SourceProperty = property(get_SourceProperty, None)
class _AnimatedVisualPlayer_Meta_(ComPtr.__class__):
    pass
class AnimatedVisualPlayer(ComPtr, metaclass=_AnimatedVisualPlayer_Meta_):
    extends: win32more.Microsoft.UI.Xaml.FrameworkElement
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisualPlayer
    _classid_ = 'Microsoft.UI.Xaml.Controls.AnimatedVisualPlayer'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.AnimatedVisualPlayer.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisualPlayerFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.AnimatedVisualPlayer: ...
    @winrt_mixinmethod
    def get_Diagnostics(self: win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisualPlayer) -> IInspectable: ...
    @winrt_mixinmethod
    def get_Duration(self: win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisualPlayer) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_mixinmethod
    def get_Source(self: win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisualPlayer) -> win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisualSource: ...
    @winrt_mixinmethod
    def put_Source(self: win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisualPlayer, value: win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisualSource) -> Void: ...
    @winrt_mixinmethod
    def get_FallbackContent(self: win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisualPlayer) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def put_FallbackContent(self: win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisualPlayer, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_mixinmethod
    def get_AutoPlay(self: win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisualPlayer) -> Boolean: ...
    @winrt_mixinmethod
    def put_AutoPlay(self: win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisualPlayer, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsAnimatedVisualLoaded(self: win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisualPlayer) -> Boolean: ...
    @winrt_mixinmethod
    def get_IsPlaying(self: win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisualPlayer) -> Boolean: ...
    @winrt_mixinmethod
    def get_PlaybackRate(self: win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisualPlayer) -> Double: ...
    @winrt_mixinmethod
    def put_PlaybackRate(self: win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisualPlayer, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_ProgressObject(self: win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisualPlayer) -> win32more.Microsoft.UI.Composition.CompositionObject: ...
    @winrt_mixinmethod
    def get_Stretch(self: win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisualPlayer) -> win32more.Microsoft.UI.Xaml.Media.Stretch: ...
    @winrt_mixinmethod
    def put_Stretch(self: win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisualPlayer, value: win32more.Microsoft.UI.Xaml.Media.Stretch) -> Void: ...
    @winrt_mixinmethod
    def Pause(self: win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisualPlayer) -> Void: ...
    @winrt_mixinmethod
    def PlayAsync(self: win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisualPlayer, fromProgress: Double, toProgress: Double, looped: Boolean) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def Resume(self: win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisualPlayer) -> Void: ...
    @winrt_mixinmethod
    def SetProgress(self: win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisualPlayer, progress: Double) -> Void: ...
    @winrt_mixinmethod
    def Stop(self: win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisualPlayer) -> Void: ...
    @winrt_mixinmethod
    def get_AnimationOptimization(self: win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisualPlayer2) -> win32more.Microsoft.UI.Xaml.Controls.PlayerAnimationOptimization: ...
    @winrt_mixinmethod
    def put_AnimationOptimization(self: win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisualPlayer2, value: win32more.Microsoft.UI.Xaml.Controls.PlayerAnimationOptimization) -> Void: ...
    @winrt_classmethod
    def get_AnimationOptimizationProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisualPlayerStatics2) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_AutoPlayProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisualPlayerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DiagnosticsProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisualPlayerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DurationProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisualPlayerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FallbackContentProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisualPlayerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsAnimatedVisualLoadedProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisualPlayerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsPlayingProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisualPlayerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PlaybackRateProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisualPlayerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SourceProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisualPlayerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_StretchProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisualPlayerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    AnimationOptimization = property(get_AnimationOptimization, put_AnimationOptimization)
    AutoPlay = property(get_AutoPlay, put_AutoPlay)
    Diagnostics = property(get_Diagnostics, None)
    Duration = property(get_Duration, None)
    FallbackContent = property(get_FallbackContent, put_FallbackContent)
    IsAnimatedVisualLoaded = property(get_IsAnimatedVisualLoaded, None)
    IsPlaying = property(get_IsPlaying, None)
    PlaybackRate = property(get_PlaybackRate, put_PlaybackRate)
    ProgressObject = property(get_ProgressObject, None)
    Source = property(get_Source, put_Source)
    Stretch = property(get_Stretch, put_Stretch)
    _AnimatedVisualPlayer_Meta_.AnimationOptimizationProperty = property(get_AnimationOptimizationProperty, None)
    _AnimatedVisualPlayer_Meta_.AutoPlayProperty = property(get_AutoPlayProperty, None)
    _AnimatedVisualPlayer_Meta_.DiagnosticsProperty = property(get_DiagnosticsProperty, None)
    _AnimatedVisualPlayer_Meta_.DurationProperty = property(get_DurationProperty, None)
    _AnimatedVisualPlayer_Meta_.FallbackContentProperty = property(get_FallbackContentProperty, None)
    _AnimatedVisualPlayer_Meta_.IsAnimatedVisualLoadedProperty = property(get_IsAnimatedVisualLoadedProperty, None)
    _AnimatedVisualPlayer_Meta_.IsPlayingProperty = property(get_IsPlayingProperty, None)
    _AnimatedVisualPlayer_Meta_.PlaybackRateProperty = property(get_PlaybackRateProperty, None)
    _AnimatedVisualPlayer_Meta_.SourceProperty = property(get_SourceProperty, None)
    _AnimatedVisualPlayer_Meta_.StretchProperty = property(get_StretchProperty, None)
class _AnnotatedScrollBar_Meta_(ComPtr.__class__):
    pass
class AnnotatedScrollBar(ComPtr, metaclass=_AnnotatedScrollBar_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.Control
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IAnnotatedScrollBar
    _classid_ = 'Microsoft.UI.Xaml.Controls.AnnotatedScrollBar'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.AnnotatedScrollBar.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IAnnotatedScrollBarFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.AnnotatedScrollBar: ...
    @winrt_mixinmethod
    def get_ScrollController(self: win32more.Microsoft.UI.Xaml.Controls.IAnnotatedScrollBar) -> win32more.Microsoft.UI.Xaml.Controls.Primitives.IScrollController: ...
    @winrt_mixinmethod
    def get_Labels(self: win32more.Microsoft.UI.Xaml.Controls.IAnnotatedScrollBar) -> win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.AnnotatedScrollBarLabel]: ...
    @winrt_mixinmethod
    def put_Labels(self: win32more.Microsoft.UI.Xaml.Controls.IAnnotatedScrollBar, value: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.AnnotatedScrollBarLabel]) -> Void: ...
    @winrt_mixinmethod
    def get_LabelTemplate(self: win32more.Microsoft.UI.Xaml.Controls.IAnnotatedScrollBar) -> win32more.Microsoft.UI.Xaml.IElementFactory: ...
    @winrt_mixinmethod
    def put_LabelTemplate(self: win32more.Microsoft.UI.Xaml.Controls.IAnnotatedScrollBar, value: win32more.Microsoft.UI.Xaml.IElementFactory) -> Void: ...
    @winrt_mixinmethod
    def get_DetailLabelTemplate(self: win32more.Microsoft.UI.Xaml.Controls.IAnnotatedScrollBar) -> win32more.Microsoft.UI.Xaml.IElementFactory: ...
    @winrt_mixinmethod
    def put_DetailLabelTemplate(self: win32more.Microsoft.UI.Xaml.Controls.IAnnotatedScrollBar, value: win32more.Microsoft.UI.Xaml.IElementFactory) -> Void: ...
    @winrt_mixinmethod
    def get_SmallChange(self: win32more.Microsoft.UI.Xaml.Controls.IAnnotatedScrollBar) -> Double: ...
    @winrt_mixinmethod
    def put_SmallChange(self: win32more.Microsoft.UI.Xaml.Controls.IAnnotatedScrollBar, value: Double) -> Void: ...
    @winrt_mixinmethod
    def add_Scrolling(self: win32more.Microsoft.UI.Xaml.Controls.IAnnotatedScrollBar, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.AnnotatedScrollBar, win32more.Microsoft.UI.Xaml.Controls.AnnotatedScrollBarScrollingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Scrolling(self: win32more.Microsoft.UI.Xaml.Controls.IAnnotatedScrollBar, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_DetailLabelRequested(self: win32more.Microsoft.UI.Xaml.Controls.IAnnotatedScrollBar, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.AnnotatedScrollBar, win32more.Microsoft.UI.Xaml.Controls.AnnotatedScrollBarDetailLabelRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_DetailLabelRequested(self: win32more.Microsoft.UI.Xaml.Controls.IAnnotatedScrollBar, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def get_LabelsProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IAnnotatedScrollBarStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_LabelTemplateProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IAnnotatedScrollBarStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DetailLabelTemplateProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IAnnotatedScrollBarStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SmallChangeProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IAnnotatedScrollBarStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    DetailLabelTemplate = property(get_DetailLabelTemplate, put_DetailLabelTemplate)
    LabelTemplate = property(get_LabelTemplate, put_LabelTemplate)
    Labels = property(get_Labels, put_Labels)
    ScrollController = property(get_ScrollController, None)
    SmallChange = property(get_SmallChange, put_SmallChange)
    _AnnotatedScrollBar_Meta_.DetailLabelTemplateProperty = property(get_DetailLabelTemplateProperty, None)
    _AnnotatedScrollBar_Meta_.LabelTemplateProperty = property(get_LabelTemplateProperty, None)
    _AnnotatedScrollBar_Meta_.LabelsProperty = property(get_LabelsProperty, None)
    _AnnotatedScrollBar_Meta_.SmallChangeProperty = property(get_SmallChangeProperty, None)
    DetailLabelRequested = event(add_DetailLabelRequested, remove_DetailLabelRequested)
    Scrolling = event(add_Scrolling, remove_Scrolling)
class AnnotatedScrollBarDetailLabelRequestedEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IAnnotatedScrollBarDetailLabelRequestedEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.AnnotatedScrollBarDetailLabelRequestedEventArgs'
    @winrt_mixinmethod
    def get_Content(self: win32more.Microsoft.UI.Xaml.Controls.IAnnotatedScrollBarDetailLabelRequestedEventArgs) -> IInspectable: ...
    @winrt_mixinmethod
    def put_Content(self: win32more.Microsoft.UI.Xaml.Controls.IAnnotatedScrollBarDetailLabelRequestedEventArgs, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_ScrollOffset(self: win32more.Microsoft.UI.Xaml.Controls.IAnnotatedScrollBarDetailLabelRequestedEventArgs) -> Double: ...
    Content = property(get_Content, put_Content)
    ScrollOffset = property(get_ScrollOffset, None)
class AnnotatedScrollBarLabel(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IAnnotatedScrollBarLabel
    _classid_ = 'Microsoft.UI.Xaml.Controls.AnnotatedScrollBarLabel'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 2:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.AnnotatedScrollBarLabel.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IAnnotatedScrollBarLabelFactory, content: IInspectable, scrollOffset: Double) -> win32more.Microsoft.UI.Xaml.Controls.AnnotatedScrollBarLabel: ...
    @winrt_mixinmethod
    def get_Content(self: win32more.Microsoft.UI.Xaml.Controls.IAnnotatedScrollBarLabel) -> IInspectable: ...
    @winrt_mixinmethod
    def get_ScrollOffset(self: win32more.Microsoft.UI.Xaml.Controls.IAnnotatedScrollBarLabel) -> Double: ...
    Content = property(get_Content, None)
    ScrollOffset = property(get_ScrollOffset, None)
class AnnotatedScrollBarScrollingEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IAnnotatedScrollBarScrollingEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.AnnotatedScrollBarScrollingEventArgs'
    @winrt_mixinmethod
    def get_ScrollOffset(self: win32more.Microsoft.UI.Xaml.Controls.IAnnotatedScrollBarScrollingEventArgs) -> Double: ...
    @winrt_mixinmethod
    def get_ScrollingEventKind(self: win32more.Microsoft.UI.Xaml.Controls.IAnnotatedScrollBarScrollingEventArgs) -> win32more.Microsoft.UI.Xaml.Controls.AnnotatedScrollBarScrollingEventKind: ...
    @winrt_mixinmethod
    def get_Cancel(self: win32more.Microsoft.UI.Xaml.Controls.IAnnotatedScrollBarScrollingEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def put_Cancel(self: win32more.Microsoft.UI.Xaml.Controls.IAnnotatedScrollBarScrollingEventArgs, value: Boolean) -> Void: ...
    Cancel = property(get_Cancel, put_Cancel)
    ScrollOffset = property(get_ScrollOffset, None)
    ScrollingEventKind = property(get_ScrollingEventKind, None)
class AnnotatedScrollBarScrollingEventKind(Enum, Int32):
    Click = 0
    Drag = 1
    IncrementButton = 2
    DecrementButton = 3
class _AppBar_Meta_(ComPtr.__class__):
    pass
class AppBar(ComPtr, metaclass=_AppBar_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.ContentControl
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IAppBar
    _classid_ = 'Microsoft.UI.Xaml.Controls.AppBar'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.AppBar.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IAppBarFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.AppBar: ...
    @winrt_mixinmethod
    def get_IsOpen(self: win32more.Microsoft.UI.Xaml.Controls.IAppBar) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsOpen(self: win32more.Microsoft.UI.Xaml.Controls.IAppBar, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsSticky(self: win32more.Microsoft.UI.Xaml.Controls.IAppBar) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsSticky(self: win32more.Microsoft.UI.Xaml.Controls.IAppBar, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_ClosedDisplayMode(self: win32more.Microsoft.UI.Xaml.Controls.IAppBar) -> win32more.Microsoft.UI.Xaml.Controls.AppBarClosedDisplayMode: ...
    @winrt_mixinmethod
    def put_ClosedDisplayMode(self: win32more.Microsoft.UI.Xaml.Controls.IAppBar, value: win32more.Microsoft.UI.Xaml.Controls.AppBarClosedDisplayMode) -> Void: ...
    @winrt_mixinmethod
    def get_TemplateSettings(self: win32more.Microsoft.UI.Xaml.Controls.IAppBar) -> win32more.Microsoft.UI.Xaml.Controls.Primitives.AppBarTemplateSettings: ...
    @winrt_mixinmethod
    def get_LightDismissOverlayMode(self: win32more.Microsoft.UI.Xaml.Controls.IAppBar) -> win32more.Microsoft.UI.Xaml.Controls.LightDismissOverlayMode: ...
    @winrt_mixinmethod
    def put_LightDismissOverlayMode(self: win32more.Microsoft.UI.Xaml.Controls.IAppBar, value: win32more.Microsoft.UI.Xaml.Controls.LightDismissOverlayMode) -> Void: ...
    @winrt_mixinmethod
    def add_Opening(self: win32more.Microsoft.UI.Xaml.Controls.IAppBar, handler: win32more.Windows.Foundation.EventHandler[IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Opening(self: win32more.Microsoft.UI.Xaml.Controls.IAppBar, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_Opened(self: win32more.Microsoft.UI.Xaml.Controls.IAppBar, handler: win32more.Windows.Foundation.EventHandler[IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Opened(self: win32more.Microsoft.UI.Xaml.Controls.IAppBar, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_Closing(self: win32more.Microsoft.UI.Xaml.Controls.IAppBar, handler: win32more.Windows.Foundation.EventHandler[IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Closing(self: win32more.Microsoft.UI.Xaml.Controls.IAppBar, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_Closed(self: win32more.Microsoft.UI.Xaml.Controls.IAppBar, handler: win32more.Windows.Foundation.EventHandler[IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Closed(self: win32more.Microsoft.UI.Xaml.Controls.IAppBar, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def OnClosed(self: win32more.Microsoft.UI.Xaml.Controls.IAppBarOverrides, e: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def OnOpened(self: win32more.Microsoft.UI.Xaml.Controls.IAppBarOverrides, e: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def OnClosing(self: win32more.Microsoft.UI.Xaml.Controls.IAppBarOverrides, e: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def OnOpening(self: win32more.Microsoft.UI.Xaml.Controls.IAppBarOverrides, e: IInspectable) -> Void: ...
    @winrt_classmethod
    def get_IsOpenProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IAppBarStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsStickyProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IAppBarStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ClosedDisplayModeProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IAppBarStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_LightDismissOverlayModeProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IAppBarStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    ClosedDisplayMode = property(get_ClosedDisplayMode, put_ClosedDisplayMode)
    IsOpen = property(get_IsOpen, put_IsOpen)
    IsSticky = property(get_IsSticky, put_IsSticky)
    LightDismissOverlayMode = property(get_LightDismissOverlayMode, put_LightDismissOverlayMode)
    TemplateSettings = property(get_TemplateSettings, None)
    _AppBar_Meta_.ClosedDisplayModeProperty = property(get_ClosedDisplayModeProperty, None)
    _AppBar_Meta_.IsOpenProperty = property(get_IsOpenProperty, None)
    _AppBar_Meta_.IsStickyProperty = property(get_IsStickyProperty, None)
    _AppBar_Meta_.LightDismissOverlayModeProperty = property(get_LightDismissOverlayModeProperty, None)
    Closed = event(add_Closed, remove_Closed)
    Closing = event(add_Closing, remove_Closing)
    Opened = event(add_Opened, remove_Opened)
    Opening = event(add_Opening, remove_Opening)
class _AppBarButton_Meta_(ComPtr.__class__):
    pass
class AppBarButton(ComPtr, metaclass=_AppBarButton_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.Button
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IAppBarButton
    _classid_ = 'Microsoft.UI.Xaml.Controls.AppBarButton'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.AppBarButton.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IAppBarButtonFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.AppBarButton: ...
    @winrt_mixinmethod
    def get_Label(self: win32more.Microsoft.UI.Xaml.Controls.IAppBarButton) -> hstr: ...
    @winrt_mixinmethod
    def put_Label(self: win32more.Microsoft.UI.Xaml.Controls.IAppBarButton, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def get_Icon(self: win32more.Microsoft.UI.Xaml.Controls.IAppBarButton) -> win32more.Microsoft.UI.Xaml.Controls.IconElement: ...
    @winrt_mixinmethod
    def put_Icon(self: win32more.Microsoft.UI.Xaml.Controls.IAppBarButton, value: win32more.Microsoft.UI.Xaml.Controls.IconElement) -> Void: ...
    @winrt_mixinmethod
    def get_LabelPosition(self: win32more.Microsoft.UI.Xaml.Controls.IAppBarButton) -> win32more.Microsoft.UI.Xaml.Controls.CommandBarLabelPosition: ...
    @winrt_mixinmethod
    def put_LabelPosition(self: win32more.Microsoft.UI.Xaml.Controls.IAppBarButton, value: win32more.Microsoft.UI.Xaml.Controls.CommandBarLabelPosition) -> Void: ...
    @winrt_mixinmethod
    def get_KeyboardAcceleratorTextOverride(self: win32more.Microsoft.UI.Xaml.Controls.IAppBarButton) -> hstr: ...
    @winrt_mixinmethod
    def put_KeyboardAcceleratorTextOverride(self: win32more.Microsoft.UI.Xaml.Controls.IAppBarButton, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def get_TemplateSettings(self: win32more.Microsoft.UI.Xaml.Controls.IAppBarButton) -> win32more.Microsoft.UI.Xaml.Controls.Primitives.AppBarButtonTemplateSettings: ...
    @winrt_mixinmethod
    def get_IsCompact(self: win32more.Microsoft.UI.Xaml.Controls.ICommandBarElement) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsCompact(self: win32more.Microsoft.UI.Xaml.Controls.ICommandBarElement, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsInOverflow(self: win32more.Microsoft.UI.Xaml.Controls.ICommandBarElement) -> Boolean: ...
    @winrt_mixinmethod
    def get_DynamicOverflowOrder(self: win32more.Microsoft.UI.Xaml.Controls.ICommandBarElement) -> Int32: ...
    @winrt_mixinmethod
    def put_DynamicOverflowOrder(self: win32more.Microsoft.UI.Xaml.Controls.ICommandBarElement, value: Int32) -> Void: ...
    @winrt_classmethod
    def get_LabelProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IAppBarButtonStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IconProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IAppBarButtonStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_LabelPositionProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IAppBarButtonStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_KeyboardAcceleratorTextOverrideProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IAppBarButtonStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsCompactProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IAppBarButtonStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsInOverflowProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IAppBarButtonStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DynamicOverflowOrderProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IAppBarButtonStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    DynamicOverflowOrder = property(get_DynamicOverflowOrder, put_DynamicOverflowOrder)
    Icon = property(get_Icon, put_Icon)
    IsCompact = property(get_IsCompact, put_IsCompact)
    IsInOverflow = property(get_IsInOverflow, None)
    KeyboardAcceleratorTextOverride = property(get_KeyboardAcceleratorTextOverride, put_KeyboardAcceleratorTextOverride)
    Label = property(get_Label, put_Label)
    LabelPosition = property(get_LabelPosition, put_LabelPosition)
    TemplateSettings = property(get_TemplateSettings, None)
    _AppBarButton_Meta_.DynamicOverflowOrderProperty = property(get_DynamicOverflowOrderProperty, None)
    _AppBarButton_Meta_.IconProperty = property(get_IconProperty, None)
    _AppBarButton_Meta_.IsCompactProperty = property(get_IsCompactProperty, None)
    _AppBarButton_Meta_.IsInOverflowProperty = property(get_IsInOverflowProperty, None)
    _AppBarButton_Meta_.KeyboardAcceleratorTextOverrideProperty = property(get_KeyboardAcceleratorTextOverrideProperty, None)
    _AppBarButton_Meta_.LabelPositionProperty = property(get_LabelPositionProperty, None)
    _AppBarButton_Meta_.LabelProperty = property(get_LabelProperty, None)
class AppBarClosedDisplayMode(Enum, Int32):
    Compact = 0
    Minimal = 1
    Hidden = 2
class _AppBarElementContainer_Meta_(ComPtr.__class__):
    pass
class AppBarElementContainer(ComPtr, metaclass=_AppBarElementContainer_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.ContentControl
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IAppBarElementContainer
    _classid_ = 'Microsoft.UI.Xaml.Controls.AppBarElementContainer'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.AppBarElementContainer.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IAppBarElementContainerFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.AppBarElementContainer: ...
    @winrt_mixinmethod
    def get_IsCompact(self: win32more.Microsoft.UI.Xaml.Controls.ICommandBarElement) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsCompact(self: win32more.Microsoft.UI.Xaml.Controls.ICommandBarElement, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsInOverflow(self: win32more.Microsoft.UI.Xaml.Controls.ICommandBarElement) -> Boolean: ...
    @winrt_mixinmethod
    def get_DynamicOverflowOrder(self: win32more.Microsoft.UI.Xaml.Controls.ICommandBarElement) -> Int32: ...
    @winrt_mixinmethod
    def put_DynamicOverflowOrder(self: win32more.Microsoft.UI.Xaml.Controls.ICommandBarElement, value: Int32) -> Void: ...
    @winrt_classmethod
    def get_IsCompactProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IAppBarElementContainerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsInOverflowProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IAppBarElementContainerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DynamicOverflowOrderProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IAppBarElementContainerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    DynamicOverflowOrder = property(get_DynamicOverflowOrder, put_DynamicOverflowOrder)
    IsCompact = property(get_IsCompact, put_IsCompact)
    IsInOverflow = property(get_IsInOverflow, None)
    _AppBarElementContainer_Meta_.DynamicOverflowOrderProperty = property(get_DynamicOverflowOrderProperty, None)
    _AppBarElementContainer_Meta_.IsCompactProperty = property(get_IsCompactProperty, None)
    _AppBarElementContainer_Meta_.IsInOverflowProperty = property(get_IsInOverflowProperty, None)
class _AppBarSeparator_Meta_(ComPtr.__class__):
    pass
class AppBarSeparator(ComPtr, metaclass=_AppBarSeparator_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.Control
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IAppBarSeparator
    _classid_ = 'Microsoft.UI.Xaml.Controls.AppBarSeparator'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.AppBarSeparator.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IAppBarSeparatorFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.AppBarSeparator: ...
    @winrt_mixinmethod
    def get_IsCompact(self: win32more.Microsoft.UI.Xaml.Controls.ICommandBarElement) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsCompact(self: win32more.Microsoft.UI.Xaml.Controls.ICommandBarElement, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsInOverflow(self: win32more.Microsoft.UI.Xaml.Controls.ICommandBarElement) -> Boolean: ...
    @winrt_mixinmethod
    def get_DynamicOverflowOrder(self: win32more.Microsoft.UI.Xaml.Controls.ICommandBarElement) -> Int32: ...
    @winrt_mixinmethod
    def put_DynamicOverflowOrder(self: win32more.Microsoft.UI.Xaml.Controls.ICommandBarElement, value: Int32) -> Void: ...
    @winrt_classmethod
    def get_IsCompactProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IAppBarSeparatorStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsInOverflowProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IAppBarSeparatorStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DynamicOverflowOrderProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IAppBarSeparatorStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    DynamicOverflowOrder = property(get_DynamicOverflowOrder, put_DynamicOverflowOrder)
    IsCompact = property(get_IsCompact, put_IsCompact)
    IsInOverflow = property(get_IsInOverflow, None)
    _AppBarSeparator_Meta_.DynamicOverflowOrderProperty = property(get_DynamicOverflowOrderProperty, None)
    _AppBarSeparator_Meta_.IsCompactProperty = property(get_IsCompactProperty, None)
    _AppBarSeparator_Meta_.IsInOverflowProperty = property(get_IsInOverflowProperty, None)
class _AppBarToggleButton_Meta_(ComPtr.__class__):
    pass
class AppBarToggleButton(ComPtr, metaclass=_AppBarToggleButton_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.Primitives.ToggleButton
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IAppBarToggleButton
    _classid_ = 'Microsoft.UI.Xaml.Controls.AppBarToggleButton'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.AppBarToggleButton.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IAppBarToggleButtonFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.AppBarToggleButton: ...
    @winrt_mixinmethod
    def get_Label(self: win32more.Microsoft.UI.Xaml.Controls.IAppBarToggleButton) -> hstr: ...
    @winrt_mixinmethod
    def put_Label(self: win32more.Microsoft.UI.Xaml.Controls.IAppBarToggleButton, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def get_Icon(self: win32more.Microsoft.UI.Xaml.Controls.IAppBarToggleButton) -> win32more.Microsoft.UI.Xaml.Controls.IconElement: ...
    @winrt_mixinmethod
    def put_Icon(self: win32more.Microsoft.UI.Xaml.Controls.IAppBarToggleButton, value: win32more.Microsoft.UI.Xaml.Controls.IconElement) -> Void: ...
    @winrt_mixinmethod
    def get_LabelPosition(self: win32more.Microsoft.UI.Xaml.Controls.IAppBarToggleButton) -> win32more.Microsoft.UI.Xaml.Controls.CommandBarLabelPosition: ...
    @winrt_mixinmethod
    def put_LabelPosition(self: win32more.Microsoft.UI.Xaml.Controls.IAppBarToggleButton, value: win32more.Microsoft.UI.Xaml.Controls.CommandBarLabelPosition) -> Void: ...
    @winrt_mixinmethod
    def get_KeyboardAcceleratorTextOverride(self: win32more.Microsoft.UI.Xaml.Controls.IAppBarToggleButton) -> hstr: ...
    @winrt_mixinmethod
    def put_KeyboardAcceleratorTextOverride(self: win32more.Microsoft.UI.Xaml.Controls.IAppBarToggleButton, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def get_TemplateSettings(self: win32more.Microsoft.UI.Xaml.Controls.IAppBarToggleButton) -> win32more.Microsoft.UI.Xaml.Controls.Primitives.AppBarToggleButtonTemplateSettings: ...
    @winrt_mixinmethod
    def get_IsCompact(self: win32more.Microsoft.UI.Xaml.Controls.ICommandBarElement) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsCompact(self: win32more.Microsoft.UI.Xaml.Controls.ICommandBarElement, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsInOverflow(self: win32more.Microsoft.UI.Xaml.Controls.ICommandBarElement) -> Boolean: ...
    @winrt_mixinmethod
    def get_DynamicOverflowOrder(self: win32more.Microsoft.UI.Xaml.Controls.ICommandBarElement) -> Int32: ...
    @winrt_mixinmethod
    def put_DynamicOverflowOrder(self: win32more.Microsoft.UI.Xaml.Controls.ICommandBarElement, value: Int32) -> Void: ...
    @winrt_classmethod
    def get_LabelProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IAppBarToggleButtonStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IconProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IAppBarToggleButtonStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_LabelPositionProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IAppBarToggleButtonStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_KeyboardAcceleratorTextOverrideProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IAppBarToggleButtonStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsCompactProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IAppBarToggleButtonStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsInOverflowProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IAppBarToggleButtonStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DynamicOverflowOrderProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IAppBarToggleButtonStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    DynamicOverflowOrder = property(get_DynamicOverflowOrder, put_DynamicOverflowOrder)
    Icon = property(get_Icon, put_Icon)
    IsCompact = property(get_IsCompact, put_IsCompact)
    IsInOverflow = property(get_IsInOverflow, None)
    KeyboardAcceleratorTextOverride = property(get_KeyboardAcceleratorTextOverride, put_KeyboardAcceleratorTextOverride)
    Label = property(get_Label, put_Label)
    LabelPosition = property(get_LabelPosition, put_LabelPosition)
    TemplateSettings = property(get_TemplateSettings, None)
    _AppBarToggleButton_Meta_.DynamicOverflowOrderProperty = property(get_DynamicOverflowOrderProperty, None)
    _AppBarToggleButton_Meta_.IconProperty = property(get_IconProperty, None)
    _AppBarToggleButton_Meta_.IsCompactProperty = property(get_IsCompactProperty, None)
    _AppBarToggleButton_Meta_.IsInOverflowProperty = property(get_IsInOverflowProperty, None)
    _AppBarToggleButton_Meta_.KeyboardAcceleratorTextOverrideProperty = property(get_KeyboardAcceleratorTextOverrideProperty, None)
    _AppBarToggleButton_Meta_.LabelPositionProperty = property(get_LabelPositionProperty, None)
    _AppBarToggleButton_Meta_.LabelProperty = property(get_LabelProperty, None)
class _AutoSuggestBox_Meta_(ComPtr.__class__):
    pass
class AutoSuggestBox(ComPtr, metaclass=_AutoSuggestBox_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.ItemsControl
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IAutoSuggestBox
    _classid_ = 'Microsoft.UI.Xaml.Controls.AutoSuggestBox'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.AutoSuggestBox.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Controls.AutoSuggestBox: ...
    @winrt_mixinmethod
    def get_MaxSuggestionListHeight(self: win32more.Microsoft.UI.Xaml.Controls.IAutoSuggestBox) -> Double: ...
    @winrt_mixinmethod
    def put_MaxSuggestionListHeight(self: win32more.Microsoft.UI.Xaml.Controls.IAutoSuggestBox, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_IsSuggestionListOpen(self: win32more.Microsoft.UI.Xaml.Controls.IAutoSuggestBox) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsSuggestionListOpen(self: win32more.Microsoft.UI.Xaml.Controls.IAutoSuggestBox, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_TextMemberPath(self: win32more.Microsoft.UI.Xaml.Controls.IAutoSuggestBox) -> hstr: ...
    @winrt_mixinmethod
    def put_TextMemberPath(self: win32more.Microsoft.UI.Xaml.Controls.IAutoSuggestBox, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def get_Text(self: win32more.Microsoft.UI.Xaml.Controls.IAutoSuggestBox) -> hstr: ...
    @winrt_mixinmethod
    def put_Text(self: win32more.Microsoft.UI.Xaml.Controls.IAutoSuggestBox, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def get_UpdateTextOnSelect(self: win32more.Microsoft.UI.Xaml.Controls.IAutoSuggestBox) -> Boolean: ...
    @winrt_mixinmethod
    def put_UpdateTextOnSelect(self: win32more.Microsoft.UI.Xaml.Controls.IAutoSuggestBox, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_PlaceholderText(self: win32more.Microsoft.UI.Xaml.Controls.IAutoSuggestBox) -> hstr: ...
    @winrt_mixinmethod
    def put_PlaceholderText(self: win32more.Microsoft.UI.Xaml.Controls.IAutoSuggestBox, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def get_Header(self: win32more.Microsoft.UI.Xaml.Controls.IAutoSuggestBox) -> IInspectable: ...
    @winrt_mixinmethod
    def put_Header(self: win32more.Microsoft.UI.Xaml.Controls.IAutoSuggestBox, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_AutoMaximizeSuggestionArea(self: win32more.Microsoft.UI.Xaml.Controls.IAutoSuggestBox) -> Boolean: ...
    @winrt_mixinmethod
    def put_AutoMaximizeSuggestionArea(self: win32more.Microsoft.UI.Xaml.Controls.IAutoSuggestBox, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_TextBoxStyle(self: win32more.Microsoft.UI.Xaml.Controls.IAutoSuggestBox) -> win32more.Microsoft.UI.Xaml.Style: ...
    @winrt_mixinmethod
    def put_TextBoxStyle(self: win32more.Microsoft.UI.Xaml.Controls.IAutoSuggestBox, value: win32more.Microsoft.UI.Xaml.Style) -> Void: ...
    @winrt_mixinmethod
    def get_QueryIcon(self: win32more.Microsoft.UI.Xaml.Controls.IAutoSuggestBox) -> win32more.Microsoft.UI.Xaml.Controls.IconElement: ...
    @winrt_mixinmethod
    def put_QueryIcon(self: win32more.Microsoft.UI.Xaml.Controls.IAutoSuggestBox, value: win32more.Microsoft.UI.Xaml.Controls.IconElement) -> Void: ...
    @winrt_mixinmethod
    def get_LightDismissOverlayMode(self: win32more.Microsoft.UI.Xaml.Controls.IAutoSuggestBox) -> win32more.Microsoft.UI.Xaml.Controls.LightDismissOverlayMode: ...
    @winrt_mixinmethod
    def put_LightDismissOverlayMode(self: win32more.Microsoft.UI.Xaml.Controls.IAutoSuggestBox, value: win32more.Microsoft.UI.Xaml.Controls.LightDismissOverlayMode) -> Void: ...
    @winrt_mixinmethod
    def get_Description(self: win32more.Microsoft.UI.Xaml.Controls.IAutoSuggestBox) -> IInspectable: ...
    @winrt_mixinmethod
    def put_Description(self: win32more.Microsoft.UI.Xaml.Controls.IAutoSuggestBox, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def add_SuggestionChosen(self: win32more.Microsoft.UI.Xaml.Controls.IAutoSuggestBox, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.AutoSuggestBox, win32more.Microsoft.UI.Xaml.Controls.AutoSuggestBoxSuggestionChosenEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_SuggestionChosen(self: win32more.Microsoft.UI.Xaml.Controls.IAutoSuggestBox, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_TextChanged(self: win32more.Microsoft.UI.Xaml.Controls.IAutoSuggestBox, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.AutoSuggestBox, win32more.Microsoft.UI.Xaml.Controls.AutoSuggestBoxTextChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_TextChanged(self: win32more.Microsoft.UI.Xaml.Controls.IAutoSuggestBox, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_QuerySubmitted(self: win32more.Microsoft.UI.Xaml.Controls.IAutoSuggestBox, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.AutoSuggestBox, win32more.Microsoft.UI.Xaml.Controls.AutoSuggestBoxQuerySubmittedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_QuerySubmitted(self: win32more.Microsoft.UI.Xaml.Controls.IAutoSuggestBox, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def get_MaxSuggestionListHeightProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IAutoSuggestBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsSuggestionListOpenProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IAutoSuggestBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TextMemberPathProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IAutoSuggestBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TextProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IAutoSuggestBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_UpdateTextOnSelectProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IAutoSuggestBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PlaceholderTextProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IAutoSuggestBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HeaderProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IAutoSuggestBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_AutoMaximizeSuggestionAreaProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IAutoSuggestBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TextBoxStyleProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IAutoSuggestBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_QueryIconProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IAutoSuggestBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_LightDismissOverlayModeProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IAutoSuggestBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DescriptionProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IAutoSuggestBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    AutoMaximizeSuggestionArea = property(get_AutoMaximizeSuggestionArea, put_AutoMaximizeSuggestionArea)
    Description = property(get_Description, put_Description)
    Header = property(get_Header, put_Header)
    IsSuggestionListOpen = property(get_IsSuggestionListOpen, put_IsSuggestionListOpen)
    LightDismissOverlayMode = property(get_LightDismissOverlayMode, put_LightDismissOverlayMode)
    MaxSuggestionListHeight = property(get_MaxSuggestionListHeight, put_MaxSuggestionListHeight)
    PlaceholderText = property(get_PlaceholderText, put_PlaceholderText)
    QueryIcon = property(get_QueryIcon, put_QueryIcon)
    Text = property(get_Text, put_Text)
    TextBoxStyle = property(get_TextBoxStyle, put_TextBoxStyle)
    TextMemberPath = property(get_TextMemberPath, put_TextMemberPath)
    UpdateTextOnSelect = property(get_UpdateTextOnSelect, put_UpdateTextOnSelect)
    _AutoSuggestBox_Meta_.AutoMaximizeSuggestionAreaProperty = property(get_AutoMaximizeSuggestionAreaProperty, None)
    _AutoSuggestBox_Meta_.DescriptionProperty = property(get_DescriptionProperty, None)
    _AutoSuggestBox_Meta_.HeaderProperty = property(get_HeaderProperty, None)
    _AutoSuggestBox_Meta_.IsSuggestionListOpenProperty = property(get_IsSuggestionListOpenProperty, None)
    _AutoSuggestBox_Meta_.LightDismissOverlayModeProperty = property(get_LightDismissOverlayModeProperty, None)
    _AutoSuggestBox_Meta_.MaxSuggestionListHeightProperty = property(get_MaxSuggestionListHeightProperty, None)
    _AutoSuggestBox_Meta_.PlaceholderTextProperty = property(get_PlaceholderTextProperty, None)
    _AutoSuggestBox_Meta_.QueryIconProperty = property(get_QueryIconProperty, None)
    _AutoSuggestBox_Meta_.TextBoxStyleProperty = property(get_TextBoxStyleProperty, None)
    _AutoSuggestBox_Meta_.TextMemberPathProperty = property(get_TextMemberPathProperty, None)
    _AutoSuggestBox_Meta_.TextProperty = property(get_TextProperty, None)
    _AutoSuggestBox_Meta_.UpdateTextOnSelectProperty = property(get_UpdateTextOnSelectProperty, None)
    QuerySubmitted = event(add_QuerySubmitted, remove_QuerySubmitted)
    SuggestionChosen = event(add_SuggestionChosen, remove_SuggestionChosen)
    TextChanged = event(add_TextChanged, remove_TextChanged)
class AutoSuggestBoxQuerySubmittedEventArgs(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.DependencyObject
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IAutoSuggestBoxQuerySubmittedEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.AutoSuggestBoxQuerySubmittedEventArgs'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.AutoSuggestBoxQuerySubmittedEventArgs.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Controls.AutoSuggestBoxQuerySubmittedEventArgs: ...
    @winrt_mixinmethod
    def get_QueryText(self: win32more.Microsoft.UI.Xaml.Controls.IAutoSuggestBoxQuerySubmittedEventArgs) -> hstr: ...
    @winrt_mixinmethod
    def get_ChosenSuggestion(self: win32more.Microsoft.UI.Xaml.Controls.IAutoSuggestBoxQuerySubmittedEventArgs) -> IInspectable: ...
    ChosenSuggestion = property(get_ChosenSuggestion, None)
    QueryText = property(get_QueryText, None)
class AutoSuggestBoxSuggestionChosenEventArgs(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.DependencyObject
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IAutoSuggestBoxSuggestionChosenEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.AutoSuggestBoxSuggestionChosenEventArgs'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.AutoSuggestBoxSuggestionChosenEventArgs.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Controls.AutoSuggestBoxSuggestionChosenEventArgs: ...
    @winrt_mixinmethod
    def get_SelectedItem(self: win32more.Microsoft.UI.Xaml.Controls.IAutoSuggestBoxSuggestionChosenEventArgs) -> IInspectable: ...
    SelectedItem = property(get_SelectedItem, None)
class _AutoSuggestBoxTextChangedEventArgs_Meta_(ComPtr.__class__):
    pass
class AutoSuggestBoxTextChangedEventArgs(ComPtr, metaclass=_AutoSuggestBoxTextChangedEventArgs_Meta_):
    extends: win32more.Microsoft.UI.Xaml.DependencyObject
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IAutoSuggestBoxTextChangedEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.AutoSuggestBoxTextChangedEventArgs'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.AutoSuggestBoxTextChangedEventArgs.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Controls.AutoSuggestBoxTextChangedEventArgs: ...
    @winrt_mixinmethod
    def get_Reason(self: win32more.Microsoft.UI.Xaml.Controls.IAutoSuggestBoxTextChangedEventArgs) -> win32more.Microsoft.UI.Xaml.Controls.AutoSuggestionBoxTextChangeReason: ...
    @winrt_mixinmethod
    def put_Reason(self: win32more.Microsoft.UI.Xaml.Controls.IAutoSuggestBoxTextChangedEventArgs, value: win32more.Microsoft.UI.Xaml.Controls.AutoSuggestionBoxTextChangeReason) -> Void: ...
    @winrt_mixinmethod
    def CheckCurrent(self: win32more.Microsoft.UI.Xaml.Controls.IAutoSuggestBoxTextChangedEventArgs) -> Boolean: ...
    @winrt_classmethod
    def get_ReasonProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IAutoSuggestBoxTextChangedEventArgsStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    Reason = property(get_Reason, put_Reason)
    _AutoSuggestBoxTextChangedEventArgs_Meta_.ReasonProperty = property(get_ReasonProperty, None)
class AutoSuggestionBoxTextChangeReason(Enum, Int32):
    UserInput = 0
    ProgrammaticChange = 1
    SuggestionChosen = 2
class BackgroundSizing(Enum, Int32):
    InnerBorderEdge = 0
    OuterBorderEdge = 1
class _BitmapIcon_Meta_(ComPtr.__class__):
    pass
class BitmapIcon(ComPtr, metaclass=_BitmapIcon_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.IconElement
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IBitmapIcon
    _classid_ = 'Microsoft.UI.Xaml.Controls.BitmapIcon'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.BitmapIcon.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IBitmapIconFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.BitmapIcon: ...
    @winrt_mixinmethod
    def get_UriSource(self: win32more.Microsoft.UI.Xaml.Controls.IBitmapIcon) -> win32more.Windows.Foundation.Uri: ...
    @winrt_mixinmethod
    def put_UriSource(self: win32more.Microsoft.UI.Xaml.Controls.IBitmapIcon, value: win32more.Windows.Foundation.Uri) -> Void: ...
    @winrt_mixinmethod
    def get_ShowAsMonochrome(self: win32more.Microsoft.UI.Xaml.Controls.IBitmapIcon) -> Boolean: ...
    @winrt_mixinmethod
    def put_ShowAsMonochrome(self: win32more.Microsoft.UI.Xaml.Controls.IBitmapIcon, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_UriSourceProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IBitmapIconStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ShowAsMonochromeProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IBitmapIconStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    ShowAsMonochrome = property(get_ShowAsMonochrome, put_ShowAsMonochrome)
    UriSource = property(get_UriSource, put_UriSource)
    _BitmapIcon_Meta_.ShowAsMonochromeProperty = property(get_ShowAsMonochromeProperty, None)
    _BitmapIcon_Meta_.UriSourceProperty = property(get_UriSourceProperty, None)
class _BitmapIconSource_Meta_(ComPtr.__class__):
    pass
class BitmapIconSource(ComPtr, metaclass=_BitmapIconSource_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.IconSource
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IBitmapIconSource
    _classid_ = 'Microsoft.UI.Xaml.Controls.BitmapIconSource'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.BitmapIconSource.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IBitmapIconSourceFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.BitmapIconSource: ...
    @winrt_mixinmethod
    def get_UriSource(self: win32more.Microsoft.UI.Xaml.Controls.IBitmapIconSource) -> win32more.Windows.Foundation.Uri: ...
    @winrt_mixinmethod
    def put_UriSource(self: win32more.Microsoft.UI.Xaml.Controls.IBitmapIconSource, value: win32more.Windows.Foundation.Uri) -> Void: ...
    @winrt_mixinmethod
    def get_ShowAsMonochrome(self: win32more.Microsoft.UI.Xaml.Controls.IBitmapIconSource) -> Boolean: ...
    @winrt_mixinmethod
    def put_ShowAsMonochrome(self: win32more.Microsoft.UI.Xaml.Controls.IBitmapIconSource, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_UriSourceProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IBitmapIconSourceStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ShowAsMonochromeProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IBitmapIconSourceStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    ShowAsMonochrome = property(get_ShowAsMonochrome, put_ShowAsMonochrome)
    UriSource = property(get_UriSource, put_UriSource)
    _BitmapIconSource_Meta_.ShowAsMonochromeProperty = property(get_ShowAsMonochromeProperty, None)
    _BitmapIconSource_Meta_.UriSourceProperty = property(get_UriSourceProperty, None)
class _Border_Meta_(ComPtr.__class__):
    pass
class Border(ComPtr, metaclass=_Border_Meta_):
    extends: win32more.Microsoft.UI.Xaml.FrameworkElement
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IBorder
    _classid_ = 'Microsoft.UI.Xaml.Controls.Border'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.Border.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Controls.Border: ...
    @winrt_mixinmethod
    def get_BorderBrush(self: win32more.Microsoft.UI.Xaml.Controls.IBorder) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_BorderBrush(self: win32more.Microsoft.UI.Xaml.Controls.IBorder, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_BorderThickness(self: win32more.Microsoft.UI.Xaml.Controls.IBorder) -> win32more.Microsoft.UI.Xaml.Thickness: ...
    @winrt_mixinmethod
    def put_BorderThickness(self: win32more.Microsoft.UI.Xaml.Controls.IBorder, value: win32more.Microsoft.UI.Xaml.Thickness) -> Void: ...
    @winrt_mixinmethod
    def get_Background(self: win32more.Microsoft.UI.Xaml.Controls.IBorder) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_Background(self: win32more.Microsoft.UI.Xaml.Controls.IBorder, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_BackgroundSizing(self: win32more.Microsoft.UI.Xaml.Controls.IBorder) -> win32more.Microsoft.UI.Xaml.Controls.BackgroundSizing: ...
    @winrt_mixinmethod
    def put_BackgroundSizing(self: win32more.Microsoft.UI.Xaml.Controls.IBorder, value: win32more.Microsoft.UI.Xaml.Controls.BackgroundSizing) -> Void: ...
    @winrt_mixinmethod
    def get_CornerRadius(self: win32more.Microsoft.UI.Xaml.Controls.IBorder) -> win32more.Microsoft.UI.Xaml.CornerRadius: ...
    @winrt_mixinmethod
    def put_CornerRadius(self: win32more.Microsoft.UI.Xaml.Controls.IBorder, value: win32more.Microsoft.UI.Xaml.CornerRadius) -> Void: ...
    @winrt_mixinmethod
    def get_Padding(self: win32more.Microsoft.UI.Xaml.Controls.IBorder) -> win32more.Microsoft.UI.Xaml.Thickness: ...
    @winrt_mixinmethod
    def put_Padding(self: win32more.Microsoft.UI.Xaml.Controls.IBorder, value: win32more.Microsoft.UI.Xaml.Thickness) -> Void: ...
    @winrt_mixinmethod
    def get_Child(self: win32more.Microsoft.UI.Xaml.Controls.IBorder) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_mixinmethod
    def put_Child(self: win32more.Microsoft.UI.Xaml.Controls.IBorder, value: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    @winrt_mixinmethod
    def get_ChildTransitions(self: win32more.Microsoft.UI.Xaml.Controls.IBorder) -> win32more.Microsoft.UI.Xaml.Media.Animation.TransitionCollection: ...
    @winrt_mixinmethod
    def put_ChildTransitions(self: win32more.Microsoft.UI.Xaml.Controls.IBorder, value: win32more.Microsoft.UI.Xaml.Media.Animation.TransitionCollection) -> Void: ...
    @winrt_mixinmethod
    def get_BackgroundTransition(self: win32more.Microsoft.UI.Xaml.Controls.IBorder) -> win32more.Microsoft.UI.Xaml.BrushTransition: ...
    @winrt_mixinmethod
    def put_BackgroundTransition(self: win32more.Microsoft.UI.Xaml.Controls.IBorder, value: win32more.Microsoft.UI.Xaml.BrushTransition) -> Void: ...
    @winrt_classmethod
    def get_BorderBrushProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IBorderStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_BorderThicknessProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IBorderStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_BackgroundProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IBorderStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_BackgroundSizingProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IBorderStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CornerRadiusProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IBorderStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PaddingProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IBorderStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ChildTransitionsProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IBorderStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    Background = property(get_Background, put_Background)
    BackgroundSizing = property(get_BackgroundSizing, put_BackgroundSizing)
    BackgroundTransition = property(get_BackgroundTransition, put_BackgroundTransition)
    BorderBrush = property(get_BorderBrush, put_BorderBrush)
    BorderThickness = property(get_BorderThickness, put_BorderThickness)
    Child = property(get_Child, put_Child)
    ChildTransitions = property(get_ChildTransitions, put_ChildTransitions)
    CornerRadius = property(get_CornerRadius, put_CornerRadius)
    Padding = property(get_Padding, put_Padding)
    _Border_Meta_.BackgroundProperty = property(get_BackgroundProperty, None)
    _Border_Meta_.BackgroundSizingProperty = property(get_BackgroundSizingProperty, None)
    _Border_Meta_.BorderBrushProperty = property(get_BorderBrushProperty, None)
    _Border_Meta_.BorderThicknessProperty = property(get_BorderThicknessProperty, None)
    _Border_Meta_.ChildTransitionsProperty = property(get_ChildTransitionsProperty, None)
    _Border_Meta_.CornerRadiusProperty = property(get_CornerRadiusProperty, None)
    _Border_Meta_.PaddingProperty = property(get_PaddingProperty, None)
class _BreadcrumbBar_Meta_(ComPtr.__class__):
    pass
class BreadcrumbBar(ComPtr, metaclass=_BreadcrumbBar_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.Control
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IBreadcrumbBar
    _classid_ = 'Microsoft.UI.Xaml.Controls.BreadcrumbBar'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.BreadcrumbBar.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IBreadcrumbBarFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.BreadcrumbBar: ...
    @winrt_mixinmethod
    def get_ItemsSource(self: win32more.Microsoft.UI.Xaml.Controls.IBreadcrumbBar) -> IInspectable: ...
    @winrt_mixinmethod
    def put_ItemsSource(self: win32more.Microsoft.UI.Xaml.Controls.IBreadcrumbBar, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_ItemTemplate(self: win32more.Microsoft.UI.Xaml.Controls.IBreadcrumbBar) -> IInspectable: ...
    @winrt_mixinmethod
    def put_ItemTemplate(self: win32more.Microsoft.UI.Xaml.Controls.IBreadcrumbBar, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def add_ItemClicked(self: win32more.Microsoft.UI.Xaml.Controls.IBreadcrumbBar, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.BreadcrumbBar, win32more.Microsoft.UI.Xaml.Controls.BreadcrumbBarItemClickedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ItemClicked(self: win32more.Microsoft.UI.Xaml.Controls.IBreadcrumbBar, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def get_ItemsSourceProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IBreadcrumbBarStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ItemTemplateProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IBreadcrumbBarStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    ItemTemplate = property(get_ItemTemplate, put_ItemTemplate)
    ItemsSource = property(get_ItemsSource, put_ItemsSource)
    _BreadcrumbBar_Meta_.ItemTemplateProperty = property(get_ItemTemplateProperty, None)
    _BreadcrumbBar_Meta_.ItemsSourceProperty = property(get_ItemsSourceProperty, None)
    ItemClicked = event(add_ItemClicked, remove_ItemClicked)
class BreadcrumbBarItem(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.Controls.ContentControl
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IBreadcrumbBarItem
    _classid_ = 'Microsoft.UI.Xaml.Controls.BreadcrumbBarItem'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.BreadcrumbBarItem.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IBreadcrumbBarItemFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.BreadcrumbBarItem: ...
class BreadcrumbBarItemClickedEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IBreadcrumbBarItemClickedEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.BreadcrumbBarItemClickedEventArgs'
    @winrt_mixinmethod
    def get_Index(self: win32more.Microsoft.UI.Xaml.Controls.IBreadcrumbBarItemClickedEventArgs) -> Int32: ...
    @winrt_mixinmethod
    def get_Item(self: win32more.Microsoft.UI.Xaml.Controls.IBreadcrumbBarItemClickedEventArgs) -> IInspectable: ...
    Index = property(get_Index, None)
    Item = property(get_Item, None)
class _Button_Meta_(ComPtr.__class__):
    pass
class Button(ComPtr, metaclass=_Button_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.Primitives.ButtonBase
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IButton
    _classid_ = 'Microsoft.UI.Xaml.Controls.Button'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.Button.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IButtonFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.Button: ...
    @winrt_mixinmethod
    def get_Flyout(self: win32more.Microsoft.UI.Xaml.Controls.IButton) -> win32more.Microsoft.UI.Xaml.Controls.Primitives.FlyoutBase: ...
    @winrt_mixinmethod
    def put_Flyout(self: win32more.Microsoft.UI.Xaml.Controls.IButton, value: win32more.Microsoft.UI.Xaml.Controls.Primitives.FlyoutBase) -> Void: ...
    @winrt_classmethod
    def get_FlyoutProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IButtonStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    Flyout = property(get_Flyout, put_Flyout)
    _Button_Meta_.FlyoutProperty = property(get_FlyoutProperty, None)
class _CalendarDatePicker_Meta_(ComPtr.__class__):
    pass
class CalendarDatePicker(ComPtr, metaclass=_CalendarDatePicker_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.Control
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ICalendarDatePicker
    _classid_ = 'Microsoft.UI.Xaml.Controls.CalendarDatePicker'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.CalendarDatePicker.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarDatePickerFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.CalendarDatePicker: ...
    @winrt_mixinmethod
    def get_Date(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarDatePicker) -> win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.DateTime]: ...
    @winrt_mixinmethod
    def put_Date(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarDatePicker, value: win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.DateTime]) -> Void: ...
    @winrt_mixinmethod
    def get_IsCalendarOpen(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarDatePicker) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsCalendarOpen(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarDatePicker, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_DateFormat(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarDatePicker) -> hstr: ...
    @winrt_mixinmethod
    def put_DateFormat(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarDatePicker, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def get_PlaceholderText(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarDatePicker) -> hstr: ...
    @winrt_mixinmethod
    def put_PlaceholderText(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarDatePicker, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def get_Header(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarDatePicker) -> IInspectable: ...
    @winrt_mixinmethod
    def put_Header(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarDatePicker, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_HeaderTemplate(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarDatePicker) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def put_HeaderTemplate(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarDatePicker, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_mixinmethod
    def get_CalendarViewStyle(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarDatePicker) -> win32more.Microsoft.UI.Xaml.Style: ...
    @winrt_mixinmethod
    def put_CalendarViewStyle(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarDatePicker, value: win32more.Microsoft.UI.Xaml.Style) -> Void: ...
    @winrt_mixinmethod
    def get_LightDismissOverlayMode(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarDatePicker) -> win32more.Microsoft.UI.Xaml.Controls.LightDismissOverlayMode: ...
    @winrt_mixinmethod
    def put_LightDismissOverlayMode(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarDatePicker, value: win32more.Microsoft.UI.Xaml.Controls.LightDismissOverlayMode) -> Void: ...
    @winrt_mixinmethod
    def get_Description(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarDatePicker) -> IInspectable: ...
    @winrt_mixinmethod
    def put_Description(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarDatePicker, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_MinDate(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarDatePicker) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_mixinmethod
    def put_MinDate(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarDatePicker, value: win32more.Windows.Foundation.DateTime) -> Void: ...
    @winrt_mixinmethod
    def get_MaxDate(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarDatePicker) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_mixinmethod
    def put_MaxDate(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarDatePicker, value: win32more.Windows.Foundation.DateTime) -> Void: ...
    @winrt_mixinmethod
    def get_IsTodayHighlighted(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarDatePicker) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsTodayHighlighted(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarDatePicker, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_DisplayMode(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarDatePicker) -> win32more.Microsoft.UI.Xaml.Controls.CalendarViewDisplayMode: ...
    @winrt_mixinmethod
    def put_DisplayMode(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarDatePicker, value: win32more.Microsoft.UI.Xaml.Controls.CalendarViewDisplayMode) -> Void: ...
    @winrt_mixinmethod
    def get_FirstDayOfWeek(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarDatePicker) -> win32more.Windows.Globalization.DayOfWeek: ...
    @winrt_mixinmethod
    def put_FirstDayOfWeek(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarDatePicker, value: win32more.Windows.Globalization.DayOfWeek) -> Void: ...
    @winrt_mixinmethod
    def get_DayOfWeekFormat(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarDatePicker) -> hstr: ...
    @winrt_mixinmethod
    def put_DayOfWeekFormat(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarDatePicker, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def get_CalendarIdentifier(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarDatePicker) -> hstr: ...
    @winrt_mixinmethod
    def put_CalendarIdentifier(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarDatePicker, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def get_IsOutOfScopeEnabled(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarDatePicker) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsOutOfScopeEnabled(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarDatePicker, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsGroupLabelVisible(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarDatePicker) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsGroupLabelVisible(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarDatePicker, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def add_CalendarViewDayItemChanging(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarDatePicker, handler: win32more.Microsoft.UI.Xaml.Controls.CalendarViewDayItemChangingEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_CalendarViewDayItemChanging(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarDatePicker, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_DateChanged(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarDatePicker, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.CalendarDatePicker, win32more.Microsoft.UI.Xaml.Controls.CalendarDatePickerDateChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_DateChanged(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarDatePicker, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_Opened(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarDatePicker, handler: win32more.Windows.Foundation.EventHandler[IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Opened(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarDatePicker, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_Closed(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarDatePicker, handler: win32more.Windows.Foundation.EventHandler[IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Closed(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarDatePicker, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def SetDisplayDate(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarDatePicker, date: win32more.Windows.Foundation.DateTime) -> Void: ...
    @winrt_mixinmethod
    def SetYearDecadeDisplayDimensions(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarDatePicker, columns: Int32, rows: Int32) -> Void: ...
    @winrt_classmethod
    def get_DateProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarDatePickerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsCalendarOpenProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarDatePickerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DateFormatProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarDatePickerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PlaceholderTextProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarDatePickerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HeaderProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarDatePickerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HeaderTemplateProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarDatePickerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CalendarViewStyleProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarDatePickerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_LightDismissOverlayModeProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarDatePickerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DescriptionProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarDatePickerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MinDateProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarDatePickerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MaxDateProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarDatePickerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsTodayHighlightedProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarDatePickerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DisplayModeProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarDatePickerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FirstDayOfWeekProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarDatePickerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DayOfWeekFormatProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarDatePickerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CalendarIdentifierProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarDatePickerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsOutOfScopeEnabledProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarDatePickerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsGroupLabelVisibleProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarDatePickerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    CalendarIdentifier = property(get_CalendarIdentifier, put_CalendarIdentifier)
    CalendarViewStyle = property(get_CalendarViewStyle, put_CalendarViewStyle)
    Date = property(get_Date, put_Date)
    DateFormat = property(get_DateFormat, put_DateFormat)
    DayOfWeekFormat = property(get_DayOfWeekFormat, put_DayOfWeekFormat)
    Description = property(get_Description, put_Description)
    DisplayMode = property(get_DisplayMode, put_DisplayMode)
    FirstDayOfWeek = property(get_FirstDayOfWeek, put_FirstDayOfWeek)
    Header = property(get_Header, put_Header)
    HeaderTemplate = property(get_HeaderTemplate, put_HeaderTemplate)
    IsCalendarOpen = property(get_IsCalendarOpen, put_IsCalendarOpen)
    IsGroupLabelVisible = property(get_IsGroupLabelVisible, put_IsGroupLabelVisible)
    IsOutOfScopeEnabled = property(get_IsOutOfScopeEnabled, put_IsOutOfScopeEnabled)
    IsTodayHighlighted = property(get_IsTodayHighlighted, put_IsTodayHighlighted)
    LightDismissOverlayMode = property(get_LightDismissOverlayMode, put_LightDismissOverlayMode)
    MaxDate = property(get_MaxDate, put_MaxDate)
    MinDate = property(get_MinDate, put_MinDate)
    PlaceholderText = property(get_PlaceholderText, put_PlaceholderText)
    _CalendarDatePicker_Meta_.CalendarIdentifierProperty = property(get_CalendarIdentifierProperty, None)
    _CalendarDatePicker_Meta_.CalendarViewStyleProperty = property(get_CalendarViewStyleProperty, None)
    _CalendarDatePicker_Meta_.DateFormatProperty = property(get_DateFormatProperty, None)
    _CalendarDatePicker_Meta_.DateProperty = property(get_DateProperty, None)
    _CalendarDatePicker_Meta_.DayOfWeekFormatProperty = property(get_DayOfWeekFormatProperty, None)
    _CalendarDatePicker_Meta_.DescriptionProperty = property(get_DescriptionProperty, None)
    _CalendarDatePicker_Meta_.DisplayModeProperty = property(get_DisplayModeProperty, None)
    _CalendarDatePicker_Meta_.FirstDayOfWeekProperty = property(get_FirstDayOfWeekProperty, None)
    _CalendarDatePicker_Meta_.HeaderProperty = property(get_HeaderProperty, None)
    _CalendarDatePicker_Meta_.HeaderTemplateProperty = property(get_HeaderTemplateProperty, None)
    _CalendarDatePicker_Meta_.IsCalendarOpenProperty = property(get_IsCalendarOpenProperty, None)
    _CalendarDatePicker_Meta_.IsGroupLabelVisibleProperty = property(get_IsGroupLabelVisibleProperty, None)
    _CalendarDatePicker_Meta_.IsOutOfScopeEnabledProperty = property(get_IsOutOfScopeEnabledProperty, None)
    _CalendarDatePicker_Meta_.IsTodayHighlightedProperty = property(get_IsTodayHighlightedProperty, None)
    _CalendarDatePicker_Meta_.LightDismissOverlayModeProperty = property(get_LightDismissOverlayModeProperty, None)
    _CalendarDatePicker_Meta_.MaxDateProperty = property(get_MaxDateProperty, None)
    _CalendarDatePicker_Meta_.MinDateProperty = property(get_MinDateProperty, None)
    _CalendarDatePicker_Meta_.PlaceholderTextProperty = property(get_PlaceholderTextProperty, None)
    CalendarViewDayItemChanging = event(add_CalendarViewDayItemChanging, remove_CalendarViewDayItemChanging)
    Closed = event(add_Closed, remove_Closed)
    DateChanged = event(add_DateChanged, remove_DateChanged)
    Opened = event(add_Opened, remove_Opened)
class CalendarDatePickerDateChangedEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ICalendarDatePickerDateChangedEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.CalendarDatePickerDateChangedEventArgs'
    @winrt_mixinmethod
    def get_NewDate(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarDatePickerDateChangedEventArgs) -> win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.DateTime]: ...
    @winrt_mixinmethod
    def get_OldDate(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarDatePickerDateChangedEventArgs) -> win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.DateTime]: ...
    NewDate = property(get_NewDate, None)
    OldDate = property(get_OldDate, None)
class _CalendarView_Meta_(ComPtr.__class__):
    pass
class CalendarView(ComPtr, metaclass=_CalendarView_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.Control
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ICalendarView
    _classid_ = 'Microsoft.UI.Xaml.Controls.CalendarView'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.CalendarView.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.CalendarView: ...
    @winrt_mixinmethod
    def get_CalendarIdentifier(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView) -> hstr: ...
    @winrt_mixinmethod
    def put_CalendarIdentifier(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def get_DayOfWeekFormat(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView) -> hstr: ...
    @winrt_mixinmethod
    def put_DayOfWeekFormat(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def get_IsGroupLabelVisible(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsGroupLabelVisible(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_DisplayMode(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView) -> win32more.Microsoft.UI.Xaml.Controls.CalendarViewDisplayMode: ...
    @winrt_mixinmethod
    def put_DisplayMode(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView, value: win32more.Microsoft.UI.Xaml.Controls.CalendarViewDisplayMode) -> Void: ...
    @winrt_mixinmethod
    def get_FirstDayOfWeek(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView) -> win32more.Windows.Globalization.DayOfWeek: ...
    @winrt_mixinmethod
    def put_FirstDayOfWeek(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView, value: win32more.Windows.Globalization.DayOfWeek) -> Void: ...
    @winrt_mixinmethod
    def get_IsOutOfScopeEnabled(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsOutOfScopeEnabled(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsTodayHighlighted(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsTodayHighlighted(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_MaxDate(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_mixinmethod
    def put_MaxDate(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView, value: win32more.Windows.Foundation.DateTime) -> Void: ...
    @winrt_mixinmethod
    def get_MinDate(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_mixinmethod
    def put_MinDate(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView, value: win32more.Windows.Foundation.DateTime) -> Void: ...
    @winrt_mixinmethod
    def get_NumberOfWeeksInView(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView) -> Int32: ...
    @winrt_mixinmethod
    def put_NumberOfWeeksInView(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_SelectedDates(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Foundation.DateTime]: ...
    @winrt_mixinmethod
    def get_SelectionMode(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView) -> win32more.Microsoft.UI.Xaml.Controls.CalendarViewSelectionMode: ...
    @winrt_mixinmethod
    def put_SelectionMode(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView, value: win32more.Microsoft.UI.Xaml.Controls.CalendarViewSelectionMode) -> Void: ...
    @winrt_mixinmethod
    def get_TemplateSettings(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView) -> win32more.Microsoft.UI.Xaml.Controls.Primitives.CalendarViewTemplateSettings: ...
    @winrt_mixinmethod
    def get_FocusBorderBrush(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_FocusBorderBrush(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_SelectedHoverBorderBrush(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_SelectedHoverBorderBrush(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_SelectedPressedBorderBrush(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_SelectedPressedBorderBrush(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_SelectedDisabledBorderBrush(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_SelectedDisabledBorderBrush(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_SelectedBorderBrush(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_SelectedBorderBrush(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_HoverBorderBrush(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_HoverBorderBrush(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_PressedBorderBrush(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_PressedBorderBrush(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_TodaySelectedInnerBorderBrush(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_TodaySelectedInnerBorderBrush(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_BlackoutStrikethroughBrush(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_BlackoutStrikethroughBrush(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_CalendarItemBorderBrush(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_CalendarItemBorderBrush(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_BlackoutBackground(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_BlackoutBackground(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_OutOfScopeBackground(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_OutOfScopeBackground(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_CalendarItemBackground(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_CalendarItemBackground(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_CalendarItemHoverBackground(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_CalendarItemHoverBackground(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_CalendarItemPressedBackground(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_CalendarItemPressedBackground(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_CalendarItemDisabledBackground(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_CalendarItemDisabledBackground(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_TodayBackground(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_TodayBackground(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_TodayBlackoutBackground(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_TodayBlackoutBackground(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_TodayHoverBackground(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_TodayHoverBackground(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_TodayPressedBackground(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_TodayPressedBackground(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_TodayDisabledBackground(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_TodayDisabledBackground(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_PressedForeground(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_PressedForeground(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_TodayForeground(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_TodayForeground(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_BlackoutForeground(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_BlackoutForeground(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_TodayBlackoutForeground(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_TodayBlackoutForeground(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_SelectedForeground(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_SelectedForeground(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_SelectedHoverForeground(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_SelectedHoverForeground(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_SelectedPressedForeground(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_SelectedPressedForeground(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_SelectedDisabledForeground(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_SelectedDisabledForeground(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_OutOfScopeForeground(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_OutOfScopeForeground(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_OutOfScopeHoverForeground(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_OutOfScopeHoverForeground(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_OutOfScopePressedForeground(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_OutOfScopePressedForeground(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_CalendarItemForeground(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_CalendarItemForeground(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_DisabledForeground(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_DisabledForeground(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_DayItemFontFamily(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView) -> win32more.Microsoft.UI.Xaml.Media.FontFamily: ...
    @winrt_mixinmethod
    def put_DayItemFontFamily(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView, value: win32more.Microsoft.UI.Xaml.Media.FontFamily) -> Void: ...
    @winrt_mixinmethod
    def get_DayItemFontSize(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView) -> Double: ...
    @winrt_mixinmethod
    def put_DayItemFontSize(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_DayItemFontStyle(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView) -> win32more.Windows.UI.Text.FontStyle: ...
    @winrt_mixinmethod
    def put_DayItemFontStyle(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView, value: win32more.Windows.UI.Text.FontStyle) -> Void: ...
    @winrt_mixinmethod
    def get_DayItemFontWeight(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_mixinmethod
    def put_DayItemFontWeight(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView, value: win32more.Windows.UI.Text.FontWeight) -> Void: ...
    @winrt_mixinmethod
    def get_TodayFontWeight(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_mixinmethod
    def put_TodayFontWeight(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView, value: win32more.Windows.UI.Text.FontWeight) -> Void: ...
    @winrt_mixinmethod
    def get_FirstOfMonthLabelFontFamily(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView) -> win32more.Microsoft.UI.Xaml.Media.FontFamily: ...
    @winrt_mixinmethod
    def put_FirstOfMonthLabelFontFamily(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView, value: win32more.Microsoft.UI.Xaml.Media.FontFamily) -> Void: ...
    @winrt_mixinmethod
    def get_FirstOfMonthLabelFontSize(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView) -> Double: ...
    @winrt_mixinmethod
    def put_FirstOfMonthLabelFontSize(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_FirstOfMonthLabelFontStyle(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView) -> win32more.Windows.UI.Text.FontStyle: ...
    @winrt_mixinmethod
    def put_FirstOfMonthLabelFontStyle(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView, value: win32more.Windows.UI.Text.FontStyle) -> Void: ...
    @winrt_mixinmethod
    def get_FirstOfMonthLabelFontWeight(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_mixinmethod
    def put_FirstOfMonthLabelFontWeight(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView, value: win32more.Windows.UI.Text.FontWeight) -> Void: ...
    @winrt_mixinmethod
    def get_MonthYearItemFontFamily(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView) -> win32more.Microsoft.UI.Xaml.Media.FontFamily: ...
    @winrt_mixinmethod
    def put_MonthYearItemFontFamily(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView, value: win32more.Microsoft.UI.Xaml.Media.FontFamily) -> Void: ...
    @winrt_mixinmethod
    def get_MonthYearItemFontSize(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView) -> Double: ...
    @winrt_mixinmethod
    def put_MonthYearItemFontSize(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_MonthYearItemFontStyle(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView) -> win32more.Windows.UI.Text.FontStyle: ...
    @winrt_mixinmethod
    def put_MonthYearItemFontStyle(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView, value: win32more.Windows.UI.Text.FontStyle) -> Void: ...
    @winrt_mixinmethod
    def get_MonthYearItemFontWeight(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_mixinmethod
    def put_MonthYearItemFontWeight(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView, value: win32more.Windows.UI.Text.FontWeight) -> Void: ...
    @winrt_mixinmethod
    def get_FirstOfYearDecadeLabelFontFamily(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView) -> win32more.Microsoft.UI.Xaml.Media.FontFamily: ...
    @winrt_mixinmethod
    def put_FirstOfYearDecadeLabelFontFamily(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView, value: win32more.Microsoft.UI.Xaml.Media.FontFamily) -> Void: ...
    @winrt_mixinmethod
    def get_FirstOfYearDecadeLabelFontSize(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView) -> Double: ...
    @winrt_mixinmethod
    def put_FirstOfYearDecadeLabelFontSize(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_FirstOfYearDecadeLabelFontStyle(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView) -> win32more.Windows.UI.Text.FontStyle: ...
    @winrt_mixinmethod
    def put_FirstOfYearDecadeLabelFontStyle(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView, value: win32more.Windows.UI.Text.FontStyle) -> Void: ...
    @winrt_mixinmethod
    def get_FirstOfYearDecadeLabelFontWeight(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_mixinmethod
    def put_FirstOfYearDecadeLabelFontWeight(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView, value: win32more.Windows.UI.Text.FontWeight) -> Void: ...
    @winrt_mixinmethod
    def get_DayItemMargin(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView) -> win32more.Microsoft.UI.Xaml.Thickness: ...
    @winrt_mixinmethod
    def put_DayItemMargin(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView, value: win32more.Microsoft.UI.Xaml.Thickness) -> Void: ...
    @winrt_mixinmethod
    def get_MonthYearItemMargin(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView) -> win32more.Microsoft.UI.Xaml.Thickness: ...
    @winrt_mixinmethod
    def put_MonthYearItemMargin(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView, value: win32more.Microsoft.UI.Xaml.Thickness) -> Void: ...
    @winrt_mixinmethod
    def get_FirstOfMonthLabelMargin(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView) -> win32more.Microsoft.UI.Xaml.Thickness: ...
    @winrt_mixinmethod
    def put_FirstOfMonthLabelMargin(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView, value: win32more.Microsoft.UI.Xaml.Thickness) -> Void: ...
    @winrt_mixinmethod
    def get_FirstOfYearDecadeLabelMargin(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView) -> win32more.Microsoft.UI.Xaml.Thickness: ...
    @winrt_mixinmethod
    def put_FirstOfYearDecadeLabelMargin(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView, value: win32more.Microsoft.UI.Xaml.Thickness) -> Void: ...
    @winrt_mixinmethod
    def get_HorizontalDayItemAlignment(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView) -> win32more.Microsoft.UI.Xaml.HorizontalAlignment: ...
    @winrt_mixinmethod
    def put_HorizontalDayItemAlignment(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView, value: win32more.Microsoft.UI.Xaml.HorizontalAlignment) -> Void: ...
    @winrt_mixinmethod
    def get_VerticalDayItemAlignment(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView) -> win32more.Microsoft.UI.Xaml.VerticalAlignment: ...
    @winrt_mixinmethod
    def put_VerticalDayItemAlignment(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView, value: win32more.Microsoft.UI.Xaml.VerticalAlignment) -> Void: ...
    @winrt_mixinmethod
    def get_HorizontalFirstOfMonthLabelAlignment(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView) -> win32more.Microsoft.UI.Xaml.HorizontalAlignment: ...
    @winrt_mixinmethod
    def put_HorizontalFirstOfMonthLabelAlignment(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView, value: win32more.Microsoft.UI.Xaml.HorizontalAlignment) -> Void: ...
    @winrt_mixinmethod
    def get_VerticalFirstOfMonthLabelAlignment(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView) -> win32more.Microsoft.UI.Xaml.VerticalAlignment: ...
    @winrt_mixinmethod
    def put_VerticalFirstOfMonthLabelAlignment(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView, value: win32more.Microsoft.UI.Xaml.VerticalAlignment) -> Void: ...
    @winrt_mixinmethod
    def get_CalendarItemBorderThickness(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView) -> win32more.Microsoft.UI.Xaml.Thickness: ...
    @winrt_mixinmethod
    def put_CalendarItemBorderThickness(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView, value: win32more.Microsoft.UI.Xaml.Thickness) -> Void: ...
    @winrt_mixinmethod
    def get_CalendarViewDayItemStyle(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView) -> win32more.Microsoft.UI.Xaml.Style: ...
    @winrt_mixinmethod
    def put_CalendarViewDayItemStyle(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView, value: win32more.Microsoft.UI.Xaml.Style) -> Void: ...
    @winrt_mixinmethod
    def get_CalendarItemCornerRadius(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView) -> win32more.Microsoft.UI.Xaml.CornerRadius: ...
    @winrt_mixinmethod
    def put_CalendarItemCornerRadius(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView, value: win32more.Microsoft.UI.Xaml.CornerRadius) -> Void: ...
    @winrt_mixinmethod
    def add_CalendarViewDayItemChanging(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.CalendarView, win32more.Microsoft.UI.Xaml.Controls.CalendarViewDayItemChangingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_CalendarViewDayItemChanging(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_SelectedDatesChanged(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.CalendarView, win32more.Microsoft.UI.Xaml.Controls.CalendarViewSelectedDatesChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_SelectedDatesChanged(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def SetDisplayDate(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView, date: win32more.Windows.Foundation.DateTime) -> Void: ...
    @winrt_mixinmethod
    def SetYearDecadeDisplayDimensions(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarView, columns: Int32, rows: Int32) -> Void: ...
    @winrt_classmethod
    def get_CalendarIdentifierProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DayOfWeekFormatProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsGroupLabelVisibleProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DisplayModeProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FirstDayOfWeekProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsOutOfScopeEnabledProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsTodayHighlightedProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MaxDateProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MinDateProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_NumberOfWeeksInViewProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectedDatesProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectionModeProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TemplateSettingsProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FocusBorderBrushProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectedHoverBorderBrushProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectedPressedBorderBrushProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectedDisabledBorderBrushProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectedBorderBrushProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HoverBorderBrushProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PressedBorderBrushProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TodaySelectedInnerBorderBrushProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_BlackoutStrikethroughBrushProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CalendarItemBorderBrushProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_BlackoutBackgroundProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_OutOfScopeBackgroundProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CalendarItemBackgroundProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CalendarItemHoverBackgroundProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CalendarItemPressedBackgroundProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CalendarItemDisabledBackgroundProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TodayBackgroundProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TodayBlackoutBackgroundProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TodayHoverBackgroundProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TodayPressedBackgroundProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TodayDisabledBackgroundProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PressedForegroundProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TodayForegroundProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_BlackoutForegroundProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TodayBlackoutForegroundProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectedForegroundProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectedHoverForegroundProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectedPressedForegroundProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectedDisabledForegroundProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_OutOfScopeForegroundProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_OutOfScopeHoverForegroundProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_OutOfScopePressedForegroundProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CalendarItemForegroundProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DisabledForegroundProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DayItemFontFamilyProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DayItemFontSizeProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DayItemFontStyleProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DayItemFontWeightProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TodayFontWeightProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FirstOfMonthLabelFontFamilyProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FirstOfMonthLabelFontSizeProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FirstOfMonthLabelFontStyleProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FirstOfMonthLabelFontWeightProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MonthYearItemFontFamilyProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MonthYearItemFontSizeProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MonthYearItemFontStyleProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MonthYearItemFontWeightProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FirstOfYearDecadeLabelFontFamilyProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FirstOfYearDecadeLabelFontSizeProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FirstOfYearDecadeLabelFontStyleProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FirstOfYearDecadeLabelFontWeightProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DayItemMarginProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MonthYearItemMarginProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FirstOfMonthLabelMarginProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FirstOfYearDecadeLabelMarginProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HorizontalDayItemAlignmentProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_VerticalDayItemAlignmentProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HorizontalFirstOfMonthLabelAlignmentProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_VerticalFirstOfMonthLabelAlignmentProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CalendarItemBorderThicknessProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CalendarViewDayItemStyleProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CalendarItemCornerRadiusProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    BlackoutBackground = property(get_BlackoutBackground, put_BlackoutBackground)
    BlackoutForeground = property(get_BlackoutForeground, put_BlackoutForeground)
    BlackoutStrikethroughBrush = property(get_BlackoutStrikethroughBrush, put_BlackoutStrikethroughBrush)
    CalendarIdentifier = property(get_CalendarIdentifier, put_CalendarIdentifier)
    CalendarItemBackground = property(get_CalendarItemBackground, put_CalendarItemBackground)
    CalendarItemBorderBrush = property(get_CalendarItemBorderBrush, put_CalendarItemBorderBrush)
    CalendarItemBorderThickness = property(get_CalendarItemBorderThickness, put_CalendarItemBorderThickness)
    CalendarItemCornerRadius = property(get_CalendarItemCornerRadius, put_CalendarItemCornerRadius)
    CalendarItemDisabledBackground = property(get_CalendarItemDisabledBackground, put_CalendarItemDisabledBackground)
    CalendarItemForeground = property(get_CalendarItemForeground, put_CalendarItemForeground)
    CalendarItemHoverBackground = property(get_CalendarItemHoverBackground, put_CalendarItemHoverBackground)
    CalendarItemPressedBackground = property(get_CalendarItemPressedBackground, put_CalendarItemPressedBackground)
    CalendarViewDayItemStyle = property(get_CalendarViewDayItemStyle, put_CalendarViewDayItemStyle)
    DayItemFontFamily = property(get_DayItemFontFamily, put_DayItemFontFamily)
    DayItemFontSize = property(get_DayItemFontSize, put_DayItemFontSize)
    DayItemFontStyle = property(get_DayItemFontStyle, put_DayItemFontStyle)
    DayItemFontWeight = property(get_DayItemFontWeight, put_DayItemFontWeight)
    DayItemMargin = property(get_DayItemMargin, put_DayItemMargin)
    DayOfWeekFormat = property(get_DayOfWeekFormat, put_DayOfWeekFormat)
    DisabledForeground = property(get_DisabledForeground, put_DisabledForeground)
    DisplayMode = property(get_DisplayMode, put_DisplayMode)
    FirstDayOfWeek = property(get_FirstDayOfWeek, put_FirstDayOfWeek)
    FirstOfMonthLabelFontFamily = property(get_FirstOfMonthLabelFontFamily, put_FirstOfMonthLabelFontFamily)
    FirstOfMonthLabelFontSize = property(get_FirstOfMonthLabelFontSize, put_FirstOfMonthLabelFontSize)
    FirstOfMonthLabelFontStyle = property(get_FirstOfMonthLabelFontStyle, put_FirstOfMonthLabelFontStyle)
    FirstOfMonthLabelFontWeight = property(get_FirstOfMonthLabelFontWeight, put_FirstOfMonthLabelFontWeight)
    FirstOfMonthLabelMargin = property(get_FirstOfMonthLabelMargin, put_FirstOfMonthLabelMargin)
    FirstOfYearDecadeLabelFontFamily = property(get_FirstOfYearDecadeLabelFontFamily, put_FirstOfYearDecadeLabelFontFamily)
    FirstOfYearDecadeLabelFontSize = property(get_FirstOfYearDecadeLabelFontSize, put_FirstOfYearDecadeLabelFontSize)
    FirstOfYearDecadeLabelFontStyle = property(get_FirstOfYearDecadeLabelFontStyle, put_FirstOfYearDecadeLabelFontStyle)
    FirstOfYearDecadeLabelFontWeight = property(get_FirstOfYearDecadeLabelFontWeight, put_FirstOfYearDecadeLabelFontWeight)
    FirstOfYearDecadeLabelMargin = property(get_FirstOfYearDecadeLabelMargin, put_FirstOfYearDecadeLabelMargin)
    FocusBorderBrush = property(get_FocusBorderBrush, put_FocusBorderBrush)
    HorizontalDayItemAlignment = property(get_HorizontalDayItemAlignment, put_HorizontalDayItemAlignment)
    HorizontalFirstOfMonthLabelAlignment = property(get_HorizontalFirstOfMonthLabelAlignment, put_HorizontalFirstOfMonthLabelAlignment)
    HoverBorderBrush = property(get_HoverBorderBrush, put_HoverBorderBrush)
    IsGroupLabelVisible = property(get_IsGroupLabelVisible, put_IsGroupLabelVisible)
    IsOutOfScopeEnabled = property(get_IsOutOfScopeEnabled, put_IsOutOfScopeEnabled)
    IsTodayHighlighted = property(get_IsTodayHighlighted, put_IsTodayHighlighted)
    MaxDate = property(get_MaxDate, put_MaxDate)
    MinDate = property(get_MinDate, put_MinDate)
    MonthYearItemFontFamily = property(get_MonthYearItemFontFamily, put_MonthYearItemFontFamily)
    MonthYearItemFontSize = property(get_MonthYearItemFontSize, put_MonthYearItemFontSize)
    MonthYearItemFontStyle = property(get_MonthYearItemFontStyle, put_MonthYearItemFontStyle)
    MonthYearItemFontWeight = property(get_MonthYearItemFontWeight, put_MonthYearItemFontWeight)
    MonthYearItemMargin = property(get_MonthYearItemMargin, put_MonthYearItemMargin)
    NumberOfWeeksInView = property(get_NumberOfWeeksInView, put_NumberOfWeeksInView)
    OutOfScopeBackground = property(get_OutOfScopeBackground, put_OutOfScopeBackground)
    OutOfScopeForeground = property(get_OutOfScopeForeground, put_OutOfScopeForeground)
    OutOfScopeHoverForeground = property(get_OutOfScopeHoverForeground, put_OutOfScopeHoverForeground)
    OutOfScopePressedForeground = property(get_OutOfScopePressedForeground, put_OutOfScopePressedForeground)
    PressedBorderBrush = property(get_PressedBorderBrush, put_PressedBorderBrush)
    PressedForeground = property(get_PressedForeground, put_PressedForeground)
    SelectedBorderBrush = property(get_SelectedBorderBrush, put_SelectedBorderBrush)
    SelectedDates = property(get_SelectedDates, None)
    SelectedDisabledBorderBrush = property(get_SelectedDisabledBorderBrush, put_SelectedDisabledBorderBrush)
    SelectedDisabledForeground = property(get_SelectedDisabledForeground, put_SelectedDisabledForeground)
    SelectedForeground = property(get_SelectedForeground, put_SelectedForeground)
    SelectedHoverBorderBrush = property(get_SelectedHoverBorderBrush, put_SelectedHoverBorderBrush)
    SelectedHoverForeground = property(get_SelectedHoverForeground, put_SelectedHoverForeground)
    SelectedPressedBorderBrush = property(get_SelectedPressedBorderBrush, put_SelectedPressedBorderBrush)
    SelectedPressedForeground = property(get_SelectedPressedForeground, put_SelectedPressedForeground)
    SelectionMode = property(get_SelectionMode, put_SelectionMode)
    TemplateSettings = property(get_TemplateSettings, None)
    TodayBackground = property(get_TodayBackground, put_TodayBackground)
    TodayBlackoutBackground = property(get_TodayBlackoutBackground, put_TodayBlackoutBackground)
    TodayBlackoutForeground = property(get_TodayBlackoutForeground, put_TodayBlackoutForeground)
    TodayDisabledBackground = property(get_TodayDisabledBackground, put_TodayDisabledBackground)
    TodayFontWeight = property(get_TodayFontWeight, put_TodayFontWeight)
    TodayForeground = property(get_TodayForeground, put_TodayForeground)
    TodayHoverBackground = property(get_TodayHoverBackground, put_TodayHoverBackground)
    TodayPressedBackground = property(get_TodayPressedBackground, put_TodayPressedBackground)
    TodaySelectedInnerBorderBrush = property(get_TodaySelectedInnerBorderBrush, put_TodaySelectedInnerBorderBrush)
    VerticalDayItemAlignment = property(get_VerticalDayItemAlignment, put_VerticalDayItemAlignment)
    VerticalFirstOfMonthLabelAlignment = property(get_VerticalFirstOfMonthLabelAlignment, put_VerticalFirstOfMonthLabelAlignment)
    _CalendarView_Meta_.BlackoutBackgroundProperty = property(get_BlackoutBackgroundProperty, None)
    _CalendarView_Meta_.BlackoutForegroundProperty = property(get_BlackoutForegroundProperty, None)
    _CalendarView_Meta_.BlackoutStrikethroughBrushProperty = property(get_BlackoutStrikethroughBrushProperty, None)
    _CalendarView_Meta_.CalendarIdentifierProperty = property(get_CalendarIdentifierProperty, None)
    _CalendarView_Meta_.CalendarItemBackgroundProperty = property(get_CalendarItemBackgroundProperty, None)
    _CalendarView_Meta_.CalendarItemBorderBrushProperty = property(get_CalendarItemBorderBrushProperty, None)
    _CalendarView_Meta_.CalendarItemBorderThicknessProperty = property(get_CalendarItemBorderThicknessProperty, None)
    _CalendarView_Meta_.CalendarItemCornerRadiusProperty = property(get_CalendarItemCornerRadiusProperty, None)
    _CalendarView_Meta_.CalendarItemDisabledBackgroundProperty = property(get_CalendarItemDisabledBackgroundProperty, None)
    _CalendarView_Meta_.CalendarItemForegroundProperty = property(get_CalendarItemForegroundProperty, None)
    _CalendarView_Meta_.CalendarItemHoverBackgroundProperty = property(get_CalendarItemHoverBackgroundProperty, None)
    _CalendarView_Meta_.CalendarItemPressedBackgroundProperty = property(get_CalendarItemPressedBackgroundProperty, None)
    _CalendarView_Meta_.CalendarViewDayItemStyleProperty = property(get_CalendarViewDayItemStyleProperty, None)
    _CalendarView_Meta_.DayItemFontFamilyProperty = property(get_DayItemFontFamilyProperty, None)
    _CalendarView_Meta_.DayItemFontSizeProperty = property(get_DayItemFontSizeProperty, None)
    _CalendarView_Meta_.DayItemFontStyleProperty = property(get_DayItemFontStyleProperty, None)
    _CalendarView_Meta_.DayItemFontWeightProperty = property(get_DayItemFontWeightProperty, None)
    _CalendarView_Meta_.DayItemMarginProperty = property(get_DayItemMarginProperty, None)
    _CalendarView_Meta_.DayOfWeekFormatProperty = property(get_DayOfWeekFormatProperty, None)
    _CalendarView_Meta_.DisabledForegroundProperty = property(get_DisabledForegroundProperty, None)
    _CalendarView_Meta_.DisplayModeProperty = property(get_DisplayModeProperty, None)
    _CalendarView_Meta_.FirstDayOfWeekProperty = property(get_FirstDayOfWeekProperty, None)
    _CalendarView_Meta_.FirstOfMonthLabelFontFamilyProperty = property(get_FirstOfMonthLabelFontFamilyProperty, None)
    _CalendarView_Meta_.FirstOfMonthLabelFontSizeProperty = property(get_FirstOfMonthLabelFontSizeProperty, None)
    _CalendarView_Meta_.FirstOfMonthLabelFontStyleProperty = property(get_FirstOfMonthLabelFontStyleProperty, None)
    _CalendarView_Meta_.FirstOfMonthLabelFontWeightProperty = property(get_FirstOfMonthLabelFontWeightProperty, None)
    _CalendarView_Meta_.FirstOfMonthLabelMarginProperty = property(get_FirstOfMonthLabelMarginProperty, None)
    _CalendarView_Meta_.FirstOfYearDecadeLabelFontFamilyProperty = property(get_FirstOfYearDecadeLabelFontFamilyProperty, None)
    _CalendarView_Meta_.FirstOfYearDecadeLabelFontSizeProperty = property(get_FirstOfYearDecadeLabelFontSizeProperty, None)
    _CalendarView_Meta_.FirstOfYearDecadeLabelFontStyleProperty = property(get_FirstOfYearDecadeLabelFontStyleProperty, None)
    _CalendarView_Meta_.FirstOfYearDecadeLabelFontWeightProperty = property(get_FirstOfYearDecadeLabelFontWeightProperty, None)
    _CalendarView_Meta_.FirstOfYearDecadeLabelMarginProperty = property(get_FirstOfYearDecadeLabelMarginProperty, None)
    _CalendarView_Meta_.FocusBorderBrushProperty = property(get_FocusBorderBrushProperty, None)
    _CalendarView_Meta_.HorizontalDayItemAlignmentProperty = property(get_HorizontalDayItemAlignmentProperty, None)
    _CalendarView_Meta_.HorizontalFirstOfMonthLabelAlignmentProperty = property(get_HorizontalFirstOfMonthLabelAlignmentProperty, None)
    _CalendarView_Meta_.HoverBorderBrushProperty = property(get_HoverBorderBrushProperty, None)
    _CalendarView_Meta_.IsGroupLabelVisibleProperty = property(get_IsGroupLabelVisibleProperty, None)
    _CalendarView_Meta_.IsOutOfScopeEnabledProperty = property(get_IsOutOfScopeEnabledProperty, None)
    _CalendarView_Meta_.IsTodayHighlightedProperty = property(get_IsTodayHighlightedProperty, None)
    _CalendarView_Meta_.MaxDateProperty = property(get_MaxDateProperty, None)
    _CalendarView_Meta_.MinDateProperty = property(get_MinDateProperty, None)
    _CalendarView_Meta_.MonthYearItemFontFamilyProperty = property(get_MonthYearItemFontFamilyProperty, None)
    _CalendarView_Meta_.MonthYearItemFontSizeProperty = property(get_MonthYearItemFontSizeProperty, None)
    _CalendarView_Meta_.MonthYearItemFontStyleProperty = property(get_MonthYearItemFontStyleProperty, None)
    _CalendarView_Meta_.MonthYearItemFontWeightProperty = property(get_MonthYearItemFontWeightProperty, None)
    _CalendarView_Meta_.MonthYearItemMarginProperty = property(get_MonthYearItemMarginProperty, None)
    _CalendarView_Meta_.NumberOfWeeksInViewProperty = property(get_NumberOfWeeksInViewProperty, None)
    _CalendarView_Meta_.OutOfScopeBackgroundProperty = property(get_OutOfScopeBackgroundProperty, None)
    _CalendarView_Meta_.OutOfScopeForegroundProperty = property(get_OutOfScopeForegroundProperty, None)
    _CalendarView_Meta_.OutOfScopeHoverForegroundProperty = property(get_OutOfScopeHoverForegroundProperty, None)
    _CalendarView_Meta_.OutOfScopePressedForegroundProperty = property(get_OutOfScopePressedForegroundProperty, None)
    _CalendarView_Meta_.PressedBorderBrushProperty = property(get_PressedBorderBrushProperty, None)
    _CalendarView_Meta_.PressedForegroundProperty = property(get_PressedForegroundProperty, None)
    _CalendarView_Meta_.SelectedBorderBrushProperty = property(get_SelectedBorderBrushProperty, None)
    _CalendarView_Meta_.SelectedDatesProperty = property(get_SelectedDatesProperty, None)
    _CalendarView_Meta_.SelectedDisabledBorderBrushProperty = property(get_SelectedDisabledBorderBrushProperty, None)
    _CalendarView_Meta_.SelectedDisabledForegroundProperty = property(get_SelectedDisabledForegroundProperty, None)
    _CalendarView_Meta_.SelectedForegroundProperty = property(get_SelectedForegroundProperty, None)
    _CalendarView_Meta_.SelectedHoverBorderBrushProperty = property(get_SelectedHoverBorderBrushProperty, None)
    _CalendarView_Meta_.SelectedHoverForegroundProperty = property(get_SelectedHoverForegroundProperty, None)
    _CalendarView_Meta_.SelectedPressedBorderBrushProperty = property(get_SelectedPressedBorderBrushProperty, None)
    _CalendarView_Meta_.SelectedPressedForegroundProperty = property(get_SelectedPressedForegroundProperty, None)
    _CalendarView_Meta_.SelectionModeProperty = property(get_SelectionModeProperty, None)
    _CalendarView_Meta_.TemplateSettingsProperty = property(get_TemplateSettingsProperty, None)
    _CalendarView_Meta_.TodayBackgroundProperty = property(get_TodayBackgroundProperty, None)
    _CalendarView_Meta_.TodayBlackoutBackgroundProperty = property(get_TodayBlackoutBackgroundProperty, None)
    _CalendarView_Meta_.TodayBlackoutForegroundProperty = property(get_TodayBlackoutForegroundProperty, None)
    _CalendarView_Meta_.TodayDisabledBackgroundProperty = property(get_TodayDisabledBackgroundProperty, None)
    _CalendarView_Meta_.TodayFontWeightProperty = property(get_TodayFontWeightProperty, None)
    _CalendarView_Meta_.TodayForegroundProperty = property(get_TodayForegroundProperty, None)
    _CalendarView_Meta_.TodayHoverBackgroundProperty = property(get_TodayHoverBackgroundProperty, None)
    _CalendarView_Meta_.TodayPressedBackgroundProperty = property(get_TodayPressedBackgroundProperty, None)
    _CalendarView_Meta_.TodaySelectedInnerBorderBrushProperty = property(get_TodaySelectedInnerBorderBrushProperty, None)
    _CalendarView_Meta_.VerticalDayItemAlignmentProperty = property(get_VerticalDayItemAlignmentProperty, None)
    _CalendarView_Meta_.VerticalFirstOfMonthLabelAlignmentProperty = property(get_VerticalFirstOfMonthLabelAlignmentProperty, None)
    CalendarViewDayItemChanging = event(add_CalendarViewDayItemChanging, remove_CalendarViewDayItemChanging)
    SelectedDatesChanged = event(add_SelectedDatesChanged, remove_SelectedDatesChanged)
class _CalendarViewDayItem_Meta_(ComPtr.__class__):
    pass
class CalendarViewDayItem(ComPtr, metaclass=_CalendarViewDayItem_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.Control
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewDayItem
    _classid_ = 'Microsoft.UI.Xaml.Controls.CalendarViewDayItem'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.CalendarViewDayItem.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewDayItemFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.CalendarViewDayItem: ...
    @winrt_mixinmethod
    def get_IsBlackout(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewDayItem) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsBlackout(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewDayItem, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_Date(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewDayItem) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_mixinmethod
    def SetDensityColors(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewDayItem, colors: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.UI.Color]) -> Void: ...
    @winrt_classmethod
    def get_IsBlackoutProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewDayItemStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DateProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewDayItemStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    Date = property(get_Date, None)
    IsBlackout = property(get_IsBlackout, put_IsBlackout)
    _CalendarViewDayItem_Meta_.DateProperty = property(get_DateProperty, None)
    _CalendarViewDayItem_Meta_.IsBlackoutProperty = property(get_IsBlackoutProperty, None)
class CalendarViewDayItemChangingEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewDayItemChangingEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.CalendarViewDayItemChangingEventArgs'
    @winrt_mixinmethod
    def get_InRecycleQueue(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewDayItemChangingEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def get_Item(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewDayItemChangingEventArgs) -> win32more.Microsoft.UI.Xaml.Controls.CalendarViewDayItem: ...
    @winrt_mixinmethod
    def get_Phase(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewDayItemChangingEventArgs) -> UInt32: ...
    @winrt_mixinmethod
    def RegisterUpdateCallback(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewDayItemChangingEventArgs, callback: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.CalendarView, win32more.Microsoft.UI.Xaml.Controls.CalendarViewDayItemChangingEventArgs]) -> Void: ...
    @winrt_mixinmethod
    def RegisterUpdateCallbackWithPhase(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewDayItemChangingEventArgs, callbackPhase: UInt32, callback: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.CalendarView, win32more.Microsoft.UI.Xaml.Controls.CalendarViewDayItemChangingEventArgs]) -> Void: ...
    InRecycleQueue = property(get_InRecycleQueue, None)
    Item = property(get_Item, None)
    Phase = property(get_Phase, None)
class CalendarViewDayItemChangingEventHandler(MulticastDelegate):
    extends: IUnknown
    _iid_ = Guid('{ab8075fd-7a4b-504e-8a63-d7f35570bd86}')
    @winrt_commethod(3)
    def Invoke(self, sender: win32more.Microsoft.UI.Xaml.Controls.CalendarView, e: win32more.Microsoft.UI.Xaml.Controls.CalendarViewDayItemChangingEventArgs) -> Void: ...
class CalendarViewDisplayMode(Enum, Int32):
    Month = 0
    Year = 1
    Decade = 2
class CalendarViewSelectedDatesChangedEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewSelectedDatesChangedEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.CalendarViewSelectedDatesChangedEventArgs'
    @winrt_mixinmethod
    def get_AddedDates(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewSelectedDatesChangedEventArgs) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Foundation.DateTime]: ...
    @winrt_mixinmethod
    def get_RemovedDates(self: win32more.Microsoft.UI.Xaml.Controls.ICalendarViewSelectedDatesChangedEventArgs) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Foundation.DateTime]: ...
    AddedDates = property(get_AddedDates, None)
    RemovedDates = property(get_RemovedDates, None)
class CalendarViewSelectionMode(Enum, Int32):
    None_ = 0
    Single = 1
    Multiple = 2
class CandidateWindowAlignment(Enum, Int32):
    Default = 0
    BottomEdge = 1
class CandidateWindowBoundsChangedEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ICandidateWindowBoundsChangedEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.CandidateWindowBoundsChangedEventArgs'
    @winrt_mixinmethod
    def get_Bounds(self: win32more.Microsoft.UI.Xaml.Controls.ICandidateWindowBoundsChangedEventArgs) -> win32more.Windows.Foundation.Rect: ...
    Bounds = property(get_Bounds, None)
class _Canvas_Meta_(ComPtr.__class__):
    pass
class Canvas(ComPtr, metaclass=_Canvas_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.Panel
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ICanvas
    _classid_ = 'Microsoft.UI.Xaml.Controls.Canvas'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.Canvas.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.ICanvasFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.Canvas: ...
    @winrt_classmethod
    def get_LeftProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICanvasStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetLeft(cls: win32more.Microsoft.UI.Xaml.Controls.ICanvasStatics, element: win32more.Microsoft.UI.Xaml.UIElement) -> Double: ...
    @winrt_classmethod
    def SetLeft(cls: win32more.Microsoft.UI.Xaml.Controls.ICanvasStatics, element: win32more.Microsoft.UI.Xaml.UIElement, length: Double) -> Void: ...
    @winrt_classmethod
    def get_TopProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICanvasStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetTop(cls: win32more.Microsoft.UI.Xaml.Controls.ICanvasStatics, element: win32more.Microsoft.UI.Xaml.UIElement) -> Double: ...
    @winrt_classmethod
    def SetTop(cls: win32more.Microsoft.UI.Xaml.Controls.ICanvasStatics, element: win32more.Microsoft.UI.Xaml.UIElement, length: Double) -> Void: ...
    @winrt_classmethod
    def get_ZIndexProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICanvasStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetZIndex(cls: win32more.Microsoft.UI.Xaml.Controls.ICanvasStatics, element: win32more.Microsoft.UI.Xaml.UIElement) -> Int32: ...
    @winrt_classmethod
    def SetZIndex(cls: win32more.Microsoft.UI.Xaml.Controls.ICanvasStatics, element: win32more.Microsoft.UI.Xaml.UIElement, value: Int32) -> Void: ...
    _Canvas_Meta_.LeftProperty = property(get_LeftProperty, None)
    _Canvas_Meta_.TopProperty = property(get_TopProperty, None)
    _Canvas_Meta_.ZIndexProperty = property(get_ZIndexProperty, None)
class CharacterCasing(Enum, Int32):
    Normal = 0
    Lower = 1
    Upper = 2
class CheckBox(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.Controls.Primitives.ToggleButton
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ICheckBox
    _classid_ = 'Microsoft.UI.Xaml.Controls.CheckBox'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.CheckBox.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.ICheckBoxFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.CheckBox: ...
class ChoosingGroupHeaderContainerEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IChoosingGroupHeaderContainerEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.ChoosingGroupHeaderContainerEventArgs'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.ChoosingGroupHeaderContainerEventArgs.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Controls.ChoosingGroupHeaderContainerEventArgs: ...
    @winrt_mixinmethod
    def get_GroupHeaderContainer(self: win32more.Microsoft.UI.Xaml.Controls.IChoosingGroupHeaderContainerEventArgs) -> win32more.Microsoft.UI.Xaml.Controls.ListViewBaseHeaderItem: ...
    @winrt_mixinmethod
    def put_GroupHeaderContainer(self: win32more.Microsoft.UI.Xaml.Controls.IChoosingGroupHeaderContainerEventArgs, value: win32more.Microsoft.UI.Xaml.Controls.ListViewBaseHeaderItem) -> Void: ...
    @winrt_mixinmethod
    def get_GroupIndex(self: win32more.Microsoft.UI.Xaml.Controls.IChoosingGroupHeaderContainerEventArgs) -> Int32: ...
    @winrt_mixinmethod
    def get_Group(self: win32more.Microsoft.UI.Xaml.Controls.IChoosingGroupHeaderContainerEventArgs) -> IInspectable: ...
    Group = property(get_Group, None)
    GroupHeaderContainer = property(get_GroupHeaderContainer, put_GroupHeaderContainer)
    GroupIndex = property(get_GroupIndex, None)
class ChoosingItemContainerEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IChoosingItemContainerEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.ChoosingItemContainerEventArgs'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.ChoosingItemContainerEventArgs.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Controls.ChoosingItemContainerEventArgs: ...
    @winrt_mixinmethod
    def get_ItemIndex(self: win32more.Microsoft.UI.Xaml.Controls.IChoosingItemContainerEventArgs) -> Int32: ...
    @winrt_mixinmethod
    def get_Item(self: win32more.Microsoft.UI.Xaml.Controls.IChoosingItemContainerEventArgs) -> IInspectable: ...
    @winrt_mixinmethod
    def get_ItemContainer(self: win32more.Microsoft.UI.Xaml.Controls.IChoosingItemContainerEventArgs) -> win32more.Microsoft.UI.Xaml.Controls.Primitives.SelectorItem: ...
    @winrt_mixinmethod
    def put_ItemContainer(self: win32more.Microsoft.UI.Xaml.Controls.IChoosingItemContainerEventArgs, value: win32more.Microsoft.UI.Xaml.Controls.Primitives.SelectorItem) -> Void: ...
    @winrt_mixinmethod
    def get_IsContainerPrepared(self: win32more.Microsoft.UI.Xaml.Controls.IChoosingItemContainerEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsContainerPrepared(self: win32more.Microsoft.UI.Xaml.Controls.IChoosingItemContainerEventArgs, value: Boolean) -> Void: ...
    IsContainerPrepared = property(get_IsContainerPrepared, put_IsContainerPrepared)
    Item = property(get_Item, None)
    ItemContainer = property(get_ItemContainer, put_ItemContainer)
    ItemIndex = property(get_ItemIndex, None)
class CleanUpVirtualizedItemEventArgs(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.RoutedEventArgs
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ICleanUpVirtualizedItemEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.CleanUpVirtualizedItemEventArgs'
    @winrt_mixinmethod
    def get_Value(self: win32more.Microsoft.UI.Xaml.Controls.ICleanUpVirtualizedItemEventArgs) -> IInspectable: ...
    @winrt_mixinmethod
    def get_UIElement(self: win32more.Microsoft.UI.Xaml.Controls.ICleanUpVirtualizedItemEventArgs) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_mixinmethod
    def get_Cancel(self: win32more.Microsoft.UI.Xaml.Controls.ICleanUpVirtualizedItemEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def put_Cancel(self: win32more.Microsoft.UI.Xaml.Controls.ICleanUpVirtualizedItemEventArgs, value: Boolean) -> Void: ...
    Cancel = property(get_Cancel, put_Cancel)
    UIElement = property(get_UIElement, None)
    Value = property(get_Value, None)
class CleanUpVirtualizedItemEventHandler(MulticastDelegate):
    extends: IUnknown
    _iid_ = Guid('{da6960de-89ff-575f-932f-023f6fc1f992}')
    @winrt_commethod(3)
    def Invoke(self, sender: IInspectable, e: win32more.Microsoft.UI.Xaml.Controls.CleanUpVirtualizedItemEventArgs) -> Void: ...
class ClickMode(Enum, Int32):
    Release = 0
    Press = 1
    Hover = 2
class ColorChangedEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IColorChangedEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.ColorChangedEventArgs'
    @winrt_mixinmethod
    def get_OldColor(self: win32more.Microsoft.UI.Xaml.Controls.IColorChangedEventArgs) -> win32more.Windows.UI.Color: ...
    @winrt_mixinmethod
    def get_NewColor(self: win32more.Microsoft.UI.Xaml.Controls.IColorChangedEventArgs) -> win32more.Windows.UI.Color: ...
    NewColor = property(get_NewColor, None)
    OldColor = property(get_OldColor, None)
class _ColorPicker_Meta_(ComPtr.__class__):
    pass
class ColorPicker(ComPtr, metaclass=_ColorPicker_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.Control
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IColorPicker
    _classid_ = 'Microsoft.UI.Xaml.Controls.ColorPicker'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.ColorPicker.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IColorPickerFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.ColorPicker: ...
    @winrt_mixinmethod
    def get_Color(self: win32more.Microsoft.UI.Xaml.Controls.IColorPicker) -> win32more.Windows.UI.Color: ...
    @winrt_mixinmethod
    def put_Color(self: win32more.Microsoft.UI.Xaml.Controls.IColorPicker, value: win32more.Windows.UI.Color) -> Void: ...
    @winrt_mixinmethod
    def get_PreviousColor(self: win32more.Microsoft.UI.Xaml.Controls.IColorPicker) -> win32more.Windows.Foundation.IReference[win32more.Windows.UI.Color]: ...
    @winrt_mixinmethod
    def put_PreviousColor(self: win32more.Microsoft.UI.Xaml.Controls.IColorPicker, value: win32more.Windows.Foundation.IReference[win32more.Windows.UI.Color]) -> Void: ...
    @winrt_mixinmethod
    def get_IsAlphaEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IColorPicker) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsAlphaEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IColorPicker, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsColorSpectrumVisible(self: win32more.Microsoft.UI.Xaml.Controls.IColorPicker) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsColorSpectrumVisible(self: win32more.Microsoft.UI.Xaml.Controls.IColorPicker, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsColorPreviewVisible(self: win32more.Microsoft.UI.Xaml.Controls.IColorPicker) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsColorPreviewVisible(self: win32more.Microsoft.UI.Xaml.Controls.IColorPicker, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsColorSliderVisible(self: win32more.Microsoft.UI.Xaml.Controls.IColorPicker) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsColorSliderVisible(self: win32more.Microsoft.UI.Xaml.Controls.IColorPicker, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsAlphaSliderVisible(self: win32more.Microsoft.UI.Xaml.Controls.IColorPicker) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsAlphaSliderVisible(self: win32more.Microsoft.UI.Xaml.Controls.IColorPicker, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsMoreButtonVisible(self: win32more.Microsoft.UI.Xaml.Controls.IColorPicker) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsMoreButtonVisible(self: win32more.Microsoft.UI.Xaml.Controls.IColorPicker, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsColorChannelTextInputVisible(self: win32more.Microsoft.UI.Xaml.Controls.IColorPicker) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsColorChannelTextInputVisible(self: win32more.Microsoft.UI.Xaml.Controls.IColorPicker, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsAlphaTextInputVisible(self: win32more.Microsoft.UI.Xaml.Controls.IColorPicker) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsAlphaTextInputVisible(self: win32more.Microsoft.UI.Xaml.Controls.IColorPicker, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsHexInputVisible(self: win32more.Microsoft.UI.Xaml.Controls.IColorPicker) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsHexInputVisible(self: win32more.Microsoft.UI.Xaml.Controls.IColorPicker, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_MinHue(self: win32more.Microsoft.UI.Xaml.Controls.IColorPicker) -> Int32: ...
    @winrt_mixinmethod
    def put_MinHue(self: win32more.Microsoft.UI.Xaml.Controls.IColorPicker, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_MaxHue(self: win32more.Microsoft.UI.Xaml.Controls.IColorPicker) -> Int32: ...
    @winrt_mixinmethod
    def put_MaxHue(self: win32more.Microsoft.UI.Xaml.Controls.IColorPicker, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_MinSaturation(self: win32more.Microsoft.UI.Xaml.Controls.IColorPicker) -> Int32: ...
    @winrt_mixinmethod
    def put_MinSaturation(self: win32more.Microsoft.UI.Xaml.Controls.IColorPicker, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_MaxSaturation(self: win32more.Microsoft.UI.Xaml.Controls.IColorPicker) -> Int32: ...
    @winrt_mixinmethod
    def put_MaxSaturation(self: win32more.Microsoft.UI.Xaml.Controls.IColorPicker, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_MinValue(self: win32more.Microsoft.UI.Xaml.Controls.IColorPicker) -> Int32: ...
    @winrt_mixinmethod
    def put_MinValue(self: win32more.Microsoft.UI.Xaml.Controls.IColorPicker, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_MaxValue(self: win32more.Microsoft.UI.Xaml.Controls.IColorPicker) -> Int32: ...
    @winrt_mixinmethod
    def put_MaxValue(self: win32more.Microsoft.UI.Xaml.Controls.IColorPicker, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_ColorSpectrumShape(self: win32more.Microsoft.UI.Xaml.Controls.IColorPicker) -> win32more.Microsoft.UI.Xaml.Controls.ColorSpectrumShape: ...
    @winrt_mixinmethod
    def put_ColorSpectrumShape(self: win32more.Microsoft.UI.Xaml.Controls.IColorPicker, value: win32more.Microsoft.UI.Xaml.Controls.ColorSpectrumShape) -> Void: ...
    @winrt_mixinmethod
    def get_ColorSpectrumComponents(self: win32more.Microsoft.UI.Xaml.Controls.IColorPicker) -> win32more.Microsoft.UI.Xaml.Controls.ColorSpectrumComponents: ...
    @winrt_mixinmethod
    def put_ColorSpectrumComponents(self: win32more.Microsoft.UI.Xaml.Controls.IColorPicker, value: win32more.Microsoft.UI.Xaml.Controls.ColorSpectrumComponents) -> Void: ...
    @winrt_mixinmethod
    def add_ColorChanged(self: win32more.Microsoft.UI.Xaml.Controls.IColorPicker, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.ColorPicker, win32more.Microsoft.UI.Xaml.Controls.ColorChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ColorChanged(self: win32more.Microsoft.UI.Xaml.Controls.IColorPicker, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def get_Orientation(self: win32more.Microsoft.UI.Xaml.Controls.IColorPicker2) -> win32more.Microsoft.UI.Xaml.Controls.Orientation: ...
    @winrt_mixinmethod
    def put_Orientation(self: win32more.Microsoft.UI.Xaml.Controls.IColorPicker2, value: win32more.Microsoft.UI.Xaml.Controls.Orientation) -> Void: ...
    @winrt_classmethod
    def get_OrientationProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IColorPickerStatics2) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ColorProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IColorPickerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PreviousColorProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IColorPickerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsAlphaEnabledProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IColorPickerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsColorSpectrumVisibleProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IColorPickerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsColorPreviewVisibleProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IColorPickerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsColorSliderVisibleProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IColorPickerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsAlphaSliderVisibleProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IColorPickerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsMoreButtonVisibleProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IColorPickerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsColorChannelTextInputVisibleProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IColorPickerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsAlphaTextInputVisibleProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IColorPickerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsHexInputVisibleProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IColorPickerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MinHueProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IColorPickerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MaxHueProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IColorPickerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MinSaturationProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IColorPickerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MaxSaturationProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IColorPickerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MinValueProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IColorPickerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MaxValueProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IColorPickerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ColorSpectrumShapeProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IColorPickerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ColorSpectrumComponentsProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IColorPickerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    Color = property(get_Color, put_Color)
    ColorSpectrumComponents = property(get_ColorSpectrumComponents, put_ColorSpectrumComponents)
    ColorSpectrumShape = property(get_ColorSpectrumShape, put_ColorSpectrumShape)
    IsAlphaEnabled = property(get_IsAlphaEnabled, put_IsAlphaEnabled)
    IsAlphaSliderVisible = property(get_IsAlphaSliderVisible, put_IsAlphaSliderVisible)
    IsAlphaTextInputVisible = property(get_IsAlphaTextInputVisible, put_IsAlphaTextInputVisible)
    IsColorChannelTextInputVisible = property(get_IsColorChannelTextInputVisible, put_IsColorChannelTextInputVisible)
    IsColorPreviewVisible = property(get_IsColorPreviewVisible, put_IsColorPreviewVisible)
    IsColorSliderVisible = property(get_IsColorSliderVisible, put_IsColorSliderVisible)
    IsColorSpectrumVisible = property(get_IsColorSpectrumVisible, put_IsColorSpectrumVisible)
    IsHexInputVisible = property(get_IsHexInputVisible, put_IsHexInputVisible)
    IsMoreButtonVisible = property(get_IsMoreButtonVisible, put_IsMoreButtonVisible)
    MaxHue = property(get_MaxHue, put_MaxHue)
    MaxSaturation = property(get_MaxSaturation, put_MaxSaturation)
    MaxValue = property(get_MaxValue, put_MaxValue)
    MinHue = property(get_MinHue, put_MinHue)
    MinSaturation = property(get_MinSaturation, put_MinSaturation)
    MinValue = property(get_MinValue, put_MinValue)
    Orientation = property(get_Orientation, put_Orientation)
    PreviousColor = property(get_PreviousColor, put_PreviousColor)
    _ColorPicker_Meta_.ColorProperty = property(get_ColorProperty, None)
    _ColorPicker_Meta_.ColorSpectrumComponentsProperty = property(get_ColorSpectrumComponentsProperty, None)
    _ColorPicker_Meta_.ColorSpectrumShapeProperty = property(get_ColorSpectrumShapeProperty, None)
    _ColorPicker_Meta_.IsAlphaEnabledProperty = property(get_IsAlphaEnabledProperty, None)
    _ColorPicker_Meta_.IsAlphaSliderVisibleProperty = property(get_IsAlphaSliderVisibleProperty, None)
    _ColorPicker_Meta_.IsAlphaTextInputVisibleProperty = property(get_IsAlphaTextInputVisibleProperty, None)
    _ColorPicker_Meta_.IsColorChannelTextInputVisibleProperty = property(get_IsColorChannelTextInputVisibleProperty, None)
    _ColorPicker_Meta_.IsColorPreviewVisibleProperty = property(get_IsColorPreviewVisibleProperty, None)
    _ColorPicker_Meta_.IsColorSliderVisibleProperty = property(get_IsColorSliderVisibleProperty, None)
    _ColorPicker_Meta_.IsColorSpectrumVisibleProperty = property(get_IsColorSpectrumVisibleProperty, None)
    _ColorPicker_Meta_.IsHexInputVisibleProperty = property(get_IsHexInputVisibleProperty, None)
    _ColorPicker_Meta_.IsMoreButtonVisibleProperty = property(get_IsMoreButtonVisibleProperty, None)
    _ColorPicker_Meta_.MaxHueProperty = property(get_MaxHueProperty, None)
    _ColorPicker_Meta_.MaxSaturationProperty = property(get_MaxSaturationProperty, None)
    _ColorPicker_Meta_.MaxValueProperty = property(get_MaxValueProperty, None)
    _ColorPicker_Meta_.MinHueProperty = property(get_MinHueProperty, None)
    _ColorPicker_Meta_.MinSaturationProperty = property(get_MinSaturationProperty, None)
    _ColorPicker_Meta_.MinValueProperty = property(get_MinValueProperty, None)
    _ColorPicker_Meta_.OrientationProperty = property(get_OrientationProperty, None)
    _ColorPicker_Meta_.PreviousColorProperty = property(get_PreviousColorProperty, None)
    ColorChanged = event(add_ColorChanged, remove_ColorChanged)
class ColorPickerHsvChannel(Enum, Int32):
    Hue = 0
    Saturation = 1
    Value = 2
    Alpha = 3
class ColorSpectrumComponents(Enum, Int32):
    HueValue = 0
    ValueHue = 1
    HueSaturation = 2
    SaturationHue = 3
    SaturationValue = 4
    ValueSaturation = 5
class ColorSpectrumShape(Enum, Int32):
    Box = 0
    Ring = 1
class _ColumnDefinition_Meta_(ComPtr.__class__):
    pass
class ColumnDefinition(ComPtr, metaclass=_ColumnDefinition_Meta_):
    extends: win32more.Microsoft.UI.Xaml.DependencyObject
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IColumnDefinition
    _classid_ = 'Microsoft.UI.Xaml.Controls.ColumnDefinition'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.ColumnDefinition.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Controls.ColumnDefinition: ...
    @winrt_mixinmethod
    def get_Width(self: win32more.Microsoft.UI.Xaml.Controls.IColumnDefinition) -> win32more.Microsoft.UI.Xaml.GridLength: ...
    @winrt_mixinmethod
    def put_Width(self: win32more.Microsoft.UI.Xaml.Controls.IColumnDefinition, value: win32more.Microsoft.UI.Xaml.GridLength) -> Void: ...
    @winrt_mixinmethod
    def get_MaxWidth(self: win32more.Microsoft.UI.Xaml.Controls.IColumnDefinition) -> Double: ...
    @winrt_mixinmethod
    def put_MaxWidth(self: win32more.Microsoft.UI.Xaml.Controls.IColumnDefinition, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_MinWidth(self: win32more.Microsoft.UI.Xaml.Controls.IColumnDefinition) -> Double: ...
    @winrt_mixinmethod
    def put_MinWidth(self: win32more.Microsoft.UI.Xaml.Controls.IColumnDefinition, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_ActualWidth(self: win32more.Microsoft.UI.Xaml.Controls.IColumnDefinition) -> Double: ...
    @winrt_classmethod
    def get_WidthProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IColumnDefinitionStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MaxWidthProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IColumnDefinitionStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MinWidthProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IColumnDefinitionStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    ActualWidth = property(get_ActualWidth, None)
    MaxWidth = property(get_MaxWidth, put_MaxWidth)
    MinWidth = property(get_MinWidth, put_MinWidth)
    Width = property(get_Width, put_Width)
    _ColumnDefinition_Meta_.MaxWidthProperty = property(get_MaxWidthProperty, None)
    _ColumnDefinition_Meta_.MinWidthProperty = property(get_MinWidthProperty, None)
    _ColumnDefinition_Meta_.WidthProperty = property(get_WidthProperty, None)
class ColumnDefinitionCollection(ComPtr):
    extends: IInspectable
    implements: Tuple[SequenceProtocol[win32more.Microsoft.UI.Xaml.Controls.ColumnDefinition]]
    default_interface: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.ColumnDefinition]
    _classid_ = 'Microsoft.UI.Xaml.Controls.ColumnDefinitionCollection'
    @winrt_mixinmethod
    def GetAt(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.ColumnDefinition], index: UInt32) -> win32more.Microsoft.UI.Xaml.Controls.ColumnDefinition: ...
    @winrt_mixinmethod
    def get_Size(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.ColumnDefinition]) -> UInt32: ...
    @winrt_mixinmethod
    def GetView(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.ColumnDefinition]) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Microsoft.UI.Xaml.Controls.ColumnDefinition]: ...
    @winrt_mixinmethod
    def IndexOf(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.ColumnDefinition], value: win32more.Microsoft.UI.Xaml.Controls.ColumnDefinition, index: POINTER(UInt32)) -> Boolean: ...
    @winrt_mixinmethod
    def SetAt(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.ColumnDefinition], index: UInt32, value: win32more.Microsoft.UI.Xaml.Controls.ColumnDefinition) -> Void: ...
    @winrt_mixinmethod
    def InsertAt(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.ColumnDefinition], index: UInt32, value: win32more.Microsoft.UI.Xaml.Controls.ColumnDefinition) -> Void: ...
    @winrt_mixinmethod
    def RemoveAt(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.ColumnDefinition], index: UInt32) -> Void: ...
    @winrt_mixinmethod
    def Append(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.ColumnDefinition], value: win32more.Microsoft.UI.Xaml.Controls.ColumnDefinition) -> Void: ...
    @winrt_mixinmethod
    def RemoveAtEnd(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.ColumnDefinition]) -> Void: ...
    @winrt_mixinmethod
    def Clear(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.ColumnDefinition]) -> Void: ...
    @winrt_mixinmethod
    def GetMany(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.ColumnDefinition], startIndex: UInt32, items: FillArray[win32more.Microsoft.UI.Xaml.Controls.ColumnDefinition]) -> UInt32: ...
    @winrt_mixinmethod
    def ReplaceAll(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.ColumnDefinition], items: PassArray[win32more.Microsoft.UI.Xaml.Controls.ColumnDefinition]) -> Void: ...
    @winrt_mixinmethod
    def First(self: win32more.Windows.Foundation.Collections.IIterable[win32more.Microsoft.UI.Xaml.Controls.ColumnDefinition]) -> win32more.Windows.Foundation.Collections.IIterator[win32more.Microsoft.UI.Xaml.Controls.ColumnDefinition]: ...
    Size = property(get_Size, None)
class _ComboBox_Meta_(ComPtr.__class__):
    pass
class ComboBox(ComPtr, metaclass=_ComboBox_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.Primitives.Selector
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IComboBox
    _classid_ = 'Microsoft.UI.Xaml.Controls.ComboBox'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.ComboBox.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IComboBoxFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.ComboBox: ...
    @winrt_mixinmethod
    def get_IsDropDownOpen(self: win32more.Microsoft.UI.Xaml.Controls.IComboBox) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsDropDownOpen(self: win32more.Microsoft.UI.Xaml.Controls.IComboBox, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsEditable(self: win32more.Microsoft.UI.Xaml.Controls.IComboBox) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsEditable(self: win32more.Microsoft.UI.Xaml.Controls.IComboBox, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsSelectionBoxHighlighted(self: win32more.Microsoft.UI.Xaml.Controls.IComboBox) -> Boolean: ...
    @winrt_mixinmethod
    def get_MaxDropDownHeight(self: win32more.Microsoft.UI.Xaml.Controls.IComboBox) -> Double: ...
    @winrt_mixinmethod
    def put_MaxDropDownHeight(self: win32more.Microsoft.UI.Xaml.Controls.IComboBox, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_SelectionBoxItem(self: win32more.Microsoft.UI.Xaml.Controls.IComboBox) -> IInspectable: ...
    @winrt_mixinmethod
    def get_SelectionBoxItemTemplate(self: win32more.Microsoft.UI.Xaml.Controls.IComboBox) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def get_TemplateSettings(self: win32more.Microsoft.UI.Xaml.Controls.IComboBox) -> win32more.Microsoft.UI.Xaml.Controls.Primitives.ComboBoxTemplateSettings: ...
    @winrt_mixinmethod
    def get_Header(self: win32more.Microsoft.UI.Xaml.Controls.IComboBox) -> IInspectable: ...
    @winrt_mixinmethod
    def put_Header(self: win32more.Microsoft.UI.Xaml.Controls.IComboBox, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_HeaderTemplate(self: win32more.Microsoft.UI.Xaml.Controls.IComboBox) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def put_HeaderTemplate(self: win32more.Microsoft.UI.Xaml.Controls.IComboBox, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_mixinmethod
    def get_PlaceholderText(self: win32more.Microsoft.UI.Xaml.Controls.IComboBox) -> hstr: ...
    @winrt_mixinmethod
    def put_PlaceholderText(self: win32more.Microsoft.UI.Xaml.Controls.IComboBox, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def get_LightDismissOverlayMode(self: win32more.Microsoft.UI.Xaml.Controls.IComboBox) -> win32more.Microsoft.UI.Xaml.Controls.LightDismissOverlayMode: ...
    @winrt_mixinmethod
    def put_LightDismissOverlayMode(self: win32more.Microsoft.UI.Xaml.Controls.IComboBox, value: win32more.Microsoft.UI.Xaml.Controls.LightDismissOverlayMode) -> Void: ...
    @winrt_mixinmethod
    def get_IsTextSearchEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IComboBox) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsTextSearchEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IComboBox, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_SelectionChangedTrigger(self: win32more.Microsoft.UI.Xaml.Controls.IComboBox) -> win32more.Microsoft.UI.Xaml.Controls.ComboBoxSelectionChangedTrigger: ...
    @winrt_mixinmethod
    def put_SelectionChangedTrigger(self: win32more.Microsoft.UI.Xaml.Controls.IComboBox, value: win32more.Microsoft.UI.Xaml.Controls.ComboBoxSelectionChangedTrigger) -> Void: ...
    @winrt_mixinmethod
    def get_PlaceholderForeground(self: win32more.Microsoft.UI.Xaml.Controls.IComboBox) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_PlaceholderForeground(self: win32more.Microsoft.UI.Xaml.Controls.IComboBox, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_Text(self: win32more.Microsoft.UI.Xaml.Controls.IComboBox) -> hstr: ...
    @winrt_mixinmethod
    def put_Text(self: win32more.Microsoft.UI.Xaml.Controls.IComboBox, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def get_TextBoxStyle(self: win32more.Microsoft.UI.Xaml.Controls.IComboBox) -> win32more.Microsoft.UI.Xaml.Style: ...
    @winrt_mixinmethod
    def put_TextBoxStyle(self: win32more.Microsoft.UI.Xaml.Controls.IComboBox, value: win32more.Microsoft.UI.Xaml.Style) -> Void: ...
    @winrt_mixinmethod
    def get_Description(self: win32more.Microsoft.UI.Xaml.Controls.IComboBox) -> IInspectable: ...
    @winrt_mixinmethod
    def put_Description(self: win32more.Microsoft.UI.Xaml.Controls.IComboBox, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def add_DropDownClosed(self: win32more.Microsoft.UI.Xaml.Controls.IComboBox, handler: win32more.Windows.Foundation.EventHandler[IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_DropDownClosed(self: win32more.Microsoft.UI.Xaml.Controls.IComboBox, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_DropDownOpened(self: win32more.Microsoft.UI.Xaml.Controls.IComboBox, handler: win32more.Windows.Foundation.EventHandler[IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_DropDownOpened(self: win32more.Microsoft.UI.Xaml.Controls.IComboBox, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_TextSubmitted(self: win32more.Microsoft.UI.Xaml.Controls.IComboBox, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.ComboBox, win32more.Microsoft.UI.Xaml.Controls.ComboBoxTextSubmittedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_TextSubmitted(self: win32more.Microsoft.UI.Xaml.Controls.IComboBox, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def OnDropDownClosed(self: win32more.Microsoft.UI.Xaml.Controls.IComboBoxOverrides, e: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def OnDropDownOpened(self: win32more.Microsoft.UI.Xaml.Controls.IComboBoxOverrides, e: IInspectable) -> Void: ...
    @winrt_classmethod
    def get_IsEditableProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IComboBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsDropDownOpenProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IComboBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MaxDropDownHeightProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IComboBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HeaderProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IComboBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HeaderTemplateProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IComboBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PlaceholderTextProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IComboBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_LightDismissOverlayModeProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IComboBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsTextSearchEnabledProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IComboBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectionChangedTriggerProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IComboBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PlaceholderForegroundProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IComboBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TextProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IComboBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TextBoxStyleProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IComboBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DescriptionProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IComboBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    Description = property(get_Description, put_Description)
    Header = property(get_Header, put_Header)
    HeaderTemplate = property(get_HeaderTemplate, put_HeaderTemplate)
    IsDropDownOpen = property(get_IsDropDownOpen, put_IsDropDownOpen)
    IsEditable = property(get_IsEditable, put_IsEditable)
    IsSelectionBoxHighlighted = property(get_IsSelectionBoxHighlighted, None)
    IsTextSearchEnabled = property(get_IsTextSearchEnabled, put_IsTextSearchEnabled)
    LightDismissOverlayMode = property(get_LightDismissOverlayMode, put_LightDismissOverlayMode)
    MaxDropDownHeight = property(get_MaxDropDownHeight, put_MaxDropDownHeight)
    PlaceholderForeground = property(get_PlaceholderForeground, put_PlaceholderForeground)
    PlaceholderText = property(get_PlaceholderText, put_PlaceholderText)
    SelectionBoxItem = property(get_SelectionBoxItem, None)
    SelectionBoxItemTemplate = property(get_SelectionBoxItemTemplate, None)
    SelectionChangedTrigger = property(get_SelectionChangedTrigger, put_SelectionChangedTrigger)
    TemplateSettings = property(get_TemplateSettings, None)
    Text = property(get_Text, put_Text)
    TextBoxStyle = property(get_TextBoxStyle, put_TextBoxStyle)
    _ComboBox_Meta_.DescriptionProperty = property(get_DescriptionProperty, None)
    _ComboBox_Meta_.HeaderProperty = property(get_HeaderProperty, None)
    _ComboBox_Meta_.HeaderTemplateProperty = property(get_HeaderTemplateProperty, None)
    _ComboBox_Meta_.IsDropDownOpenProperty = property(get_IsDropDownOpenProperty, None)
    _ComboBox_Meta_.IsEditableProperty = property(get_IsEditableProperty, None)
    _ComboBox_Meta_.IsTextSearchEnabledProperty = property(get_IsTextSearchEnabledProperty, None)
    _ComboBox_Meta_.LightDismissOverlayModeProperty = property(get_LightDismissOverlayModeProperty, None)
    _ComboBox_Meta_.MaxDropDownHeightProperty = property(get_MaxDropDownHeightProperty, None)
    _ComboBox_Meta_.PlaceholderForegroundProperty = property(get_PlaceholderForegroundProperty, None)
    _ComboBox_Meta_.PlaceholderTextProperty = property(get_PlaceholderTextProperty, None)
    _ComboBox_Meta_.SelectionChangedTriggerProperty = property(get_SelectionChangedTriggerProperty, None)
    _ComboBox_Meta_.TextBoxStyleProperty = property(get_TextBoxStyleProperty, None)
    _ComboBox_Meta_.TextProperty = property(get_TextProperty, None)
    DropDownClosed = event(add_DropDownClosed, remove_DropDownClosed)
    DropDownOpened = event(add_DropDownOpened, remove_DropDownOpened)
    TextSubmitted = event(add_TextSubmitted, remove_TextSubmitted)
class ComboBoxItem(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.Controls.Primitives.SelectorItem
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IComboBoxItem
    _classid_ = 'Microsoft.UI.Xaml.Controls.ComboBoxItem'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.ComboBoxItem.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IComboBoxItemFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.ComboBoxItem: ...
class ComboBoxSelectionChangedTrigger(Enum, Int32):
    Committed = 0
    Always = 1
class ComboBoxTextSubmittedEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IComboBoxTextSubmittedEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.ComboBoxTextSubmittedEventArgs'
    @winrt_mixinmethod
    def get_Text(self: win32more.Microsoft.UI.Xaml.Controls.IComboBoxTextSubmittedEventArgs) -> hstr: ...
    @winrt_mixinmethod
    def get_Handled(self: win32more.Microsoft.UI.Xaml.Controls.IComboBoxTextSubmittedEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def put_Handled(self: win32more.Microsoft.UI.Xaml.Controls.IComboBoxTextSubmittedEventArgs, value: Boolean) -> Void: ...
    Handled = property(get_Handled, put_Handled)
    Text = property(get_Text, None)
class _CommandBar_Meta_(ComPtr.__class__):
    pass
class CommandBar(ComPtr, metaclass=_CommandBar_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.AppBar
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ICommandBar
    _classid_ = 'Microsoft.UI.Xaml.Controls.CommandBar'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.CommandBar.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.ICommandBarFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.CommandBar: ...
    @winrt_mixinmethod
    def get_PrimaryCommands(self: win32more.Microsoft.UI.Xaml.Controls.ICommandBar) -> win32more.Windows.Foundation.Collections.IObservableVector[win32more.Microsoft.UI.Xaml.Controls.ICommandBarElement]: ...
    @winrt_mixinmethod
    def get_SecondaryCommands(self: win32more.Microsoft.UI.Xaml.Controls.ICommandBar) -> win32more.Windows.Foundation.Collections.IObservableVector[win32more.Microsoft.UI.Xaml.Controls.ICommandBarElement]: ...
    @winrt_mixinmethod
    def get_CommandBarOverflowPresenterStyle(self: win32more.Microsoft.UI.Xaml.Controls.ICommandBar) -> win32more.Microsoft.UI.Xaml.Style: ...
    @winrt_mixinmethod
    def put_CommandBarOverflowPresenterStyle(self: win32more.Microsoft.UI.Xaml.Controls.ICommandBar, value: win32more.Microsoft.UI.Xaml.Style) -> Void: ...
    @winrt_mixinmethod
    def get_CommandBarTemplateSettings(self: win32more.Microsoft.UI.Xaml.Controls.ICommandBar) -> win32more.Microsoft.UI.Xaml.Controls.Primitives.CommandBarTemplateSettings: ...
    @winrt_mixinmethod
    def get_DefaultLabelPosition(self: win32more.Microsoft.UI.Xaml.Controls.ICommandBar) -> win32more.Microsoft.UI.Xaml.Controls.CommandBarDefaultLabelPosition: ...
    @winrt_mixinmethod
    def put_DefaultLabelPosition(self: win32more.Microsoft.UI.Xaml.Controls.ICommandBar, value: win32more.Microsoft.UI.Xaml.Controls.CommandBarDefaultLabelPosition) -> Void: ...
    @winrt_mixinmethod
    def get_OverflowButtonVisibility(self: win32more.Microsoft.UI.Xaml.Controls.ICommandBar) -> win32more.Microsoft.UI.Xaml.Controls.CommandBarOverflowButtonVisibility: ...
    @winrt_mixinmethod
    def put_OverflowButtonVisibility(self: win32more.Microsoft.UI.Xaml.Controls.ICommandBar, value: win32more.Microsoft.UI.Xaml.Controls.CommandBarOverflowButtonVisibility) -> Void: ...
    @winrt_mixinmethod
    def get_IsDynamicOverflowEnabled(self: win32more.Microsoft.UI.Xaml.Controls.ICommandBar) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsDynamicOverflowEnabled(self: win32more.Microsoft.UI.Xaml.Controls.ICommandBar, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def add_DynamicOverflowItemsChanging(self: win32more.Microsoft.UI.Xaml.Controls.ICommandBar, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.CommandBar, win32more.Microsoft.UI.Xaml.Controls.DynamicOverflowItemsChangingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_DynamicOverflowItemsChanging(self: win32more.Microsoft.UI.Xaml.Controls.ICommandBar, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def get_PrimaryCommandsProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICommandBarStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SecondaryCommandsProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICommandBarStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CommandBarOverflowPresenterStyleProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICommandBarStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DefaultLabelPositionProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICommandBarStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_OverflowButtonVisibilityProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICommandBarStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsDynamicOverflowEnabledProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ICommandBarStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    CommandBarOverflowPresenterStyle = property(get_CommandBarOverflowPresenterStyle, put_CommandBarOverflowPresenterStyle)
    CommandBarTemplateSettings = property(get_CommandBarTemplateSettings, None)
    DefaultLabelPosition = property(get_DefaultLabelPosition, put_DefaultLabelPosition)
    IsDynamicOverflowEnabled = property(get_IsDynamicOverflowEnabled, put_IsDynamicOverflowEnabled)
    OverflowButtonVisibility = property(get_OverflowButtonVisibility, put_OverflowButtonVisibility)
    PrimaryCommands = property(get_PrimaryCommands, None)
    SecondaryCommands = property(get_SecondaryCommands, None)
    _CommandBar_Meta_.CommandBarOverflowPresenterStyleProperty = property(get_CommandBarOverflowPresenterStyleProperty, None)
    _CommandBar_Meta_.DefaultLabelPositionProperty = property(get_DefaultLabelPositionProperty, None)
    _CommandBar_Meta_.IsDynamicOverflowEnabledProperty = property(get_IsDynamicOverflowEnabledProperty, None)
    _CommandBar_Meta_.OverflowButtonVisibilityProperty = property(get_OverflowButtonVisibilityProperty, None)
    _CommandBar_Meta_.PrimaryCommandsProperty = property(get_PrimaryCommandsProperty, None)
    _CommandBar_Meta_.SecondaryCommandsProperty = property(get_SecondaryCommandsProperty, None)
    DynamicOverflowItemsChanging = event(add_DynamicOverflowItemsChanging, remove_DynamicOverflowItemsChanging)
class CommandBarDefaultLabelPosition(Enum, Int32):
    Bottom = 0
    Right = 1
    Collapsed = 2
class CommandBarDynamicOverflowAction(Enum, Int32):
    AddingToOverflow = 0
    RemovingFromOverflow = 1
class CommandBarFlyout(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.Controls.Primitives.FlyoutBase
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ICommandBarFlyout
    _classid_ = 'Microsoft.UI.Xaml.Controls.CommandBarFlyout'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.CommandBarFlyout.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.ICommandBarFlyoutFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.CommandBarFlyout: ...
    @winrt_mixinmethod
    def get_PrimaryCommands(self: win32more.Microsoft.UI.Xaml.Controls.ICommandBarFlyout) -> win32more.Windows.Foundation.Collections.IObservableVector[win32more.Microsoft.UI.Xaml.Controls.ICommandBarElement]: ...
    @winrt_mixinmethod
    def get_SecondaryCommands(self: win32more.Microsoft.UI.Xaml.Controls.ICommandBarFlyout) -> win32more.Windows.Foundation.Collections.IObservableVector[win32more.Microsoft.UI.Xaml.Controls.ICommandBarElement]: ...
    @winrt_mixinmethod
    def get_AlwaysExpanded(self: win32more.Microsoft.UI.Xaml.Controls.ICommandBarFlyout2) -> Boolean: ...
    @winrt_mixinmethod
    def put_AlwaysExpanded(self: win32more.Microsoft.UI.Xaml.Controls.ICommandBarFlyout2, value: Boolean) -> Void: ...
    AlwaysExpanded = property(get_AlwaysExpanded, put_AlwaysExpanded)
    PrimaryCommands = property(get_PrimaryCommands, None)
    SecondaryCommands = property(get_SecondaryCommands, None)
class CommandBarLabelPosition(Enum, Int32):
    Default = 0
    Collapsed = 1
class CommandBarOverflowButtonVisibility(Enum, Int32):
    Auto = 0
    Visible = 1
    Collapsed = 2
class CommandBarOverflowPresenter(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.Controls.ItemsControl
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ICommandBarOverflowPresenter
    _classid_ = 'Microsoft.UI.Xaml.Controls.CommandBarOverflowPresenter'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.CommandBarOverflowPresenter.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.ICommandBarOverflowPresenterFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.CommandBarOverflowPresenter: ...
class ContainerContentChangingEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IContainerContentChangingEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.ContainerContentChangingEventArgs'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.ContainerContentChangingEventArgs.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Controls.ContainerContentChangingEventArgs: ...
    @winrt_mixinmethod
    def get_ItemContainer(self: win32more.Microsoft.UI.Xaml.Controls.IContainerContentChangingEventArgs) -> win32more.Microsoft.UI.Xaml.Controls.Primitives.SelectorItem: ...
    @winrt_mixinmethod
    def get_InRecycleQueue(self: win32more.Microsoft.UI.Xaml.Controls.IContainerContentChangingEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def get_ItemIndex(self: win32more.Microsoft.UI.Xaml.Controls.IContainerContentChangingEventArgs) -> Int32: ...
    @winrt_mixinmethod
    def get_Item(self: win32more.Microsoft.UI.Xaml.Controls.IContainerContentChangingEventArgs) -> IInspectable: ...
    @winrt_mixinmethod
    def get_Phase(self: win32more.Microsoft.UI.Xaml.Controls.IContainerContentChangingEventArgs) -> UInt32: ...
    @winrt_mixinmethod
    def get_Handled(self: win32more.Microsoft.UI.Xaml.Controls.IContainerContentChangingEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def put_Handled(self: win32more.Microsoft.UI.Xaml.Controls.IContainerContentChangingEventArgs, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def RegisterUpdateCallback(self: win32more.Microsoft.UI.Xaml.Controls.IContainerContentChangingEventArgs, callback: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.ListViewBase, win32more.Microsoft.UI.Xaml.Controls.ContainerContentChangingEventArgs]) -> Void: ...
    @winrt_mixinmethod
    def RegisterUpdateCallbackWithPhase(self: win32more.Microsoft.UI.Xaml.Controls.IContainerContentChangingEventArgs, callbackPhase: UInt32, callback: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.ListViewBase, win32more.Microsoft.UI.Xaml.Controls.ContainerContentChangingEventArgs]) -> Void: ...
    Handled = property(get_Handled, put_Handled)
    InRecycleQueue = property(get_InRecycleQueue, None)
    Item = property(get_Item, None)
    ItemContainer = property(get_ItemContainer, None)
    ItemIndex = property(get_ItemIndex, None)
    Phase = property(get_Phase, None)
class _ContentControl_Meta_(ComPtr.__class__):
    pass
class ContentControl(ComPtr, metaclass=_ContentControl_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.Control
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IContentControl
    _classid_ = 'Microsoft.UI.Xaml.Controls.ContentControl'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.ContentControl.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IContentControlFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.ContentControl: ...
    @winrt_mixinmethod
    def get_Content(self: win32more.Microsoft.UI.Xaml.Controls.IContentControl) -> IInspectable: ...
    @winrt_mixinmethod
    def put_Content(self: win32more.Microsoft.UI.Xaml.Controls.IContentControl, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_ContentTemplate(self: win32more.Microsoft.UI.Xaml.Controls.IContentControl) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def put_ContentTemplate(self: win32more.Microsoft.UI.Xaml.Controls.IContentControl, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_mixinmethod
    def get_ContentTemplateSelector(self: win32more.Microsoft.UI.Xaml.Controls.IContentControl) -> win32more.Microsoft.UI.Xaml.Controls.DataTemplateSelector: ...
    @winrt_mixinmethod
    def put_ContentTemplateSelector(self: win32more.Microsoft.UI.Xaml.Controls.IContentControl, value: win32more.Microsoft.UI.Xaml.Controls.DataTemplateSelector) -> Void: ...
    @winrt_mixinmethod
    def get_ContentTransitions(self: win32more.Microsoft.UI.Xaml.Controls.IContentControl) -> win32more.Microsoft.UI.Xaml.Media.Animation.TransitionCollection: ...
    @winrt_mixinmethod
    def put_ContentTransitions(self: win32more.Microsoft.UI.Xaml.Controls.IContentControl, value: win32more.Microsoft.UI.Xaml.Media.Animation.TransitionCollection) -> Void: ...
    @winrt_mixinmethod
    def get_ContentTemplateRoot(self: win32more.Microsoft.UI.Xaml.Controls.IContentControl) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_mixinmethod
    def OnContentChanged(self: win32more.Microsoft.UI.Xaml.Controls.IContentControlOverrides, oldContent: IInspectable, newContent: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def OnContentTemplateChanged(self: win32more.Microsoft.UI.Xaml.Controls.IContentControlOverrides, oldContentTemplate: win32more.Microsoft.UI.Xaml.DataTemplate, newContentTemplate: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_mixinmethod
    def OnContentTemplateSelectorChanged(self: win32more.Microsoft.UI.Xaml.Controls.IContentControlOverrides, oldContentTemplateSelector: win32more.Microsoft.UI.Xaml.Controls.DataTemplateSelector, newContentTemplateSelector: win32more.Microsoft.UI.Xaml.Controls.DataTemplateSelector) -> Void: ...
    @winrt_classmethod
    def get_ContentProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IContentControlStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ContentTemplateProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IContentControlStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ContentTemplateSelectorProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IContentControlStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ContentTransitionsProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IContentControlStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    Content = property(get_Content, put_Content)
    ContentTemplate = property(get_ContentTemplate, put_ContentTemplate)
    ContentTemplateRoot = property(get_ContentTemplateRoot, None)
    ContentTemplateSelector = property(get_ContentTemplateSelector, put_ContentTemplateSelector)
    ContentTransitions = property(get_ContentTransitions, put_ContentTransitions)
    _ContentControl_Meta_.ContentProperty = property(get_ContentProperty, None)
    _ContentControl_Meta_.ContentTemplateProperty = property(get_ContentTemplateProperty, None)
    _ContentControl_Meta_.ContentTemplateSelectorProperty = property(get_ContentTemplateSelectorProperty, None)
    _ContentControl_Meta_.ContentTransitionsProperty = property(get_ContentTransitionsProperty, None)
class _ContentDialog_Meta_(ComPtr.__class__):
    pass
class ContentDialog(ComPtr, metaclass=_ContentDialog_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.ContentControl
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IContentDialog
    _classid_ = 'Microsoft.UI.Xaml.Controls.ContentDialog'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.ContentDialog.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IContentDialogFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.ContentDialog: ...
    @winrt_mixinmethod
    def get_Title(self: win32more.Microsoft.UI.Xaml.Controls.IContentDialog) -> IInspectable: ...
    @winrt_mixinmethod
    def put_Title(self: win32more.Microsoft.UI.Xaml.Controls.IContentDialog, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_TitleTemplate(self: win32more.Microsoft.UI.Xaml.Controls.IContentDialog) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def put_TitleTemplate(self: win32more.Microsoft.UI.Xaml.Controls.IContentDialog, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_mixinmethod
    def get_FullSizeDesired(self: win32more.Microsoft.UI.Xaml.Controls.IContentDialog) -> Boolean: ...
    @winrt_mixinmethod
    def put_FullSizeDesired(self: win32more.Microsoft.UI.Xaml.Controls.IContentDialog, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_PrimaryButtonText(self: win32more.Microsoft.UI.Xaml.Controls.IContentDialog) -> hstr: ...
    @winrt_mixinmethod
    def put_PrimaryButtonText(self: win32more.Microsoft.UI.Xaml.Controls.IContentDialog, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def get_SecondaryButtonText(self: win32more.Microsoft.UI.Xaml.Controls.IContentDialog) -> hstr: ...
    @winrt_mixinmethod
    def put_SecondaryButtonText(self: win32more.Microsoft.UI.Xaml.Controls.IContentDialog, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def get_CloseButtonText(self: win32more.Microsoft.UI.Xaml.Controls.IContentDialog) -> hstr: ...
    @winrt_mixinmethod
    def put_CloseButtonText(self: win32more.Microsoft.UI.Xaml.Controls.IContentDialog, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def get_PrimaryButtonCommand(self: win32more.Microsoft.UI.Xaml.Controls.IContentDialog) -> win32more.Microsoft.UI.Xaml.Input.ICommand: ...
    @winrt_mixinmethod
    def put_PrimaryButtonCommand(self: win32more.Microsoft.UI.Xaml.Controls.IContentDialog, value: win32more.Microsoft.UI.Xaml.Input.ICommand) -> Void: ...
    @winrt_mixinmethod
    def get_SecondaryButtonCommand(self: win32more.Microsoft.UI.Xaml.Controls.IContentDialog) -> win32more.Microsoft.UI.Xaml.Input.ICommand: ...
    @winrt_mixinmethod
    def put_SecondaryButtonCommand(self: win32more.Microsoft.UI.Xaml.Controls.IContentDialog, value: win32more.Microsoft.UI.Xaml.Input.ICommand) -> Void: ...
    @winrt_mixinmethod
    def get_CloseButtonCommand(self: win32more.Microsoft.UI.Xaml.Controls.IContentDialog) -> win32more.Microsoft.UI.Xaml.Input.ICommand: ...
    @winrt_mixinmethod
    def put_CloseButtonCommand(self: win32more.Microsoft.UI.Xaml.Controls.IContentDialog, value: win32more.Microsoft.UI.Xaml.Input.ICommand) -> Void: ...
    @winrt_mixinmethod
    def get_PrimaryButtonCommandParameter(self: win32more.Microsoft.UI.Xaml.Controls.IContentDialog) -> IInspectable: ...
    @winrt_mixinmethod
    def put_PrimaryButtonCommandParameter(self: win32more.Microsoft.UI.Xaml.Controls.IContentDialog, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_SecondaryButtonCommandParameter(self: win32more.Microsoft.UI.Xaml.Controls.IContentDialog) -> IInspectable: ...
    @winrt_mixinmethod
    def put_SecondaryButtonCommandParameter(self: win32more.Microsoft.UI.Xaml.Controls.IContentDialog, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_CloseButtonCommandParameter(self: win32more.Microsoft.UI.Xaml.Controls.IContentDialog) -> IInspectable: ...
    @winrt_mixinmethod
    def put_CloseButtonCommandParameter(self: win32more.Microsoft.UI.Xaml.Controls.IContentDialog, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_IsPrimaryButtonEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IContentDialog) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsPrimaryButtonEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IContentDialog, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsSecondaryButtonEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IContentDialog) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsSecondaryButtonEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IContentDialog, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_PrimaryButtonStyle(self: win32more.Microsoft.UI.Xaml.Controls.IContentDialog) -> win32more.Microsoft.UI.Xaml.Style: ...
    @winrt_mixinmethod
    def put_PrimaryButtonStyle(self: win32more.Microsoft.UI.Xaml.Controls.IContentDialog, value: win32more.Microsoft.UI.Xaml.Style) -> Void: ...
    @winrt_mixinmethod
    def get_SecondaryButtonStyle(self: win32more.Microsoft.UI.Xaml.Controls.IContentDialog) -> win32more.Microsoft.UI.Xaml.Style: ...
    @winrt_mixinmethod
    def put_SecondaryButtonStyle(self: win32more.Microsoft.UI.Xaml.Controls.IContentDialog, value: win32more.Microsoft.UI.Xaml.Style) -> Void: ...
    @winrt_mixinmethod
    def get_CloseButtonStyle(self: win32more.Microsoft.UI.Xaml.Controls.IContentDialog) -> win32more.Microsoft.UI.Xaml.Style: ...
    @winrt_mixinmethod
    def put_CloseButtonStyle(self: win32more.Microsoft.UI.Xaml.Controls.IContentDialog, value: win32more.Microsoft.UI.Xaml.Style) -> Void: ...
    @winrt_mixinmethod
    def get_DefaultButton(self: win32more.Microsoft.UI.Xaml.Controls.IContentDialog) -> win32more.Microsoft.UI.Xaml.Controls.ContentDialogButton: ...
    @winrt_mixinmethod
    def put_DefaultButton(self: win32more.Microsoft.UI.Xaml.Controls.IContentDialog, value: win32more.Microsoft.UI.Xaml.Controls.ContentDialogButton) -> Void: ...
    @winrt_mixinmethod
    def add_Closing(self: win32more.Microsoft.UI.Xaml.Controls.IContentDialog, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.ContentDialog, win32more.Microsoft.UI.Xaml.Controls.ContentDialogClosingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Closing(self: win32more.Microsoft.UI.Xaml.Controls.IContentDialog, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_Closed(self: win32more.Microsoft.UI.Xaml.Controls.IContentDialog, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.ContentDialog, win32more.Microsoft.UI.Xaml.Controls.ContentDialogClosedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Closed(self: win32more.Microsoft.UI.Xaml.Controls.IContentDialog, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_Opened(self: win32more.Microsoft.UI.Xaml.Controls.IContentDialog, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.ContentDialog, win32more.Microsoft.UI.Xaml.Controls.ContentDialogOpenedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Opened(self: win32more.Microsoft.UI.Xaml.Controls.IContentDialog, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_PrimaryButtonClick(self: win32more.Microsoft.UI.Xaml.Controls.IContentDialog, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.ContentDialog, win32more.Microsoft.UI.Xaml.Controls.ContentDialogButtonClickEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_PrimaryButtonClick(self: win32more.Microsoft.UI.Xaml.Controls.IContentDialog, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_SecondaryButtonClick(self: win32more.Microsoft.UI.Xaml.Controls.IContentDialog, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.ContentDialog, win32more.Microsoft.UI.Xaml.Controls.ContentDialogButtonClickEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_SecondaryButtonClick(self: win32more.Microsoft.UI.Xaml.Controls.IContentDialog, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_CloseButtonClick(self: win32more.Microsoft.UI.Xaml.Controls.IContentDialog, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.ContentDialog, win32more.Microsoft.UI.Xaml.Controls.ContentDialogButtonClickEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_CloseButtonClick(self: win32more.Microsoft.UI.Xaml.Controls.IContentDialog, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def Hide(self: win32more.Microsoft.UI.Xaml.Controls.IContentDialog) -> Void: ...
    @winrt_mixinmethod
    def ShowAsync(self: win32more.Microsoft.UI.Xaml.Controls.IContentDialog) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Microsoft.UI.Xaml.Controls.ContentDialogResult]: ...
    @winrt_mixinmethod
    def ShowAsyncWithPlacement(self: win32more.Microsoft.UI.Xaml.Controls.IContentDialog, placement: win32more.Microsoft.UI.Xaml.Controls.ContentDialogPlacement) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Microsoft.UI.Xaml.Controls.ContentDialogResult]: ...
    @winrt_classmethod
    def get_TitleProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IContentDialogStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TitleTemplateProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IContentDialogStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FullSizeDesiredProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IContentDialogStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PrimaryButtonTextProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IContentDialogStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SecondaryButtonTextProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IContentDialogStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CloseButtonTextProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IContentDialogStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PrimaryButtonCommandProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IContentDialogStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SecondaryButtonCommandProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IContentDialogStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CloseButtonCommandProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IContentDialogStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PrimaryButtonCommandParameterProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IContentDialogStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SecondaryButtonCommandParameterProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IContentDialogStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CloseButtonCommandParameterProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IContentDialogStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsPrimaryButtonEnabledProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IContentDialogStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsSecondaryButtonEnabledProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IContentDialogStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PrimaryButtonStyleProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IContentDialogStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SecondaryButtonStyleProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IContentDialogStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CloseButtonStyleProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IContentDialogStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DefaultButtonProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IContentDialogStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    CloseButtonCommand = property(get_CloseButtonCommand, put_CloseButtonCommand)
    CloseButtonCommandParameter = property(get_CloseButtonCommandParameter, put_CloseButtonCommandParameter)
    CloseButtonStyle = property(get_CloseButtonStyle, put_CloseButtonStyle)
    CloseButtonText = property(get_CloseButtonText, put_CloseButtonText)
    DefaultButton = property(get_DefaultButton, put_DefaultButton)
    FullSizeDesired = property(get_FullSizeDesired, put_FullSizeDesired)
    IsPrimaryButtonEnabled = property(get_IsPrimaryButtonEnabled, put_IsPrimaryButtonEnabled)
    IsSecondaryButtonEnabled = property(get_IsSecondaryButtonEnabled, put_IsSecondaryButtonEnabled)
    PrimaryButtonCommand = property(get_PrimaryButtonCommand, put_PrimaryButtonCommand)
    PrimaryButtonCommandParameter = property(get_PrimaryButtonCommandParameter, put_PrimaryButtonCommandParameter)
    PrimaryButtonStyle = property(get_PrimaryButtonStyle, put_PrimaryButtonStyle)
    PrimaryButtonText = property(get_PrimaryButtonText, put_PrimaryButtonText)
    SecondaryButtonCommand = property(get_SecondaryButtonCommand, put_SecondaryButtonCommand)
    SecondaryButtonCommandParameter = property(get_SecondaryButtonCommandParameter, put_SecondaryButtonCommandParameter)
    SecondaryButtonStyle = property(get_SecondaryButtonStyle, put_SecondaryButtonStyle)
    SecondaryButtonText = property(get_SecondaryButtonText, put_SecondaryButtonText)
    Title = property(get_Title, put_Title)
    TitleTemplate = property(get_TitleTemplate, put_TitleTemplate)
    _ContentDialog_Meta_.CloseButtonCommandParameterProperty = property(get_CloseButtonCommandParameterProperty, None)
    _ContentDialog_Meta_.CloseButtonCommandProperty = property(get_CloseButtonCommandProperty, None)
    _ContentDialog_Meta_.CloseButtonStyleProperty = property(get_CloseButtonStyleProperty, None)
    _ContentDialog_Meta_.CloseButtonTextProperty = property(get_CloseButtonTextProperty, None)
    _ContentDialog_Meta_.DefaultButtonProperty = property(get_DefaultButtonProperty, None)
    _ContentDialog_Meta_.FullSizeDesiredProperty = property(get_FullSizeDesiredProperty, None)
    _ContentDialog_Meta_.IsPrimaryButtonEnabledProperty = property(get_IsPrimaryButtonEnabledProperty, None)
    _ContentDialog_Meta_.IsSecondaryButtonEnabledProperty = property(get_IsSecondaryButtonEnabledProperty, None)
    _ContentDialog_Meta_.PrimaryButtonCommandParameterProperty = property(get_PrimaryButtonCommandParameterProperty, None)
    _ContentDialog_Meta_.PrimaryButtonCommandProperty = property(get_PrimaryButtonCommandProperty, None)
    _ContentDialog_Meta_.PrimaryButtonStyleProperty = property(get_PrimaryButtonStyleProperty, None)
    _ContentDialog_Meta_.PrimaryButtonTextProperty = property(get_PrimaryButtonTextProperty, None)
    _ContentDialog_Meta_.SecondaryButtonCommandParameterProperty = property(get_SecondaryButtonCommandParameterProperty, None)
    _ContentDialog_Meta_.SecondaryButtonCommandProperty = property(get_SecondaryButtonCommandProperty, None)
    _ContentDialog_Meta_.SecondaryButtonStyleProperty = property(get_SecondaryButtonStyleProperty, None)
    _ContentDialog_Meta_.SecondaryButtonTextProperty = property(get_SecondaryButtonTextProperty, None)
    _ContentDialog_Meta_.TitleProperty = property(get_TitleProperty, None)
    _ContentDialog_Meta_.TitleTemplateProperty = property(get_TitleTemplateProperty, None)
    CloseButtonClick = event(add_CloseButtonClick, remove_CloseButtonClick)
    Closed = event(add_Closed, remove_Closed)
    Closing = event(add_Closing, remove_Closing)
    Opened = event(add_Opened, remove_Opened)
    PrimaryButtonClick = event(add_PrimaryButtonClick, remove_PrimaryButtonClick)
    SecondaryButtonClick = event(add_SecondaryButtonClick, remove_SecondaryButtonClick)
class ContentDialogButton(Enum, Int32):
    None_ = 0
    Primary = 1
    Secondary = 2
    Close = 3
class ContentDialogButtonClickDeferral(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IContentDialogButtonClickDeferral
    _classid_ = 'Microsoft.UI.Xaml.Controls.ContentDialogButtonClickDeferral'
    @winrt_mixinmethod
    def Complete(self: win32more.Microsoft.UI.Xaml.Controls.IContentDialogButtonClickDeferral) -> Void: ...
class ContentDialogButtonClickEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IContentDialogButtonClickEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.ContentDialogButtonClickEventArgs'
    @winrt_mixinmethod
    def get_Cancel(self: win32more.Microsoft.UI.Xaml.Controls.IContentDialogButtonClickEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def put_Cancel(self: win32more.Microsoft.UI.Xaml.Controls.IContentDialogButtonClickEventArgs, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def GetDeferral(self: win32more.Microsoft.UI.Xaml.Controls.IContentDialogButtonClickEventArgs) -> win32more.Microsoft.UI.Xaml.Controls.ContentDialogButtonClickDeferral: ...
    Cancel = property(get_Cancel, put_Cancel)
class ContentDialogClosedEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IContentDialogClosedEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.ContentDialogClosedEventArgs'
    @winrt_mixinmethod
    def get_Result(self: win32more.Microsoft.UI.Xaml.Controls.IContentDialogClosedEventArgs) -> win32more.Microsoft.UI.Xaml.Controls.ContentDialogResult: ...
    Result = property(get_Result, None)
class ContentDialogClosingDeferral(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IContentDialogClosingDeferral
    _classid_ = 'Microsoft.UI.Xaml.Controls.ContentDialogClosingDeferral'
    @winrt_mixinmethod
    def Complete(self: win32more.Microsoft.UI.Xaml.Controls.IContentDialogClosingDeferral) -> Void: ...
class ContentDialogClosingEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IContentDialogClosingEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.ContentDialogClosingEventArgs'
    @winrt_mixinmethod
    def get_Result(self: win32more.Microsoft.UI.Xaml.Controls.IContentDialogClosingEventArgs) -> win32more.Microsoft.UI.Xaml.Controls.ContentDialogResult: ...
    @winrt_mixinmethod
    def get_Cancel(self: win32more.Microsoft.UI.Xaml.Controls.IContentDialogClosingEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def put_Cancel(self: win32more.Microsoft.UI.Xaml.Controls.IContentDialogClosingEventArgs, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def GetDeferral(self: win32more.Microsoft.UI.Xaml.Controls.IContentDialogClosingEventArgs) -> win32more.Microsoft.UI.Xaml.Controls.ContentDialogClosingDeferral: ...
    Cancel = property(get_Cancel, put_Cancel)
    Result = property(get_Result, None)
class ContentDialogOpenedEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IContentDialogOpenedEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.ContentDialogOpenedEventArgs'
class ContentDialogPlacement(Enum, Int32):
    Popup = 0
    InPlace = 1
class ContentDialogResult(Enum, Int32):
    None_ = 0
    Primary = 1
    Secondary = 2
class _ContentPresenter_Meta_(ComPtr.__class__):
    pass
class ContentPresenter(ComPtr, metaclass=_ContentPresenter_Meta_):
    extends: win32more.Microsoft.UI.Xaml.FrameworkElement
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IContentPresenter
    _classid_ = 'Microsoft.UI.Xaml.Controls.ContentPresenter'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.ContentPresenter.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IContentPresenterFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.ContentPresenter: ...
    @winrt_mixinmethod
    def get_Content(self: win32more.Microsoft.UI.Xaml.Controls.IContentPresenter) -> IInspectable: ...
    @winrt_mixinmethod
    def put_Content(self: win32more.Microsoft.UI.Xaml.Controls.IContentPresenter, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_ContentTemplate(self: win32more.Microsoft.UI.Xaml.Controls.IContentPresenter) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def put_ContentTemplate(self: win32more.Microsoft.UI.Xaml.Controls.IContentPresenter, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_mixinmethod
    def get_ContentTemplateSelector(self: win32more.Microsoft.UI.Xaml.Controls.IContentPresenter) -> win32more.Microsoft.UI.Xaml.Controls.DataTemplateSelector: ...
    @winrt_mixinmethod
    def put_ContentTemplateSelector(self: win32more.Microsoft.UI.Xaml.Controls.IContentPresenter, value: win32more.Microsoft.UI.Xaml.Controls.DataTemplateSelector) -> Void: ...
    @winrt_mixinmethod
    def get_ContentTransitions(self: win32more.Microsoft.UI.Xaml.Controls.IContentPresenter) -> win32more.Microsoft.UI.Xaml.Media.Animation.TransitionCollection: ...
    @winrt_mixinmethod
    def put_ContentTransitions(self: win32more.Microsoft.UI.Xaml.Controls.IContentPresenter, value: win32more.Microsoft.UI.Xaml.Media.Animation.TransitionCollection) -> Void: ...
    @winrt_mixinmethod
    def get_FontSize(self: win32more.Microsoft.UI.Xaml.Controls.IContentPresenter) -> Double: ...
    @winrt_mixinmethod
    def put_FontSize(self: win32more.Microsoft.UI.Xaml.Controls.IContentPresenter, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_FontFamily(self: win32more.Microsoft.UI.Xaml.Controls.IContentPresenter) -> win32more.Microsoft.UI.Xaml.Media.FontFamily: ...
    @winrt_mixinmethod
    def put_FontFamily(self: win32more.Microsoft.UI.Xaml.Controls.IContentPresenter, value: win32more.Microsoft.UI.Xaml.Media.FontFamily) -> Void: ...
    @winrt_mixinmethod
    def get_FontWeight(self: win32more.Microsoft.UI.Xaml.Controls.IContentPresenter) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_mixinmethod
    def put_FontWeight(self: win32more.Microsoft.UI.Xaml.Controls.IContentPresenter, value: win32more.Windows.UI.Text.FontWeight) -> Void: ...
    @winrt_mixinmethod
    def get_FontStyle(self: win32more.Microsoft.UI.Xaml.Controls.IContentPresenter) -> win32more.Windows.UI.Text.FontStyle: ...
    @winrt_mixinmethod
    def put_FontStyle(self: win32more.Microsoft.UI.Xaml.Controls.IContentPresenter, value: win32more.Windows.UI.Text.FontStyle) -> Void: ...
    @winrt_mixinmethod
    def get_FontStretch(self: win32more.Microsoft.UI.Xaml.Controls.IContentPresenter) -> win32more.Windows.UI.Text.FontStretch: ...
    @winrt_mixinmethod
    def put_FontStretch(self: win32more.Microsoft.UI.Xaml.Controls.IContentPresenter, value: win32more.Windows.UI.Text.FontStretch) -> Void: ...
    @winrt_mixinmethod
    def get_CharacterSpacing(self: win32more.Microsoft.UI.Xaml.Controls.IContentPresenter) -> Int32: ...
    @winrt_mixinmethod
    def put_CharacterSpacing(self: win32more.Microsoft.UI.Xaml.Controls.IContentPresenter, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_Foreground(self: win32more.Microsoft.UI.Xaml.Controls.IContentPresenter) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_Foreground(self: win32more.Microsoft.UI.Xaml.Controls.IContentPresenter, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_OpticalMarginAlignment(self: win32more.Microsoft.UI.Xaml.Controls.IContentPresenter) -> win32more.Microsoft.UI.Xaml.OpticalMarginAlignment: ...
    @winrt_mixinmethod
    def put_OpticalMarginAlignment(self: win32more.Microsoft.UI.Xaml.Controls.IContentPresenter, value: win32more.Microsoft.UI.Xaml.OpticalMarginAlignment) -> Void: ...
    @winrt_mixinmethod
    def get_TextLineBounds(self: win32more.Microsoft.UI.Xaml.Controls.IContentPresenter) -> win32more.Microsoft.UI.Xaml.TextLineBounds: ...
    @winrt_mixinmethod
    def put_TextLineBounds(self: win32more.Microsoft.UI.Xaml.Controls.IContentPresenter, value: win32more.Microsoft.UI.Xaml.TextLineBounds) -> Void: ...
    @winrt_mixinmethod
    def get_IsTextScaleFactorEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IContentPresenter) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsTextScaleFactorEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IContentPresenter, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_BackgroundTransition(self: win32more.Microsoft.UI.Xaml.Controls.IContentPresenter) -> win32more.Microsoft.UI.Xaml.BrushTransition: ...
    @winrt_mixinmethod
    def put_BackgroundTransition(self: win32more.Microsoft.UI.Xaml.Controls.IContentPresenter, value: win32more.Microsoft.UI.Xaml.BrushTransition) -> Void: ...
    @winrt_mixinmethod
    def get_TextWrapping(self: win32more.Microsoft.UI.Xaml.Controls.IContentPresenter) -> win32more.Microsoft.UI.Xaml.TextWrapping: ...
    @winrt_mixinmethod
    def put_TextWrapping(self: win32more.Microsoft.UI.Xaml.Controls.IContentPresenter, value: win32more.Microsoft.UI.Xaml.TextWrapping) -> Void: ...
    @winrt_mixinmethod
    def get_MaxLines(self: win32more.Microsoft.UI.Xaml.Controls.IContentPresenter) -> Int32: ...
    @winrt_mixinmethod
    def put_MaxLines(self: win32more.Microsoft.UI.Xaml.Controls.IContentPresenter, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_LineStackingStrategy(self: win32more.Microsoft.UI.Xaml.Controls.IContentPresenter) -> win32more.Microsoft.UI.Xaml.LineStackingStrategy: ...
    @winrt_mixinmethod
    def put_LineStackingStrategy(self: win32more.Microsoft.UI.Xaml.Controls.IContentPresenter, value: win32more.Microsoft.UI.Xaml.LineStackingStrategy) -> Void: ...
    @winrt_mixinmethod
    def get_LineHeight(self: win32more.Microsoft.UI.Xaml.Controls.IContentPresenter) -> Double: ...
    @winrt_mixinmethod
    def put_LineHeight(self: win32more.Microsoft.UI.Xaml.Controls.IContentPresenter, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_BorderBrush(self: win32more.Microsoft.UI.Xaml.Controls.IContentPresenter) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_BorderBrush(self: win32more.Microsoft.UI.Xaml.Controls.IContentPresenter, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_BorderThickness(self: win32more.Microsoft.UI.Xaml.Controls.IContentPresenter) -> win32more.Microsoft.UI.Xaml.Thickness: ...
    @winrt_mixinmethod
    def put_BorderThickness(self: win32more.Microsoft.UI.Xaml.Controls.IContentPresenter, value: win32more.Microsoft.UI.Xaml.Thickness) -> Void: ...
    @winrt_mixinmethod
    def get_CornerRadius(self: win32more.Microsoft.UI.Xaml.Controls.IContentPresenter) -> win32more.Microsoft.UI.Xaml.CornerRadius: ...
    @winrt_mixinmethod
    def put_CornerRadius(self: win32more.Microsoft.UI.Xaml.Controls.IContentPresenter, value: win32more.Microsoft.UI.Xaml.CornerRadius) -> Void: ...
    @winrt_mixinmethod
    def get_Padding(self: win32more.Microsoft.UI.Xaml.Controls.IContentPresenter) -> win32more.Microsoft.UI.Xaml.Thickness: ...
    @winrt_mixinmethod
    def put_Padding(self: win32more.Microsoft.UI.Xaml.Controls.IContentPresenter, value: win32more.Microsoft.UI.Xaml.Thickness) -> Void: ...
    @winrt_mixinmethod
    def get_Background(self: win32more.Microsoft.UI.Xaml.Controls.IContentPresenter) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_Background(self: win32more.Microsoft.UI.Xaml.Controls.IContentPresenter, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_BackgroundSizing(self: win32more.Microsoft.UI.Xaml.Controls.IContentPresenter) -> win32more.Microsoft.UI.Xaml.Controls.BackgroundSizing: ...
    @winrt_mixinmethod
    def put_BackgroundSizing(self: win32more.Microsoft.UI.Xaml.Controls.IContentPresenter, value: win32more.Microsoft.UI.Xaml.Controls.BackgroundSizing) -> Void: ...
    @winrt_mixinmethod
    def get_HorizontalContentAlignment(self: win32more.Microsoft.UI.Xaml.Controls.IContentPresenter) -> win32more.Microsoft.UI.Xaml.HorizontalAlignment: ...
    @winrt_mixinmethod
    def put_HorizontalContentAlignment(self: win32more.Microsoft.UI.Xaml.Controls.IContentPresenter, value: win32more.Microsoft.UI.Xaml.HorizontalAlignment) -> Void: ...
    @winrt_mixinmethod
    def get_VerticalContentAlignment(self: win32more.Microsoft.UI.Xaml.Controls.IContentPresenter) -> win32more.Microsoft.UI.Xaml.VerticalAlignment: ...
    @winrt_mixinmethod
    def put_VerticalContentAlignment(self: win32more.Microsoft.UI.Xaml.Controls.IContentPresenter, value: win32more.Microsoft.UI.Xaml.VerticalAlignment) -> Void: ...
    @winrt_mixinmethod
    def OnContentTemplateChanged(self: win32more.Microsoft.UI.Xaml.Controls.IContentPresenterOverrides, oldContentTemplate: win32more.Microsoft.UI.Xaml.DataTemplate, newContentTemplate: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_mixinmethod
    def OnContentTemplateSelectorChanged(self: win32more.Microsoft.UI.Xaml.Controls.IContentPresenterOverrides, oldContentTemplateSelector: win32more.Microsoft.UI.Xaml.Controls.DataTemplateSelector, newContentTemplateSelector: win32more.Microsoft.UI.Xaml.Controls.DataTemplateSelector) -> Void: ...
    @winrt_classmethod
    def get_ContentProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IContentPresenterStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ContentTemplateProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IContentPresenterStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ContentTemplateSelectorProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IContentPresenterStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ContentTransitionsProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IContentPresenterStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FontSizeProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IContentPresenterStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FontFamilyProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IContentPresenterStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FontWeightProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IContentPresenterStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FontStyleProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IContentPresenterStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FontStretchProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IContentPresenterStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CharacterSpacingProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IContentPresenterStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ForegroundProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IContentPresenterStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_OpticalMarginAlignmentProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IContentPresenterStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TextLineBoundsProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IContentPresenterStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsTextScaleFactorEnabledProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IContentPresenterStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TextWrappingProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IContentPresenterStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MaxLinesProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IContentPresenterStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_LineStackingStrategyProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IContentPresenterStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_LineHeightProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IContentPresenterStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_BorderBrushProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IContentPresenterStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_BorderThicknessProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IContentPresenterStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CornerRadiusProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IContentPresenterStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PaddingProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IContentPresenterStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_BackgroundProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IContentPresenterStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_BackgroundSizingProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IContentPresenterStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HorizontalContentAlignmentProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IContentPresenterStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_VerticalContentAlignmentProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IContentPresenterStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    Background = property(get_Background, put_Background)
    BackgroundSizing = property(get_BackgroundSizing, put_BackgroundSizing)
    BackgroundTransition = property(get_BackgroundTransition, put_BackgroundTransition)
    BorderBrush = property(get_BorderBrush, put_BorderBrush)
    BorderThickness = property(get_BorderThickness, put_BorderThickness)
    CharacterSpacing = property(get_CharacterSpacing, put_CharacterSpacing)
    Content = property(get_Content, put_Content)
    ContentTemplate = property(get_ContentTemplate, put_ContentTemplate)
    ContentTemplateSelector = property(get_ContentTemplateSelector, put_ContentTemplateSelector)
    ContentTransitions = property(get_ContentTransitions, put_ContentTransitions)
    CornerRadius = property(get_CornerRadius, put_CornerRadius)
    FontFamily = property(get_FontFamily, put_FontFamily)
    FontSize = property(get_FontSize, put_FontSize)
    FontStretch = property(get_FontStretch, put_FontStretch)
    FontStyle = property(get_FontStyle, put_FontStyle)
    FontWeight = property(get_FontWeight, put_FontWeight)
    Foreground = property(get_Foreground, put_Foreground)
    HorizontalContentAlignment = property(get_HorizontalContentAlignment, put_HorizontalContentAlignment)
    IsTextScaleFactorEnabled = property(get_IsTextScaleFactorEnabled, put_IsTextScaleFactorEnabled)
    LineHeight = property(get_LineHeight, put_LineHeight)
    LineStackingStrategy = property(get_LineStackingStrategy, put_LineStackingStrategy)
    MaxLines = property(get_MaxLines, put_MaxLines)
    OpticalMarginAlignment = property(get_OpticalMarginAlignment, put_OpticalMarginAlignment)
    Padding = property(get_Padding, put_Padding)
    TextLineBounds = property(get_TextLineBounds, put_TextLineBounds)
    TextWrapping = property(get_TextWrapping, put_TextWrapping)
    VerticalContentAlignment = property(get_VerticalContentAlignment, put_VerticalContentAlignment)
    _ContentPresenter_Meta_.BackgroundProperty = property(get_BackgroundProperty, None)
    _ContentPresenter_Meta_.BackgroundSizingProperty = property(get_BackgroundSizingProperty, None)
    _ContentPresenter_Meta_.BorderBrushProperty = property(get_BorderBrushProperty, None)
    _ContentPresenter_Meta_.BorderThicknessProperty = property(get_BorderThicknessProperty, None)
    _ContentPresenter_Meta_.CharacterSpacingProperty = property(get_CharacterSpacingProperty, None)
    _ContentPresenter_Meta_.ContentProperty = property(get_ContentProperty, None)
    _ContentPresenter_Meta_.ContentTemplateProperty = property(get_ContentTemplateProperty, None)
    _ContentPresenter_Meta_.ContentTemplateSelectorProperty = property(get_ContentTemplateSelectorProperty, None)
    _ContentPresenter_Meta_.ContentTransitionsProperty = property(get_ContentTransitionsProperty, None)
    _ContentPresenter_Meta_.CornerRadiusProperty = property(get_CornerRadiusProperty, None)
    _ContentPresenter_Meta_.FontFamilyProperty = property(get_FontFamilyProperty, None)
    _ContentPresenter_Meta_.FontSizeProperty = property(get_FontSizeProperty, None)
    _ContentPresenter_Meta_.FontStretchProperty = property(get_FontStretchProperty, None)
    _ContentPresenter_Meta_.FontStyleProperty = property(get_FontStyleProperty, None)
    _ContentPresenter_Meta_.FontWeightProperty = property(get_FontWeightProperty, None)
    _ContentPresenter_Meta_.ForegroundProperty = property(get_ForegroundProperty, None)
    _ContentPresenter_Meta_.HorizontalContentAlignmentProperty = property(get_HorizontalContentAlignmentProperty, None)
    _ContentPresenter_Meta_.IsTextScaleFactorEnabledProperty = property(get_IsTextScaleFactorEnabledProperty, None)
    _ContentPresenter_Meta_.LineHeightProperty = property(get_LineHeightProperty, None)
    _ContentPresenter_Meta_.LineStackingStrategyProperty = property(get_LineStackingStrategyProperty, None)
    _ContentPresenter_Meta_.MaxLinesProperty = property(get_MaxLinesProperty, None)
    _ContentPresenter_Meta_.OpticalMarginAlignmentProperty = property(get_OpticalMarginAlignmentProperty, None)
    _ContentPresenter_Meta_.PaddingProperty = property(get_PaddingProperty, None)
    _ContentPresenter_Meta_.TextLineBoundsProperty = property(get_TextLineBoundsProperty, None)
    _ContentPresenter_Meta_.TextWrappingProperty = property(get_TextWrappingProperty, None)
    _ContentPresenter_Meta_.VerticalContentAlignmentProperty = property(get_VerticalContentAlignmentProperty, None)
class ContextMenuEventArgs(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.RoutedEventArgs
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IContextMenuEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.ContextMenuEventArgs'
    @winrt_mixinmethod
    def get_Handled(self: win32more.Microsoft.UI.Xaml.Controls.IContextMenuEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def put_Handled(self: win32more.Microsoft.UI.Xaml.Controls.IContextMenuEventArgs, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_CursorLeft(self: win32more.Microsoft.UI.Xaml.Controls.IContextMenuEventArgs) -> Double: ...
    @winrt_mixinmethod
    def get_CursorTop(self: win32more.Microsoft.UI.Xaml.Controls.IContextMenuEventArgs) -> Double: ...
    CursorLeft = property(get_CursorLeft, None)
    CursorTop = property(get_CursorTop, None)
    Handled = property(get_Handled, put_Handled)
class ContextMenuOpeningEventHandler(MulticastDelegate):
    extends: IUnknown
    _iid_ = Guid('{d010ff61-4067-526a-95a3-517577bc5273}')
    @winrt_commethod(3)
    def Invoke(self, sender: IInspectable, e: win32more.Microsoft.UI.Xaml.Controls.ContextMenuEventArgs) -> Void: ...
class _Control_Meta_(ComPtr.__class__):
    pass
class Control(ComPtr, metaclass=_Control_Meta_):
    extends: win32more.Microsoft.UI.Xaml.FrameworkElement
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IControl
    _classid_ = 'Microsoft.UI.Xaml.Controls.Control'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.Control.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IControlFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.Control: ...
    @winrt_mixinmethod
    def get_IsFocusEngagementEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IControl) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsFocusEngagementEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IControl, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsFocusEngaged(self: win32more.Microsoft.UI.Xaml.Controls.IControl) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsFocusEngaged(self: win32more.Microsoft.UI.Xaml.Controls.IControl, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_RequiresPointer(self: win32more.Microsoft.UI.Xaml.Controls.IControl) -> win32more.Microsoft.UI.Xaml.Controls.RequiresPointer: ...
    @winrt_mixinmethod
    def put_RequiresPointer(self: win32more.Microsoft.UI.Xaml.Controls.IControl, value: win32more.Microsoft.UI.Xaml.Controls.RequiresPointer) -> Void: ...
    @winrt_mixinmethod
    def get_FontSize(self: win32more.Microsoft.UI.Xaml.Controls.IControl) -> Double: ...
    @winrt_mixinmethod
    def put_FontSize(self: win32more.Microsoft.UI.Xaml.Controls.IControl, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_FontFamily(self: win32more.Microsoft.UI.Xaml.Controls.IControl) -> win32more.Microsoft.UI.Xaml.Media.FontFamily: ...
    @winrt_mixinmethod
    def put_FontFamily(self: win32more.Microsoft.UI.Xaml.Controls.IControl, value: win32more.Microsoft.UI.Xaml.Media.FontFamily) -> Void: ...
    @winrt_mixinmethod
    def get_FontWeight(self: win32more.Microsoft.UI.Xaml.Controls.IControl) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_mixinmethod
    def put_FontWeight(self: win32more.Microsoft.UI.Xaml.Controls.IControl, value: win32more.Windows.UI.Text.FontWeight) -> Void: ...
    @winrt_mixinmethod
    def get_FontStyle(self: win32more.Microsoft.UI.Xaml.Controls.IControl) -> win32more.Windows.UI.Text.FontStyle: ...
    @winrt_mixinmethod
    def put_FontStyle(self: win32more.Microsoft.UI.Xaml.Controls.IControl, value: win32more.Windows.UI.Text.FontStyle) -> Void: ...
    @winrt_mixinmethod
    def get_FontStretch(self: win32more.Microsoft.UI.Xaml.Controls.IControl) -> win32more.Windows.UI.Text.FontStretch: ...
    @winrt_mixinmethod
    def put_FontStretch(self: win32more.Microsoft.UI.Xaml.Controls.IControl, value: win32more.Windows.UI.Text.FontStretch) -> Void: ...
    @winrt_mixinmethod
    def get_CharacterSpacing(self: win32more.Microsoft.UI.Xaml.Controls.IControl) -> Int32: ...
    @winrt_mixinmethod
    def put_CharacterSpacing(self: win32more.Microsoft.UI.Xaml.Controls.IControl, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_Foreground(self: win32more.Microsoft.UI.Xaml.Controls.IControl) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_Foreground(self: win32more.Microsoft.UI.Xaml.Controls.IControl, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_IsTextScaleFactorEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IControl) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsTextScaleFactorEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IControl, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IControl) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IControl, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_TabNavigation(self: win32more.Microsoft.UI.Xaml.Controls.IControl) -> win32more.Microsoft.UI.Xaml.Input.KeyboardNavigationMode: ...
    @winrt_mixinmethod
    def put_TabNavigation(self: win32more.Microsoft.UI.Xaml.Controls.IControl, value: win32more.Microsoft.UI.Xaml.Input.KeyboardNavigationMode) -> Void: ...
    @winrt_mixinmethod
    def get_Template(self: win32more.Microsoft.UI.Xaml.Controls.IControl) -> win32more.Microsoft.UI.Xaml.Controls.ControlTemplate: ...
    @winrt_mixinmethod
    def put_Template(self: win32more.Microsoft.UI.Xaml.Controls.IControl, value: win32more.Microsoft.UI.Xaml.Controls.ControlTemplate) -> Void: ...
    @winrt_mixinmethod
    def get_Padding(self: win32more.Microsoft.UI.Xaml.Controls.IControl) -> win32more.Microsoft.UI.Xaml.Thickness: ...
    @winrt_mixinmethod
    def put_Padding(self: win32more.Microsoft.UI.Xaml.Controls.IControl, value: win32more.Microsoft.UI.Xaml.Thickness) -> Void: ...
    @winrt_mixinmethod
    def get_HorizontalContentAlignment(self: win32more.Microsoft.UI.Xaml.Controls.IControl) -> win32more.Microsoft.UI.Xaml.HorizontalAlignment: ...
    @winrt_mixinmethod
    def put_HorizontalContentAlignment(self: win32more.Microsoft.UI.Xaml.Controls.IControl, value: win32more.Microsoft.UI.Xaml.HorizontalAlignment) -> Void: ...
    @winrt_mixinmethod
    def get_VerticalContentAlignment(self: win32more.Microsoft.UI.Xaml.Controls.IControl) -> win32more.Microsoft.UI.Xaml.VerticalAlignment: ...
    @winrt_mixinmethod
    def put_VerticalContentAlignment(self: win32more.Microsoft.UI.Xaml.Controls.IControl, value: win32more.Microsoft.UI.Xaml.VerticalAlignment) -> Void: ...
    @winrt_mixinmethod
    def get_Background(self: win32more.Microsoft.UI.Xaml.Controls.IControl) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_Background(self: win32more.Microsoft.UI.Xaml.Controls.IControl, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_BackgroundSizing(self: win32more.Microsoft.UI.Xaml.Controls.IControl) -> win32more.Microsoft.UI.Xaml.Controls.BackgroundSizing: ...
    @winrt_mixinmethod
    def put_BackgroundSizing(self: win32more.Microsoft.UI.Xaml.Controls.IControl, value: win32more.Microsoft.UI.Xaml.Controls.BackgroundSizing) -> Void: ...
    @winrt_mixinmethod
    def get_BorderThickness(self: win32more.Microsoft.UI.Xaml.Controls.IControl) -> win32more.Microsoft.UI.Xaml.Thickness: ...
    @winrt_mixinmethod
    def put_BorderThickness(self: win32more.Microsoft.UI.Xaml.Controls.IControl, value: win32more.Microsoft.UI.Xaml.Thickness) -> Void: ...
    @winrt_mixinmethod
    def get_BorderBrush(self: win32more.Microsoft.UI.Xaml.Controls.IControl) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_BorderBrush(self: win32more.Microsoft.UI.Xaml.Controls.IControl, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_DefaultStyleResourceUri(self: win32more.Microsoft.UI.Xaml.Controls.IControl) -> win32more.Windows.Foundation.Uri: ...
    @winrt_mixinmethod
    def put_DefaultStyleResourceUri(self: win32more.Microsoft.UI.Xaml.Controls.IControl, value: win32more.Windows.Foundation.Uri) -> Void: ...
    @winrt_mixinmethod
    def get_ElementSoundMode(self: win32more.Microsoft.UI.Xaml.Controls.IControl) -> win32more.Microsoft.UI.Xaml.ElementSoundMode: ...
    @winrt_mixinmethod
    def put_ElementSoundMode(self: win32more.Microsoft.UI.Xaml.Controls.IControl, value: win32more.Microsoft.UI.Xaml.ElementSoundMode) -> Void: ...
    @winrt_mixinmethod
    def get_CornerRadius(self: win32more.Microsoft.UI.Xaml.Controls.IControl) -> win32more.Microsoft.UI.Xaml.CornerRadius: ...
    @winrt_mixinmethod
    def put_CornerRadius(self: win32more.Microsoft.UI.Xaml.Controls.IControl, value: win32more.Microsoft.UI.Xaml.CornerRadius) -> Void: ...
    @winrt_mixinmethod
    def add_FocusEngaged(self: win32more.Microsoft.UI.Xaml.Controls.IControl, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.Control, win32more.Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_FocusEngaged(self: win32more.Microsoft.UI.Xaml.Controls.IControl, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_FocusDisengaged(self: win32more.Microsoft.UI.Xaml.Controls.IControl, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.Control, win32more.Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_FocusDisengaged(self: win32more.Microsoft.UI.Xaml.Controls.IControl, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_IsEnabledChanged(self: win32more.Microsoft.UI.Xaml.Controls.IControl, handler: win32more.Microsoft.UI.Xaml.DependencyPropertyChangedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_IsEnabledChanged(self: win32more.Microsoft.UI.Xaml.Controls.IControl, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def RemoveFocusEngagement(self: win32more.Microsoft.UI.Xaml.Controls.IControl) -> Void: ...
    @winrt_mixinmethod
    def ApplyTemplate(self: win32more.Microsoft.UI.Xaml.Controls.IControl) -> Boolean: ...
    @winrt_mixinmethod
    def get_DefaultStyleKey(self: win32more.Microsoft.UI.Xaml.Controls.IControlProtected) -> IInspectable: ...
    @winrt_mixinmethod
    def put_DefaultStyleKey(self: win32more.Microsoft.UI.Xaml.Controls.IControlProtected, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def GetTemplateChild(self: win32more.Microsoft.UI.Xaml.Controls.IControlProtected, childName: hstr) -> win32more.Microsoft.UI.Xaml.DependencyObject: ...
    @winrt_mixinmethod
    def OnPointerEntered(self: win32more.Microsoft.UI.Xaml.Controls.IControlOverrides, e: win32more.Microsoft.UI.Xaml.Input.PointerRoutedEventArgs) -> Void: ...
    @winrt_mixinmethod
    def OnPointerPressed(self: win32more.Microsoft.UI.Xaml.Controls.IControlOverrides, e: win32more.Microsoft.UI.Xaml.Input.PointerRoutedEventArgs) -> Void: ...
    @winrt_mixinmethod
    def OnPointerMoved(self: win32more.Microsoft.UI.Xaml.Controls.IControlOverrides, e: win32more.Microsoft.UI.Xaml.Input.PointerRoutedEventArgs) -> Void: ...
    @winrt_mixinmethod
    def OnPointerReleased(self: win32more.Microsoft.UI.Xaml.Controls.IControlOverrides, e: win32more.Microsoft.UI.Xaml.Input.PointerRoutedEventArgs) -> Void: ...
    @winrt_mixinmethod
    def OnPointerExited(self: win32more.Microsoft.UI.Xaml.Controls.IControlOverrides, e: win32more.Microsoft.UI.Xaml.Input.PointerRoutedEventArgs) -> Void: ...
    @winrt_mixinmethod
    def OnPointerCaptureLost(self: win32more.Microsoft.UI.Xaml.Controls.IControlOverrides, e: win32more.Microsoft.UI.Xaml.Input.PointerRoutedEventArgs) -> Void: ...
    @winrt_mixinmethod
    def OnPointerCanceled(self: win32more.Microsoft.UI.Xaml.Controls.IControlOverrides, e: win32more.Microsoft.UI.Xaml.Input.PointerRoutedEventArgs) -> Void: ...
    @winrt_mixinmethod
    def OnPointerWheelChanged(self: win32more.Microsoft.UI.Xaml.Controls.IControlOverrides, e: win32more.Microsoft.UI.Xaml.Input.PointerRoutedEventArgs) -> Void: ...
    @winrt_mixinmethod
    def OnTapped(self: win32more.Microsoft.UI.Xaml.Controls.IControlOverrides, e: win32more.Microsoft.UI.Xaml.Input.TappedRoutedEventArgs) -> Void: ...
    @winrt_mixinmethod
    def OnDoubleTapped(self: win32more.Microsoft.UI.Xaml.Controls.IControlOverrides, e: win32more.Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs) -> Void: ...
    @winrt_mixinmethod
    def OnHolding(self: win32more.Microsoft.UI.Xaml.Controls.IControlOverrides, e: win32more.Microsoft.UI.Xaml.Input.HoldingRoutedEventArgs) -> Void: ...
    @winrt_mixinmethod
    def OnRightTapped(self: win32more.Microsoft.UI.Xaml.Controls.IControlOverrides, e: win32more.Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs) -> Void: ...
    @winrt_mixinmethod
    def OnManipulationStarting(self: win32more.Microsoft.UI.Xaml.Controls.IControlOverrides, e: win32more.Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs) -> Void: ...
    @winrt_mixinmethod
    def OnManipulationInertiaStarting(self: win32more.Microsoft.UI.Xaml.Controls.IControlOverrides, e: win32more.Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs) -> Void: ...
    @winrt_mixinmethod
    def OnManipulationStarted(self: win32more.Microsoft.UI.Xaml.Controls.IControlOverrides, e: win32more.Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs) -> Void: ...
    @winrt_mixinmethod
    def OnManipulationDelta(self: win32more.Microsoft.UI.Xaml.Controls.IControlOverrides, e: win32more.Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs) -> Void: ...
    @winrt_mixinmethod
    def OnManipulationCompleted(self: win32more.Microsoft.UI.Xaml.Controls.IControlOverrides, e: win32more.Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs) -> Void: ...
    @winrt_mixinmethod
    def OnKeyUp(self: win32more.Microsoft.UI.Xaml.Controls.IControlOverrides, e: win32more.Microsoft.UI.Xaml.Input.KeyRoutedEventArgs) -> Void: ...
    @winrt_mixinmethod
    def OnKeyDown(self: win32more.Microsoft.UI.Xaml.Controls.IControlOverrides, e: win32more.Microsoft.UI.Xaml.Input.KeyRoutedEventArgs) -> Void: ...
    @winrt_mixinmethod
    def OnPreviewKeyDown(self: win32more.Microsoft.UI.Xaml.Controls.IControlOverrides, e: win32more.Microsoft.UI.Xaml.Input.KeyRoutedEventArgs) -> Void: ...
    @winrt_mixinmethod
    def OnPreviewKeyUp(self: win32more.Microsoft.UI.Xaml.Controls.IControlOverrides, e: win32more.Microsoft.UI.Xaml.Input.KeyRoutedEventArgs) -> Void: ...
    @winrt_mixinmethod
    def OnGotFocus(self: win32more.Microsoft.UI.Xaml.Controls.IControlOverrides, e: win32more.Microsoft.UI.Xaml.RoutedEventArgs) -> Void: ...
    @winrt_mixinmethod
    def OnLostFocus(self: win32more.Microsoft.UI.Xaml.Controls.IControlOverrides, e: win32more.Microsoft.UI.Xaml.RoutedEventArgs) -> Void: ...
    @winrt_mixinmethod
    def OnCharacterReceived(self: win32more.Microsoft.UI.Xaml.Controls.IControlOverrides, e: win32more.Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs) -> Void: ...
    @winrt_mixinmethod
    def OnDragEnter(self: win32more.Microsoft.UI.Xaml.Controls.IControlOverrides, e: win32more.Microsoft.UI.Xaml.DragEventArgs) -> Void: ...
    @winrt_mixinmethod
    def OnDragLeave(self: win32more.Microsoft.UI.Xaml.Controls.IControlOverrides, e: win32more.Microsoft.UI.Xaml.DragEventArgs) -> Void: ...
    @winrt_mixinmethod
    def OnDragOver(self: win32more.Microsoft.UI.Xaml.Controls.IControlOverrides, e: win32more.Microsoft.UI.Xaml.DragEventArgs) -> Void: ...
    @winrt_mixinmethod
    def OnDrop(self: win32more.Microsoft.UI.Xaml.Controls.IControlOverrides, e: win32more.Microsoft.UI.Xaml.DragEventArgs) -> Void: ...
    @winrt_classmethod
    def get_IsFocusEngagementEnabledProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IControlStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsFocusEngagedProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IControlStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_RequiresPointerProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IControlStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FontSizeProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IControlStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FontFamilyProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IControlStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FontWeightProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IControlStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FontStyleProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IControlStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FontStretchProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IControlStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CharacterSpacingProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IControlStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ForegroundProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IControlStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsTextScaleFactorEnabledProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IControlStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsEnabledProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IControlStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TabNavigationProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IControlStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TemplateProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IControlStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PaddingProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IControlStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HorizontalContentAlignmentProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IControlStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_VerticalContentAlignmentProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IControlStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_BackgroundProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IControlStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_BackgroundSizingProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IControlStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_BorderThicknessProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IControlStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_BorderBrushProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IControlStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DefaultStyleKeyProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IControlStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DefaultStyleResourceUriProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IControlStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ElementSoundModeProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IControlStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CornerRadiusProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IControlStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsTemplateFocusTargetProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IControlStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetIsTemplateFocusTarget(cls: win32more.Microsoft.UI.Xaml.Controls.IControlStatics, element: win32more.Microsoft.UI.Xaml.FrameworkElement) -> Boolean: ...
    @winrt_classmethod
    def SetIsTemplateFocusTarget(cls: win32more.Microsoft.UI.Xaml.Controls.IControlStatics, element: win32more.Microsoft.UI.Xaml.FrameworkElement, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_IsTemplateKeyTipTargetProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IControlStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetIsTemplateKeyTipTarget(cls: win32more.Microsoft.UI.Xaml.Controls.IControlStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_classmethod
    def SetIsTemplateKeyTipTarget(cls: win32more.Microsoft.UI.Xaml.Controls.IControlStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: Boolean) -> Void: ...
    Background = property(get_Background, put_Background)
    BackgroundSizing = property(get_BackgroundSizing, put_BackgroundSizing)
    BorderBrush = property(get_BorderBrush, put_BorderBrush)
    BorderThickness = property(get_BorderThickness, put_BorderThickness)
    CharacterSpacing = property(get_CharacterSpacing, put_CharacterSpacing)
    CornerRadius = property(get_CornerRadius, put_CornerRadius)
    DefaultStyleKey = property(get_DefaultStyleKey, put_DefaultStyleKey)
    DefaultStyleResourceUri = property(get_DefaultStyleResourceUri, put_DefaultStyleResourceUri)
    ElementSoundMode = property(get_ElementSoundMode, put_ElementSoundMode)
    FontFamily = property(get_FontFamily, put_FontFamily)
    FontSize = property(get_FontSize, put_FontSize)
    FontStretch = property(get_FontStretch, put_FontStretch)
    FontStyle = property(get_FontStyle, put_FontStyle)
    FontWeight = property(get_FontWeight, put_FontWeight)
    Foreground = property(get_Foreground, put_Foreground)
    HorizontalContentAlignment = property(get_HorizontalContentAlignment, put_HorizontalContentAlignment)
    IsEnabled = property(get_IsEnabled, put_IsEnabled)
    IsFocusEngaged = property(get_IsFocusEngaged, put_IsFocusEngaged)
    IsFocusEngagementEnabled = property(get_IsFocusEngagementEnabled, put_IsFocusEngagementEnabled)
    IsTextScaleFactorEnabled = property(get_IsTextScaleFactorEnabled, put_IsTextScaleFactorEnabled)
    Padding = property(get_Padding, put_Padding)
    RequiresPointer = property(get_RequiresPointer, put_RequiresPointer)
    TabNavigation = property(get_TabNavigation, put_TabNavigation)
    Template = property(get_Template, put_Template)
    VerticalContentAlignment = property(get_VerticalContentAlignment, put_VerticalContentAlignment)
    _Control_Meta_.BackgroundProperty = property(get_BackgroundProperty, None)
    _Control_Meta_.BackgroundSizingProperty = property(get_BackgroundSizingProperty, None)
    _Control_Meta_.BorderBrushProperty = property(get_BorderBrushProperty, None)
    _Control_Meta_.BorderThicknessProperty = property(get_BorderThicknessProperty, None)
    _Control_Meta_.CharacterSpacingProperty = property(get_CharacterSpacingProperty, None)
    _Control_Meta_.CornerRadiusProperty = property(get_CornerRadiusProperty, None)
    _Control_Meta_.DefaultStyleKeyProperty = property(get_DefaultStyleKeyProperty, None)
    _Control_Meta_.DefaultStyleResourceUriProperty = property(get_DefaultStyleResourceUriProperty, None)
    _Control_Meta_.ElementSoundModeProperty = property(get_ElementSoundModeProperty, None)
    _Control_Meta_.FontFamilyProperty = property(get_FontFamilyProperty, None)
    _Control_Meta_.FontSizeProperty = property(get_FontSizeProperty, None)
    _Control_Meta_.FontStretchProperty = property(get_FontStretchProperty, None)
    _Control_Meta_.FontStyleProperty = property(get_FontStyleProperty, None)
    _Control_Meta_.FontWeightProperty = property(get_FontWeightProperty, None)
    _Control_Meta_.ForegroundProperty = property(get_ForegroundProperty, None)
    _Control_Meta_.HorizontalContentAlignmentProperty = property(get_HorizontalContentAlignmentProperty, None)
    _Control_Meta_.IsEnabledProperty = property(get_IsEnabledProperty, None)
    _Control_Meta_.IsFocusEngagedProperty = property(get_IsFocusEngagedProperty, None)
    _Control_Meta_.IsFocusEngagementEnabledProperty = property(get_IsFocusEngagementEnabledProperty, None)
    _Control_Meta_.IsTemplateFocusTargetProperty = property(get_IsTemplateFocusTargetProperty, None)
    _Control_Meta_.IsTemplateKeyTipTargetProperty = property(get_IsTemplateKeyTipTargetProperty, None)
    _Control_Meta_.IsTextScaleFactorEnabledProperty = property(get_IsTextScaleFactorEnabledProperty, None)
    _Control_Meta_.PaddingProperty = property(get_PaddingProperty, None)
    _Control_Meta_.RequiresPointerProperty = property(get_RequiresPointerProperty, None)
    _Control_Meta_.TabNavigationProperty = property(get_TabNavigationProperty, None)
    _Control_Meta_.TemplateProperty = property(get_TemplateProperty, None)
    _Control_Meta_.VerticalContentAlignmentProperty = property(get_VerticalContentAlignmentProperty, None)
    FocusDisengaged = event(add_FocusDisengaged, remove_FocusDisengaged)
    FocusEngaged = event(add_FocusEngaged, remove_FocusEngaged)
    IsEnabledChanged = event(add_IsEnabledChanged, remove_IsEnabledChanged)
class ControlTemplate(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.FrameworkTemplate
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IControlTemplate
    _classid_ = 'Microsoft.UI.Xaml.Controls.ControlTemplate'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.ControlTemplate.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Controls.ControlTemplate: ...
    @winrt_mixinmethod
    def get_TargetType(self: win32more.Microsoft.UI.Xaml.Controls.IControlTemplate) -> win32more.Windows.UI.Xaml.Interop.TypeName: ...
    @winrt_mixinmethod
    def put_TargetType(self: win32more.Microsoft.UI.Xaml.Controls.IControlTemplate, value: win32more.Windows.UI.Xaml.Interop.TypeName) -> Void: ...
    TargetType = property(get_TargetType, put_TargetType)
class CoreWebView2InitializedEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ICoreWebView2InitializedEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.CoreWebView2InitializedEventArgs'
    @winrt_mixinmethod
    def get_Exception(self: win32more.Microsoft.UI.Xaml.Controls.ICoreWebView2InitializedEventArgs) -> win32more.Windows.Foundation.HResult: ...
    Exception = property(get_Exception, None)
class DataTemplateSelector(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IDataTemplateSelector
    _classid_ = 'Microsoft.UI.Xaml.Controls.DataTemplateSelector'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.DataTemplateSelector.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IDataTemplateSelectorFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.DataTemplateSelector: ...
    @winrt_mixinmethod
    def SelectTemplate(self: win32more.Microsoft.UI.Xaml.Controls.IDataTemplateSelector, item: IInspectable, container: win32more.Microsoft.UI.Xaml.DependencyObject) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def SelectTemplateForItem(self: win32more.Microsoft.UI.Xaml.Controls.IDataTemplateSelector, item: IInspectable) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def SelectTemplateCore(self: win32more.Microsoft.UI.Xaml.Controls.IDataTemplateSelectorOverrides, item: IInspectable, container: win32more.Microsoft.UI.Xaml.DependencyObject) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def SelectTemplateForItemCore(self: win32more.Microsoft.UI.Xaml.Controls.IDataTemplateSelectorOverrides, item: IInspectable) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def GetElement(self: win32more.Microsoft.UI.Xaml.IElementFactory, args: win32more.Microsoft.UI.Xaml.ElementFactoryGetArgs) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_mixinmethod
    def RecycleElement(self: win32more.Microsoft.UI.Xaml.IElementFactory, args: win32more.Microsoft.UI.Xaml.ElementFactoryRecycleArgs) -> Void: ...
class DatePickedEventArgs(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.DependencyObject
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IDatePickedEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.DatePickedEventArgs'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.DatePickedEventArgs.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Controls.DatePickedEventArgs: ...
    @winrt_mixinmethod
    def get_OldDate(self: win32more.Microsoft.UI.Xaml.Controls.IDatePickedEventArgs) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_mixinmethod
    def get_NewDate(self: win32more.Microsoft.UI.Xaml.Controls.IDatePickedEventArgs) -> win32more.Windows.Foundation.DateTime: ...
    NewDate = property(get_NewDate, None)
    OldDate = property(get_OldDate, None)
class _DatePicker_Meta_(ComPtr.__class__):
    pass
class DatePicker(ComPtr, metaclass=_DatePicker_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.Control
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IDatePicker
    _classid_ = 'Microsoft.UI.Xaml.Controls.DatePicker'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.DatePicker.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IDatePickerFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.DatePicker: ...
    @winrt_mixinmethod
    def get_Header(self: win32more.Microsoft.UI.Xaml.Controls.IDatePicker) -> IInspectable: ...
    @winrt_mixinmethod
    def put_Header(self: win32more.Microsoft.UI.Xaml.Controls.IDatePicker, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_HeaderTemplate(self: win32more.Microsoft.UI.Xaml.Controls.IDatePicker) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def put_HeaderTemplate(self: win32more.Microsoft.UI.Xaml.Controls.IDatePicker, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_mixinmethod
    def get_CalendarIdentifier(self: win32more.Microsoft.UI.Xaml.Controls.IDatePicker) -> hstr: ...
    @winrt_mixinmethod
    def put_CalendarIdentifier(self: win32more.Microsoft.UI.Xaml.Controls.IDatePicker, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def get_Date(self: win32more.Microsoft.UI.Xaml.Controls.IDatePicker) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_mixinmethod
    def put_Date(self: win32more.Microsoft.UI.Xaml.Controls.IDatePicker, value: win32more.Windows.Foundation.DateTime) -> Void: ...
    @winrt_mixinmethod
    def get_DayVisible(self: win32more.Microsoft.UI.Xaml.Controls.IDatePicker) -> Boolean: ...
    @winrt_mixinmethod
    def put_DayVisible(self: win32more.Microsoft.UI.Xaml.Controls.IDatePicker, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_MonthVisible(self: win32more.Microsoft.UI.Xaml.Controls.IDatePicker) -> Boolean: ...
    @winrt_mixinmethod
    def put_MonthVisible(self: win32more.Microsoft.UI.Xaml.Controls.IDatePicker, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_YearVisible(self: win32more.Microsoft.UI.Xaml.Controls.IDatePicker) -> Boolean: ...
    @winrt_mixinmethod
    def put_YearVisible(self: win32more.Microsoft.UI.Xaml.Controls.IDatePicker, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_DayFormat(self: win32more.Microsoft.UI.Xaml.Controls.IDatePicker) -> hstr: ...
    @winrt_mixinmethod
    def put_DayFormat(self: win32more.Microsoft.UI.Xaml.Controls.IDatePicker, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def get_MonthFormat(self: win32more.Microsoft.UI.Xaml.Controls.IDatePicker) -> hstr: ...
    @winrt_mixinmethod
    def put_MonthFormat(self: win32more.Microsoft.UI.Xaml.Controls.IDatePicker, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def get_YearFormat(self: win32more.Microsoft.UI.Xaml.Controls.IDatePicker) -> hstr: ...
    @winrt_mixinmethod
    def put_YearFormat(self: win32more.Microsoft.UI.Xaml.Controls.IDatePicker, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def get_MinYear(self: win32more.Microsoft.UI.Xaml.Controls.IDatePicker) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_mixinmethod
    def put_MinYear(self: win32more.Microsoft.UI.Xaml.Controls.IDatePicker, value: win32more.Windows.Foundation.DateTime) -> Void: ...
    @winrt_mixinmethod
    def get_MaxYear(self: win32more.Microsoft.UI.Xaml.Controls.IDatePicker) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_mixinmethod
    def put_MaxYear(self: win32more.Microsoft.UI.Xaml.Controls.IDatePicker, value: win32more.Windows.Foundation.DateTime) -> Void: ...
    @winrt_mixinmethod
    def get_Orientation(self: win32more.Microsoft.UI.Xaml.Controls.IDatePicker) -> win32more.Microsoft.UI.Xaml.Controls.Orientation: ...
    @winrt_mixinmethod
    def put_Orientation(self: win32more.Microsoft.UI.Xaml.Controls.IDatePicker, value: win32more.Microsoft.UI.Xaml.Controls.Orientation) -> Void: ...
    @winrt_mixinmethod
    def get_LightDismissOverlayMode(self: win32more.Microsoft.UI.Xaml.Controls.IDatePicker) -> win32more.Microsoft.UI.Xaml.Controls.LightDismissOverlayMode: ...
    @winrt_mixinmethod
    def put_LightDismissOverlayMode(self: win32more.Microsoft.UI.Xaml.Controls.IDatePicker, value: win32more.Microsoft.UI.Xaml.Controls.LightDismissOverlayMode) -> Void: ...
    @winrt_mixinmethod
    def get_SelectedDate(self: win32more.Microsoft.UI.Xaml.Controls.IDatePicker) -> win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.DateTime]: ...
    @winrt_mixinmethod
    def put_SelectedDate(self: win32more.Microsoft.UI.Xaml.Controls.IDatePicker, value: win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.DateTime]) -> Void: ...
    @winrt_mixinmethod
    def add_DateChanged(self: win32more.Microsoft.UI.Xaml.Controls.IDatePicker, handler: win32more.Windows.Foundation.EventHandler[win32more.Microsoft.UI.Xaml.Controls.DatePickerValueChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_DateChanged(self: win32more.Microsoft.UI.Xaml.Controls.IDatePicker, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_SelectedDateChanged(self: win32more.Microsoft.UI.Xaml.Controls.IDatePicker, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.DatePicker, win32more.Microsoft.UI.Xaml.Controls.DatePickerSelectedValueChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_SelectedDateChanged(self: win32more.Microsoft.UI.Xaml.Controls.IDatePicker, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def get_HeaderProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IDatePickerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HeaderTemplateProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IDatePickerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CalendarIdentifierProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IDatePickerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DateProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IDatePickerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DayVisibleProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IDatePickerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MonthVisibleProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IDatePickerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_YearVisibleProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IDatePickerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DayFormatProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IDatePickerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MonthFormatProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IDatePickerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_YearFormatProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IDatePickerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MinYearProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IDatePickerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MaxYearProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IDatePickerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_OrientationProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IDatePickerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_LightDismissOverlayModeProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IDatePickerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectedDateProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IDatePickerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    CalendarIdentifier = property(get_CalendarIdentifier, put_CalendarIdentifier)
    Date = property(get_Date, put_Date)
    DayFormat = property(get_DayFormat, put_DayFormat)
    DayVisible = property(get_DayVisible, put_DayVisible)
    Header = property(get_Header, put_Header)
    HeaderTemplate = property(get_HeaderTemplate, put_HeaderTemplate)
    LightDismissOverlayMode = property(get_LightDismissOverlayMode, put_LightDismissOverlayMode)
    MaxYear = property(get_MaxYear, put_MaxYear)
    MinYear = property(get_MinYear, put_MinYear)
    MonthFormat = property(get_MonthFormat, put_MonthFormat)
    MonthVisible = property(get_MonthVisible, put_MonthVisible)
    Orientation = property(get_Orientation, put_Orientation)
    SelectedDate = property(get_SelectedDate, put_SelectedDate)
    YearFormat = property(get_YearFormat, put_YearFormat)
    YearVisible = property(get_YearVisible, put_YearVisible)
    _DatePicker_Meta_.CalendarIdentifierProperty = property(get_CalendarIdentifierProperty, None)
    _DatePicker_Meta_.DateProperty = property(get_DateProperty, None)
    _DatePicker_Meta_.DayFormatProperty = property(get_DayFormatProperty, None)
    _DatePicker_Meta_.DayVisibleProperty = property(get_DayVisibleProperty, None)
    _DatePicker_Meta_.HeaderProperty = property(get_HeaderProperty, None)
    _DatePicker_Meta_.HeaderTemplateProperty = property(get_HeaderTemplateProperty, None)
    _DatePicker_Meta_.LightDismissOverlayModeProperty = property(get_LightDismissOverlayModeProperty, None)
    _DatePicker_Meta_.MaxYearProperty = property(get_MaxYearProperty, None)
    _DatePicker_Meta_.MinYearProperty = property(get_MinYearProperty, None)
    _DatePicker_Meta_.MonthFormatProperty = property(get_MonthFormatProperty, None)
    _DatePicker_Meta_.MonthVisibleProperty = property(get_MonthVisibleProperty, None)
    _DatePicker_Meta_.OrientationProperty = property(get_OrientationProperty, None)
    _DatePicker_Meta_.SelectedDateProperty = property(get_SelectedDateProperty, None)
    _DatePicker_Meta_.YearFormatProperty = property(get_YearFormatProperty, None)
    _DatePicker_Meta_.YearVisibleProperty = property(get_YearVisibleProperty, None)
    DateChanged = event(add_DateChanged, remove_DateChanged)
    SelectedDateChanged = event(add_SelectedDateChanged, remove_SelectedDateChanged)
class _DatePickerFlyout_Meta_(ComPtr.__class__):
    pass
class DatePickerFlyout(ComPtr, metaclass=_DatePickerFlyout_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.Primitives.PickerFlyoutBase
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IDatePickerFlyout
    _classid_ = 'Microsoft.UI.Xaml.Controls.DatePickerFlyout'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.DatePickerFlyout.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Controls.DatePickerFlyout: ...
    @winrt_mixinmethod
    def get_CalendarIdentifier(self: win32more.Microsoft.UI.Xaml.Controls.IDatePickerFlyout) -> hstr: ...
    @winrt_mixinmethod
    def put_CalendarIdentifier(self: win32more.Microsoft.UI.Xaml.Controls.IDatePickerFlyout, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def get_Date(self: win32more.Microsoft.UI.Xaml.Controls.IDatePickerFlyout) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_mixinmethod
    def put_Date(self: win32more.Microsoft.UI.Xaml.Controls.IDatePickerFlyout, value: win32more.Windows.Foundation.DateTime) -> Void: ...
    @winrt_mixinmethod
    def get_DayVisible(self: win32more.Microsoft.UI.Xaml.Controls.IDatePickerFlyout) -> Boolean: ...
    @winrt_mixinmethod
    def put_DayVisible(self: win32more.Microsoft.UI.Xaml.Controls.IDatePickerFlyout, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_MonthVisible(self: win32more.Microsoft.UI.Xaml.Controls.IDatePickerFlyout) -> Boolean: ...
    @winrt_mixinmethod
    def put_MonthVisible(self: win32more.Microsoft.UI.Xaml.Controls.IDatePickerFlyout, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_YearVisible(self: win32more.Microsoft.UI.Xaml.Controls.IDatePickerFlyout) -> Boolean: ...
    @winrt_mixinmethod
    def put_YearVisible(self: win32more.Microsoft.UI.Xaml.Controls.IDatePickerFlyout, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_MinYear(self: win32more.Microsoft.UI.Xaml.Controls.IDatePickerFlyout) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_mixinmethod
    def put_MinYear(self: win32more.Microsoft.UI.Xaml.Controls.IDatePickerFlyout, value: win32more.Windows.Foundation.DateTime) -> Void: ...
    @winrt_mixinmethod
    def get_MaxYear(self: win32more.Microsoft.UI.Xaml.Controls.IDatePickerFlyout) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_mixinmethod
    def put_MaxYear(self: win32more.Microsoft.UI.Xaml.Controls.IDatePickerFlyout, value: win32more.Windows.Foundation.DateTime) -> Void: ...
    @winrt_mixinmethod
    def get_DayFormat(self: win32more.Microsoft.UI.Xaml.Controls.IDatePickerFlyout) -> hstr: ...
    @winrt_mixinmethod
    def put_DayFormat(self: win32more.Microsoft.UI.Xaml.Controls.IDatePickerFlyout, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def get_MonthFormat(self: win32more.Microsoft.UI.Xaml.Controls.IDatePickerFlyout) -> hstr: ...
    @winrt_mixinmethod
    def put_MonthFormat(self: win32more.Microsoft.UI.Xaml.Controls.IDatePickerFlyout, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def get_YearFormat(self: win32more.Microsoft.UI.Xaml.Controls.IDatePickerFlyout) -> hstr: ...
    @winrt_mixinmethod
    def put_YearFormat(self: win32more.Microsoft.UI.Xaml.Controls.IDatePickerFlyout, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def add_DatePicked(self: win32more.Microsoft.UI.Xaml.Controls.IDatePickerFlyout, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.DatePickerFlyout, win32more.Microsoft.UI.Xaml.Controls.DatePickedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_DatePicked(self: win32more.Microsoft.UI.Xaml.Controls.IDatePickerFlyout, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def ShowAtAsync(self: win32more.Microsoft.UI.Xaml.Controls.IDatePickerFlyout, target: win32more.Microsoft.UI.Xaml.FrameworkElement) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.DateTime]]: ...
    @winrt_classmethod
    def get_CalendarIdentifierProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IDatePickerFlyoutStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DateProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IDatePickerFlyoutStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DayVisibleProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IDatePickerFlyoutStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MonthVisibleProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IDatePickerFlyoutStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_YearVisibleProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IDatePickerFlyoutStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MinYearProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IDatePickerFlyoutStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MaxYearProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IDatePickerFlyoutStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DayFormatProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IDatePickerFlyoutStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MonthFormatProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IDatePickerFlyoutStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_YearFormatProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IDatePickerFlyoutStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    CalendarIdentifier = property(get_CalendarIdentifier, put_CalendarIdentifier)
    Date = property(get_Date, put_Date)
    DayFormat = property(get_DayFormat, put_DayFormat)
    DayVisible = property(get_DayVisible, put_DayVisible)
    MaxYear = property(get_MaxYear, put_MaxYear)
    MinYear = property(get_MinYear, put_MinYear)
    MonthFormat = property(get_MonthFormat, put_MonthFormat)
    MonthVisible = property(get_MonthVisible, put_MonthVisible)
    YearFormat = property(get_YearFormat, put_YearFormat)
    YearVisible = property(get_YearVisible, put_YearVisible)
    _DatePickerFlyout_Meta_.CalendarIdentifierProperty = property(get_CalendarIdentifierProperty, None)
    _DatePickerFlyout_Meta_.DateProperty = property(get_DateProperty, None)
    _DatePickerFlyout_Meta_.DayFormatProperty = property(get_DayFormatProperty, None)
    _DatePickerFlyout_Meta_.DayVisibleProperty = property(get_DayVisibleProperty, None)
    _DatePickerFlyout_Meta_.MaxYearProperty = property(get_MaxYearProperty, None)
    _DatePickerFlyout_Meta_.MinYearProperty = property(get_MinYearProperty, None)
    _DatePickerFlyout_Meta_.MonthFormatProperty = property(get_MonthFormatProperty, None)
    _DatePickerFlyout_Meta_.MonthVisibleProperty = property(get_MonthVisibleProperty, None)
    _DatePickerFlyout_Meta_.YearFormatProperty = property(get_YearFormatProperty, None)
    _DatePickerFlyout_Meta_.YearVisibleProperty = property(get_YearVisibleProperty, None)
    DatePicked = event(add_DatePicked, remove_DatePicked)
class _DatePickerFlyoutItem_Meta_(ComPtr.__class__):
    pass
class DatePickerFlyoutItem(ComPtr, metaclass=_DatePickerFlyoutItem_Meta_):
    extends: win32more.Microsoft.UI.Xaml.DependencyObject
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IDatePickerFlyoutItem
    _classid_ = 'Microsoft.UI.Xaml.Controls.DatePickerFlyoutItem'
    @winrt_mixinmethod
    def get_PrimaryText(self: win32more.Microsoft.UI.Xaml.Controls.IDatePickerFlyoutItem) -> hstr: ...
    @winrt_mixinmethod
    def put_PrimaryText(self: win32more.Microsoft.UI.Xaml.Controls.IDatePickerFlyoutItem, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def get_SecondaryText(self: win32more.Microsoft.UI.Xaml.Controls.IDatePickerFlyoutItem) -> hstr: ...
    @winrt_mixinmethod
    def put_SecondaryText(self: win32more.Microsoft.UI.Xaml.Controls.IDatePickerFlyoutItem, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def GetCustomProperty(self: win32more.Microsoft.UI.Xaml.Data.ICustomPropertyProvider, name: hstr) -> win32more.Microsoft.UI.Xaml.Data.ICustomProperty: ...
    @winrt_mixinmethod
    def GetIndexedProperty(self: win32more.Microsoft.UI.Xaml.Data.ICustomPropertyProvider, name: hstr, type: win32more.Windows.UI.Xaml.Interop.TypeName) -> win32more.Microsoft.UI.Xaml.Data.ICustomProperty: ...
    @winrt_mixinmethod
    def GetStringRepresentation(self: win32more.Microsoft.UI.Xaml.Data.ICustomPropertyProvider) -> hstr: ...
    @winrt_mixinmethod
    def get_Type(self: win32more.Microsoft.UI.Xaml.Data.ICustomPropertyProvider) -> win32more.Windows.UI.Xaml.Interop.TypeName: ...
    @winrt_classmethod
    def get_PrimaryTextProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IDatePickerFlyoutItemStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SecondaryTextProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IDatePickerFlyoutItemStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    PrimaryText = property(get_PrimaryText, put_PrimaryText)
    SecondaryText = property(get_SecondaryText, put_SecondaryText)
    Type = property(get_Type, None)
    _DatePickerFlyoutItem_Meta_.PrimaryTextProperty = property(get_PrimaryTextProperty, None)
    _DatePickerFlyoutItem_Meta_.SecondaryTextProperty = property(get_SecondaryTextProperty, None)
class _DatePickerFlyoutPresenter_Meta_(ComPtr.__class__):
    pass
class DatePickerFlyoutPresenter(ComPtr, metaclass=_DatePickerFlyoutPresenter_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.Control
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IDatePickerFlyoutPresenter
    _classid_ = 'Microsoft.UI.Xaml.Controls.DatePickerFlyoutPresenter'
    @winrt_mixinmethod
    def get_IsDefaultShadowEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IDatePickerFlyoutPresenter) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsDefaultShadowEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IDatePickerFlyoutPresenter, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_IsDefaultShadowEnabledProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IDatePickerFlyoutPresenterStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    IsDefaultShadowEnabled = property(get_IsDefaultShadowEnabled, put_IsDefaultShadowEnabled)
    _DatePickerFlyoutPresenter_Meta_.IsDefaultShadowEnabledProperty = property(get_IsDefaultShadowEnabledProperty, None)
class DatePickerSelectedValueChangedEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IDatePickerSelectedValueChangedEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.DatePickerSelectedValueChangedEventArgs'
    @winrt_mixinmethod
    def get_OldDate(self: win32more.Microsoft.UI.Xaml.Controls.IDatePickerSelectedValueChangedEventArgs) -> win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.DateTime]: ...
    @winrt_mixinmethod
    def get_NewDate(self: win32more.Microsoft.UI.Xaml.Controls.IDatePickerSelectedValueChangedEventArgs) -> win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.DateTime]: ...
    NewDate = property(get_NewDate, None)
    OldDate = property(get_OldDate, None)
class DatePickerValueChangedEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IDatePickerValueChangedEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.DatePickerValueChangedEventArgs'
    @winrt_mixinmethod
    def get_OldDate(self: win32more.Microsoft.UI.Xaml.Controls.IDatePickerValueChangedEventArgs) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_mixinmethod
    def get_NewDate(self: win32more.Microsoft.UI.Xaml.Controls.IDatePickerValueChangedEventArgs) -> win32more.Windows.Foundation.DateTime: ...
    NewDate = property(get_NewDate, None)
    OldDate = property(get_OldDate, None)
class DisabledFormattingAccelerators(Enum, UInt32):
    None_ = 0
    Bold = 1
    Italic = 2
    Underline = 4
    All = 4294967295
class DragItemsCompletedEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IDragItemsCompletedEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.DragItemsCompletedEventArgs'
    @winrt_mixinmethod
    def get_Items(self: win32more.Microsoft.UI.Xaml.Controls.IDragItemsCompletedEventArgs) -> win32more.Windows.Foundation.Collections.IVectorView[IInspectable]: ...
    @winrt_mixinmethod
    def get_DropResult(self: win32more.Microsoft.UI.Xaml.Controls.IDragItemsCompletedEventArgs) -> win32more.Windows.ApplicationModel.DataTransfer.DataPackageOperation: ...
    DropResult = property(get_DropResult, None)
    Items = property(get_Items, None)
class DragItemsStartingEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IDragItemsStartingEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.DragItemsStartingEventArgs'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.DragItemsStartingEventArgs.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Controls.DragItemsStartingEventArgs: ...
    @winrt_mixinmethod
    def get_Cancel(self: win32more.Microsoft.UI.Xaml.Controls.IDragItemsStartingEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def put_Cancel(self: win32more.Microsoft.UI.Xaml.Controls.IDragItemsStartingEventArgs, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_Items(self: win32more.Microsoft.UI.Xaml.Controls.IDragItemsStartingEventArgs) -> win32more.Windows.Foundation.Collections.IVector[IInspectable]: ...
    @winrt_mixinmethod
    def get_Data(self: win32more.Microsoft.UI.Xaml.Controls.IDragItemsStartingEventArgs) -> win32more.Windows.ApplicationModel.DataTransfer.DataPackage: ...
    Cancel = property(get_Cancel, put_Cancel)
    Data = property(get_Data, None)
    Items = property(get_Items, None)
class DragItemsStartingEventHandler(MulticastDelegate):
    extends: IUnknown
    _iid_ = Guid('{55532800-7617-5d67-80bf-b98c0a41b9d6}')
    @winrt_commethod(3)
    def Invoke(self, sender: IInspectable, e: win32more.Microsoft.UI.Xaml.Controls.DragItemsStartingEventArgs) -> Void: ...
class DropDownButton(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.Controls.Button
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IDropDownButton
    _classid_ = 'Microsoft.UI.Xaml.Controls.DropDownButton'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.DropDownButton.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IDropDownButtonFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.DropDownButton: ...
class DynamicOverflowItemsChangingEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IDynamicOverflowItemsChangingEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.DynamicOverflowItemsChangingEventArgs'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.DynamicOverflowItemsChangingEventArgs.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Controls.DynamicOverflowItemsChangingEventArgs: ...
    @winrt_mixinmethod
    def get_Action(self: win32more.Microsoft.UI.Xaml.Controls.IDynamicOverflowItemsChangingEventArgs) -> win32more.Microsoft.UI.Xaml.Controls.CommandBarDynamicOverflowAction: ...
    Action = property(get_Action, None)
class ElementRealizationOptions(Enum, UInt32):
    None_ = 0
    ForceCreate = 1
    SuppressAutoRecycle = 2
class ExpandDirection(Enum, Int32):
    Down = 0
    Up = 1
class _Expander_Meta_(ComPtr.__class__):
    pass
class Expander(ComPtr, metaclass=_Expander_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.ContentControl
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IExpander
    _classid_ = 'Microsoft.UI.Xaml.Controls.Expander'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.Expander.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IExpanderFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.Expander: ...
    @winrt_mixinmethod
    def get_Header(self: win32more.Microsoft.UI.Xaml.Controls.IExpander) -> IInspectable: ...
    @winrt_mixinmethod
    def put_Header(self: win32more.Microsoft.UI.Xaml.Controls.IExpander, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_HeaderTemplate(self: win32more.Microsoft.UI.Xaml.Controls.IExpander) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def put_HeaderTemplate(self: win32more.Microsoft.UI.Xaml.Controls.IExpander, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_mixinmethod
    def get_HeaderTemplateSelector(self: win32more.Microsoft.UI.Xaml.Controls.IExpander) -> win32more.Microsoft.UI.Xaml.Controls.DataTemplateSelector: ...
    @winrt_mixinmethod
    def put_HeaderTemplateSelector(self: win32more.Microsoft.UI.Xaml.Controls.IExpander, value: win32more.Microsoft.UI.Xaml.Controls.DataTemplateSelector) -> Void: ...
    @winrt_mixinmethod
    def get_IsExpanded(self: win32more.Microsoft.UI.Xaml.Controls.IExpander) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsExpanded(self: win32more.Microsoft.UI.Xaml.Controls.IExpander, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_ExpandDirection(self: win32more.Microsoft.UI.Xaml.Controls.IExpander) -> win32more.Microsoft.UI.Xaml.Controls.ExpandDirection: ...
    @winrt_mixinmethod
    def put_ExpandDirection(self: win32more.Microsoft.UI.Xaml.Controls.IExpander, value: win32more.Microsoft.UI.Xaml.Controls.ExpandDirection) -> Void: ...
    @winrt_mixinmethod
    def add_Expanding(self: win32more.Microsoft.UI.Xaml.Controls.IExpander, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.Expander, win32more.Microsoft.UI.Xaml.Controls.ExpanderExpandingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Expanding(self: win32more.Microsoft.UI.Xaml.Controls.IExpander, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_Collapsed(self: win32more.Microsoft.UI.Xaml.Controls.IExpander, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.Expander, win32more.Microsoft.UI.Xaml.Controls.ExpanderCollapsedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Collapsed(self: win32more.Microsoft.UI.Xaml.Controls.IExpander, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def get_TemplateSettings(self: win32more.Microsoft.UI.Xaml.Controls.IExpander) -> win32more.Microsoft.UI.Xaml.Controls.ExpanderTemplateSettings: ...
    @winrt_classmethod
    def get_HeaderProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IExpanderStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HeaderTemplateProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IExpanderStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HeaderTemplateSelectorProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IExpanderStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsExpandedProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IExpanderStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ExpandDirectionProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IExpanderStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    ExpandDirection = property(get_ExpandDirection, put_ExpandDirection)
    Header = property(get_Header, put_Header)
    HeaderTemplate = property(get_HeaderTemplate, put_HeaderTemplate)
    HeaderTemplateSelector = property(get_HeaderTemplateSelector, put_HeaderTemplateSelector)
    IsExpanded = property(get_IsExpanded, put_IsExpanded)
    TemplateSettings = property(get_TemplateSettings, None)
    _Expander_Meta_.ExpandDirectionProperty = property(get_ExpandDirectionProperty, None)
    _Expander_Meta_.HeaderProperty = property(get_HeaderProperty, None)
    _Expander_Meta_.HeaderTemplateProperty = property(get_HeaderTemplateProperty, None)
    _Expander_Meta_.HeaderTemplateSelectorProperty = property(get_HeaderTemplateSelectorProperty, None)
    _Expander_Meta_.IsExpandedProperty = property(get_IsExpandedProperty, None)
    Collapsed = event(add_Collapsed, remove_Collapsed)
    Expanding = event(add_Expanding, remove_Expanding)
class ExpanderCollapsedEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IExpanderCollapsedEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.ExpanderCollapsedEventArgs'
class ExpanderExpandingEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IExpanderExpandingEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.ExpanderExpandingEventArgs'
class ExpanderTemplateSettings(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.DependencyObject
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IExpanderTemplateSettings
    _classid_ = 'Microsoft.UI.Xaml.Controls.ExpanderTemplateSettings'
    @winrt_mixinmethod
    def get_ContentHeight(self: win32more.Microsoft.UI.Xaml.Controls.IExpanderTemplateSettings) -> Double: ...
    @winrt_mixinmethod
    def get_NegativeContentHeight(self: win32more.Microsoft.UI.Xaml.Controls.IExpanderTemplateSettings) -> Double: ...
    ContentHeight = property(get_ContentHeight, None)
    NegativeContentHeight = property(get_NegativeContentHeight, None)
class _FlipView_Meta_(ComPtr.__class__):
    pass
class FlipView(ComPtr, metaclass=_FlipView_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.Primitives.Selector
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IFlipView
    _classid_ = 'Microsoft.UI.Xaml.Controls.FlipView'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.FlipView.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IFlipViewFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.FlipView: ...
    @winrt_mixinmethod
    def get_UseTouchAnimationsForAllNavigation(self: win32more.Microsoft.UI.Xaml.Controls.IFlipView) -> Boolean: ...
    @winrt_mixinmethod
    def put_UseTouchAnimationsForAllNavigation(self: win32more.Microsoft.UI.Xaml.Controls.IFlipView, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_UseTouchAnimationsForAllNavigationProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IFlipViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    UseTouchAnimationsForAllNavigation = property(get_UseTouchAnimationsForAllNavigation, put_UseTouchAnimationsForAllNavigation)
    _FlipView_Meta_.UseTouchAnimationsForAllNavigationProperty = property(get_UseTouchAnimationsForAllNavigationProperty, None)
class FlipViewItem(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.Controls.Primitives.SelectorItem
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IFlipViewItem
    _classid_ = 'Microsoft.UI.Xaml.Controls.FlipViewItem'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.FlipViewItem.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IFlipViewItemFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.FlipViewItem: ...
class _Flyout_Meta_(ComPtr.__class__):
    pass
class Flyout(ComPtr, metaclass=_Flyout_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.Primitives.FlyoutBase
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IFlyout
    _classid_ = 'Microsoft.UI.Xaml.Controls.Flyout'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.Flyout.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IFlyoutFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.Flyout: ...
    @winrt_mixinmethod
    def get_Content(self: win32more.Microsoft.UI.Xaml.Controls.IFlyout) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_mixinmethod
    def put_Content(self: win32more.Microsoft.UI.Xaml.Controls.IFlyout, value: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    @winrt_mixinmethod
    def get_FlyoutPresenterStyle(self: win32more.Microsoft.UI.Xaml.Controls.IFlyout) -> win32more.Microsoft.UI.Xaml.Style: ...
    @winrt_mixinmethod
    def put_FlyoutPresenterStyle(self: win32more.Microsoft.UI.Xaml.Controls.IFlyout, value: win32more.Microsoft.UI.Xaml.Style) -> Void: ...
    @winrt_classmethod
    def get_ContentProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IFlyoutStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FlyoutPresenterStyleProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IFlyoutStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    Content = property(get_Content, put_Content)
    FlyoutPresenterStyle = property(get_FlyoutPresenterStyle, put_FlyoutPresenterStyle)
    _Flyout_Meta_.ContentProperty = property(get_ContentProperty, None)
    _Flyout_Meta_.FlyoutPresenterStyleProperty = property(get_FlyoutPresenterStyleProperty, None)
class _FlyoutPresenter_Meta_(ComPtr.__class__):
    pass
class FlyoutPresenter(ComPtr, metaclass=_FlyoutPresenter_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.ContentControl
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IFlyoutPresenter
    _classid_ = 'Microsoft.UI.Xaml.Controls.FlyoutPresenter'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.FlyoutPresenter.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IFlyoutPresenterFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.FlyoutPresenter: ...
    @winrt_mixinmethod
    def get_IsDefaultShadowEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IFlyoutPresenter) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsDefaultShadowEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IFlyoutPresenter, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_IsDefaultShadowEnabledProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IFlyoutPresenterStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    IsDefaultShadowEnabled = property(get_IsDefaultShadowEnabled, put_IsDefaultShadowEnabled)
    _FlyoutPresenter_Meta_.IsDefaultShadowEnabledProperty = property(get_IsDefaultShadowEnabledProperty, None)
class FocusDisengagedEventArgs(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.RoutedEventArgs
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IFocusDisengagedEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs'
class FocusEngagedEventArgs(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.RoutedEventArgs
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IFocusEngagedEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs'
    @winrt_mixinmethod
    def get_Handled(self: win32more.Microsoft.UI.Xaml.Controls.IFocusEngagedEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def put_Handled(self: win32more.Microsoft.UI.Xaml.Controls.IFocusEngagedEventArgs, value: Boolean) -> Void: ...
    Handled = property(get_Handled, put_Handled)
class _FontIcon_Meta_(ComPtr.__class__):
    pass
class FontIcon(ComPtr, metaclass=_FontIcon_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.IconElement
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IFontIcon
    _classid_ = 'Microsoft.UI.Xaml.Controls.FontIcon'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.FontIcon.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IFontIconFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.FontIcon: ...
    @winrt_mixinmethod
    def get_Glyph(self: win32more.Microsoft.UI.Xaml.Controls.IFontIcon) -> hstr: ...
    @winrt_mixinmethod
    def put_Glyph(self: win32more.Microsoft.UI.Xaml.Controls.IFontIcon, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def get_FontSize(self: win32more.Microsoft.UI.Xaml.Controls.IFontIcon) -> Double: ...
    @winrt_mixinmethod
    def put_FontSize(self: win32more.Microsoft.UI.Xaml.Controls.IFontIcon, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_FontFamily(self: win32more.Microsoft.UI.Xaml.Controls.IFontIcon) -> win32more.Microsoft.UI.Xaml.Media.FontFamily: ...
    @winrt_mixinmethod
    def put_FontFamily(self: win32more.Microsoft.UI.Xaml.Controls.IFontIcon, value: win32more.Microsoft.UI.Xaml.Media.FontFamily) -> Void: ...
    @winrt_mixinmethod
    def get_FontWeight(self: win32more.Microsoft.UI.Xaml.Controls.IFontIcon) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_mixinmethod
    def put_FontWeight(self: win32more.Microsoft.UI.Xaml.Controls.IFontIcon, value: win32more.Windows.UI.Text.FontWeight) -> Void: ...
    @winrt_mixinmethod
    def get_FontStyle(self: win32more.Microsoft.UI.Xaml.Controls.IFontIcon) -> win32more.Windows.UI.Text.FontStyle: ...
    @winrt_mixinmethod
    def put_FontStyle(self: win32more.Microsoft.UI.Xaml.Controls.IFontIcon, value: win32more.Windows.UI.Text.FontStyle) -> Void: ...
    @winrt_mixinmethod
    def get_IsTextScaleFactorEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IFontIcon) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsTextScaleFactorEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IFontIcon, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_MirroredWhenRightToLeft(self: win32more.Microsoft.UI.Xaml.Controls.IFontIcon) -> Boolean: ...
    @winrt_mixinmethod
    def put_MirroredWhenRightToLeft(self: win32more.Microsoft.UI.Xaml.Controls.IFontIcon, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_GlyphProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IFontIconStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FontSizeProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IFontIconStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FontFamilyProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IFontIconStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FontWeightProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IFontIconStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FontStyleProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IFontIconStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsTextScaleFactorEnabledProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IFontIconStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MirroredWhenRightToLeftProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IFontIconStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    FontFamily = property(get_FontFamily, put_FontFamily)
    FontSize = property(get_FontSize, put_FontSize)
    FontStyle = property(get_FontStyle, put_FontStyle)
    FontWeight = property(get_FontWeight, put_FontWeight)
    Glyph = property(get_Glyph, put_Glyph)
    IsTextScaleFactorEnabled = property(get_IsTextScaleFactorEnabled, put_IsTextScaleFactorEnabled)
    MirroredWhenRightToLeft = property(get_MirroredWhenRightToLeft, put_MirroredWhenRightToLeft)
    _FontIcon_Meta_.FontFamilyProperty = property(get_FontFamilyProperty, None)
    _FontIcon_Meta_.FontSizeProperty = property(get_FontSizeProperty, None)
    _FontIcon_Meta_.FontStyleProperty = property(get_FontStyleProperty, None)
    _FontIcon_Meta_.FontWeightProperty = property(get_FontWeightProperty, None)
    _FontIcon_Meta_.GlyphProperty = property(get_GlyphProperty, None)
    _FontIcon_Meta_.IsTextScaleFactorEnabledProperty = property(get_IsTextScaleFactorEnabledProperty, None)
    _FontIcon_Meta_.MirroredWhenRightToLeftProperty = property(get_MirroredWhenRightToLeftProperty, None)
class _FontIconSource_Meta_(ComPtr.__class__):
    pass
class FontIconSource(ComPtr, metaclass=_FontIconSource_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.IconSource
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IFontIconSource
    _classid_ = 'Microsoft.UI.Xaml.Controls.FontIconSource'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.FontIconSource.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IFontIconSourceFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.FontIconSource: ...
    @winrt_mixinmethod
    def get_Glyph(self: win32more.Microsoft.UI.Xaml.Controls.IFontIconSource) -> hstr: ...
    @winrt_mixinmethod
    def put_Glyph(self: win32more.Microsoft.UI.Xaml.Controls.IFontIconSource, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def get_FontSize(self: win32more.Microsoft.UI.Xaml.Controls.IFontIconSource) -> Double: ...
    @winrt_mixinmethod
    def put_FontSize(self: win32more.Microsoft.UI.Xaml.Controls.IFontIconSource, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_FontFamily(self: win32more.Microsoft.UI.Xaml.Controls.IFontIconSource) -> win32more.Microsoft.UI.Xaml.Media.FontFamily: ...
    @winrt_mixinmethod
    def put_FontFamily(self: win32more.Microsoft.UI.Xaml.Controls.IFontIconSource, value: win32more.Microsoft.UI.Xaml.Media.FontFamily) -> Void: ...
    @winrt_mixinmethod
    def get_FontWeight(self: win32more.Microsoft.UI.Xaml.Controls.IFontIconSource) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_mixinmethod
    def put_FontWeight(self: win32more.Microsoft.UI.Xaml.Controls.IFontIconSource, value: win32more.Windows.UI.Text.FontWeight) -> Void: ...
    @winrt_mixinmethod
    def get_FontStyle(self: win32more.Microsoft.UI.Xaml.Controls.IFontIconSource) -> win32more.Windows.UI.Text.FontStyle: ...
    @winrt_mixinmethod
    def put_FontStyle(self: win32more.Microsoft.UI.Xaml.Controls.IFontIconSource, value: win32more.Windows.UI.Text.FontStyle) -> Void: ...
    @winrt_mixinmethod
    def get_IsTextScaleFactorEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IFontIconSource) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsTextScaleFactorEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IFontIconSource, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_MirroredWhenRightToLeft(self: win32more.Microsoft.UI.Xaml.Controls.IFontIconSource) -> Boolean: ...
    @winrt_mixinmethod
    def put_MirroredWhenRightToLeft(self: win32more.Microsoft.UI.Xaml.Controls.IFontIconSource, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_GlyphProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IFontIconSourceStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FontSizeProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IFontIconSourceStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FontFamilyProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IFontIconSourceStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FontWeightProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IFontIconSourceStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FontStyleProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IFontIconSourceStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsTextScaleFactorEnabledProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IFontIconSourceStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MirroredWhenRightToLeftProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IFontIconSourceStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    FontFamily = property(get_FontFamily, put_FontFamily)
    FontSize = property(get_FontSize, put_FontSize)
    FontStyle = property(get_FontStyle, put_FontStyle)
    FontWeight = property(get_FontWeight, put_FontWeight)
    Glyph = property(get_Glyph, put_Glyph)
    IsTextScaleFactorEnabled = property(get_IsTextScaleFactorEnabled, put_IsTextScaleFactorEnabled)
    MirroredWhenRightToLeft = property(get_MirroredWhenRightToLeft, put_MirroredWhenRightToLeft)
    _FontIconSource_Meta_.FontFamilyProperty = property(get_FontFamilyProperty, None)
    _FontIconSource_Meta_.FontSizeProperty = property(get_FontSizeProperty, None)
    _FontIconSource_Meta_.FontStyleProperty = property(get_FontStyleProperty, None)
    _FontIconSource_Meta_.FontWeightProperty = property(get_FontWeightProperty, None)
    _FontIconSource_Meta_.GlyphProperty = property(get_GlyphProperty, None)
    _FontIconSource_Meta_.IsTextScaleFactorEnabledProperty = property(get_IsTextScaleFactorEnabledProperty, None)
    _FontIconSource_Meta_.MirroredWhenRightToLeftProperty = property(get_MirroredWhenRightToLeftProperty, None)
class _Frame_Meta_(ComPtr.__class__):
    pass
class Frame(ComPtr, metaclass=_Frame_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.ContentControl
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IFrame
    _classid_ = 'Microsoft.UI.Xaml.Controls.Frame'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.Frame.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IFrameFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.Frame: ...
    @winrt_mixinmethod
    def get_CacheSize(self: win32more.Microsoft.UI.Xaml.Controls.IFrame) -> Int32: ...
    @winrt_mixinmethod
    def put_CacheSize(self: win32more.Microsoft.UI.Xaml.Controls.IFrame, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_CanGoBack(self: win32more.Microsoft.UI.Xaml.Controls.IFrame) -> Boolean: ...
    @winrt_mixinmethod
    def get_CanGoForward(self: win32more.Microsoft.UI.Xaml.Controls.IFrame) -> Boolean: ...
    @winrt_mixinmethod
    def get_CurrentSourcePageType(self: win32more.Microsoft.UI.Xaml.Controls.IFrame) -> win32more.Windows.UI.Xaml.Interop.TypeName: ...
    @winrt_mixinmethod
    def get_SourcePageType(self: win32more.Microsoft.UI.Xaml.Controls.IFrame) -> win32more.Windows.UI.Xaml.Interop.TypeName: ...
    @winrt_mixinmethod
    def put_SourcePageType(self: win32more.Microsoft.UI.Xaml.Controls.IFrame, value: win32more.Windows.UI.Xaml.Interop.TypeName) -> Void: ...
    @winrt_mixinmethod
    def get_BackStackDepth(self: win32more.Microsoft.UI.Xaml.Controls.IFrame) -> Int32: ...
    @winrt_mixinmethod
    def get_BackStack(self: win32more.Microsoft.UI.Xaml.Controls.IFrame) -> win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Navigation.PageStackEntry]: ...
    @winrt_mixinmethod
    def get_ForwardStack(self: win32more.Microsoft.UI.Xaml.Controls.IFrame) -> win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Navigation.PageStackEntry]: ...
    @winrt_mixinmethod
    def get_IsNavigationStackEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IFrame) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsNavigationStackEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IFrame, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def add_Navigated(self: win32more.Microsoft.UI.Xaml.Controls.IFrame, handler: win32more.Microsoft.UI.Xaml.Navigation.NavigatedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Navigated(self: win32more.Microsoft.UI.Xaml.Controls.IFrame, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_Navigating(self: win32more.Microsoft.UI.Xaml.Controls.IFrame, handler: win32more.Microsoft.UI.Xaml.Navigation.NavigatingCancelEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Navigating(self: win32more.Microsoft.UI.Xaml.Controls.IFrame, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_NavigationFailed(self: win32more.Microsoft.UI.Xaml.Controls.IFrame, handler: win32more.Microsoft.UI.Xaml.Navigation.NavigationFailedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_NavigationFailed(self: win32more.Microsoft.UI.Xaml.Controls.IFrame, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_NavigationStopped(self: win32more.Microsoft.UI.Xaml.Controls.IFrame, handler: win32more.Microsoft.UI.Xaml.Navigation.NavigationStoppedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_NavigationStopped(self: win32more.Microsoft.UI.Xaml.Controls.IFrame, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def GoBack(self: win32more.Microsoft.UI.Xaml.Controls.IFrame) -> Void: ...
    @winrt_mixinmethod
    def GoBackWithTransitionInfo(self: win32more.Microsoft.UI.Xaml.Controls.IFrame, transitionInfoOverride: win32more.Microsoft.UI.Xaml.Media.Animation.NavigationTransitionInfo) -> Void: ...
    @winrt_mixinmethod
    def GoForward(self: win32more.Microsoft.UI.Xaml.Controls.IFrame) -> Void: ...
    @winrt_overload
    @winrt_mixinmethod
    def Navigate(self: win32more.Microsoft.UI.Xaml.Controls.IFrame, sourcePageType: win32more.Windows.UI.Xaml.Interop.TypeName, parameter: IInspectable) -> Boolean: ...
    @winrt_mixinmethod
    def NavigateWithTransitionInfo(self: win32more.Microsoft.UI.Xaml.Controls.IFrame, sourcePageType: win32more.Windows.UI.Xaml.Interop.TypeName, parameter: IInspectable, infoOverride: win32more.Microsoft.UI.Xaml.Media.Animation.NavigationTransitionInfo) -> Boolean: ...
    @winrt_mixinmethod
    def NavigateToType(self: win32more.Microsoft.UI.Xaml.Controls.IFrame, sourcePageType: win32more.Windows.UI.Xaml.Interop.TypeName, parameter: IInspectable, navigationOptions: win32more.Microsoft.UI.Xaml.Navigation.FrameNavigationOptions) -> Boolean: ...
    @winrt_mixinmethod
    def GetNavigationState(self: win32more.Microsoft.UI.Xaml.Controls.IFrame) -> hstr: ...
    @winrt_mixinmethod
    def SetNavigationState(self: win32more.Microsoft.UI.Xaml.Controls.IFrame, navigationState: hstr) -> Void: ...
    @winrt_mixinmethod
    def SetNavigationStateWithNavigationControl(self: win32more.Microsoft.UI.Xaml.Controls.IFrame, navigationState: hstr, suppressNavigate: Boolean) -> Void: ...
    @Navigate.register
    @winrt_mixinmethod
    def Navigate(self: win32more.Microsoft.UI.Xaml.Controls.INavigate, sourcePageType: win32more.Windows.UI.Xaml.Interop.TypeName) -> Boolean: ...
    @winrt_classmethod
    def get_CacheSizeProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IFrameStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CanGoBackProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IFrameStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CanGoForwardProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IFrameStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CurrentSourcePageTypeProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IFrameStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SourcePageTypeProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IFrameStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_BackStackDepthProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IFrameStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_BackStackProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IFrameStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ForwardStackProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IFrameStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsNavigationStackEnabledProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IFrameStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    BackStack = property(get_BackStack, None)
    BackStackDepth = property(get_BackStackDepth, None)
    CacheSize = property(get_CacheSize, put_CacheSize)
    CanGoBack = property(get_CanGoBack, None)
    CanGoForward = property(get_CanGoForward, None)
    CurrentSourcePageType = property(get_CurrentSourcePageType, None)
    ForwardStack = property(get_ForwardStack, None)
    IsNavigationStackEnabled = property(get_IsNavigationStackEnabled, put_IsNavigationStackEnabled)
    SourcePageType = property(get_SourcePageType, put_SourcePageType)
    _Frame_Meta_.BackStackDepthProperty = property(get_BackStackDepthProperty, None)
    _Frame_Meta_.BackStackProperty = property(get_BackStackProperty, None)
    _Frame_Meta_.CacheSizeProperty = property(get_CacheSizeProperty, None)
    _Frame_Meta_.CanGoBackProperty = property(get_CanGoBackProperty, None)
    _Frame_Meta_.CanGoForwardProperty = property(get_CanGoForwardProperty, None)
    _Frame_Meta_.CurrentSourcePageTypeProperty = property(get_CurrentSourcePageTypeProperty, None)
    _Frame_Meta_.ForwardStackProperty = property(get_ForwardStackProperty, None)
    _Frame_Meta_.IsNavigationStackEnabledProperty = property(get_IsNavigationStackEnabledProperty, None)
    _Frame_Meta_.SourcePageTypeProperty = property(get_SourcePageTypeProperty, None)
    Navigated = event(add_Navigated, remove_Navigated)
    Navigating = event(add_Navigating, remove_Navigating)
    NavigationFailed = event(add_NavigationFailed, remove_NavigationFailed)
    NavigationStopped = event(add_NavigationStopped, remove_NavigationStopped)
class _Grid_Meta_(ComPtr.__class__):
    pass
class Grid(ComPtr, metaclass=_Grid_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.Panel
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IGrid
    _classid_ = 'Microsoft.UI.Xaml.Controls.Grid'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.Grid.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IGridFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.Grid: ...
    @winrt_mixinmethod
    def get_RowDefinitions(self: win32more.Microsoft.UI.Xaml.Controls.IGrid) -> win32more.Microsoft.UI.Xaml.Controls.RowDefinitionCollection: ...
    @winrt_mixinmethod
    def get_ColumnDefinitions(self: win32more.Microsoft.UI.Xaml.Controls.IGrid) -> win32more.Microsoft.UI.Xaml.Controls.ColumnDefinitionCollection: ...
    @winrt_mixinmethod
    def get_BackgroundSizing(self: win32more.Microsoft.UI.Xaml.Controls.IGrid) -> win32more.Microsoft.UI.Xaml.Controls.BackgroundSizing: ...
    @winrt_mixinmethod
    def put_BackgroundSizing(self: win32more.Microsoft.UI.Xaml.Controls.IGrid, value: win32more.Microsoft.UI.Xaml.Controls.BackgroundSizing) -> Void: ...
    @winrt_mixinmethod
    def get_BorderBrush(self: win32more.Microsoft.UI.Xaml.Controls.IGrid) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_BorderBrush(self: win32more.Microsoft.UI.Xaml.Controls.IGrid, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_BorderThickness(self: win32more.Microsoft.UI.Xaml.Controls.IGrid) -> win32more.Microsoft.UI.Xaml.Thickness: ...
    @winrt_mixinmethod
    def put_BorderThickness(self: win32more.Microsoft.UI.Xaml.Controls.IGrid, value: win32more.Microsoft.UI.Xaml.Thickness) -> Void: ...
    @winrt_mixinmethod
    def get_CornerRadius(self: win32more.Microsoft.UI.Xaml.Controls.IGrid) -> win32more.Microsoft.UI.Xaml.CornerRadius: ...
    @winrt_mixinmethod
    def put_CornerRadius(self: win32more.Microsoft.UI.Xaml.Controls.IGrid, value: win32more.Microsoft.UI.Xaml.CornerRadius) -> Void: ...
    @winrt_mixinmethod
    def get_Padding(self: win32more.Microsoft.UI.Xaml.Controls.IGrid) -> win32more.Microsoft.UI.Xaml.Thickness: ...
    @winrt_mixinmethod
    def put_Padding(self: win32more.Microsoft.UI.Xaml.Controls.IGrid, value: win32more.Microsoft.UI.Xaml.Thickness) -> Void: ...
    @winrt_mixinmethod
    def get_RowSpacing(self: win32more.Microsoft.UI.Xaml.Controls.IGrid) -> Double: ...
    @winrt_mixinmethod
    def put_RowSpacing(self: win32more.Microsoft.UI.Xaml.Controls.IGrid, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_ColumnSpacing(self: win32more.Microsoft.UI.Xaml.Controls.IGrid) -> Double: ...
    @winrt_mixinmethod
    def put_ColumnSpacing(self: win32more.Microsoft.UI.Xaml.Controls.IGrid, value: Double) -> Void: ...
    @winrt_classmethod
    def get_BackgroundSizingProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IGridStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_BorderBrushProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IGridStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_BorderThicknessProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IGridStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CornerRadiusProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IGridStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PaddingProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IGridStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_RowSpacingProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IGridStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ColumnSpacingProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IGridStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_RowProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IGridStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetRow(cls: win32more.Microsoft.UI.Xaml.Controls.IGridStatics, element: win32more.Microsoft.UI.Xaml.FrameworkElement) -> Int32: ...
    @winrt_classmethod
    def SetRow(cls: win32more.Microsoft.UI.Xaml.Controls.IGridStatics, element: win32more.Microsoft.UI.Xaml.FrameworkElement, value: Int32) -> Void: ...
    @winrt_classmethod
    def get_ColumnProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IGridStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetColumn(cls: win32more.Microsoft.UI.Xaml.Controls.IGridStatics, element: win32more.Microsoft.UI.Xaml.FrameworkElement) -> Int32: ...
    @winrt_classmethod
    def SetColumn(cls: win32more.Microsoft.UI.Xaml.Controls.IGridStatics, element: win32more.Microsoft.UI.Xaml.FrameworkElement, value: Int32) -> Void: ...
    @winrt_classmethod
    def get_RowSpanProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IGridStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetRowSpan(cls: win32more.Microsoft.UI.Xaml.Controls.IGridStatics, element: win32more.Microsoft.UI.Xaml.FrameworkElement) -> Int32: ...
    @winrt_classmethod
    def SetRowSpan(cls: win32more.Microsoft.UI.Xaml.Controls.IGridStatics, element: win32more.Microsoft.UI.Xaml.FrameworkElement, value: Int32) -> Void: ...
    @winrt_classmethod
    def get_ColumnSpanProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IGridStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetColumnSpan(cls: win32more.Microsoft.UI.Xaml.Controls.IGridStatics, element: win32more.Microsoft.UI.Xaml.FrameworkElement) -> Int32: ...
    @winrt_classmethod
    def SetColumnSpan(cls: win32more.Microsoft.UI.Xaml.Controls.IGridStatics, element: win32more.Microsoft.UI.Xaml.FrameworkElement, value: Int32) -> Void: ...
    BackgroundSizing = property(get_BackgroundSizing, put_BackgroundSizing)
    BorderBrush = property(get_BorderBrush, put_BorderBrush)
    BorderThickness = property(get_BorderThickness, put_BorderThickness)
    ColumnDefinitions = property(get_ColumnDefinitions, None)
    ColumnSpacing = property(get_ColumnSpacing, put_ColumnSpacing)
    CornerRadius = property(get_CornerRadius, put_CornerRadius)
    Padding = property(get_Padding, put_Padding)
    RowDefinitions = property(get_RowDefinitions, None)
    RowSpacing = property(get_RowSpacing, put_RowSpacing)
    _Grid_Meta_.BackgroundSizingProperty = property(get_BackgroundSizingProperty, None)
    _Grid_Meta_.BorderBrushProperty = property(get_BorderBrushProperty, None)
    _Grid_Meta_.BorderThicknessProperty = property(get_BorderThicknessProperty, None)
    _Grid_Meta_.ColumnProperty = property(get_ColumnProperty, None)
    _Grid_Meta_.ColumnSpacingProperty = property(get_ColumnSpacingProperty, None)
    _Grid_Meta_.ColumnSpanProperty = property(get_ColumnSpanProperty, None)
    _Grid_Meta_.CornerRadiusProperty = property(get_CornerRadiusProperty, None)
    _Grid_Meta_.PaddingProperty = property(get_PaddingProperty, None)
    _Grid_Meta_.RowProperty = property(get_RowProperty, None)
    _Grid_Meta_.RowSpacingProperty = property(get_RowSpacingProperty, None)
    _Grid_Meta_.RowSpanProperty = property(get_RowSpanProperty, None)
class GridView(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.Controls.ListViewBase
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IGridView
    _classid_ = 'Microsoft.UI.Xaml.Controls.GridView'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.GridView.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IGridViewFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.GridView: ...
class GridViewHeaderItem(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.Controls.ListViewBaseHeaderItem
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IGridViewHeaderItem
    _classid_ = 'Microsoft.UI.Xaml.Controls.GridViewHeaderItem'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.GridViewHeaderItem.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IGridViewHeaderItemFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.GridViewHeaderItem: ...
class GridViewItem(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.Controls.Primitives.SelectorItem
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IGridViewItem
    _classid_ = 'Microsoft.UI.Xaml.Controls.GridViewItem'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.GridViewItem.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IGridViewItemFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.GridViewItem: ...
    @winrt_mixinmethod
    def get_TemplateSettings(self: win32more.Microsoft.UI.Xaml.Controls.IGridViewItem) -> win32more.Microsoft.UI.Xaml.Controls.Primitives.GridViewItemTemplateSettings: ...
    TemplateSettings = property(get_TemplateSettings, None)
class GroupItem(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.Controls.ContentControl
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IGroupItem
    _classid_ = 'Microsoft.UI.Xaml.Controls.GroupItem'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.GroupItem.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IGroupItemFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.GroupItem: ...
class GroupStyle(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IGroupStyle
    _classid_ = 'Microsoft.UI.Xaml.Controls.GroupStyle'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.GroupStyle.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IGroupStyleFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.GroupStyle: ...
    @winrt_mixinmethod
    def get_Panel(self: win32more.Microsoft.UI.Xaml.Controls.IGroupStyle) -> win32more.Microsoft.UI.Xaml.Controls.ItemsPanelTemplate: ...
    @winrt_mixinmethod
    def put_Panel(self: win32more.Microsoft.UI.Xaml.Controls.IGroupStyle, value: win32more.Microsoft.UI.Xaml.Controls.ItemsPanelTemplate) -> Void: ...
    @winrt_mixinmethod
    def get_ContainerStyle(self: win32more.Microsoft.UI.Xaml.Controls.IGroupStyle) -> win32more.Microsoft.UI.Xaml.Style: ...
    @winrt_mixinmethod
    def put_ContainerStyle(self: win32more.Microsoft.UI.Xaml.Controls.IGroupStyle, value: win32more.Microsoft.UI.Xaml.Style) -> Void: ...
    @winrt_mixinmethod
    def get_HeaderContainerStyle(self: win32more.Microsoft.UI.Xaml.Controls.IGroupStyle) -> win32more.Microsoft.UI.Xaml.Style: ...
    @winrt_mixinmethod
    def put_HeaderContainerStyle(self: win32more.Microsoft.UI.Xaml.Controls.IGroupStyle, value: win32more.Microsoft.UI.Xaml.Style) -> Void: ...
    @winrt_mixinmethod
    def get_ContainerStyleSelector(self: win32more.Microsoft.UI.Xaml.Controls.IGroupStyle) -> win32more.Microsoft.UI.Xaml.Controls.StyleSelector: ...
    @winrt_mixinmethod
    def put_ContainerStyleSelector(self: win32more.Microsoft.UI.Xaml.Controls.IGroupStyle, value: win32more.Microsoft.UI.Xaml.Controls.StyleSelector) -> Void: ...
    @winrt_mixinmethod
    def get_HeaderTemplate(self: win32more.Microsoft.UI.Xaml.Controls.IGroupStyle) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def put_HeaderTemplate(self: win32more.Microsoft.UI.Xaml.Controls.IGroupStyle, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_mixinmethod
    def get_HeaderTemplateSelector(self: win32more.Microsoft.UI.Xaml.Controls.IGroupStyle) -> win32more.Microsoft.UI.Xaml.Controls.DataTemplateSelector: ...
    @winrt_mixinmethod
    def put_HeaderTemplateSelector(self: win32more.Microsoft.UI.Xaml.Controls.IGroupStyle, value: win32more.Microsoft.UI.Xaml.Controls.DataTemplateSelector) -> Void: ...
    @winrt_mixinmethod
    def get_HidesIfEmpty(self: win32more.Microsoft.UI.Xaml.Controls.IGroupStyle) -> Boolean: ...
    @winrt_mixinmethod
    def put_HidesIfEmpty(self: win32more.Microsoft.UI.Xaml.Controls.IGroupStyle, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def add_PropertyChanged(self: win32more.Microsoft.UI.Xaml.Data.INotifyPropertyChanged, handler: win32more.Microsoft.UI.Xaml.Data.PropertyChangedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_PropertyChanged(self: win32more.Microsoft.UI.Xaml.Data.INotifyPropertyChanged, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    ContainerStyle = property(get_ContainerStyle, put_ContainerStyle)
    ContainerStyleSelector = property(get_ContainerStyleSelector, put_ContainerStyleSelector)
    HeaderContainerStyle = property(get_HeaderContainerStyle, put_HeaderContainerStyle)
    HeaderTemplate = property(get_HeaderTemplate, put_HeaderTemplate)
    HeaderTemplateSelector = property(get_HeaderTemplateSelector, put_HeaderTemplateSelector)
    HidesIfEmpty = property(get_HidesIfEmpty, put_HidesIfEmpty)
    Panel = property(get_Panel, put_Panel)
    PropertyChanged = event(add_PropertyChanged, remove_PropertyChanged)
class GroupStyleSelector(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IGroupStyleSelector
    _classid_ = 'Microsoft.UI.Xaml.Controls.GroupStyleSelector'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.GroupStyleSelector.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IGroupStyleSelectorFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.GroupStyleSelector: ...
    @winrt_mixinmethod
    def SelectGroupStyle(self: win32more.Microsoft.UI.Xaml.Controls.IGroupStyleSelector, group: IInspectable, level: UInt32) -> win32more.Microsoft.UI.Xaml.Controls.GroupStyle: ...
    @winrt_mixinmethod
    def SelectGroupStyleCore(self: win32more.Microsoft.UI.Xaml.Controls.IGroupStyleSelectorOverrides, group: IInspectable, level: UInt32) -> win32more.Microsoft.UI.Xaml.Controls.GroupStyle: ...
class HasValidationErrorsChangedEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IHasValidationErrorsChangedEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.HasValidationErrorsChangedEventArgs'
    @winrt_mixinmethod
    def get_NewValue(self: win32more.Microsoft.UI.Xaml.Controls.IHasValidationErrorsChangedEventArgs) -> Boolean: ...
    NewValue = property(get_NewValue, None)
class _Hub_Meta_(ComPtr.__class__):
    pass
class Hub(ComPtr, metaclass=_Hub_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.Control
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IHub
    _classid_ = 'Microsoft.UI.Xaml.Controls.Hub'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.Hub.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IHubFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.Hub: ...
    @winrt_mixinmethod
    def get_Header(self: win32more.Microsoft.UI.Xaml.Controls.IHub) -> IInspectable: ...
    @winrt_mixinmethod
    def put_Header(self: win32more.Microsoft.UI.Xaml.Controls.IHub, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_HeaderTemplate(self: win32more.Microsoft.UI.Xaml.Controls.IHub) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def put_HeaderTemplate(self: win32more.Microsoft.UI.Xaml.Controls.IHub, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_mixinmethod
    def get_Orientation(self: win32more.Microsoft.UI.Xaml.Controls.IHub) -> win32more.Microsoft.UI.Xaml.Controls.Orientation: ...
    @winrt_mixinmethod
    def put_Orientation(self: win32more.Microsoft.UI.Xaml.Controls.IHub, value: win32more.Microsoft.UI.Xaml.Controls.Orientation) -> Void: ...
    @winrt_mixinmethod
    def get_DefaultSectionIndex(self: win32more.Microsoft.UI.Xaml.Controls.IHub) -> Int32: ...
    @winrt_mixinmethod
    def put_DefaultSectionIndex(self: win32more.Microsoft.UI.Xaml.Controls.IHub, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_Sections(self: win32more.Microsoft.UI.Xaml.Controls.IHub) -> win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.HubSection]: ...
    @winrt_mixinmethod
    def get_SectionsInView(self: win32more.Microsoft.UI.Xaml.Controls.IHub) -> win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.HubSection]: ...
    @winrt_mixinmethod
    def get_SectionHeaders(self: win32more.Microsoft.UI.Xaml.Controls.IHub) -> win32more.Windows.Foundation.Collections.IObservableVector[IInspectable]: ...
    @winrt_mixinmethod
    def add_SectionHeaderClick(self: win32more.Microsoft.UI.Xaml.Controls.IHub, handler: win32more.Microsoft.UI.Xaml.Controls.HubSectionHeaderClickEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_SectionHeaderClick(self: win32more.Microsoft.UI.Xaml.Controls.IHub, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_SectionsInViewChanged(self: win32more.Microsoft.UI.Xaml.Controls.IHub, handler: win32more.Microsoft.UI.Xaml.Controls.SectionsInViewChangedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_SectionsInViewChanged(self: win32more.Microsoft.UI.Xaml.Controls.IHub, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def ScrollToSection(self: win32more.Microsoft.UI.Xaml.Controls.IHub, section: win32more.Microsoft.UI.Xaml.Controls.HubSection) -> Void: ...
    @winrt_mixinmethod
    def get_SemanticZoomOwner(self: win32more.Microsoft.UI.Xaml.Controls.ISemanticZoomInformation) -> win32more.Microsoft.UI.Xaml.Controls.SemanticZoom: ...
    @winrt_mixinmethod
    def put_SemanticZoomOwner(self: win32more.Microsoft.UI.Xaml.Controls.ISemanticZoomInformation, value: win32more.Microsoft.UI.Xaml.Controls.SemanticZoom) -> Void: ...
    @winrt_mixinmethod
    def get_IsActiveView(self: win32more.Microsoft.UI.Xaml.Controls.ISemanticZoomInformation) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsActiveView(self: win32more.Microsoft.UI.Xaml.Controls.ISemanticZoomInformation, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsZoomedInView(self: win32more.Microsoft.UI.Xaml.Controls.ISemanticZoomInformation) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsZoomedInView(self: win32more.Microsoft.UI.Xaml.Controls.ISemanticZoomInformation, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def InitializeViewChange(self: win32more.Microsoft.UI.Xaml.Controls.ISemanticZoomInformation) -> Void: ...
    @winrt_mixinmethod
    def CompleteViewChange(self: win32more.Microsoft.UI.Xaml.Controls.ISemanticZoomInformation) -> Void: ...
    @winrt_mixinmethod
    def MakeVisible(self: win32more.Microsoft.UI.Xaml.Controls.ISemanticZoomInformation, item: win32more.Microsoft.UI.Xaml.Controls.SemanticZoomLocation) -> Void: ...
    @winrt_mixinmethod
    def StartViewChangeFrom(self: win32more.Microsoft.UI.Xaml.Controls.ISemanticZoomInformation, source: win32more.Microsoft.UI.Xaml.Controls.SemanticZoomLocation, destination: win32more.Microsoft.UI.Xaml.Controls.SemanticZoomLocation) -> Void: ...
    @winrt_mixinmethod
    def StartViewChangeTo(self: win32more.Microsoft.UI.Xaml.Controls.ISemanticZoomInformation, source: win32more.Microsoft.UI.Xaml.Controls.SemanticZoomLocation, destination: win32more.Microsoft.UI.Xaml.Controls.SemanticZoomLocation) -> Void: ...
    @winrt_mixinmethod
    def CompleteViewChangeFrom(self: win32more.Microsoft.UI.Xaml.Controls.ISemanticZoomInformation, source: win32more.Microsoft.UI.Xaml.Controls.SemanticZoomLocation, destination: win32more.Microsoft.UI.Xaml.Controls.SemanticZoomLocation) -> Void: ...
    @winrt_mixinmethod
    def CompleteViewChangeTo(self: win32more.Microsoft.UI.Xaml.Controls.ISemanticZoomInformation, source: win32more.Microsoft.UI.Xaml.Controls.SemanticZoomLocation, destination: win32more.Microsoft.UI.Xaml.Controls.SemanticZoomLocation) -> Void: ...
    @winrt_classmethod
    def get_HeaderProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IHubStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HeaderTemplateProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IHubStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_OrientationProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IHubStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DefaultSectionIndexProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IHubStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SemanticZoomOwnerProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IHubStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsActiveViewProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IHubStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsZoomedInViewProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IHubStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    DefaultSectionIndex = property(get_DefaultSectionIndex, put_DefaultSectionIndex)
    Header = property(get_Header, put_Header)
    HeaderTemplate = property(get_HeaderTemplate, put_HeaderTemplate)
    IsActiveView = property(get_IsActiveView, put_IsActiveView)
    IsZoomedInView = property(get_IsZoomedInView, put_IsZoomedInView)
    Orientation = property(get_Orientation, put_Orientation)
    SectionHeaders = property(get_SectionHeaders, None)
    Sections = property(get_Sections, None)
    SectionsInView = property(get_SectionsInView, None)
    SemanticZoomOwner = property(get_SemanticZoomOwner, put_SemanticZoomOwner)
    _Hub_Meta_.DefaultSectionIndexProperty = property(get_DefaultSectionIndexProperty, None)
    _Hub_Meta_.HeaderProperty = property(get_HeaderProperty, None)
    _Hub_Meta_.HeaderTemplateProperty = property(get_HeaderTemplateProperty, None)
    _Hub_Meta_.IsActiveViewProperty = property(get_IsActiveViewProperty, None)
    _Hub_Meta_.IsZoomedInViewProperty = property(get_IsZoomedInViewProperty, None)
    _Hub_Meta_.OrientationProperty = property(get_OrientationProperty, None)
    _Hub_Meta_.SemanticZoomOwnerProperty = property(get_SemanticZoomOwnerProperty, None)
    SectionHeaderClick = event(add_SectionHeaderClick, remove_SectionHeaderClick)
    SectionsInViewChanged = event(add_SectionsInViewChanged, remove_SectionsInViewChanged)
class _HubSection_Meta_(ComPtr.__class__):
    pass
class HubSection(ComPtr, metaclass=_HubSection_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.Control
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IHubSection
    _classid_ = 'Microsoft.UI.Xaml.Controls.HubSection'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.HubSection.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IHubSectionFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.HubSection: ...
    @winrt_mixinmethod
    def get_Header(self: win32more.Microsoft.UI.Xaml.Controls.IHubSection) -> IInspectable: ...
    @winrt_mixinmethod
    def put_Header(self: win32more.Microsoft.UI.Xaml.Controls.IHubSection, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_HeaderTemplate(self: win32more.Microsoft.UI.Xaml.Controls.IHubSection) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def put_HeaderTemplate(self: win32more.Microsoft.UI.Xaml.Controls.IHubSection, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_mixinmethod
    def get_ContentTemplate(self: win32more.Microsoft.UI.Xaml.Controls.IHubSection) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def put_ContentTemplate(self: win32more.Microsoft.UI.Xaml.Controls.IHubSection, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_mixinmethod
    def get_IsHeaderInteractive(self: win32more.Microsoft.UI.Xaml.Controls.IHubSection) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsHeaderInteractive(self: win32more.Microsoft.UI.Xaml.Controls.IHubSection, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_HeaderProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IHubSectionStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HeaderTemplateProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IHubSectionStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ContentTemplateProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IHubSectionStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsHeaderInteractiveProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IHubSectionStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    ContentTemplate = property(get_ContentTemplate, put_ContentTemplate)
    Header = property(get_Header, put_Header)
    HeaderTemplate = property(get_HeaderTemplate, put_HeaderTemplate)
    IsHeaderInteractive = property(get_IsHeaderInteractive, put_IsHeaderInteractive)
    _HubSection_Meta_.ContentTemplateProperty = property(get_ContentTemplateProperty, None)
    _HubSection_Meta_.HeaderProperty = property(get_HeaderProperty, None)
    _HubSection_Meta_.HeaderTemplateProperty = property(get_HeaderTemplateProperty, None)
    _HubSection_Meta_.IsHeaderInteractiveProperty = property(get_IsHeaderInteractiveProperty, None)
class HubSectionCollection(ComPtr):
    extends: IInspectable
    implements: Tuple[SequenceProtocol[win32more.Microsoft.UI.Xaml.Controls.HubSection]]
    default_interface: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.HubSection]
    _classid_ = 'Microsoft.UI.Xaml.Controls.HubSectionCollection'
    @winrt_mixinmethod
    def GetAt(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.HubSection], index: UInt32) -> win32more.Microsoft.UI.Xaml.Controls.HubSection: ...
    @winrt_mixinmethod
    def get_Size(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.HubSection]) -> UInt32: ...
    @winrt_mixinmethod
    def GetView(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.HubSection]) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Microsoft.UI.Xaml.Controls.HubSection]: ...
    @winrt_mixinmethod
    def IndexOf(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.HubSection], value: win32more.Microsoft.UI.Xaml.Controls.HubSection, index: POINTER(UInt32)) -> Boolean: ...
    @winrt_mixinmethod
    def SetAt(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.HubSection], index: UInt32, value: win32more.Microsoft.UI.Xaml.Controls.HubSection) -> Void: ...
    @winrt_mixinmethod
    def InsertAt(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.HubSection], index: UInt32, value: win32more.Microsoft.UI.Xaml.Controls.HubSection) -> Void: ...
    @winrt_mixinmethod
    def RemoveAt(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.HubSection], index: UInt32) -> Void: ...
    @winrt_mixinmethod
    def Append(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.HubSection], value: win32more.Microsoft.UI.Xaml.Controls.HubSection) -> Void: ...
    @winrt_mixinmethod
    def RemoveAtEnd(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.HubSection]) -> Void: ...
    @winrt_mixinmethod
    def Clear(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.HubSection]) -> Void: ...
    @winrt_mixinmethod
    def GetMany(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.HubSection], startIndex: UInt32, items: FillArray[win32more.Microsoft.UI.Xaml.Controls.HubSection]) -> UInt32: ...
    @winrt_mixinmethod
    def ReplaceAll(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.HubSection], items: PassArray[win32more.Microsoft.UI.Xaml.Controls.HubSection]) -> Void: ...
    @winrt_mixinmethod
    def First(self: win32more.Windows.Foundation.Collections.IIterable[win32more.Microsoft.UI.Xaml.Controls.HubSection]) -> win32more.Windows.Foundation.Collections.IIterator[win32more.Microsoft.UI.Xaml.Controls.HubSection]: ...
    Size = property(get_Size, None)
class HubSectionHeaderClickEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IHubSectionHeaderClickEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.HubSectionHeaderClickEventArgs'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.HubSectionHeaderClickEventArgs.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Controls.HubSectionHeaderClickEventArgs: ...
    @winrt_mixinmethod
    def get_Section(self: win32more.Microsoft.UI.Xaml.Controls.IHubSectionHeaderClickEventArgs) -> win32more.Microsoft.UI.Xaml.Controls.HubSection: ...
    Section = property(get_Section, None)
class HubSectionHeaderClickEventHandler(MulticastDelegate):
    extends: IUnknown
    _iid_ = Guid('{f69971da-162f-51ec-9fd9-37f9b57a68f9}')
    @winrt_commethod(3)
    def Invoke(self, sender: IInspectable, e: win32more.Microsoft.UI.Xaml.Controls.HubSectionHeaderClickEventArgs) -> Void: ...
class _HyperlinkButton_Meta_(ComPtr.__class__):
    pass
class HyperlinkButton(ComPtr, metaclass=_HyperlinkButton_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.Primitives.ButtonBase
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IHyperlinkButton
    _classid_ = 'Microsoft.UI.Xaml.Controls.HyperlinkButton'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.HyperlinkButton.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IHyperlinkButtonFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.HyperlinkButton: ...
    @winrt_mixinmethod
    def get_NavigateUri(self: win32more.Microsoft.UI.Xaml.Controls.IHyperlinkButton) -> win32more.Windows.Foundation.Uri: ...
    @winrt_mixinmethod
    def put_NavigateUri(self: win32more.Microsoft.UI.Xaml.Controls.IHyperlinkButton, value: win32more.Windows.Foundation.Uri) -> Void: ...
    @winrt_classmethod
    def get_NavigateUriProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IHyperlinkButtonStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    NavigateUri = property(get_NavigateUri, put_NavigateUri)
    _HyperlinkButton_Meta_.NavigateUriProperty = property(get_NavigateUriProperty, None)
class IAnchorRequestedEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IAnchorRequestedEventArgs'
    _iid_ = Guid('{d5645e80-d4d3-5df8-a3ac-1f9beeb2bcef}')
    @winrt_commethod(6)
    def get_Anchor(self) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_commethod(7)
    def put_Anchor(self, value: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    @winrt_commethod(8)
    def get_AnchorCandidates(self) -> win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.UIElement]: ...
    Anchor = property(get_Anchor, put_Anchor)
    AnchorCandidates = property(get_AnchorCandidates, None)
class IAnimatedIcon(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IAnimatedIcon'
    _iid_ = Guid('{f705dfda-8196-56d0-8dcf-2b66c2aed791}')
    @winrt_commethod(6)
    def get_Source(self) -> win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisualSource2: ...
    @winrt_commethod(7)
    def put_Source(self, value: win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisualSource2) -> Void: ...
    @winrt_commethod(8)
    def get_FallbackIconSource(self) -> win32more.Microsoft.UI.Xaml.Controls.IconSource: ...
    @winrt_commethod(9)
    def put_FallbackIconSource(self, value: win32more.Microsoft.UI.Xaml.Controls.IconSource) -> Void: ...
    @winrt_commethod(10)
    def get_MirroredWhenRightToLeft(self) -> Boolean: ...
    @winrt_commethod(11)
    def put_MirroredWhenRightToLeft(self, value: Boolean) -> Void: ...
    FallbackIconSource = property(get_FallbackIconSource, put_FallbackIconSource)
    MirroredWhenRightToLeft = property(get_MirroredWhenRightToLeft, put_MirroredWhenRightToLeft)
    Source = property(get_Source, put_Source)
class IAnimatedIconFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IAnimatedIconFactory'
    _iid_ = Guid('{3356e0d1-d82f-5fc1-8165-9b9d1b9d9514}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.AnimatedIcon: ...
class IAnimatedIconSource(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IAnimatedIconSource'
    _iid_ = Guid('{2846a198-731b-5379-85ac-8f28027f7183}')
    @winrt_commethod(6)
    def get_Source(self) -> win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisualSource2: ...
    @winrt_commethod(7)
    def put_Source(self, value: win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisualSource2) -> Void: ...
    @winrt_commethod(8)
    def get_FallbackIconSource(self) -> win32more.Microsoft.UI.Xaml.Controls.IconSource: ...
    @winrt_commethod(9)
    def put_FallbackIconSource(self, value: win32more.Microsoft.UI.Xaml.Controls.IconSource) -> Void: ...
    @winrt_commethod(10)
    def get_MirroredWhenRightToLeft(self) -> Boolean: ...
    @winrt_commethod(11)
    def put_MirroredWhenRightToLeft(self, value: Boolean) -> Void: ...
    FallbackIconSource = property(get_FallbackIconSource, put_FallbackIconSource)
    MirroredWhenRightToLeft = property(get_MirroredWhenRightToLeft, put_MirroredWhenRightToLeft)
    Source = property(get_Source, put_Source)
class IAnimatedIconSourceFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IAnimatedIconSourceFactory'
    _iid_ = Guid('{ae8fb7de-7ec2-5ae2-b461-bead570420fa}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.AnimatedIconSource: ...
class IAnimatedIconSourceStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IAnimatedIconSourceStatics'
    _iid_ = Guid('{8e4919fc-e8aa-5428-9779-6fe7168afa1c}')
    @winrt_commethod(6)
    def get_SourceProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_FallbackIconSourceProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_MirroredWhenRightToLeftProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    FallbackIconSourceProperty = property(get_FallbackIconSourceProperty, None)
    MirroredWhenRightToLeftProperty = property(get_MirroredWhenRightToLeftProperty, None)
    SourceProperty = property(get_SourceProperty, None)
class IAnimatedIconStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IAnimatedIconStatics'
    _iid_ = Guid('{51cc5230-a001-55ff-9fc8-bd51b2a3277b}')
    @winrt_commethod(6)
    def get_StateProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def SetState(self, object: win32more.Microsoft.UI.Xaml.DependencyObject, value: hstr) -> Void: ...
    @winrt_commethod(8)
    def GetState(self, object: win32more.Microsoft.UI.Xaml.DependencyObject) -> hstr: ...
    @winrt_commethod(9)
    def get_SourceProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_FallbackIconSourceProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_MirroredWhenRightToLeftProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    FallbackIconSourceProperty = property(get_FallbackIconSourceProperty, None)
    MirroredWhenRightToLeftProperty = property(get_MirroredWhenRightToLeftProperty, None)
    SourceProperty = property(get_SourceProperty, None)
    StateProperty = property(get_StateProperty, None)
class IAnimatedVisual(ComPtr):
    extends: IInspectable
    implements: Tuple[ContextManagerProtocol]
    _classid_ = 'Microsoft.UI.Xaml.Controls.IAnimatedVisual'
    _iid_ = Guid('{645ff609-fd6b-5fef-bdc0-9c34eff33c64}')
    @winrt_commethod(6)
    def get_RootVisual(self) -> win32more.Microsoft.UI.Composition.Visual: ...
    @winrt_commethod(7)
    def get_Size(self) -> win32more.Windows.Foundation.Numerics.Vector2: ...
    @winrt_commethod(8)
    def get_Duration(self) -> win32more.Windows.Foundation.TimeSpan: ...
    Duration = property(get_Duration, None)
    RootVisual = property(get_RootVisual, None)
    Size = property(get_Size, None)
class IAnimatedVisual2(ComPtr):
    extends: IInspectable
    implements: Tuple[ContextManagerProtocol]
    _classid_ = 'Microsoft.UI.Xaml.Controls.IAnimatedVisual2'
    _iid_ = Guid('{763a3f0b-95cc-59ef-9890-147868599de9}')
    @winrt_commethod(6)
    def CreateAnimations(self) -> Void: ...
    @winrt_commethod(7)
    def DestroyAnimations(self) -> Void: ...
class IAnimatedVisualPlayer(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IAnimatedVisualPlayer'
    _iid_ = Guid('{17f024f0-1692-51dd-a4da-f4ed648d614c}')
    @winrt_commethod(6)
    def get_Diagnostics(self) -> IInspectable: ...
    @winrt_commethod(7)
    def get_Duration(self) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_commethod(8)
    def get_Source(self) -> win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisualSource: ...
    @winrt_commethod(9)
    def put_Source(self, value: win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisualSource) -> Void: ...
    @winrt_commethod(10)
    def get_FallbackContent(self) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_commethod(11)
    def put_FallbackContent(self, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_commethod(12)
    def get_AutoPlay(self) -> Boolean: ...
    @winrt_commethod(13)
    def put_AutoPlay(self, value: Boolean) -> Void: ...
    @winrt_commethod(14)
    def get_IsAnimatedVisualLoaded(self) -> Boolean: ...
    @winrt_commethod(15)
    def get_IsPlaying(self) -> Boolean: ...
    @winrt_commethod(16)
    def get_PlaybackRate(self) -> Double: ...
    @winrt_commethod(17)
    def put_PlaybackRate(self, value: Double) -> Void: ...
    @winrt_commethod(18)
    def get_ProgressObject(self) -> win32more.Microsoft.UI.Composition.CompositionObject: ...
    @winrt_commethod(19)
    def get_Stretch(self) -> win32more.Microsoft.UI.Xaml.Media.Stretch: ...
    @winrt_commethod(20)
    def put_Stretch(self, value: win32more.Microsoft.UI.Xaml.Media.Stretch) -> Void: ...
    @winrt_commethod(21)
    def Pause(self) -> Void: ...
    @winrt_commethod(22)
    def PlayAsync(self, fromProgress: Double, toProgress: Double, looped: Boolean) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(23)
    def Resume(self) -> Void: ...
    @winrt_commethod(24)
    def SetProgress(self, progress: Double) -> Void: ...
    @winrt_commethod(25)
    def Stop(self) -> Void: ...
    AutoPlay = property(get_AutoPlay, put_AutoPlay)
    Diagnostics = property(get_Diagnostics, None)
    Duration = property(get_Duration, None)
    FallbackContent = property(get_FallbackContent, put_FallbackContent)
    IsAnimatedVisualLoaded = property(get_IsAnimatedVisualLoaded, None)
    IsPlaying = property(get_IsPlaying, None)
    PlaybackRate = property(get_PlaybackRate, put_PlaybackRate)
    ProgressObject = property(get_ProgressObject, None)
    Source = property(get_Source, put_Source)
    Stretch = property(get_Stretch, put_Stretch)
class IAnimatedVisualPlayer2(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IAnimatedVisualPlayer2'
    _iid_ = Guid('{db33db95-9404-5385-ae32-673e7c358ad3}')
    @winrt_commethod(6)
    def get_AnimationOptimization(self) -> win32more.Microsoft.UI.Xaml.Controls.PlayerAnimationOptimization: ...
    @winrt_commethod(7)
    def put_AnimationOptimization(self, value: win32more.Microsoft.UI.Xaml.Controls.PlayerAnimationOptimization) -> Void: ...
    AnimationOptimization = property(get_AnimationOptimization, put_AnimationOptimization)
class IAnimatedVisualPlayerFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IAnimatedVisualPlayerFactory'
    _iid_ = Guid('{ebc0c6e6-c91a-5025-b4a4-e786d83be1d8}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.AnimatedVisualPlayer: ...
class IAnimatedVisualPlayerStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IAnimatedVisualPlayerStatics'
    _iid_ = Guid('{e3d18d97-c98b-5b91-80db-d70c436aa44a}')
    @winrt_commethod(6)
    def get_AutoPlayProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_DiagnosticsProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_DurationProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_FallbackContentProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_IsAnimatedVisualLoadedProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_IsPlayingProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_PlaybackRateProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_SourceProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(14)
    def get_StretchProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    AutoPlayProperty = property(get_AutoPlayProperty, None)
    DiagnosticsProperty = property(get_DiagnosticsProperty, None)
    DurationProperty = property(get_DurationProperty, None)
    FallbackContentProperty = property(get_FallbackContentProperty, None)
    IsAnimatedVisualLoadedProperty = property(get_IsAnimatedVisualLoadedProperty, None)
    IsPlayingProperty = property(get_IsPlayingProperty, None)
    PlaybackRateProperty = property(get_PlaybackRateProperty, None)
    SourceProperty = property(get_SourceProperty, None)
    StretchProperty = property(get_StretchProperty, None)
class IAnimatedVisualPlayerStatics2(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IAnimatedVisualPlayerStatics2'
    _iid_ = Guid('{559a4f35-aa2d-54e3-a7ff-9e8357c10254}')
    @winrt_commethod(6)
    def get_AnimationOptimizationProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    AnimationOptimizationProperty = property(get_AnimationOptimizationProperty, None)
class IAnimatedVisualSource(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IAnimatedVisualSource'
    _iid_ = Guid('{294765c3-70e3-555c-9657-01fc4051169d}')
    @winrt_commethod(6)
    def TryCreateAnimatedVisual(self, compositor: win32more.Microsoft.UI.Composition.Compositor, diagnostics: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisual: ...
class IAnimatedVisualSource2(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IAnimatedVisualSource2'
    _iid_ = Guid('{1a3b53a7-a8fe-59a1-b544-43a4d9c81ef2}')
    @winrt_commethod(6)
    def get_Markers(self) -> win32more.Windows.Foundation.Collections.IMapView[hstr, Double]: ...
    @winrt_commethod(7)
    def SetColorProperty(self, propertyName: hstr, value: win32more.Windows.UI.Color) -> Void: ...
    Markers = property(get_Markers, None)
class IAnimatedVisualSource3(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IAnimatedVisualSource3'
    _iid_ = Guid('{a152f00d-b7cf-5a8f-aee7-ea1b97c21639}')
    @winrt_commethod(6)
    def TryCreateAnimatedVisual(self, compositor: win32more.Microsoft.UI.Composition.Compositor, diagnostics: POINTER(IInspectable), createAnimations: Boolean) -> win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisual2: ...
class IAnnotatedScrollBar(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IAnnotatedScrollBar'
    _iid_ = Guid('{0f4904a9-b6f9-5834-8d5d-59bc3b7b7ee2}')
    @winrt_commethod(6)
    def get_ScrollController(self) -> win32more.Microsoft.UI.Xaml.Controls.Primitives.IScrollController: ...
    @winrt_commethod(7)
    def get_Labels(self) -> win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.AnnotatedScrollBarLabel]: ...
    @winrt_commethod(8)
    def put_Labels(self, value: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.AnnotatedScrollBarLabel]) -> Void: ...
    @winrt_commethod(9)
    def get_LabelTemplate(self) -> win32more.Microsoft.UI.Xaml.IElementFactory: ...
    @winrt_commethod(10)
    def put_LabelTemplate(self, value: win32more.Microsoft.UI.Xaml.IElementFactory) -> Void: ...
    @winrt_commethod(11)
    def get_DetailLabelTemplate(self) -> win32more.Microsoft.UI.Xaml.IElementFactory: ...
    @winrt_commethod(12)
    def put_DetailLabelTemplate(self, value: win32more.Microsoft.UI.Xaml.IElementFactory) -> Void: ...
    @winrt_commethod(13)
    def get_SmallChange(self) -> Double: ...
    @winrt_commethod(14)
    def put_SmallChange(self, value: Double) -> Void: ...
    @winrt_commethod(15)
    def add_Scrolling(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.AnnotatedScrollBar, win32more.Microsoft.UI.Xaml.Controls.AnnotatedScrollBarScrollingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(16)
    def remove_Scrolling(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(17)
    def add_DetailLabelRequested(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.AnnotatedScrollBar, win32more.Microsoft.UI.Xaml.Controls.AnnotatedScrollBarDetailLabelRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(18)
    def remove_DetailLabelRequested(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    DetailLabelTemplate = property(get_DetailLabelTemplate, put_DetailLabelTemplate)
    LabelTemplate = property(get_LabelTemplate, put_LabelTemplate)
    Labels = property(get_Labels, put_Labels)
    ScrollController = property(get_ScrollController, None)
    SmallChange = property(get_SmallChange, put_SmallChange)
    DetailLabelRequested = event(add_DetailLabelRequested, remove_DetailLabelRequested)
    Scrolling = event(add_Scrolling, remove_Scrolling)
class IAnnotatedScrollBarDetailLabelRequestedEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IAnnotatedScrollBarDetailLabelRequestedEventArgs'
    _iid_ = Guid('{43275b82-f594-590d-90ff-76fd219feaa8}')
    @winrt_commethod(6)
    def get_Content(self) -> IInspectable: ...
    @winrt_commethod(7)
    def put_Content(self, value: IInspectable) -> Void: ...
    @winrt_commethod(8)
    def get_ScrollOffset(self) -> Double: ...
    Content = property(get_Content, put_Content)
    ScrollOffset = property(get_ScrollOffset, None)
class IAnnotatedScrollBarFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IAnnotatedScrollBarFactory'
    _iid_ = Guid('{3f64c40f-b879-5020-b67c-b789e173c798}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.AnnotatedScrollBar: ...
class IAnnotatedScrollBarLabel(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IAnnotatedScrollBarLabel'
    _iid_ = Guid('{238ac07f-59fb-574f-bf5c-61c44ab386dc}')
    @winrt_commethod(6)
    def get_Content(self) -> IInspectable: ...
    @winrt_commethod(7)
    def get_ScrollOffset(self) -> Double: ...
    Content = property(get_Content, None)
    ScrollOffset = property(get_ScrollOffset, None)
class IAnnotatedScrollBarLabelFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IAnnotatedScrollBarLabelFactory'
    _iid_ = Guid('{b6169805-c01c-54c6-80e8-c6c98f9aaa53}')
    @winrt_commethod(6)
    def CreateInstance(self, content: IInspectable, scrollOffset: Double) -> win32more.Microsoft.UI.Xaml.Controls.AnnotatedScrollBarLabel: ...
class IAnnotatedScrollBarScrollingEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IAnnotatedScrollBarScrollingEventArgs'
    _iid_ = Guid('{a7466a60-e55e-58ae-9fc1-87fef40e521a}')
    @winrt_commethod(6)
    def get_ScrollOffset(self) -> Double: ...
    @winrt_commethod(7)
    def get_ScrollingEventKind(self) -> win32more.Microsoft.UI.Xaml.Controls.AnnotatedScrollBarScrollingEventKind: ...
    @winrt_commethod(8)
    def get_Cancel(self) -> Boolean: ...
    @winrt_commethod(9)
    def put_Cancel(self, value: Boolean) -> Void: ...
    Cancel = property(get_Cancel, put_Cancel)
    ScrollOffset = property(get_ScrollOffset, None)
    ScrollingEventKind = property(get_ScrollingEventKind, None)
class IAnnotatedScrollBarStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IAnnotatedScrollBarStatics'
    _iid_ = Guid('{daacd0f4-4912-5934-8d5b-f241c2e90e30}')
    @winrt_commethod(6)
    def get_LabelsProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_LabelTemplateProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_DetailLabelTemplateProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_SmallChangeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    DetailLabelTemplateProperty = property(get_DetailLabelTemplateProperty, None)
    LabelTemplateProperty = property(get_LabelTemplateProperty, None)
    LabelsProperty = property(get_LabelsProperty, None)
    SmallChangeProperty = property(get_SmallChangeProperty, None)
class IAppBar(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IAppBar'
    _iid_ = Guid('{3d8c2927-5ac5-51bb-8bec-13ff4c1bd6c8}')
    @winrt_commethod(6)
    def get_IsOpen(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_IsOpen(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def get_IsSticky(self) -> Boolean: ...
    @winrt_commethod(9)
    def put_IsSticky(self, value: Boolean) -> Void: ...
    @winrt_commethod(10)
    def get_ClosedDisplayMode(self) -> win32more.Microsoft.UI.Xaml.Controls.AppBarClosedDisplayMode: ...
    @winrt_commethod(11)
    def put_ClosedDisplayMode(self, value: win32more.Microsoft.UI.Xaml.Controls.AppBarClosedDisplayMode) -> Void: ...
    @winrt_commethod(12)
    def get_TemplateSettings(self) -> win32more.Microsoft.UI.Xaml.Controls.Primitives.AppBarTemplateSettings: ...
    @winrt_commethod(13)
    def get_LightDismissOverlayMode(self) -> win32more.Microsoft.UI.Xaml.Controls.LightDismissOverlayMode: ...
    @winrt_commethod(14)
    def put_LightDismissOverlayMode(self, value: win32more.Microsoft.UI.Xaml.Controls.LightDismissOverlayMode) -> Void: ...
    @winrt_commethod(15)
    def add_Opening(self, handler: win32more.Windows.Foundation.EventHandler[IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(16)
    def remove_Opening(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(17)
    def add_Opened(self, handler: win32more.Windows.Foundation.EventHandler[IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(18)
    def remove_Opened(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(19)
    def add_Closing(self, handler: win32more.Windows.Foundation.EventHandler[IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(20)
    def remove_Closing(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(21)
    def add_Closed(self, handler: win32more.Windows.Foundation.EventHandler[IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(22)
    def remove_Closed(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    ClosedDisplayMode = property(get_ClosedDisplayMode, put_ClosedDisplayMode)
    IsOpen = property(get_IsOpen, put_IsOpen)
    IsSticky = property(get_IsSticky, put_IsSticky)
    LightDismissOverlayMode = property(get_LightDismissOverlayMode, put_LightDismissOverlayMode)
    TemplateSettings = property(get_TemplateSettings, None)
    Closed = event(add_Closed, remove_Closed)
    Closing = event(add_Closing, remove_Closing)
    Opened = event(add_Opened, remove_Opened)
    Opening = event(add_Opening, remove_Opening)
class IAppBarButton(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IAppBarButton'
    _iid_ = Guid('{8ab0e278-b6ae-569e-8dcd-d293552fe4d5}')
    @winrt_commethod(6)
    def get_Label(self) -> hstr: ...
    @winrt_commethod(7)
    def put_Label(self, value: hstr) -> Void: ...
    @winrt_commethod(8)
    def get_Icon(self) -> win32more.Microsoft.UI.Xaml.Controls.IconElement: ...
    @winrt_commethod(9)
    def put_Icon(self, value: win32more.Microsoft.UI.Xaml.Controls.IconElement) -> Void: ...
    @winrt_commethod(10)
    def get_LabelPosition(self) -> win32more.Microsoft.UI.Xaml.Controls.CommandBarLabelPosition: ...
    @winrt_commethod(11)
    def put_LabelPosition(self, value: win32more.Microsoft.UI.Xaml.Controls.CommandBarLabelPosition) -> Void: ...
    @winrt_commethod(12)
    def get_KeyboardAcceleratorTextOverride(self) -> hstr: ...
    @winrt_commethod(13)
    def put_KeyboardAcceleratorTextOverride(self, value: hstr) -> Void: ...
    @winrt_commethod(14)
    def get_TemplateSettings(self) -> win32more.Microsoft.UI.Xaml.Controls.Primitives.AppBarButtonTemplateSettings: ...
    Icon = property(get_Icon, put_Icon)
    KeyboardAcceleratorTextOverride = property(get_KeyboardAcceleratorTextOverride, put_KeyboardAcceleratorTextOverride)
    Label = property(get_Label, put_Label)
    LabelPosition = property(get_LabelPosition, put_LabelPosition)
    TemplateSettings = property(get_TemplateSettings, None)
class IAppBarButtonFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IAppBarButtonFactory'
    _iid_ = Guid('{4168a40a-d11f-5aeb-974e-bb43a6e7f9b2}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.AppBarButton: ...
class IAppBarButtonStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IAppBarButtonStatics'
    _iid_ = Guid('{74327a2a-18fa-59c3-8268-ec3732a4d272}')
    @winrt_commethod(6)
    def get_LabelProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_IconProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_LabelPositionProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_KeyboardAcceleratorTextOverrideProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_IsCompactProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_IsInOverflowProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_DynamicOverflowOrderProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    DynamicOverflowOrderProperty = property(get_DynamicOverflowOrderProperty, None)
    IconProperty = property(get_IconProperty, None)
    IsCompactProperty = property(get_IsCompactProperty, None)
    IsInOverflowProperty = property(get_IsInOverflowProperty, None)
    KeyboardAcceleratorTextOverrideProperty = property(get_KeyboardAcceleratorTextOverrideProperty, None)
    LabelPositionProperty = property(get_LabelPositionProperty, None)
    LabelProperty = property(get_LabelProperty, None)
class IAppBarElementContainer(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IAppBarElementContainer'
    _iid_ = Guid('{55d90715-70bc-5b2b-bd12-a940297f935f}')
class IAppBarElementContainerFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IAppBarElementContainerFactory'
    _iid_ = Guid('{0664bf62-1fab-5873-9608-117c3b4483ff}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.AppBarElementContainer: ...
class IAppBarElementContainerStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IAppBarElementContainerStatics'
    _iid_ = Guid('{50c068de-72d0-52ba-bb42-ada6527b392f}')
    @winrt_commethod(6)
    def get_IsCompactProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_IsInOverflowProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_DynamicOverflowOrderProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    DynamicOverflowOrderProperty = property(get_DynamicOverflowOrderProperty, None)
    IsCompactProperty = property(get_IsCompactProperty, None)
    IsInOverflowProperty = property(get_IsInOverflowProperty, None)
class IAppBarFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IAppBarFactory'
    _iid_ = Guid('{66b96b53-755b-5472-b2c4-8624e977d65b}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.AppBar: ...
class IAppBarOverrides(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IAppBarOverrides'
    _iid_ = Guid('{67f17798-e281-5e53-8edf-42c29c354d63}')
    @winrt_commethod(6)
    def OnClosed(self, e: IInspectable) -> Void: ...
    @winrt_commethod(7)
    def OnOpened(self, e: IInspectable) -> Void: ...
    @winrt_commethod(8)
    def OnClosing(self, e: IInspectable) -> Void: ...
    @winrt_commethod(9)
    def OnOpening(self, e: IInspectable) -> Void: ...
class IAppBarSeparator(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IAppBarSeparator'
    _iid_ = Guid('{57bb94a3-1e56-5ebe-8a57-3a243c491d67}')
class IAppBarSeparatorFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IAppBarSeparatorFactory'
    _iid_ = Guid('{6497d326-fb55-5cf5-8cc4-c556b1a958fb}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.AppBarSeparator: ...
class IAppBarSeparatorStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IAppBarSeparatorStatics'
    _iid_ = Guid('{dda9a3d2-d3b9-5be1-abf7-dba1eaafe0f7}')
    @winrt_commethod(6)
    def get_IsCompactProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_IsInOverflowProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_DynamicOverflowOrderProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    DynamicOverflowOrderProperty = property(get_DynamicOverflowOrderProperty, None)
    IsCompactProperty = property(get_IsCompactProperty, None)
    IsInOverflowProperty = property(get_IsInOverflowProperty, None)
class IAppBarStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IAppBarStatics'
    _iid_ = Guid('{0dc7172c-a03d-5ae4-9538-ffd804823bce}')
    @winrt_commethod(6)
    def get_IsOpenProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_IsStickyProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_ClosedDisplayModeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_LightDismissOverlayModeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    ClosedDisplayModeProperty = property(get_ClosedDisplayModeProperty, None)
    IsOpenProperty = property(get_IsOpenProperty, None)
    IsStickyProperty = property(get_IsStickyProperty, None)
    LightDismissOverlayModeProperty = property(get_LightDismissOverlayModeProperty, None)
class IAppBarToggleButton(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IAppBarToggleButton'
    _iid_ = Guid('{9687c0b1-c390-59be-acdc-4fc48f552823}')
    @winrt_commethod(6)
    def get_Label(self) -> hstr: ...
    @winrt_commethod(7)
    def put_Label(self, value: hstr) -> Void: ...
    @winrt_commethod(8)
    def get_Icon(self) -> win32more.Microsoft.UI.Xaml.Controls.IconElement: ...
    @winrt_commethod(9)
    def put_Icon(self, value: win32more.Microsoft.UI.Xaml.Controls.IconElement) -> Void: ...
    @winrt_commethod(10)
    def get_LabelPosition(self) -> win32more.Microsoft.UI.Xaml.Controls.CommandBarLabelPosition: ...
    @winrt_commethod(11)
    def put_LabelPosition(self, value: win32more.Microsoft.UI.Xaml.Controls.CommandBarLabelPosition) -> Void: ...
    @winrt_commethod(12)
    def get_KeyboardAcceleratorTextOverride(self) -> hstr: ...
    @winrt_commethod(13)
    def put_KeyboardAcceleratorTextOverride(self, value: hstr) -> Void: ...
    @winrt_commethod(14)
    def get_TemplateSettings(self) -> win32more.Microsoft.UI.Xaml.Controls.Primitives.AppBarToggleButtonTemplateSettings: ...
    Icon = property(get_Icon, put_Icon)
    KeyboardAcceleratorTextOverride = property(get_KeyboardAcceleratorTextOverride, put_KeyboardAcceleratorTextOverride)
    Label = property(get_Label, put_Label)
    LabelPosition = property(get_LabelPosition, put_LabelPosition)
    TemplateSettings = property(get_TemplateSettings, None)
class IAppBarToggleButtonFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IAppBarToggleButtonFactory'
    _iid_ = Guid('{07bfb2d6-23b9-57a2-9122-006294bfa92f}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.AppBarToggleButton: ...
class IAppBarToggleButtonStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IAppBarToggleButtonStatics'
    _iid_ = Guid('{70021504-3fe8-53bc-abd6-d69762f4bc87}')
    @winrt_commethod(6)
    def get_LabelProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_IconProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_LabelPositionProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_KeyboardAcceleratorTextOverrideProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_IsCompactProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_IsInOverflowProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_DynamicOverflowOrderProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    DynamicOverflowOrderProperty = property(get_DynamicOverflowOrderProperty, None)
    IconProperty = property(get_IconProperty, None)
    IsCompactProperty = property(get_IsCompactProperty, None)
    IsInOverflowProperty = property(get_IsInOverflowProperty, None)
    KeyboardAcceleratorTextOverrideProperty = property(get_KeyboardAcceleratorTextOverrideProperty, None)
    LabelPositionProperty = property(get_LabelPositionProperty, None)
    LabelProperty = property(get_LabelProperty, None)
class IAutoSuggestBox(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IAutoSuggestBox'
    _iid_ = Guid('{3eea809e-b2db-521d-97db-e0648fb5d798}')
    @winrt_commethod(6)
    def get_MaxSuggestionListHeight(self) -> Double: ...
    @winrt_commethod(7)
    def put_MaxSuggestionListHeight(self, value: Double) -> Void: ...
    @winrt_commethod(8)
    def get_IsSuggestionListOpen(self) -> Boolean: ...
    @winrt_commethod(9)
    def put_IsSuggestionListOpen(self, value: Boolean) -> Void: ...
    @winrt_commethod(10)
    def get_TextMemberPath(self) -> hstr: ...
    @winrt_commethod(11)
    def put_TextMemberPath(self, value: hstr) -> Void: ...
    @winrt_commethod(12)
    def get_Text(self) -> hstr: ...
    @winrt_commethod(13)
    def put_Text(self, value: hstr) -> Void: ...
    @winrt_commethod(14)
    def get_UpdateTextOnSelect(self) -> Boolean: ...
    @winrt_commethod(15)
    def put_UpdateTextOnSelect(self, value: Boolean) -> Void: ...
    @winrt_commethod(16)
    def get_PlaceholderText(self) -> hstr: ...
    @winrt_commethod(17)
    def put_PlaceholderText(self, value: hstr) -> Void: ...
    @winrt_commethod(18)
    def get_Header(self) -> IInspectable: ...
    @winrt_commethod(19)
    def put_Header(self, value: IInspectable) -> Void: ...
    @winrt_commethod(20)
    def get_AutoMaximizeSuggestionArea(self) -> Boolean: ...
    @winrt_commethod(21)
    def put_AutoMaximizeSuggestionArea(self, value: Boolean) -> Void: ...
    @winrt_commethod(22)
    def get_TextBoxStyle(self) -> win32more.Microsoft.UI.Xaml.Style: ...
    @winrt_commethod(23)
    def put_TextBoxStyle(self, value: win32more.Microsoft.UI.Xaml.Style) -> Void: ...
    @winrt_commethod(24)
    def get_QueryIcon(self) -> win32more.Microsoft.UI.Xaml.Controls.IconElement: ...
    @winrt_commethod(25)
    def put_QueryIcon(self, value: win32more.Microsoft.UI.Xaml.Controls.IconElement) -> Void: ...
    @winrt_commethod(26)
    def get_LightDismissOverlayMode(self) -> win32more.Microsoft.UI.Xaml.Controls.LightDismissOverlayMode: ...
    @winrt_commethod(27)
    def put_LightDismissOverlayMode(self, value: win32more.Microsoft.UI.Xaml.Controls.LightDismissOverlayMode) -> Void: ...
    @winrt_commethod(28)
    def get_Description(self) -> IInspectable: ...
    @winrt_commethod(29)
    def put_Description(self, value: IInspectable) -> Void: ...
    @winrt_commethod(30)
    def add_SuggestionChosen(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.AutoSuggestBox, win32more.Microsoft.UI.Xaml.Controls.AutoSuggestBoxSuggestionChosenEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(31)
    def remove_SuggestionChosen(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(32)
    def add_TextChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.AutoSuggestBox, win32more.Microsoft.UI.Xaml.Controls.AutoSuggestBoxTextChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(33)
    def remove_TextChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(34)
    def add_QuerySubmitted(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.AutoSuggestBox, win32more.Microsoft.UI.Xaml.Controls.AutoSuggestBoxQuerySubmittedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(35)
    def remove_QuerySubmitted(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    AutoMaximizeSuggestionArea = property(get_AutoMaximizeSuggestionArea, put_AutoMaximizeSuggestionArea)
    Description = property(get_Description, put_Description)
    Header = property(get_Header, put_Header)
    IsSuggestionListOpen = property(get_IsSuggestionListOpen, put_IsSuggestionListOpen)
    LightDismissOverlayMode = property(get_LightDismissOverlayMode, put_LightDismissOverlayMode)
    MaxSuggestionListHeight = property(get_MaxSuggestionListHeight, put_MaxSuggestionListHeight)
    PlaceholderText = property(get_PlaceholderText, put_PlaceholderText)
    QueryIcon = property(get_QueryIcon, put_QueryIcon)
    Text = property(get_Text, put_Text)
    TextBoxStyle = property(get_TextBoxStyle, put_TextBoxStyle)
    TextMemberPath = property(get_TextMemberPath, put_TextMemberPath)
    UpdateTextOnSelect = property(get_UpdateTextOnSelect, put_UpdateTextOnSelect)
    QuerySubmitted = event(add_QuerySubmitted, remove_QuerySubmitted)
    SuggestionChosen = event(add_SuggestionChosen, remove_SuggestionChosen)
    TextChanged = event(add_TextChanged, remove_TextChanged)
class IAutoSuggestBoxQuerySubmittedEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IAutoSuggestBoxQuerySubmittedEventArgs'
    _iid_ = Guid('{26da5de4-57a6-57bf-acc9-aac599c0b22b}')
    @winrt_commethod(6)
    def get_QueryText(self) -> hstr: ...
    @winrt_commethod(7)
    def get_ChosenSuggestion(self) -> IInspectable: ...
    ChosenSuggestion = property(get_ChosenSuggestion, None)
    QueryText = property(get_QueryText, None)
class IAutoSuggestBoxStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IAutoSuggestBoxStatics'
    _iid_ = Guid('{9dfa2ff9-1094-54a8-beee-b345fa3ee089}')
    @winrt_commethod(6)
    def get_MaxSuggestionListHeightProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_IsSuggestionListOpenProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_TextMemberPathProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_TextProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_UpdateTextOnSelectProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_PlaceholderTextProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_HeaderProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_AutoMaximizeSuggestionAreaProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(14)
    def get_TextBoxStyleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(15)
    def get_QueryIconProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(16)
    def get_LightDismissOverlayModeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(17)
    def get_DescriptionProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    AutoMaximizeSuggestionAreaProperty = property(get_AutoMaximizeSuggestionAreaProperty, None)
    DescriptionProperty = property(get_DescriptionProperty, None)
    HeaderProperty = property(get_HeaderProperty, None)
    IsSuggestionListOpenProperty = property(get_IsSuggestionListOpenProperty, None)
    LightDismissOverlayModeProperty = property(get_LightDismissOverlayModeProperty, None)
    MaxSuggestionListHeightProperty = property(get_MaxSuggestionListHeightProperty, None)
    PlaceholderTextProperty = property(get_PlaceholderTextProperty, None)
    QueryIconProperty = property(get_QueryIconProperty, None)
    TextBoxStyleProperty = property(get_TextBoxStyleProperty, None)
    TextMemberPathProperty = property(get_TextMemberPathProperty, None)
    TextProperty = property(get_TextProperty, None)
    UpdateTextOnSelectProperty = property(get_UpdateTextOnSelectProperty, None)
class IAutoSuggestBoxSuggestionChosenEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IAutoSuggestBoxSuggestionChosenEventArgs'
    _iid_ = Guid('{7547c7e9-7429-5045-ad98-338a96b270b1}')
    @winrt_commethod(6)
    def get_SelectedItem(self) -> IInspectable: ...
    SelectedItem = property(get_SelectedItem, None)
class IAutoSuggestBoxTextChangedEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IAutoSuggestBoxTextChangedEventArgs'
    _iid_ = Guid('{d7191d84-e886-547f-a3e2-12f0e05b20fa}')
    @winrt_commethod(6)
    def get_Reason(self) -> win32more.Microsoft.UI.Xaml.Controls.AutoSuggestionBoxTextChangeReason: ...
    @winrt_commethod(7)
    def put_Reason(self, value: win32more.Microsoft.UI.Xaml.Controls.AutoSuggestionBoxTextChangeReason) -> Void: ...
    @winrt_commethod(8)
    def CheckCurrent(self) -> Boolean: ...
    Reason = property(get_Reason, put_Reason)
class IAutoSuggestBoxTextChangedEventArgsStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IAutoSuggestBoxTextChangedEventArgsStatics'
    _iid_ = Guid('{40155fb9-253b-5624-a17a-294be7a07f87}')
    @winrt_commethod(6)
    def get_ReasonProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    ReasonProperty = property(get_ReasonProperty, None)
class IBitmapIcon(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IBitmapIcon'
    _iid_ = Guid('{c370bc29-805b-5bad-b615-ec640e579dbb}')
    @winrt_commethod(6)
    def get_UriSource(self) -> win32more.Windows.Foundation.Uri: ...
    @winrt_commethod(7)
    def put_UriSource(self, value: win32more.Windows.Foundation.Uri) -> Void: ...
    @winrt_commethod(8)
    def get_ShowAsMonochrome(self) -> Boolean: ...
    @winrt_commethod(9)
    def put_ShowAsMonochrome(self, value: Boolean) -> Void: ...
    ShowAsMonochrome = property(get_ShowAsMonochrome, put_ShowAsMonochrome)
    UriSource = property(get_UriSource, put_UriSource)
class IBitmapIconFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IBitmapIconFactory'
    _iid_ = Guid('{b43b5ddc-cdb5-5ad6-8ac1-2fcca33be39e}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.BitmapIcon: ...
class IBitmapIconSource(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IBitmapIconSource'
    _iid_ = Guid('{a6b6cccc-ea8f-53ca-831f-2abe85cd6d8c}')
    @winrt_commethod(6)
    def get_UriSource(self) -> win32more.Windows.Foundation.Uri: ...
    @winrt_commethod(7)
    def put_UriSource(self, value: win32more.Windows.Foundation.Uri) -> Void: ...
    @winrt_commethod(8)
    def get_ShowAsMonochrome(self) -> Boolean: ...
    @winrt_commethod(9)
    def put_ShowAsMonochrome(self, value: Boolean) -> Void: ...
    ShowAsMonochrome = property(get_ShowAsMonochrome, put_ShowAsMonochrome)
    UriSource = property(get_UriSource, put_UriSource)
class IBitmapIconSourceFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IBitmapIconSourceFactory'
    _iid_ = Guid('{7d484c14-f5f6-5e39-b4e4-b6108d2ee095}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.BitmapIconSource: ...
class IBitmapIconSourceStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IBitmapIconSourceStatics'
    _iid_ = Guid('{f4ba77bd-e13f-583b-b9f6-862e73753517}')
    @winrt_commethod(6)
    def get_UriSourceProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_ShowAsMonochromeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    ShowAsMonochromeProperty = property(get_ShowAsMonochromeProperty, None)
    UriSourceProperty = property(get_UriSourceProperty, None)
class IBitmapIconStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IBitmapIconStatics'
    _iid_ = Guid('{01c67eb2-327e-5c4e-afb4-38b02ed12886}')
    @winrt_commethod(6)
    def get_UriSourceProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_ShowAsMonochromeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    ShowAsMonochromeProperty = property(get_ShowAsMonochromeProperty, None)
    UriSourceProperty = property(get_UriSourceProperty, None)
class IBorder(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IBorder'
    _iid_ = Guid('{1ca13b47-ff5c-5abc-a411-a177df9482a9}')
    @winrt_commethod(6)
    def get_BorderBrush(self) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_commethod(7)
    def put_BorderBrush(self, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(8)
    def get_BorderThickness(self) -> win32more.Microsoft.UI.Xaml.Thickness: ...
    @winrt_commethod(9)
    def put_BorderThickness(self, value: win32more.Microsoft.UI.Xaml.Thickness) -> Void: ...
    @winrt_commethod(10)
    def get_Background(self) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_commethod(11)
    def put_Background(self, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(12)
    def get_BackgroundSizing(self) -> win32more.Microsoft.UI.Xaml.Controls.BackgroundSizing: ...
    @winrt_commethod(13)
    def put_BackgroundSizing(self, value: win32more.Microsoft.UI.Xaml.Controls.BackgroundSizing) -> Void: ...
    @winrt_commethod(14)
    def get_CornerRadius(self) -> win32more.Microsoft.UI.Xaml.CornerRadius: ...
    @winrt_commethod(15)
    def put_CornerRadius(self, value: win32more.Microsoft.UI.Xaml.CornerRadius) -> Void: ...
    @winrt_commethod(16)
    def get_Padding(self) -> win32more.Microsoft.UI.Xaml.Thickness: ...
    @winrt_commethod(17)
    def put_Padding(self, value: win32more.Microsoft.UI.Xaml.Thickness) -> Void: ...
    @winrt_commethod(18)
    def get_Child(self) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_commethod(19)
    def put_Child(self, value: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    @winrt_commethod(20)
    def get_ChildTransitions(self) -> win32more.Microsoft.UI.Xaml.Media.Animation.TransitionCollection: ...
    @winrt_commethod(21)
    def put_ChildTransitions(self, value: win32more.Microsoft.UI.Xaml.Media.Animation.TransitionCollection) -> Void: ...
    @winrt_commethod(22)
    def get_BackgroundTransition(self) -> win32more.Microsoft.UI.Xaml.BrushTransition: ...
    @winrt_commethod(23)
    def put_BackgroundTransition(self, value: win32more.Microsoft.UI.Xaml.BrushTransition) -> Void: ...
    Background = property(get_Background, put_Background)
    BackgroundSizing = property(get_BackgroundSizing, put_BackgroundSizing)
    BackgroundTransition = property(get_BackgroundTransition, put_BackgroundTransition)
    BorderBrush = property(get_BorderBrush, put_BorderBrush)
    BorderThickness = property(get_BorderThickness, put_BorderThickness)
    Child = property(get_Child, put_Child)
    ChildTransitions = property(get_ChildTransitions, put_ChildTransitions)
    CornerRadius = property(get_CornerRadius, put_CornerRadius)
    Padding = property(get_Padding, put_Padding)
class IBorderStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IBorderStatics'
    _iid_ = Guid('{9385cd66-c178-5176-b4a5-160e00e93935}')
    @winrt_commethod(6)
    def get_BorderBrushProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_BorderThicknessProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_BackgroundProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_BackgroundSizingProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_CornerRadiusProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_PaddingProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_ChildTransitionsProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    BackgroundProperty = property(get_BackgroundProperty, None)
    BackgroundSizingProperty = property(get_BackgroundSizingProperty, None)
    BorderBrushProperty = property(get_BorderBrushProperty, None)
    BorderThicknessProperty = property(get_BorderThicknessProperty, None)
    ChildTransitionsProperty = property(get_ChildTransitionsProperty, None)
    CornerRadiusProperty = property(get_CornerRadiusProperty, None)
    PaddingProperty = property(get_PaddingProperty, None)
class IBreadcrumbBar(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IBreadcrumbBar'
    _iid_ = Guid('{2e47b7d6-5fbd-54c7-b0b1-ceff4a19c744}')
    @winrt_commethod(6)
    def get_ItemsSource(self) -> IInspectable: ...
    @winrt_commethod(7)
    def put_ItemsSource(self, value: IInspectable) -> Void: ...
    @winrt_commethod(8)
    def get_ItemTemplate(self) -> IInspectable: ...
    @winrt_commethod(9)
    def put_ItemTemplate(self, value: IInspectable) -> Void: ...
    @winrt_commethod(10)
    def add_ItemClicked(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.BreadcrumbBar, win32more.Microsoft.UI.Xaml.Controls.BreadcrumbBarItemClickedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(11)
    def remove_ItemClicked(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    ItemTemplate = property(get_ItemTemplate, put_ItemTemplate)
    ItemsSource = property(get_ItemsSource, put_ItemsSource)
    ItemClicked = event(add_ItemClicked, remove_ItemClicked)
class IBreadcrumbBarFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IBreadcrumbBarFactory'
    _iid_ = Guid('{d5b6a6d9-3148-5cbc-a6ae-0f44cde41952}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.BreadcrumbBar: ...
class IBreadcrumbBarItem(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IBreadcrumbBarItem'
    _iid_ = Guid('{34582de4-6bef-5ba0-86ca-7cc1a3db37ee}')
class IBreadcrumbBarItemClickedEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IBreadcrumbBarItemClickedEventArgs'
    _iid_ = Guid('{1ceea503-365e-580d-bcd4-e9ad0248f6b5}')
    @winrt_commethod(6)
    def get_Index(self) -> Int32: ...
    @winrt_commethod(7)
    def get_Item(self) -> IInspectable: ...
    Index = property(get_Index, None)
    Item = property(get_Item, None)
class IBreadcrumbBarItemFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IBreadcrumbBarItemFactory'
    _iid_ = Guid('{186c3bd3-7008-5544-8d3a-65af8fe9fe69}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.BreadcrumbBarItem: ...
class IBreadcrumbBarStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IBreadcrumbBarStatics'
    _iid_ = Guid('{4abf3fb5-6f69-54e2-a68f-e5f904f79f38}')
    @winrt_commethod(6)
    def get_ItemsSourceProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_ItemTemplateProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    ItemTemplateProperty = property(get_ItemTemplateProperty, None)
    ItemsSourceProperty = property(get_ItemsSourceProperty, None)
class IButton(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IButton'
    _iid_ = Guid('{216c183d-d07a-5aa5-b8a4-0300a2683e87}')
    @winrt_commethod(6)
    def get_Flyout(self) -> win32more.Microsoft.UI.Xaml.Controls.Primitives.FlyoutBase: ...
    @winrt_commethod(7)
    def put_Flyout(self, value: win32more.Microsoft.UI.Xaml.Controls.Primitives.FlyoutBase) -> Void: ...
    Flyout = property(get_Flyout, put_Flyout)
class IButtonFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IButtonFactory'
    _iid_ = Guid('{fe393422-d91c-57b1-9a9c-2c7e3f41f77c}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.Button: ...
class IButtonStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IButtonStatics'
    _iid_ = Guid('{57823d25-b26a-5e0f-94f6-bbae70683dc5}')
    @winrt_commethod(6)
    def get_FlyoutProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    FlyoutProperty = property(get_FlyoutProperty, None)
class ICalendarDatePicker(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ICalendarDatePicker'
    _iid_ = Guid('{e3d9faa1-0fd0-5932-a6db-ff00c003ac21}')
    @winrt_commethod(6)
    def get_Date(self) -> win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.DateTime]: ...
    @winrt_commethod(7)
    def put_Date(self, value: win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.DateTime]) -> Void: ...
    @winrt_commethod(8)
    def get_IsCalendarOpen(self) -> Boolean: ...
    @winrt_commethod(9)
    def put_IsCalendarOpen(self, value: Boolean) -> Void: ...
    @winrt_commethod(10)
    def get_DateFormat(self) -> hstr: ...
    @winrt_commethod(11)
    def put_DateFormat(self, value: hstr) -> Void: ...
    @winrt_commethod(12)
    def get_PlaceholderText(self) -> hstr: ...
    @winrt_commethod(13)
    def put_PlaceholderText(self, value: hstr) -> Void: ...
    @winrt_commethod(14)
    def get_Header(self) -> IInspectable: ...
    @winrt_commethod(15)
    def put_Header(self, value: IInspectable) -> Void: ...
    @winrt_commethod(16)
    def get_HeaderTemplate(self) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_commethod(17)
    def put_HeaderTemplate(self, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_commethod(18)
    def get_CalendarViewStyle(self) -> win32more.Microsoft.UI.Xaml.Style: ...
    @winrt_commethod(19)
    def put_CalendarViewStyle(self, value: win32more.Microsoft.UI.Xaml.Style) -> Void: ...
    @winrt_commethod(20)
    def get_LightDismissOverlayMode(self) -> win32more.Microsoft.UI.Xaml.Controls.LightDismissOverlayMode: ...
    @winrt_commethod(21)
    def put_LightDismissOverlayMode(self, value: win32more.Microsoft.UI.Xaml.Controls.LightDismissOverlayMode) -> Void: ...
    @winrt_commethod(22)
    def get_Description(self) -> IInspectable: ...
    @winrt_commethod(23)
    def put_Description(self, value: IInspectable) -> Void: ...
    @winrt_commethod(24)
    def get_MinDate(self) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_commethod(25)
    def put_MinDate(self, value: win32more.Windows.Foundation.DateTime) -> Void: ...
    @winrt_commethod(26)
    def get_MaxDate(self) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_commethod(27)
    def put_MaxDate(self, value: win32more.Windows.Foundation.DateTime) -> Void: ...
    @winrt_commethod(28)
    def get_IsTodayHighlighted(self) -> Boolean: ...
    @winrt_commethod(29)
    def put_IsTodayHighlighted(self, value: Boolean) -> Void: ...
    @winrt_commethod(30)
    def get_DisplayMode(self) -> win32more.Microsoft.UI.Xaml.Controls.CalendarViewDisplayMode: ...
    @winrt_commethod(31)
    def put_DisplayMode(self, value: win32more.Microsoft.UI.Xaml.Controls.CalendarViewDisplayMode) -> Void: ...
    @winrt_commethod(32)
    def get_FirstDayOfWeek(self) -> win32more.Windows.Globalization.DayOfWeek: ...
    @winrt_commethod(33)
    def put_FirstDayOfWeek(self, value: win32more.Windows.Globalization.DayOfWeek) -> Void: ...
    @winrt_commethod(34)
    def get_DayOfWeekFormat(self) -> hstr: ...
    @winrt_commethod(35)
    def put_DayOfWeekFormat(self, value: hstr) -> Void: ...
    @winrt_commethod(36)
    def get_CalendarIdentifier(self) -> hstr: ...
    @winrt_commethod(37)
    def put_CalendarIdentifier(self, value: hstr) -> Void: ...
    @winrt_commethod(38)
    def get_IsOutOfScopeEnabled(self) -> Boolean: ...
    @winrt_commethod(39)
    def put_IsOutOfScopeEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(40)
    def get_IsGroupLabelVisible(self) -> Boolean: ...
    @winrt_commethod(41)
    def put_IsGroupLabelVisible(self, value: Boolean) -> Void: ...
    @winrt_commethod(42)
    def add_CalendarViewDayItemChanging(self, handler: win32more.Microsoft.UI.Xaml.Controls.CalendarViewDayItemChangingEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(43)
    def remove_CalendarViewDayItemChanging(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(44)
    def add_DateChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.CalendarDatePicker, win32more.Microsoft.UI.Xaml.Controls.CalendarDatePickerDateChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(45)
    def remove_DateChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(46)
    def add_Opened(self, handler: win32more.Windows.Foundation.EventHandler[IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(47)
    def remove_Opened(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(48)
    def add_Closed(self, handler: win32more.Windows.Foundation.EventHandler[IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(49)
    def remove_Closed(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(50)
    def SetDisplayDate(self, date: win32more.Windows.Foundation.DateTime) -> Void: ...
    @winrt_commethod(51)
    def SetYearDecadeDisplayDimensions(self, columns: Int32, rows: Int32) -> Void: ...
    CalendarIdentifier = property(get_CalendarIdentifier, put_CalendarIdentifier)
    CalendarViewStyle = property(get_CalendarViewStyle, put_CalendarViewStyle)
    Date = property(get_Date, put_Date)
    DateFormat = property(get_DateFormat, put_DateFormat)
    DayOfWeekFormat = property(get_DayOfWeekFormat, put_DayOfWeekFormat)
    Description = property(get_Description, put_Description)
    DisplayMode = property(get_DisplayMode, put_DisplayMode)
    FirstDayOfWeek = property(get_FirstDayOfWeek, put_FirstDayOfWeek)
    Header = property(get_Header, put_Header)
    HeaderTemplate = property(get_HeaderTemplate, put_HeaderTemplate)
    IsCalendarOpen = property(get_IsCalendarOpen, put_IsCalendarOpen)
    IsGroupLabelVisible = property(get_IsGroupLabelVisible, put_IsGroupLabelVisible)
    IsOutOfScopeEnabled = property(get_IsOutOfScopeEnabled, put_IsOutOfScopeEnabled)
    IsTodayHighlighted = property(get_IsTodayHighlighted, put_IsTodayHighlighted)
    LightDismissOverlayMode = property(get_LightDismissOverlayMode, put_LightDismissOverlayMode)
    MaxDate = property(get_MaxDate, put_MaxDate)
    MinDate = property(get_MinDate, put_MinDate)
    PlaceholderText = property(get_PlaceholderText, put_PlaceholderText)
    CalendarViewDayItemChanging = event(add_CalendarViewDayItemChanging, remove_CalendarViewDayItemChanging)
    Closed = event(add_Closed, remove_Closed)
    DateChanged = event(add_DateChanged, remove_DateChanged)
    Opened = event(add_Opened, remove_Opened)
class ICalendarDatePickerDateChangedEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ICalendarDatePickerDateChangedEventArgs'
    _iid_ = Guid('{57c212d7-c2f2-54a0-9d41-f263b1e5106e}')
    @winrt_commethod(6)
    def get_NewDate(self) -> win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.DateTime]: ...
    @winrt_commethod(7)
    def get_OldDate(self) -> win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.DateTime]: ...
    NewDate = property(get_NewDate, None)
    OldDate = property(get_OldDate, None)
class ICalendarDatePickerFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ICalendarDatePickerFactory'
    _iid_ = Guid('{b00c7818-955a-5524-b451-93868230892f}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.CalendarDatePicker: ...
class ICalendarDatePickerStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ICalendarDatePickerStatics'
    _iid_ = Guid('{e74eb740-1aeb-591f-b84a-ef881c3b527e}')
    @winrt_commethod(6)
    def get_DateProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_IsCalendarOpenProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_DateFormatProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_PlaceholderTextProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_HeaderProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_HeaderTemplateProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_CalendarViewStyleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_LightDismissOverlayModeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(14)
    def get_DescriptionProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(15)
    def get_MinDateProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(16)
    def get_MaxDateProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(17)
    def get_IsTodayHighlightedProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(18)
    def get_DisplayModeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(19)
    def get_FirstDayOfWeekProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(20)
    def get_DayOfWeekFormatProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(21)
    def get_CalendarIdentifierProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(22)
    def get_IsOutOfScopeEnabledProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(23)
    def get_IsGroupLabelVisibleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    CalendarIdentifierProperty = property(get_CalendarIdentifierProperty, None)
    CalendarViewStyleProperty = property(get_CalendarViewStyleProperty, None)
    DateFormatProperty = property(get_DateFormatProperty, None)
    DateProperty = property(get_DateProperty, None)
    DayOfWeekFormatProperty = property(get_DayOfWeekFormatProperty, None)
    DescriptionProperty = property(get_DescriptionProperty, None)
    DisplayModeProperty = property(get_DisplayModeProperty, None)
    FirstDayOfWeekProperty = property(get_FirstDayOfWeekProperty, None)
    HeaderProperty = property(get_HeaderProperty, None)
    HeaderTemplateProperty = property(get_HeaderTemplateProperty, None)
    IsCalendarOpenProperty = property(get_IsCalendarOpenProperty, None)
    IsGroupLabelVisibleProperty = property(get_IsGroupLabelVisibleProperty, None)
    IsOutOfScopeEnabledProperty = property(get_IsOutOfScopeEnabledProperty, None)
    IsTodayHighlightedProperty = property(get_IsTodayHighlightedProperty, None)
    LightDismissOverlayModeProperty = property(get_LightDismissOverlayModeProperty, None)
    MaxDateProperty = property(get_MaxDateProperty, None)
    MinDateProperty = property(get_MinDateProperty, None)
    PlaceholderTextProperty = property(get_PlaceholderTextProperty, None)
class ICalendarView(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ICalendarView'
    _iid_ = Guid('{e786081e-b680-56ab-bfbb-52d5b17c365e}')
    @winrt_commethod(6)
    def get_CalendarIdentifier(self) -> hstr: ...
    @winrt_commethod(7)
    def put_CalendarIdentifier(self, value: hstr) -> Void: ...
    @winrt_commethod(8)
    def get_DayOfWeekFormat(self) -> hstr: ...
    @winrt_commethod(9)
    def put_DayOfWeekFormat(self, value: hstr) -> Void: ...
    @winrt_commethod(10)
    def get_IsGroupLabelVisible(self) -> Boolean: ...
    @winrt_commethod(11)
    def put_IsGroupLabelVisible(self, value: Boolean) -> Void: ...
    @winrt_commethod(12)
    def get_DisplayMode(self) -> win32more.Microsoft.UI.Xaml.Controls.CalendarViewDisplayMode: ...
    @winrt_commethod(13)
    def put_DisplayMode(self, value: win32more.Microsoft.UI.Xaml.Controls.CalendarViewDisplayMode) -> Void: ...
    @winrt_commethod(14)
    def get_FirstDayOfWeek(self) -> win32more.Windows.Globalization.DayOfWeek: ...
    @winrt_commethod(15)
    def put_FirstDayOfWeek(self, value: win32more.Windows.Globalization.DayOfWeek) -> Void: ...
    @winrt_commethod(16)
    def get_IsOutOfScopeEnabled(self) -> Boolean: ...
    @winrt_commethod(17)
    def put_IsOutOfScopeEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(18)
    def get_IsTodayHighlighted(self) -> Boolean: ...
    @winrt_commethod(19)
    def put_IsTodayHighlighted(self, value: Boolean) -> Void: ...
    @winrt_commethod(20)
    def get_MaxDate(self) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_commethod(21)
    def put_MaxDate(self, value: win32more.Windows.Foundation.DateTime) -> Void: ...
    @winrt_commethod(22)
    def get_MinDate(self) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_commethod(23)
    def put_MinDate(self, value: win32more.Windows.Foundation.DateTime) -> Void: ...
    @winrt_commethod(24)
    def get_NumberOfWeeksInView(self) -> Int32: ...
    @winrt_commethod(25)
    def put_NumberOfWeeksInView(self, value: Int32) -> Void: ...
    @winrt_commethod(26)
    def get_SelectedDates(self) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Foundation.DateTime]: ...
    @winrt_commethod(27)
    def get_SelectionMode(self) -> win32more.Microsoft.UI.Xaml.Controls.CalendarViewSelectionMode: ...
    @winrt_commethod(28)
    def put_SelectionMode(self, value: win32more.Microsoft.UI.Xaml.Controls.CalendarViewSelectionMode) -> Void: ...
    @winrt_commethod(29)
    def get_TemplateSettings(self) -> win32more.Microsoft.UI.Xaml.Controls.Primitives.CalendarViewTemplateSettings: ...
    @winrt_commethod(30)
    def get_FocusBorderBrush(self) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_commethod(31)
    def put_FocusBorderBrush(self, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(32)
    def get_SelectedHoverBorderBrush(self) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_commethod(33)
    def put_SelectedHoverBorderBrush(self, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(34)
    def get_SelectedPressedBorderBrush(self) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_commethod(35)
    def put_SelectedPressedBorderBrush(self, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(36)
    def get_SelectedDisabledBorderBrush(self) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_commethod(37)
    def put_SelectedDisabledBorderBrush(self, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(38)
    def get_SelectedBorderBrush(self) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_commethod(39)
    def put_SelectedBorderBrush(self, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(40)
    def get_HoverBorderBrush(self) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_commethod(41)
    def put_HoverBorderBrush(self, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(42)
    def get_PressedBorderBrush(self) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_commethod(43)
    def put_PressedBorderBrush(self, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(44)
    def get_TodaySelectedInnerBorderBrush(self) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_commethod(45)
    def put_TodaySelectedInnerBorderBrush(self, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(46)
    def get_BlackoutStrikethroughBrush(self) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_commethod(47)
    def put_BlackoutStrikethroughBrush(self, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(48)
    def get_CalendarItemBorderBrush(self) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_commethod(49)
    def put_CalendarItemBorderBrush(self, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(50)
    def get_BlackoutBackground(self) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_commethod(51)
    def put_BlackoutBackground(self, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(52)
    def get_OutOfScopeBackground(self) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_commethod(53)
    def put_OutOfScopeBackground(self, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(54)
    def get_CalendarItemBackground(self) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_commethod(55)
    def put_CalendarItemBackground(self, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(56)
    def get_CalendarItemHoverBackground(self) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_commethod(57)
    def put_CalendarItemHoverBackground(self, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(58)
    def get_CalendarItemPressedBackground(self) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_commethod(59)
    def put_CalendarItemPressedBackground(self, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(60)
    def get_CalendarItemDisabledBackground(self) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_commethod(61)
    def put_CalendarItemDisabledBackground(self, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(62)
    def get_TodayBackground(self) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_commethod(63)
    def put_TodayBackground(self, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(64)
    def get_TodayBlackoutBackground(self) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_commethod(65)
    def put_TodayBlackoutBackground(self, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(66)
    def get_TodayHoverBackground(self) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_commethod(67)
    def put_TodayHoverBackground(self, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(68)
    def get_TodayPressedBackground(self) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_commethod(69)
    def put_TodayPressedBackground(self, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(70)
    def get_TodayDisabledBackground(self) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_commethod(71)
    def put_TodayDisabledBackground(self, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(72)
    def get_PressedForeground(self) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_commethod(73)
    def put_PressedForeground(self, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(74)
    def get_TodayForeground(self) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_commethod(75)
    def put_TodayForeground(self, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(76)
    def get_BlackoutForeground(self) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_commethod(77)
    def put_BlackoutForeground(self, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(78)
    def get_TodayBlackoutForeground(self) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_commethod(79)
    def put_TodayBlackoutForeground(self, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(80)
    def get_SelectedForeground(self) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_commethod(81)
    def put_SelectedForeground(self, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(82)
    def get_SelectedHoverForeground(self) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_commethod(83)
    def put_SelectedHoverForeground(self, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(84)
    def get_SelectedPressedForeground(self) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_commethod(85)
    def put_SelectedPressedForeground(self, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(86)
    def get_SelectedDisabledForeground(self) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_commethod(87)
    def put_SelectedDisabledForeground(self, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(88)
    def get_OutOfScopeForeground(self) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_commethod(89)
    def put_OutOfScopeForeground(self, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(90)
    def get_OutOfScopeHoverForeground(self) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_commethod(91)
    def put_OutOfScopeHoverForeground(self, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(92)
    def get_OutOfScopePressedForeground(self) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_commethod(93)
    def put_OutOfScopePressedForeground(self, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(94)
    def get_CalendarItemForeground(self) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_commethod(95)
    def put_CalendarItemForeground(self, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(96)
    def get_DisabledForeground(self) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_commethod(97)
    def put_DisabledForeground(self, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(98)
    def get_DayItemFontFamily(self) -> win32more.Microsoft.UI.Xaml.Media.FontFamily: ...
    @winrt_commethod(99)
    def put_DayItemFontFamily(self, value: win32more.Microsoft.UI.Xaml.Media.FontFamily) -> Void: ...
    @winrt_commethod(100)
    def get_DayItemFontSize(self) -> Double: ...
    @winrt_commethod(101)
    def put_DayItemFontSize(self, value: Double) -> Void: ...
    @winrt_commethod(102)
    def get_DayItemFontStyle(self) -> win32more.Windows.UI.Text.FontStyle: ...
    @winrt_commethod(103)
    def put_DayItemFontStyle(self, value: win32more.Windows.UI.Text.FontStyle) -> Void: ...
    @winrt_commethod(104)
    def get_DayItemFontWeight(self) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_commethod(105)
    def put_DayItemFontWeight(self, value: win32more.Windows.UI.Text.FontWeight) -> Void: ...
    @winrt_commethod(106)
    def get_TodayFontWeight(self) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_commethod(107)
    def put_TodayFontWeight(self, value: win32more.Windows.UI.Text.FontWeight) -> Void: ...
    @winrt_commethod(108)
    def get_FirstOfMonthLabelFontFamily(self) -> win32more.Microsoft.UI.Xaml.Media.FontFamily: ...
    @winrt_commethod(109)
    def put_FirstOfMonthLabelFontFamily(self, value: win32more.Microsoft.UI.Xaml.Media.FontFamily) -> Void: ...
    @winrt_commethod(110)
    def get_FirstOfMonthLabelFontSize(self) -> Double: ...
    @winrt_commethod(111)
    def put_FirstOfMonthLabelFontSize(self, value: Double) -> Void: ...
    @winrt_commethod(112)
    def get_FirstOfMonthLabelFontStyle(self) -> win32more.Windows.UI.Text.FontStyle: ...
    @winrt_commethod(113)
    def put_FirstOfMonthLabelFontStyle(self, value: win32more.Windows.UI.Text.FontStyle) -> Void: ...
    @winrt_commethod(114)
    def get_FirstOfMonthLabelFontWeight(self) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_commethod(115)
    def put_FirstOfMonthLabelFontWeight(self, value: win32more.Windows.UI.Text.FontWeight) -> Void: ...
    @winrt_commethod(116)
    def get_MonthYearItemFontFamily(self) -> win32more.Microsoft.UI.Xaml.Media.FontFamily: ...
    @winrt_commethod(117)
    def put_MonthYearItemFontFamily(self, value: win32more.Microsoft.UI.Xaml.Media.FontFamily) -> Void: ...
    @winrt_commethod(118)
    def get_MonthYearItemFontSize(self) -> Double: ...
    @winrt_commethod(119)
    def put_MonthYearItemFontSize(self, value: Double) -> Void: ...
    @winrt_commethod(120)
    def get_MonthYearItemFontStyle(self) -> win32more.Windows.UI.Text.FontStyle: ...
    @winrt_commethod(121)
    def put_MonthYearItemFontStyle(self, value: win32more.Windows.UI.Text.FontStyle) -> Void: ...
    @winrt_commethod(122)
    def get_MonthYearItemFontWeight(self) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_commethod(123)
    def put_MonthYearItemFontWeight(self, value: win32more.Windows.UI.Text.FontWeight) -> Void: ...
    @winrt_commethod(124)
    def get_FirstOfYearDecadeLabelFontFamily(self) -> win32more.Microsoft.UI.Xaml.Media.FontFamily: ...
    @winrt_commethod(125)
    def put_FirstOfYearDecadeLabelFontFamily(self, value: win32more.Microsoft.UI.Xaml.Media.FontFamily) -> Void: ...
    @winrt_commethod(126)
    def get_FirstOfYearDecadeLabelFontSize(self) -> Double: ...
    @winrt_commethod(127)
    def put_FirstOfYearDecadeLabelFontSize(self, value: Double) -> Void: ...
    @winrt_commethod(128)
    def get_FirstOfYearDecadeLabelFontStyle(self) -> win32more.Windows.UI.Text.FontStyle: ...
    @winrt_commethod(129)
    def put_FirstOfYearDecadeLabelFontStyle(self, value: win32more.Windows.UI.Text.FontStyle) -> Void: ...
    @winrt_commethod(130)
    def get_FirstOfYearDecadeLabelFontWeight(self) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_commethod(131)
    def put_FirstOfYearDecadeLabelFontWeight(self, value: win32more.Windows.UI.Text.FontWeight) -> Void: ...
    @winrt_commethod(132)
    def get_DayItemMargin(self) -> win32more.Microsoft.UI.Xaml.Thickness: ...
    @winrt_commethod(133)
    def put_DayItemMargin(self, value: win32more.Microsoft.UI.Xaml.Thickness) -> Void: ...
    @winrt_commethod(134)
    def get_MonthYearItemMargin(self) -> win32more.Microsoft.UI.Xaml.Thickness: ...
    @winrt_commethod(135)
    def put_MonthYearItemMargin(self, value: win32more.Microsoft.UI.Xaml.Thickness) -> Void: ...
    @winrt_commethod(136)
    def get_FirstOfMonthLabelMargin(self) -> win32more.Microsoft.UI.Xaml.Thickness: ...
    @winrt_commethod(137)
    def put_FirstOfMonthLabelMargin(self, value: win32more.Microsoft.UI.Xaml.Thickness) -> Void: ...
    @winrt_commethod(138)
    def get_FirstOfYearDecadeLabelMargin(self) -> win32more.Microsoft.UI.Xaml.Thickness: ...
    @winrt_commethod(139)
    def put_FirstOfYearDecadeLabelMargin(self, value: win32more.Microsoft.UI.Xaml.Thickness) -> Void: ...
    @winrt_commethod(140)
    def get_HorizontalDayItemAlignment(self) -> win32more.Microsoft.UI.Xaml.HorizontalAlignment: ...
    @winrt_commethod(141)
    def put_HorizontalDayItemAlignment(self, value: win32more.Microsoft.UI.Xaml.HorizontalAlignment) -> Void: ...
    @winrt_commethod(142)
    def get_VerticalDayItemAlignment(self) -> win32more.Microsoft.UI.Xaml.VerticalAlignment: ...
    @winrt_commethod(143)
    def put_VerticalDayItemAlignment(self, value: win32more.Microsoft.UI.Xaml.VerticalAlignment) -> Void: ...
    @winrt_commethod(144)
    def get_HorizontalFirstOfMonthLabelAlignment(self) -> win32more.Microsoft.UI.Xaml.HorizontalAlignment: ...
    @winrt_commethod(145)
    def put_HorizontalFirstOfMonthLabelAlignment(self, value: win32more.Microsoft.UI.Xaml.HorizontalAlignment) -> Void: ...
    @winrt_commethod(146)
    def get_VerticalFirstOfMonthLabelAlignment(self) -> win32more.Microsoft.UI.Xaml.VerticalAlignment: ...
    @winrt_commethod(147)
    def put_VerticalFirstOfMonthLabelAlignment(self, value: win32more.Microsoft.UI.Xaml.VerticalAlignment) -> Void: ...
    @winrt_commethod(148)
    def get_CalendarItemBorderThickness(self) -> win32more.Microsoft.UI.Xaml.Thickness: ...
    @winrt_commethod(149)
    def put_CalendarItemBorderThickness(self, value: win32more.Microsoft.UI.Xaml.Thickness) -> Void: ...
    @winrt_commethod(150)
    def get_CalendarViewDayItemStyle(self) -> win32more.Microsoft.UI.Xaml.Style: ...
    @winrt_commethod(151)
    def put_CalendarViewDayItemStyle(self, value: win32more.Microsoft.UI.Xaml.Style) -> Void: ...
    @winrt_commethod(152)
    def get_CalendarItemCornerRadius(self) -> win32more.Microsoft.UI.Xaml.CornerRadius: ...
    @winrt_commethod(153)
    def put_CalendarItemCornerRadius(self, value: win32more.Microsoft.UI.Xaml.CornerRadius) -> Void: ...
    @winrt_commethod(154)
    def add_CalendarViewDayItemChanging(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.CalendarView, win32more.Microsoft.UI.Xaml.Controls.CalendarViewDayItemChangingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(155)
    def remove_CalendarViewDayItemChanging(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(156)
    def add_SelectedDatesChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.CalendarView, win32more.Microsoft.UI.Xaml.Controls.CalendarViewSelectedDatesChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(157)
    def remove_SelectedDatesChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(158)
    def SetDisplayDate(self, date: win32more.Windows.Foundation.DateTime) -> Void: ...
    @winrt_commethod(159)
    def SetYearDecadeDisplayDimensions(self, columns: Int32, rows: Int32) -> Void: ...
    BlackoutBackground = property(get_BlackoutBackground, put_BlackoutBackground)
    BlackoutForeground = property(get_BlackoutForeground, put_BlackoutForeground)
    BlackoutStrikethroughBrush = property(get_BlackoutStrikethroughBrush, put_BlackoutStrikethroughBrush)
    CalendarIdentifier = property(get_CalendarIdentifier, put_CalendarIdentifier)
    CalendarItemBackground = property(get_CalendarItemBackground, put_CalendarItemBackground)
    CalendarItemBorderBrush = property(get_CalendarItemBorderBrush, put_CalendarItemBorderBrush)
    CalendarItemBorderThickness = property(get_CalendarItemBorderThickness, put_CalendarItemBorderThickness)
    CalendarItemCornerRadius = property(get_CalendarItemCornerRadius, put_CalendarItemCornerRadius)
    CalendarItemDisabledBackground = property(get_CalendarItemDisabledBackground, put_CalendarItemDisabledBackground)
    CalendarItemForeground = property(get_CalendarItemForeground, put_CalendarItemForeground)
    CalendarItemHoverBackground = property(get_CalendarItemHoverBackground, put_CalendarItemHoverBackground)
    CalendarItemPressedBackground = property(get_CalendarItemPressedBackground, put_CalendarItemPressedBackground)
    CalendarViewDayItemStyle = property(get_CalendarViewDayItemStyle, put_CalendarViewDayItemStyle)
    DayItemFontFamily = property(get_DayItemFontFamily, put_DayItemFontFamily)
    DayItemFontSize = property(get_DayItemFontSize, put_DayItemFontSize)
    DayItemFontStyle = property(get_DayItemFontStyle, put_DayItemFontStyle)
    DayItemFontWeight = property(get_DayItemFontWeight, put_DayItemFontWeight)
    DayItemMargin = property(get_DayItemMargin, put_DayItemMargin)
    DayOfWeekFormat = property(get_DayOfWeekFormat, put_DayOfWeekFormat)
    DisabledForeground = property(get_DisabledForeground, put_DisabledForeground)
    DisplayMode = property(get_DisplayMode, put_DisplayMode)
    FirstDayOfWeek = property(get_FirstDayOfWeek, put_FirstDayOfWeek)
    FirstOfMonthLabelFontFamily = property(get_FirstOfMonthLabelFontFamily, put_FirstOfMonthLabelFontFamily)
    FirstOfMonthLabelFontSize = property(get_FirstOfMonthLabelFontSize, put_FirstOfMonthLabelFontSize)
    FirstOfMonthLabelFontStyle = property(get_FirstOfMonthLabelFontStyle, put_FirstOfMonthLabelFontStyle)
    FirstOfMonthLabelFontWeight = property(get_FirstOfMonthLabelFontWeight, put_FirstOfMonthLabelFontWeight)
    FirstOfMonthLabelMargin = property(get_FirstOfMonthLabelMargin, put_FirstOfMonthLabelMargin)
    FirstOfYearDecadeLabelFontFamily = property(get_FirstOfYearDecadeLabelFontFamily, put_FirstOfYearDecadeLabelFontFamily)
    FirstOfYearDecadeLabelFontSize = property(get_FirstOfYearDecadeLabelFontSize, put_FirstOfYearDecadeLabelFontSize)
    FirstOfYearDecadeLabelFontStyle = property(get_FirstOfYearDecadeLabelFontStyle, put_FirstOfYearDecadeLabelFontStyle)
    FirstOfYearDecadeLabelFontWeight = property(get_FirstOfYearDecadeLabelFontWeight, put_FirstOfYearDecadeLabelFontWeight)
    FirstOfYearDecadeLabelMargin = property(get_FirstOfYearDecadeLabelMargin, put_FirstOfYearDecadeLabelMargin)
    FocusBorderBrush = property(get_FocusBorderBrush, put_FocusBorderBrush)
    HorizontalDayItemAlignment = property(get_HorizontalDayItemAlignment, put_HorizontalDayItemAlignment)
    HorizontalFirstOfMonthLabelAlignment = property(get_HorizontalFirstOfMonthLabelAlignment, put_HorizontalFirstOfMonthLabelAlignment)
    HoverBorderBrush = property(get_HoverBorderBrush, put_HoverBorderBrush)
    IsGroupLabelVisible = property(get_IsGroupLabelVisible, put_IsGroupLabelVisible)
    IsOutOfScopeEnabled = property(get_IsOutOfScopeEnabled, put_IsOutOfScopeEnabled)
    IsTodayHighlighted = property(get_IsTodayHighlighted, put_IsTodayHighlighted)
    MaxDate = property(get_MaxDate, put_MaxDate)
    MinDate = property(get_MinDate, put_MinDate)
    MonthYearItemFontFamily = property(get_MonthYearItemFontFamily, put_MonthYearItemFontFamily)
    MonthYearItemFontSize = property(get_MonthYearItemFontSize, put_MonthYearItemFontSize)
    MonthYearItemFontStyle = property(get_MonthYearItemFontStyle, put_MonthYearItemFontStyle)
    MonthYearItemFontWeight = property(get_MonthYearItemFontWeight, put_MonthYearItemFontWeight)
    MonthYearItemMargin = property(get_MonthYearItemMargin, put_MonthYearItemMargin)
    NumberOfWeeksInView = property(get_NumberOfWeeksInView, put_NumberOfWeeksInView)
    OutOfScopeBackground = property(get_OutOfScopeBackground, put_OutOfScopeBackground)
    OutOfScopeForeground = property(get_OutOfScopeForeground, put_OutOfScopeForeground)
    OutOfScopeHoverForeground = property(get_OutOfScopeHoverForeground, put_OutOfScopeHoverForeground)
    OutOfScopePressedForeground = property(get_OutOfScopePressedForeground, put_OutOfScopePressedForeground)
    PressedBorderBrush = property(get_PressedBorderBrush, put_PressedBorderBrush)
    PressedForeground = property(get_PressedForeground, put_PressedForeground)
    SelectedBorderBrush = property(get_SelectedBorderBrush, put_SelectedBorderBrush)
    SelectedDates = property(get_SelectedDates, None)
    SelectedDisabledBorderBrush = property(get_SelectedDisabledBorderBrush, put_SelectedDisabledBorderBrush)
    SelectedDisabledForeground = property(get_SelectedDisabledForeground, put_SelectedDisabledForeground)
    SelectedForeground = property(get_SelectedForeground, put_SelectedForeground)
    SelectedHoverBorderBrush = property(get_SelectedHoverBorderBrush, put_SelectedHoverBorderBrush)
    SelectedHoverForeground = property(get_SelectedHoverForeground, put_SelectedHoverForeground)
    SelectedPressedBorderBrush = property(get_SelectedPressedBorderBrush, put_SelectedPressedBorderBrush)
    SelectedPressedForeground = property(get_SelectedPressedForeground, put_SelectedPressedForeground)
    SelectionMode = property(get_SelectionMode, put_SelectionMode)
    TemplateSettings = property(get_TemplateSettings, None)
    TodayBackground = property(get_TodayBackground, put_TodayBackground)
    TodayBlackoutBackground = property(get_TodayBlackoutBackground, put_TodayBlackoutBackground)
    TodayBlackoutForeground = property(get_TodayBlackoutForeground, put_TodayBlackoutForeground)
    TodayDisabledBackground = property(get_TodayDisabledBackground, put_TodayDisabledBackground)
    TodayFontWeight = property(get_TodayFontWeight, put_TodayFontWeight)
    TodayForeground = property(get_TodayForeground, put_TodayForeground)
    TodayHoverBackground = property(get_TodayHoverBackground, put_TodayHoverBackground)
    TodayPressedBackground = property(get_TodayPressedBackground, put_TodayPressedBackground)
    TodaySelectedInnerBorderBrush = property(get_TodaySelectedInnerBorderBrush, put_TodaySelectedInnerBorderBrush)
    VerticalDayItemAlignment = property(get_VerticalDayItemAlignment, put_VerticalDayItemAlignment)
    VerticalFirstOfMonthLabelAlignment = property(get_VerticalFirstOfMonthLabelAlignment, put_VerticalFirstOfMonthLabelAlignment)
    CalendarViewDayItemChanging = event(add_CalendarViewDayItemChanging, remove_CalendarViewDayItemChanging)
    SelectedDatesChanged = event(add_SelectedDatesChanged, remove_SelectedDatesChanged)
class ICalendarViewDayItem(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ICalendarViewDayItem'
    _iid_ = Guid('{947d3a07-6fa4-553c-9b12-57ca1bf72e9e}')
    @winrt_commethod(6)
    def get_IsBlackout(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_IsBlackout(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def get_Date(self) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_commethod(9)
    def SetDensityColors(self, colors: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.UI.Color]) -> Void: ...
    Date = property(get_Date, None)
    IsBlackout = property(get_IsBlackout, put_IsBlackout)
class ICalendarViewDayItemChangingEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ICalendarViewDayItemChangingEventArgs'
    _iid_ = Guid('{e894fe7f-12f6-5b1a-88a2-a96764c1273f}')
    @winrt_commethod(6)
    def get_InRecycleQueue(self) -> Boolean: ...
    @winrt_commethod(7)
    def get_Item(self) -> win32more.Microsoft.UI.Xaml.Controls.CalendarViewDayItem: ...
    @winrt_commethod(8)
    def get_Phase(self) -> UInt32: ...
    @winrt_commethod(9)
    def RegisterUpdateCallback(self, callback: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.CalendarView, win32more.Microsoft.UI.Xaml.Controls.CalendarViewDayItemChangingEventArgs]) -> Void: ...
    @winrt_commethod(10)
    def RegisterUpdateCallbackWithPhase(self, callbackPhase: UInt32, callback: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.CalendarView, win32more.Microsoft.UI.Xaml.Controls.CalendarViewDayItemChangingEventArgs]) -> Void: ...
    InRecycleQueue = property(get_InRecycleQueue, None)
    Item = property(get_Item, None)
    Phase = property(get_Phase, None)
class ICalendarViewDayItemFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ICalendarViewDayItemFactory'
    _iid_ = Guid('{e6159e51-1c48-5a77-a3a1-aef59d6a8c4e}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.CalendarViewDayItem: ...
class ICalendarViewDayItemStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ICalendarViewDayItemStatics'
    _iid_ = Guid('{2b2c4006-57fa-5f0f-b8ed-26e21f910e3a}')
    @winrt_commethod(6)
    def get_IsBlackoutProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_DateProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    DateProperty = property(get_DateProperty, None)
    IsBlackoutProperty = property(get_IsBlackoutProperty, None)
class ICalendarViewFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ICalendarViewFactory'
    _iid_ = Guid('{2f31d1eb-8229-517c-b3a6-5a5f28724e8f}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.CalendarView: ...
class ICalendarViewSelectedDatesChangedEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ICalendarViewSelectedDatesChangedEventArgs'
    _iid_ = Guid('{675f688f-bc30-59f6-83c4-140bd053a09a}')
    @winrt_commethod(6)
    def get_AddedDates(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Foundation.DateTime]: ...
    @winrt_commethod(7)
    def get_RemovedDates(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Foundation.DateTime]: ...
    AddedDates = property(get_AddedDates, None)
    RemovedDates = property(get_RemovedDates, None)
class ICalendarViewStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ICalendarViewStatics'
    _iid_ = Guid('{9553e6fc-e4da-57d4-9472-7f8ed5ff7219}')
    @winrt_commethod(6)
    def get_CalendarIdentifierProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_DayOfWeekFormatProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_IsGroupLabelVisibleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_DisplayModeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_FirstDayOfWeekProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_IsOutOfScopeEnabledProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_IsTodayHighlightedProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_MaxDateProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(14)
    def get_MinDateProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(15)
    def get_NumberOfWeeksInViewProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(16)
    def get_SelectedDatesProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(17)
    def get_SelectionModeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(18)
    def get_TemplateSettingsProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(19)
    def get_FocusBorderBrushProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(20)
    def get_SelectedHoverBorderBrushProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(21)
    def get_SelectedPressedBorderBrushProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(22)
    def get_SelectedDisabledBorderBrushProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(23)
    def get_SelectedBorderBrushProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(24)
    def get_HoverBorderBrushProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(25)
    def get_PressedBorderBrushProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(26)
    def get_TodaySelectedInnerBorderBrushProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(27)
    def get_BlackoutStrikethroughBrushProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(28)
    def get_CalendarItemBorderBrushProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(29)
    def get_BlackoutBackgroundProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(30)
    def get_OutOfScopeBackgroundProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(31)
    def get_CalendarItemBackgroundProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(32)
    def get_CalendarItemHoverBackgroundProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(33)
    def get_CalendarItemPressedBackgroundProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(34)
    def get_CalendarItemDisabledBackgroundProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(35)
    def get_TodayBackgroundProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(36)
    def get_TodayBlackoutBackgroundProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(37)
    def get_TodayHoverBackgroundProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(38)
    def get_TodayPressedBackgroundProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(39)
    def get_TodayDisabledBackgroundProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(40)
    def get_PressedForegroundProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(41)
    def get_TodayForegroundProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(42)
    def get_BlackoutForegroundProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(43)
    def get_TodayBlackoutForegroundProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(44)
    def get_SelectedForegroundProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(45)
    def get_SelectedHoverForegroundProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(46)
    def get_SelectedPressedForegroundProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(47)
    def get_SelectedDisabledForegroundProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(48)
    def get_OutOfScopeForegroundProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(49)
    def get_OutOfScopeHoverForegroundProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(50)
    def get_OutOfScopePressedForegroundProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(51)
    def get_CalendarItemForegroundProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(52)
    def get_DisabledForegroundProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(53)
    def get_DayItemFontFamilyProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(54)
    def get_DayItemFontSizeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(55)
    def get_DayItemFontStyleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(56)
    def get_DayItemFontWeightProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(57)
    def get_TodayFontWeightProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(58)
    def get_FirstOfMonthLabelFontFamilyProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(59)
    def get_FirstOfMonthLabelFontSizeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(60)
    def get_FirstOfMonthLabelFontStyleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(61)
    def get_FirstOfMonthLabelFontWeightProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(62)
    def get_MonthYearItemFontFamilyProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(63)
    def get_MonthYearItemFontSizeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(64)
    def get_MonthYearItemFontStyleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(65)
    def get_MonthYearItemFontWeightProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(66)
    def get_FirstOfYearDecadeLabelFontFamilyProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(67)
    def get_FirstOfYearDecadeLabelFontSizeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(68)
    def get_FirstOfYearDecadeLabelFontStyleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(69)
    def get_FirstOfYearDecadeLabelFontWeightProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(70)
    def get_DayItemMarginProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(71)
    def get_MonthYearItemMarginProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(72)
    def get_FirstOfMonthLabelMarginProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(73)
    def get_FirstOfYearDecadeLabelMarginProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(74)
    def get_HorizontalDayItemAlignmentProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(75)
    def get_VerticalDayItemAlignmentProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(76)
    def get_HorizontalFirstOfMonthLabelAlignmentProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(77)
    def get_VerticalFirstOfMonthLabelAlignmentProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(78)
    def get_CalendarItemBorderThicknessProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(79)
    def get_CalendarViewDayItemStyleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(80)
    def get_CalendarItemCornerRadiusProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    BlackoutBackgroundProperty = property(get_BlackoutBackgroundProperty, None)
    BlackoutForegroundProperty = property(get_BlackoutForegroundProperty, None)
    BlackoutStrikethroughBrushProperty = property(get_BlackoutStrikethroughBrushProperty, None)
    CalendarIdentifierProperty = property(get_CalendarIdentifierProperty, None)
    CalendarItemBackgroundProperty = property(get_CalendarItemBackgroundProperty, None)
    CalendarItemBorderBrushProperty = property(get_CalendarItemBorderBrushProperty, None)
    CalendarItemBorderThicknessProperty = property(get_CalendarItemBorderThicknessProperty, None)
    CalendarItemCornerRadiusProperty = property(get_CalendarItemCornerRadiusProperty, None)
    CalendarItemDisabledBackgroundProperty = property(get_CalendarItemDisabledBackgroundProperty, None)
    CalendarItemForegroundProperty = property(get_CalendarItemForegroundProperty, None)
    CalendarItemHoverBackgroundProperty = property(get_CalendarItemHoverBackgroundProperty, None)
    CalendarItemPressedBackgroundProperty = property(get_CalendarItemPressedBackgroundProperty, None)
    CalendarViewDayItemStyleProperty = property(get_CalendarViewDayItemStyleProperty, None)
    DayItemFontFamilyProperty = property(get_DayItemFontFamilyProperty, None)
    DayItemFontSizeProperty = property(get_DayItemFontSizeProperty, None)
    DayItemFontStyleProperty = property(get_DayItemFontStyleProperty, None)
    DayItemFontWeightProperty = property(get_DayItemFontWeightProperty, None)
    DayItemMarginProperty = property(get_DayItemMarginProperty, None)
    DayOfWeekFormatProperty = property(get_DayOfWeekFormatProperty, None)
    DisabledForegroundProperty = property(get_DisabledForegroundProperty, None)
    DisplayModeProperty = property(get_DisplayModeProperty, None)
    FirstDayOfWeekProperty = property(get_FirstDayOfWeekProperty, None)
    FirstOfMonthLabelFontFamilyProperty = property(get_FirstOfMonthLabelFontFamilyProperty, None)
    FirstOfMonthLabelFontSizeProperty = property(get_FirstOfMonthLabelFontSizeProperty, None)
    FirstOfMonthLabelFontStyleProperty = property(get_FirstOfMonthLabelFontStyleProperty, None)
    FirstOfMonthLabelFontWeightProperty = property(get_FirstOfMonthLabelFontWeightProperty, None)
    FirstOfMonthLabelMarginProperty = property(get_FirstOfMonthLabelMarginProperty, None)
    FirstOfYearDecadeLabelFontFamilyProperty = property(get_FirstOfYearDecadeLabelFontFamilyProperty, None)
    FirstOfYearDecadeLabelFontSizeProperty = property(get_FirstOfYearDecadeLabelFontSizeProperty, None)
    FirstOfYearDecadeLabelFontStyleProperty = property(get_FirstOfYearDecadeLabelFontStyleProperty, None)
    FirstOfYearDecadeLabelFontWeightProperty = property(get_FirstOfYearDecadeLabelFontWeightProperty, None)
    FirstOfYearDecadeLabelMarginProperty = property(get_FirstOfYearDecadeLabelMarginProperty, None)
    FocusBorderBrushProperty = property(get_FocusBorderBrushProperty, None)
    HorizontalDayItemAlignmentProperty = property(get_HorizontalDayItemAlignmentProperty, None)
    HorizontalFirstOfMonthLabelAlignmentProperty = property(get_HorizontalFirstOfMonthLabelAlignmentProperty, None)
    HoverBorderBrushProperty = property(get_HoverBorderBrushProperty, None)
    IsGroupLabelVisibleProperty = property(get_IsGroupLabelVisibleProperty, None)
    IsOutOfScopeEnabledProperty = property(get_IsOutOfScopeEnabledProperty, None)
    IsTodayHighlightedProperty = property(get_IsTodayHighlightedProperty, None)
    MaxDateProperty = property(get_MaxDateProperty, None)
    MinDateProperty = property(get_MinDateProperty, None)
    MonthYearItemFontFamilyProperty = property(get_MonthYearItemFontFamilyProperty, None)
    MonthYearItemFontSizeProperty = property(get_MonthYearItemFontSizeProperty, None)
    MonthYearItemFontStyleProperty = property(get_MonthYearItemFontStyleProperty, None)
    MonthYearItemFontWeightProperty = property(get_MonthYearItemFontWeightProperty, None)
    MonthYearItemMarginProperty = property(get_MonthYearItemMarginProperty, None)
    NumberOfWeeksInViewProperty = property(get_NumberOfWeeksInViewProperty, None)
    OutOfScopeBackgroundProperty = property(get_OutOfScopeBackgroundProperty, None)
    OutOfScopeForegroundProperty = property(get_OutOfScopeForegroundProperty, None)
    OutOfScopeHoverForegroundProperty = property(get_OutOfScopeHoverForegroundProperty, None)
    OutOfScopePressedForegroundProperty = property(get_OutOfScopePressedForegroundProperty, None)
    PressedBorderBrushProperty = property(get_PressedBorderBrushProperty, None)
    PressedForegroundProperty = property(get_PressedForegroundProperty, None)
    SelectedBorderBrushProperty = property(get_SelectedBorderBrushProperty, None)
    SelectedDatesProperty = property(get_SelectedDatesProperty, None)
    SelectedDisabledBorderBrushProperty = property(get_SelectedDisabledBorderBrushProperty, None)
    SelectedDisabledForegroundProperty = property(get_SelectedDisabledForegroundProperty, None)
    SelectedForegroundProperty = property(get_SelectedForegroundProperty, None)
    SelectedHoverBorderBrushProperty = property(get_SelectedHoverBorderBrushProperty, None)
    SelectedHoverForegroundProperty = property(get_SelectedHoverForegroundProperty, None)
    SelectedPressedBorderBrushProperty = property(get_SelectedPressedBorderBrushProperty, None)
    SelectedPressedForegroundProperty = property(get_SelectedPressedForegroundProperty, None)
    SelectionModeProperty = property(get_SelectionModeProperty, None)
    TemplateSettingsProperty = property(get_TemplateSettingsProperty, None)
    TodayBackgroundProperty = property(get_TodayBackgroundProperty, None)
    TodayBlackoutBackgroundProperty = property(get_TodayBlackoutBackgroundProperty, None)
    TodayBlackoutForegroundProperty = property(get_TodayBlackoutForegroundProperty, None)
    TodayDisabledBackgroundProperty = property(get_TodayDisabledBackgroundProperty, None)
    TodayFontWeightProperty = property(get_TodayFontWeightProperty, None)
    TodayForegroundProperty = property(get_TodayForegroundProperty, None)
    TodayHoverBackgroundProperty = property(get_TodayHoverBackgroundProperty, None)
    TodayPressedBackgroundProperty = property(get_TodayPressedBackgroundProperty, None)
    TodaySelectedInnerBorderBrushProperty = property(get_TodaySelectedInnerBorderBrushProperty, None)
    VerticalDayItemAlignmentProperty = property(get_VerticalDayItemAlignmentProperty, None)
    VerticalFirstOfMonthLabelAlignmentProperty = property(get_VerticalFirstOfMonthLabelAlignmentProperty, None)
class ICandidateWindowBoundsChangedEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ICandidateWindowBoundsChangedEventArgs'
    _iid_ = Guid('{b76faf94-3172-5c50-9507-26cd873815a1}')
    @winrt_commethod(6)
    def get_Bounds(self) -> win32more.Windows.Foundation.Rect: ...
    Bounds = property(get_Bounds, None)
class ICanvas(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ICanvas'
    _iid_ = Guid('{457ba139-1146-51d2-807e-d9d65c927060}')
class ICanvasFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ICanvasFactory'
    _iid_ = Guid('{374c5050-3481-5557-9948-804c0b8eea89}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.Canvas: ...
class ICanvasStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ICanvasStatics'
    _iid_ = Guid('{c00d5e0f-77e3-5c59-8fcd-86761f0c6607}')
    @winrt_commethod(6)
    def get_LeftProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def GetLeft(self, element: win32more.Microsoft.UI.Xaml.UIElement) -> Double: ...
    @winrt_commethod(8)
    def SetLeft(self, element: win32more.Microsoft.UI.Xaml.UIElement, length: Double) -> Void: ...
    @winrt_commethod(9)
    def get_TopProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def GetTop(self, element: win32more.Microsoft.UI.Xaml.UIElement) -> Double: ...
    @winrt_commethod(11)
    def SetTop(self, element: win32more.Microsoft.UI.Xaml.UIElement, length: Double) -> Void: ...
    @winrt_commethod(12)
    def get_ZIndexProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def GetZIndex(self, element: win32more.Microsoft.UI.Xaml.UIElement) -> Int32: ...
    @winrt_commethod(14)
    def SetZIndex(self, element: win32more.Microsoft.UI.Xaml.UIElement, value: Int32) -> Void: ...
    LeftProperty = property(get_LeftProperty, None)
    TopProperty = property(get_TopProperty, None)
    ZIndexProperty = property(get_ZIndexProperty, None)
class ICheckBox(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ICheckBox'
    _iid_ = Guid('{c5830000-4c9d-5fdd-9346-674c71cd80c5}')
class ICheckBoxFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ICheckBoxFactory'
    _iid_ = Guid('{f43ff58d-31d5-5835-af7b-375bc6a9bcf3}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.CheckBox: ...
class IChoosingGroupHeaderContainerEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IChoosingGroupHeaderContainerEventArgs'
    _iid_ = Guid('{2db1b0b0-aee9-55fa-8c30-c98f00643d00}')
    @winrt_commethod(6)
    def get_GroupHeaderContainer(self) -> win32more.Microsoft.UI.Xaml.Controls.ListViewBaseHeaderItem: ...
    @winrt_commethod(7)
    def put_GroupHeaderContainer(self, value: win32more.Microsoft.UI.Xaml.Controls.ListViewBaseHeaderItem) -> Void: ...
    @winrt_commethod(8)
    def get_GroupIndex(self) -> Int32: ...
    @winrt_commethod(9)
    def get_Group(self) -> IInspectable: ...
    Group = property(get_Group, None)
    GroupHeaderContainer = property(get_GroupHeaderContainer, put_GroupHeaderContainer)
    GroupIndex = property(get_GroupIndex, None)
class IChoosingItemContainerEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IChoosingItemContainerEventArgs'
    _iid_ = Guid('{b479b9d2-a63f-5638-9486-8ccc1f40251e}')
    @winrt_commethod(6)
    def get_ItemIndex(self) -> Int32: ...
    @winrt_commethod(7)
    def get_Item(self) -> IInspectable: ...
    @winrt_commethod(8)
    def get_ItemContainer(self) -> win32more.Microsoft.UI.Xaml.Controls.Primitives.SelectorItem: ...
    @winrt_commethod(9)
    def put_ItemContainer(self, value: win32more.Microsoft.UI.Xaml.Controls.Primitives.SelectorItem) -> Void: ...
    @winrt_commethod(10)
    def get_IsContainerPrepared(self) -> Boolean: ...
    @winrt_commethod(11)
    def put_IsContainerPrepared(self, value: Boolean) -> Void: ...
    IsContainerPrepared = property(get_IsContainerPrepared, put_IsContainerPrepared)
    Item = property(get_Item, None)
    ItemContainer = property(get_ItemContainer, put_ItemContainer)
    ItemIndex = property(get_ItemIndex, None)
class ICleanUpVirtualizedItemEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ICleanUpVirtualizedItemEventArgs'
    _iid_ = Guid('{76155ad9-e394-5313-832f-e21cf7b7fb0e}')
    @winrt_commethod(6)
    def get_Value(self) -> IInspectable: ...
    @winrt_commethod(7)
    def get_UIElement(self) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_commethod(8)
    def get_Cancel(self) -> Boolean: ...
    @winrt_commethod(9)
    def put_Cancel(self, value: Boolean) -> Void: ...
    Cancel = property(get_Cancel, put_Cancel)
    UIElement = property(get_UIElement, None)
    Value = property(get_Value, None)
class IColorChangedEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IColorChangedEventArgs'
    _iid_ = Guid('{148d57a2-b1cb-5f5d-b6b5-512805d71761}')
    @winrt_commethod(6)
    def get_OldColor(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(7)
    def get_NewColor(self) -> win32more.Windows.UI.Color: ...
    NewColor = property(get_NewColor, None)
    OldColor = property(get_OldColor, None)
class IColorPicker(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IColorPicker'
    _iid_ = Guid('{ae72b24b-f93f-5a19-8ce4-a18b73c3356d}')
    @winrt_commethod(6)
    def get_Color(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(7)
    def put_Color(self, value: win32more.Windows.UI.Color) -> Void: ...
    @winrt_commethod(8)
    def get_PreviousColor(self) -> win32more.Windows.Foundation.IReference[win32more.Windows.UI.Color]: ...
    @winrt_commethod(9)
    def put_PreviousColor(self, value: win32more.Windows.Foundation.IReference[win32more.Windows.UI.Color]) -> Void: ...
    @winrt_commethod(10)
    def get_IsAlphaEnabled(self) -> Boolean: ...
    @winrt_commethod(11)
    def put_IsAlphaEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(12)
    def get_IsColorSpectrumVisible(self) -> Boolean: ...
    @winrt_commethod(13)
    def put_IsColorSpectrumVisible(self, value: Boolean) -> Void: ...
    @winrt_commethod(14)
    def get_IsColorPreviewVisible(self) -> Boolean: ...
    @winrt_commethod(15)
    def put_IsColorPreviewVisible(self, value: Boolean) -> Void: ...
    @winrt_commethod(16)
    def get_IsColorSliderVisible(self) -> Boolean: ...
    @winrt_commethod(17)
    def put_IsColorSliderVisible(self, value: Boolean) -> Void: ...
    @winrt_commethod(18)
    def get_IsAlphaSliderVisible(self) -> Boolean: ...
    @winrt_commethod(19)
    def put_IsAlphaSliderVisible(self, value: Boolean) -> Void: ...
    @winrt_commethod(20)
    def get_IsMoreButtonVisible(self) -> Boolean: ...
    @winrt_commethod(21)
    def put_IsMoreButtonVisible(self, value: Boolean) -> Void: ...
    @winrt_commethod(22)
    def get_IsColorChannelTextInputVisible(self) -> Boolean: ...
    @winrt_commethod(23)
    def put_IsColorChannelTextInputVisible(self, value: Boolean) -> Void: ...
    @winrt_commethod(24)
    def get_IsAlphaTextInputVisible(self) -> Boolean: ...
    @winrt_commethod(25)
    def put_IsAlphaTextInputVisible(self, value: Boolean) -> Void: ...
    @winrt_commethod(26)
    def get_IsHexInputVisible(self) -> Boolean: ...
    @winrt_commethod(27)
    def put_IsHexInputVisible(self, value: Boolean) -> Void: ...
    @winrt_commethod(28)
    def get_MinHue(self) -> Int32: ...
    @winrt_commethod(29)
    def put_MinHue(self, value: Int32) -> Void: ...
    @winrt_commethod(30)
    def get_MaxHue(self) -> Int32: ...
    @winrt_commethod(31)
    def put_MaxHue(self, value: Int32) -> Void: ...
    @winrt_commethod(32)
    def get_MinSaturation(self) -> Int32: ...
    @winrt_commethod(33)
    def put_MinSaturation(self, value: Int32) -> Void: ...
    @winrt_commethod(34)
    def get_MaxSaturation(self) -> Int32: ...
    @winrt_commethod(35)
    def put_MaxSaturation(self, value: Int32) -> Void: ...
    @winrt_commethod(36)
    def get_MinValue(self) -> Int32: ...
    @winrt_commethod(37)
    def put_MinValue(self, value: Int32) -> Void: ...
    @winrt_commethod(38)
    def get_MaxValue(self) -> Int32: ...
    @winrt_commethod(39)
    def put_MaxValue(self, value: Int32) -> Void: ...
    @winrt_commethod(40)
    def get_ColorSpectrumShape(self) -> win32more.Microsoft.UI.Xaml.Controls.ColorSpectrumShape: ...
    @winrt_commethod(41)
    def put_ColorSpectrumShape(self, value: win32more.Microsoft.UI.Xaml.Controls.ColorSpectrumShape) -> Void: ...
    @winrt_commethod(42)
    def get_ColorSpectrumComponents(self) -> win32more.Microsoft.UI.Xaml.Controls.ColorSpectrumComponents: ...
    @winrt_commethod(43)
    def put_ColorSpectrumComponents(self, value: win32more.Microsoft.UI.Xaml.Controls.ColorSpectrumComponents) -> Void: ...
    @winrt_commethod(44)
    def add_ColorChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.ColorPicker, win32more.Microsoft.UI.Xaml.Controls.ColorChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(45)
    def remove_ColorChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    Color = property(get_Color, put_Color)
    ColorSpectrumComponents = property(get_ColorSpectrumComponents, put_ColorSpectrumComponents)
    ColorSpectrumShape = property(get_ColorSpectrumShape, put_ColorSpectrumShape)
    IsAlphaEnabled = property(get_IsAlphaEnabled, put_IsAlphaEnabled)
    IsAlphaSliderVisible = property(get_IsAlphaSliderVisible, put_IsAlphaSliderVisible)
    IsAlphaTextInputVisible = property(get_IsAlphaTextInputVisible, put_IsAlphaTextInputVisible)
    IsColorChannelTextInputVisible = property(get_IsColorChannelTextInputVisible, put_IsColorChannelTextInputVisible)
    IsColorPreviewVisible = property(get_IsColorPreviewVisible, put_IsColorPreviewVisible)
    IsColorSliderVisible = property(get_IsColorSliderVisible, put_IsColorSliderVisible)
    IsColorSpectrumVisible = property(get_IsColorSpectrumVisible, put_IsColorSpectrumVisible)
    IsHexInputVisible = property(get_IsHexInputVisible, put_IsHexInputVisible)
    IsMoreButtonVisible = property(get_IsMoreButtonVisible, put_IsMoreButtonVisible)
    MaxHue = property(get_MaxHue, put_MaxHue)
    MaxSaturation = property(get_MaxSaturation, put_MaxSaturation)
    MaxValue = property(get_MaxValue, put_MaxValue)
    MinHue = property(get_MinHue, put_MinHue)
    MinSaturation = property(get_MinSaturation, put_MinSaturation)
    MinValue = property(get_MinValue, put_MinValue)
    PreviousColor = property(get_PreviousColor, put_PreviousColor)
    ColorChanged = event(add_ColorChanged, remove_ColorChanged)
class IColorPicker2(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IColorPicker2'
    _iid_ = Guid('{802e64c9-4608-5c4c-93cf-6c462e3c1068}')
    @winrt_commethod(6)
    def get_Orientation(self) -> win32more.Microsoft.UI.Xaml.Controls.Orientation: ...
    @winrt_commethod(7)
    def put_Orientation(self, value: win32more.Microsoft.UI.Xaml.Controls.Orientation) -> Void: ...
    Orientation = property(get_Orientation, put_Orientation)
class IColorPickerFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IColorPickerFactory'
    _iid_ = Guid('{72c350e2-0a20-5b9b-ac54-633b97d7ffde}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.ColorPicker: ...
class IColorPickerStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IColorPickerStatics'
    _iid_ = Guid('{920d2d62-172e-5771-b677-4069b5134574}')
    @winrt_commethod(6)
    def get_ColorProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_PreviousColorProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_IsAlphaEnabledProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_IsColorSpectrumVisibleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_IsColorPreviewVisibleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_IsColorSliderVisibleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_IsAlphaSliderVisibleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_IsMoreButtonVisibleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(14)
    def get_IsColorChannelTextInputVisibleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(15)
    def get_IsAlphaTextInputVisibleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(16)
    def get_IsHexInputVisibleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(17)
    def get_MinHueProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(18)
    def get_MaxHueProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(19)
    def get_MinSaturationProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(20)
    def get_MaxSaturationProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(21)
    def get_MinValueProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(22)
    def get_MaxValueProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(23)
    def get_ColorSpectrumShapeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(24)
    def get_ColorSpectrumComponentsProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    ColorProperty = property(get_ColorProperty, None)
    ColorSpectrumComponentsProperty = property(get_ColorSpectrumComponentsProperty, None)
    ColorSpectrumShapeProperty = property(get_ColorSpectrumShapeProperty, None)
    IsAlphaEnabledProperty = property(get_IsAlphaEnabledProperty, None)
    IsAlphaSliderVisibleProperty = property(get_IsAlphaSliderVisibleProperty, None)
    IsAlphaTextInputVisibleProperty = property(get_IsAlphaTextInputVisibleProperty, None)
    IsColorChannelTextInputVisibleProperty = property(get_IsColorChannelTextInputVisibleProperty, None)
    IsColorPreviewVisibleProperty = property(get_IsColorPreviewVisibleProperty, None)
    IsColorSliderVisibleProperty = property(get_IsColorSliderVisibleProperty, None)
    IsColorSpectrumVisibleProperty = property(get_IsColorSpectrumVisibleProperty, None)
    IsHexInputVisibleProperty = property(get_IsHexInputVisibleProperty, None)
    IsMoreButtonVisibleProperty = property(get_IsMoreButtonVisibleProperty, None)
    MaxHueProperty = property(get_MaxHueProperty, None)
    MaxSaturationProperty = property(get_MaxSaturationProperty, None)
    MaxValueProperty = property(get_MaxValueProperty, None)
    MinHueProperty = property(get_MinHueProperty, None)
    MinSaturationProperty = property(get_MinSaturationProperty, None)
    MinValueProperty = property(get_MinValueProperty, None)
    PreviousColorProperty = property(get_PreviousColorProperty, None)
class IColorPickerStatics2(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IColorPickerStatics2'
    _iid_ = Guid('{2f4af95b-81cf-5304-9950-49ec934c1b35}')
    @winrt_commethod(6)
    def get_OrientationProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    OrientationProperty = property(get_OrientationProperty, None)
class IColumnDefinition(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IColumnDefinition'
    _iid_ = Guid('{454cea14-87ec-5890-bb62-f1d82a94758e}')
    @winrt_commethod(6)
    def get_Width(self) -> win32more.Microsoft.UI.Xaml.GridLength: ...
    @winrt_commethod(7)
    def put_Width(self, value: win32more.Microsoft.UI.Xaml.GridLength) -> Void: ...
    @winrt_commethod(8)
    def get_MaxWidth(self) -> Double: ...
    @winrt_commethod(9)
    def put_MaxWidth(self, value: Double) -> Void: ...
    @winrt_commethod(10)
    def get_MinWidth(self) -> Double: ...
    @winrt_commethod(11)
    def put_MinWidth(self, value: Double) -> Void: ...
    @winrt_commethod(12)
    def get_ActualWidth(self) -> Double: ...
    ActualWidth = property(get_ActualWidth, None)
    MaxWidth = property(get_MaxWidth, put_MaxWidth)
    MinWidth = property(get_MinWidth, put_MinWidth)
    Width = property(get_Width, put_Width)
class IColumnDefinitionStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IColumnDefinitionStatics'
    _iid_ = Guid('{aba4b755-ca63-5ed7-ae31-45f9f91920b0}')
    @winrt_commethod(6)
    def get_WidthProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_MaxWidthProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_MinWidthProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    MaxWidthProperty = property(get_MaxWidthProperty, None)
    MinWidthProperty = property(get_MinWidthProperty, None)
    WidthProperty = property(get_WidthProperty, None)
class IComboBox(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IComboBox'
    _iid_ = Guid('{c77da58b-4fd7-51e0-a431-f84658a83e9e}')
    @winrt_commethod(6)
    def get_IsDropDownOpen(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_IsDropDownOpen(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def get_IsEditable(self) -> Boolean: ...
    @winrt_commethod(9)
    def put_IsEditable(self, value: Boolean) -> Void: ...
    @winrt_commethod(10)
    def get_IsSelectionBoxHighlighted(self) -> Boolean: ...
    @winrt_commethod(11)
    def get_MaxDropDownHeight(self) -> Double: ...
    @winrt_commethod(12)
    def put_MaxDropDownHeight(self, value: Double) -> Void: ...
    @winrt_commethod(13)
    def get_SelectionBoxItem(self) -> IInspectable: ...
    @winrt_commethod(14)
    def get_SelectionBoxItemTemplate(self) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_commethod(15)
    def get_TemplateSettings(self) -> win32more.Microsoft.UI.Xaml.Controls.Primitives.ComboBoxTemplateSettings: ...
    @winrt_commethod(16)
    def get_Header(self) -> IInspectable: ...
    @winrt_commethod(17)
    def put_Header(self, value: IInspectable) -> Void: ...
    @winrt_commethod(18)
    def get_HeaderTemplate(self) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_commethod(19)
    def put_HeaderTemplate(self, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_commethod(20)
    def get_PlaceholderText(self) -> hstr: ...
    @winrt_commethod(21)
    def put_PlaceholderText(self, value: hstr) -> Void: ...
    @winrt_commethod(22)
    def get_LightDismissOverlayMode(self) -> win32more.Microsoft.UI.Xaml.Controls.LightDismissOverlayMode: ...
    @winrt_commethod(23)
    def put_LightDismissOverlayMode(self, value: win32more.Microsoft.UI.Xaml.Controls.LightDismissOverlayMode) -> Void: ...
    @winrt_commethod(24)
    def get_IsTextSearchEnabled(self) -> Boolean: ...
    @winrt_commethod(25)
    def put_IsTextSearchEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(26)
    def get_SelectionChangedTrigger(self) -> win32more.Microsoft.UI.Xaml.Controls.ComboBoxSelectionChangedTrigger: ...
    @winrt_commethod(27)
    def put_SelectionChangedTrigger(self, value: win32more.Microsoft.UI.Xaml.Controls.ComboBoxSelectionChangedTrigger) -> Void: ...
    @winrt_commethod(28)
    def get_PlaceholderForeground(self) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_commethod(29)
    def put_PlaceholderForeground(self, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(30)
    def get_Text(self) -> hstr: ...
    @winrt_commethod(31)
    def put_Text(self, value: hstr) -> Void: ...
    @winrt_commethod(32)
    def get_TextBoxStyle(self) -> win32more.Microsoft.UI.Xaml.Style: ...
    @winrt_commethod(33)
    def put_TextBoxStyle(self, value: win32more.Microsoft.UI.Xaml.Style) -> Void: ...
    @winrt_commethod(34)
    def get_Description(self) -> IInspectable: ...
    @winrt_commethod(35)
    def put_Description(self, value: IInspectable) -> Void: ...
    @winrt_commethod(36)
    def add_DropDownClosed(self, handler: win32more.Windows.Foundation.EventHandler[IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(37)
    def remove_DropDownClosed(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(38)
    def add_DropDownOpened(self, handler: win32more.Windows.Foundation.EventHandler[IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(39)
    def remove_DropDownOpened(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(40)
    def add_TextSubmitted(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.ComboBox, win32more.Microsoft.UI.Xaml.Controls.ComboBoxTextSubmittedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(41)
    def remove_TextSubmitted(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    Description = property(get_Description, put_Description)
    Header = property(get_Header, put_Header)
    HeaderTemplate = property(get_HeaderTemplate, put_HeaderTemplate)
    IsDropDownOpen = property(get_IsDropDownOpen, put_IsDropDownOpen)
    IsEditable = property(get_IsEditable, put_IsEditable)
    IsSelectionBoxHighlighted = property(get_IsSelectionBoxHighlighted, None)
    IsTextSearchEnabled = property(get_IsTextSearchEnabled, put_IsTextSearchEnabled)
    LightDismissOverlayMode = property(get_LightDismissOverlayMode, put_LightDismissOverlayMode)
    MaxDropDownHeight = property(get_MaxDropDownHeight, put_MaxDropDownHeight)
    PlaceholderForeground = property(get_PlaceholderForeground, put_PlaceholderForeground)
    PlaceholderText = property(get_PlaceholderText, put_PlaceholderText)
    SelectionBoxItem = property(get_SelectionBoxItem, None)
    SelectionBoxItemTemplate = property(get_SelectionBoxItemTemplate, None)
    SelectionChangedTrigger = property(get_SelectionChangedTrigger, put_SelectionChangedTrigger)
    TemplateSettings = property(get_TemplateSettings, None)
    Text = property(get_Text, put_Text)
    TextBoxStyle = property(get_TextBoxStyle, put_TextBoxStyle)
    DropDownClosed = event(add_DropDownClosed, remove_DropDownClosed)
    DropDownOpened = event(add_DropDownOpened, remove_DropDownOpened)
    TextSubmitted = event(add_TextSubmitted, remove_TextSubmitted)
class IComboBoxFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IComboBoxFactory'
    _iid_ = Guid('{71c1014b-acdf-5c03-b5ed-02871caaeb6b}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.ComboBox: ...
class IComboBoxItem(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IComboBoxItem'
    _iid_ = Guid('{df65f6f4-863f-558d-bc4e-82c12f28062f}')
class IComboBoxItemFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IComboBoxItemFactory'
    _iid_ = Guid('{8540b906-c96b-592d-88d7-0c23a3386d93}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.ComboBoxItem: ...
class IComboBoxOverrides(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IComboBoxOverrides'
    _iid_ = Guid('{a6afbc7a-284f-5b9a-89fe-a334b613f895}')
    @winrt_commethod(6)
    def OnDropDownClosed(self, e: IInspectable) -> Void: ...
    @winrt_commethod(7)
    def OnDropDownOpened(self, e: IInspectable) -> Void: ...
class IComboBoxStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IComboBoxStatics'
    _iid_ = Guid('{7da7cd09-e256-5238-9fed-02b2f3afba25}')
    @winrt_commethod(6)
    def get_IsEditableProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_IsDropDownOpenProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_MaxDropDownHeightProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_HeaderProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_HeaderTemplateProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_PlaceholderTextProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_LightDismissOverlayModeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_IsTextSearchEnabledProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(14)
    def get_SelectionChangedTriggerProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(15)
    def get_PlaceholderForegroundProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(16)
    def get_TextProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(17)
    def get_TextBoxStyleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(18)
    def get_DescriptionProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    DescriptionProperty = property(get_DescriptionProperty, None)
    HeaderProperty = property(get_HeaderProperty, None)
    HeaderTemplateProperty = property(get_HeaderTemplateProperty, None)
    IsDropDownOpenProperty = property(get_IsDropDownOpenProperty, None)
    IsEditableProperty = property(get_IsEditableProperty, None)
    IsTextSearchEnabledProperty = property(get_IsTextSearchEnabledProperty, None)
    LightDismissOverlayModeProperty = property(get_LightDismissOverlayModeProperty, None)
    MaxDropDownHeightProperty = property(get_MaxDropDownHeightProperty, None)
    PlaceholderForegroundProperty = property(get_PlaceholderForegroundProperty, None)
    PlaceholderTextProperty = property(get_PlaceholderTextProperty, None)
    SelectionChangedTriggerProperty = property(get_SelectionChangedTriggerProperty, None)
    TextBoxStyleProperty = property(get_TextBoxStyleProperty, None)
    TextProperty = property(get_TextProperty, None)
class IComboBoxTextSubmittedEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IComboBoxTextSubmittedEventArgs'
    _iid_ = Guid('{0d7a9794-73b5-585e-bfbb-de6df7eb9fcf}')
    @winrt_commethod(6)
    def get_Text(self) -> hstr: ...
    @winrt_commethod(7)
    def get_Handled(self) -> Boolean: ...
    @winrt_commethod(8)
    def put_Handled(self, value: Boolean) -> Void: ...
    Handled = property(get_Handled, put_Handled)
    Text = property(get_Text, None)
class ICommandBar(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ICommandBar'
    _iid_ = Guid('{b7ca8ee3-a07a-5f69-8ab8-be4e3e4cf0c8}')
    @winrt_commethod(6)
    def get_PrimaryCommands(self) -> win32more.Windows.Foundation.Collections.IObservableVector[win32more.Microsoft.UI.Xaml.Controls.ICommandBarElement]: ...
    @winrt_commethod(7)
    def get_SecondaryCommands(self) -> win32more.Windows.Foundation.Collections.IObservableVector[win32more.Microsoft.UI.Xaml.Controls.ICommandBarElement]: ...
    @winrt_commethod(8)
    def get_CommandBarOverflowPresenterStyle(self) -> win32more.Microsoft.UI.Xaml.Style: ...
    @winrt_commethod(9)
    def put_CommandBarOverflowPresenterStyle(self, value: win32more.Microsoft.UI.Xaml.Style) -> Void: ...
    @winrt_commethod(10)
    def get_CommandBarTemplateSettings(self) -> win32more.Microsoft.UI.Xaml.Controls.Primitives.CommandBarTemplateSettings: ...
    @winrt_commethod(11)
    def get_DefaultLabelPosition(self) -> win32more.Microsoft.UI.Xaml.Controls.CommandBarDefaultLabelPosition: ...
    @winrt_commethod(12)
    def put_DefaultLabelPosition(self, value: win32more.Microsoft.UI.Xaml.Controls.CommandBarDefaultLabelPosition) -> Void: ...
    @winrt_commethod(13)
    def get_OverflowButtonVisibility(self) -> win32more.Microsoft.UI.Xaml.Controls.CommandBarOverflowButtonVisibility: ...
    @winrt_commethod(14)
    def put_OverflowButtonVisibility(self, value: win32more.Microsoft.UI.Xaml.Controls.CommandBarOverflowButtonVisibility) -> Void: ...
    @winrt_commethod(15)
    def get_IsDynamicOverflowEnabled(self) -> Boolean: ...
    @winrt_commethod(16)
    def put_IsDynamicOverflowEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(17)
    def add_DynamicOverflowItemsChanging(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.CommandBar, win32more.Microsoft.UI.Xaml.Controls.DynamicOverflowItemsChangingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(18)
    def remove_DynamicOverflowItemsChanging(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    CommandBarOverflowPresenterStyle = property(get_CommandBarOverflowPresenterStyle, put_CommandBarOverflowPresenterStyle)
    CommandBarTemplateSettings = property(get_CommandBarTemplateSettings, None)
    DefaultLabelPosition = property(get_DefaultLabelPosition, put_DefaultLabelPosition)
    IsDynamicOverflowEnabled = property(get_IsDynamicOverflowEnabled, put_IsDynamicOverflowEnabled)
    OverflowButtonVisibility = property(get_OverflowButtonVisibility, put_OverflowButtonVisibility)
    PrimaryCommands = property(get_PrimaryCommands, None)
    SecondaryCommands = property(get_SecondaryCommands, None)
    DynamicOverflowItemsChanging = event(add_DynamicOverflowItemsChanging, remove_DynamicOverflowItemsChanging)
class ICommandBarElement(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ICommandBarElement'
    _iid_ = Guid('{f8eb20b4-373e-5327-9942-66a1ea21f5f9}')
    @winrt_commethod(6)
    def get_IsCompact(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_IsCompact(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def get_IsInOverflow(self) -> Boolean: ...
    @winrt_commethod(9)
    def get_DynamicOverflowOrder(self) -> Int32: ...
    @winrt_commethod(10)
    def put_DynamicOverflowOrder(self, value: Int32) -> Void: ...
    DynamicOverflowOrder = property(get_DynamicOverflowOrder, put_DynamicOverflowOrder)
    IsCompact = property(get_IsCompact, put_IsCompact)
    IsInOverflow = property(get_IsInOverflow, None)
class ICommandBarFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ICommandBarFactory'
    _iid_ = Guid('{8d4079c3-fa0a-5bb1-b45d-499c378761b4}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.CommandBar: ...
class ICommandBarFlyout(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ICommandBarFlyout'
    _iid_ = Guid('{18e2cc40-09cb-5f20-a715-f0b2039c5e18}')
    @winrt_commethod(6)
    def get_PrimaryCommands(self) -> win32more.Windows.Foundation.Collections.IObservableVector[win32more.Microsoft.UI.Xaml.Controls.ICommandBarElement]: ...
    @winrt_commethod(7)
    def get_SecondaryCommands(self) -> win32more.Windows.Foundation.Collections.IObservableVector[win32more.Microsoft.UI.Xaml.Controls.ICommandBarElement]: ...
    PrimaryCommands = property(get_PrimaryCommands, None)
    SecondaryCommands = property(get_SecondaryCommands, None)
class ICommandBarFlyout2(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ICommandBarFlyout2'
    _iid_ = Guid('{5f81ec9e-a9d2-5f04-b5b1-013daef026dd}')
    @winrt_commethod(6)
    def get_AlwaysExpanded(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_AlwaysExpanded(self, value: Boolean) -> Void: ...
    AlwaysExpanded = property(get_AlwaysExpanded, put_AlwaysExpanded)
class ICommandBarFlyoutFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ICommandBarFlyoutFactory'
    _iid_ = Guid('{a194dbe6-4311-5bd2-a8eb-b49c4733a33c}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.CommandBarFlyout: ...
class ICommandBarOverflowPresenter(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ICommandBarOverflowPresenter'
    _iid_ = Guid('{5ff69946-9b27-583b-a3c0-d44244b1bd38}')
class ICommandBarOverflowPresenterFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ICommandBarOverflowPresenterFactory'
    _iid_ = Guid('{d066acf7-0ef5-591a-801e-52a084eea6eb}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.CommandBarOverflowPresenter: ...
class ICommandBarStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ICommandBarStatics'
    _iid_ = Guid('{4ed65848-4c67-588f-9666-11ff56d76f02}')
    @winrt_commethod(6)
    def get_PrimaryCommandsProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_SecondaryCommandsProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_CommandBarOverflowPresenterStyleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_DefaultLabelPositionProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_OverflowButtonVisibilityProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_IsDynamicOverflowEnabledProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    CommandBarOverflowPresenterStyleProperty = property(get_CommandBarOverflowPresenterStyleProperty, None)
    DefaultLabelPositionProperty = property(get_DefaultLabelPositionProperty, None)
    IsDynamicOverflowEnabledProperty = property(get_IsDynamicOverflowEnabledProperty, None)
    OverflowButtonVisibilityProperty = property(get_OverflowButtonVisibilityProperty, None)
    PrimaryCommandsProperty = property(get_PrimaryCommandsProperty, None)
    SecondaryCommandsProperty = property(get_SecondaryCommandsProperty, None)
class IContainerContentChangingEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IContainerContentChangingEventArgs'
    _iid_ = Guid('{f4c8c937-b070-53ce-a76c-074ee5750a71}')
    @winrt_commethod(6)
    def get_ItemContainer(self) -> win32more.Microsoft.UI.Xaml.Controls.Primitives.SelectorItem: ...
    @winrt_commethod(7)
    def get_InRecycleQueue(self) -> Boolean: ...
    @winrt_commethod(8)
    def get_ItemIndex(self) -> Int32: ...
    @winrt_commethod(9)
    def get_Item(self) -> IInspectable: ...
    @winrt_commethod(10)
    def get_Phase(self) -> UInt32: ...
    @winrt_commethod(11)
    def get_Handled(self) -> Boolean: ...
    @winrt_commethod(12)
    def put_Handled(self, value: Boolean) -> Void: ...
    @winrt_commethod(13)
    def RegisterUpdateCallback(self, callback: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.ListViewBase, win32more.Microsoft.UI.Xaml.Controls.ContainerContentChangingEventArgs]) -> Void: ...
    @winrt_commethod(14)
    def RegisterUpdateCallbackWithPhase(self, callbackPhase: UInt32, callback: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.ListViewBase, win32more.Microsoft.UI.Xaml.Controls.ContainerContentChangingEventArgs]) -> Void: ...
    Handled = property(get_Handled, put_Handled)
    InRecycleQueue = property(get_InRecycleQueue, None)
    Item = property(get_Item, None)
    ItemContainer = property(get_ItemContainer, None)
    ItemIndex = property(get_ItemIndex, None)
    Phase = property(get_Phase, None)
class IContentControl(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IContentControl'
    _iid_ = Guid('{07e81761-11b2-52ae-8f8b-4d53d2b5900a}')
    @winrt_commethod(6)
    def get_Content(self) -> IInspectable: ...
    @winrt_commethod(7)
    def put_Content(self, value: IInspectable) -> Void: ...
    @winrt_commethod(8)
    def get_ContentTemplate(self) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_commethod(9)
    def put_ContentTemplate(self, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_commethod(10)
    def get_ContentTemplateSelector(self) -> win32more.Microsoft.UI.Xaml.Controls.DataTemplateSelector: ...
    @winrt_commethod(11)
    def put_ContentTemplateSelector(self, value: win32more.Microsoft.UI.Xaml.Controls.DataTemplateSelector) -> Void: ...
    @winrt_commethod(12)
    def get_ContentTransitions(self) -> win32more.Microsoft.UI.Xaml.Media.Animation.TransitionCollection: ...
    @winrt_commethod(13)
    def put_ContentTransitions(self, value: win32more.Microsoft.UI.Xaml.Media.Animation.TransitionCollection) -> Void: ...
    @winrt_commethod(14)
    def get_ContentTemplateRoot(self) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    Content = property(get_Content, put_Content)
    ContentTemplate = property(get_ContentTemplate, put_ContentTemplate)
    ContentTemplateRoot = property(get_ContentTemplateRoot, None)
    ContentTemplateSelector = property(get_ContentTemplateSelector, put_ContentTemplateSelector)
    ContentTransitions = property(get_ContentTransitions, put_ContentTransitions)
class IContentControlFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IContentControlFactory'
    _iid_ = Guid('{3dea958e-5acd-5f80-8938-38634f51493a}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.ContentControl: ...
class IContentControlOverrides(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IContentControlOverrides'
    _iid_ = Guid('{2504174a-017e-5a2d-9c28-d97c66ae9937}')
    @winrt_commethod(6)
    def OnContentChanged(self, oldContent: IInspectable, newContent: IInspectable) -> Void: ...
    @winrt_commethod(7)
    def OnContentTemplateChanged(self, oldContentTemplate: win32more.Microsoft.UI.Xaml.DataTemplate, newContentTemplate: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_commethod(8)
    def OnContentTemplateSelectorChanged(self, oldContentTemplateSelector: win32more.Microsoft.UI.Xaml.Controls.DataTemplateSelector, newContentTemplateSelector: win32more.Microsoft.UI.Xaml.Controls.DataTemplateSelector) -> Void: ...
class IContentControlStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IContentControlStatics'
    _iid_ = Guid('{f25484f4-2fed-5a0a-8864-7d6d4ac43ef8}')
    @winrt_commethod(6)
    def get_ContentProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_ContentTemplateProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_ContentTemplateSelectorProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_ContentTransitionsProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    ContentProperty = property(get_ContentProperty, None)
    ContentTemplateProperty = property(get_ContentTemplateProperty, None)
    ContentTemplateSelectorProperty = property(get_ContentTemplateSelectorProperty, None)
    ContentTransitionsProperty = property(get_ContentTransitionsProperty, None)
class IContentDialog(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IContentDialog'
    _iid_ = Guid('{ac2145a3-4a32-5305-a81d-47509515bfce}')
    @winrt_commethod(6)
    def get_Title(self) -> IInspectable: ...
    @winrt_commethod(7)
    def put_Title(self, value: IInspectable) -> Void: ...
    @winrt_commethod(8)
    def get_TitleTemplate(self) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_commethod(9)
    def put_TitleTemplate(self, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_commethod(10)
    def get_FullSizeDesired(self) -> Boolean: ...
    @winrt_commethod(11)
    def put_FullSizeDesired(self, value: Boolean) -> Void: ...
    @winrt_commethod(12)
    def get_PrimaryButtonText(self) -> hstr: ...
    @winrt_commethod(13)
    def put_PrimaryButtonText(self, value: hstr) -> Void: ...
    @winrt_commethod(14)
    def get_SecondaryButtonText(self) -> hstr: ...
    @winrt_commethod(15)
    def put_SecondaryButtonText(self, value: hstr) -> Void: ...
    @winrt_commethod(16)
    def get_CloseButtonText(self) -> hstr: ...
    @winrt_commethod(17)
    def put_CloseButtonText(self, value: hstr) -> Void: ...
    @winrt_commethod(18)
    def get_PrimaryButtonCommand(self) -> win32more.Microsoft.UI.Xaml.Input.ICommand: ...
    @winrt_commethod(19)
    def put_PrimaryButtonCommand(self, value: win32more.Microsoft.UI.Xaml.Input.ICommand) -> Void: ...
    @winrt_commethod(20)
    def get_SecondaryButtonCommand(self) -> win32more.Microsoft.UI.Xaml.Input.ICommand: ...
    @winrt_commethod(21)
    def put_SecondaryButtonCommand(self, value: win32more.Microsoft.UI.Xaml.Input.ICommand) -> Void: ...
    @winrt_commethod(22)
    def get_CloseButtonCommand(self) -> win32more.Microsoft.UI.Xaml.Input.ICommand: ...
    @winrt_commethod(23)
    def put_CloseButtonCommand(self, value: win32more.Microsoft.UI.Xaml.Input.ICommand) -> Void: ...
    @winrt_commethod(24)
    def get_PrimaryButtonCommandParameter(self) -> IInspectable: ...
    @winrt_commethod(25)
    def put_PrimaryButtonCommandParameter(self, value: IInspectable) -> Void: ...
    @winrt_commethod(26)
    def get_SecondaryButtonCommandParameter(self) -> IInspectable: ...
    @winrt_commethod(27)
    def put_SecondaryButtonCommandParameter(self, value: IInspectable) -> Void: ...
    @winrt_commethod(28)
    def get_CloseButtonCommandParameter(self) -> IInspectable: ...
    @winrt_commethod(29)
    def put_CloseButtonCommandParameter(self, value: IInspectable) -> Void: ...
    @winrt_commethod(30)
    def get_IsPrimaryButtonEnabled(self) -> Boolean: ...
    @winrt_commethod(31)
    def put_IsPrimaryButtonEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(32)
    def get_IsSecondaryButtonEnabled(self) -> Boolean: ...
    @winrt_commethod(33)
    def put_IsSecondaryButtonEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(34)
    def get_PrimaryButtonStyle(self) -> win32more.Microsoft.UI.Xaml.Style: ...
    @winrt_commethod(35)
    def put_PrimaryButtonStyle(self, value: win32more.Microsoft.UI.Xaml.Style) -> Void: ...
    @winrt_commethod(36)
    def get_SecondaryButtonStyle(self) -> win32more.Microsoft.UI.Xaml.Style: ...
    @winrt_commethod(37)
    def put_SecondaryButtonStyle(self, value: win32more.Microsoft.UI.Xaml.Style) -> Void: ...
    @winrt_commethod(38)
    def get_CloseButtonStyle(self) -> win32more.Microsoft.UI.Xaml.Style: ...
    @winrt_commethod(39)
    def put_CloseButtonStyle(self, value: win32more.Microsoft.UI.Xaml.Style) -> Void: ...
    @winrt_commethod(40)
    def get_DefaultButton(self) -> win32more.Microsoft.UI.Xaml.Controls.ContentDialogButton: ...
    @winrt_commethod(41)
    def put_DefaultButton(self, value: win32more.Microsoft.UI.Xaml.Controls.ContentDialogButton) -> Void: ...
    @winrt_commethod(42)
    def add_Closing(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.ContentDialog, win32more.Microsoft.UI.Xaml.Controls.ContentDialogClosingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(43)
    def remove_Closing(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(44)
    def add_Closed(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.ContentDialog, win32more.Microsoft.UI.Xaml.Controls.ContentDialogClosedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(45)
    def remove_Closed(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(46)
    def add_Opened(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.ContentDialog, win32more.Microsoft.UI.Xaml.Controls.ContentDialogOpenedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(47)
    def remove_Opened(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(48)
    def add_PrimaryButtonClick(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.ContentDialog, win32more.Microsoft.UI.Xaml.Controls.ContentDialogButtonClickEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(49)
    def remove_PrimaryButtonClick(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(50)
    def add_SecondaryButtonClick(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.ContentDialog, win32more.Microsoft.UI.Xaml.Controls.ContentDialogButtonClickEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(51)
    def remove_SecondaryButtonClick(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(52)
    def add_CloseButtonClick(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.ContentDialog, win32more.Microsoft.UI.Xaml.Controls.ContentDialogButtonClickEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(53)
    def remove_CloseButtonClick(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(54)
    def Hide(self) -> Void: ...
    @winrt_commethod(55)
    def ShowAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Microsoft.UI.Xaml.Controls.ContentDialogResult]: ...
    @winrt_commethod(56)
    def ShowAsyncWithPlacement(self, placement: win32more.Microsoft.UI.Xaml.Controls.ContentDialogPlacement) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Microsoft.UI.Xaml.Controls.ContentDialogResult]: ...
    CloseButtonCommand = property(get_CloseButtonCommand, put_CloseButtonCommand)
    CloseButtonCommandParameter = property(get_CloseButtonCommandParameter, put_CloseButtonCommandParameter)
    CloseButtonStyle = property(get_CloseButtonStyle, put_CloseButtonStyle)
    CloseButtonText = property(get_CloseButtonText, put_CloseButtonText)
    DefaultButton = property(get_DefaultButton, put_DefaultButton)
    FullSizeDesired = property(get_FullSizeDesired, put_FullSizeDesired)
    IsPrimaryButtonEnabled = property(get_IsPrimaryButtonEnabled, put_IsPrimaryButtonEnabled)
    IsSecondaryButtonEnabled = property(get_IsSecondaryButtonEnabled, put_IsSecondaryButtonEnabled)
    PrimaryButtonCommand = property(get_PrimaryButtonCommand, put_PrimaryButtonCommand)
    PrimaryButtonCommandParameter = property(get_PrimaryButtonCommandParameter, put_PrimaryButtonCommandParameter)
    PrimaryButtonStyle = property(get_PrimaryButtonStyle, put_PrimaryButtonStyle)
    PrimaryButtonText = property(get_PrimaryButtonText, put_PrimaryButtonText)
    SecondaryButtonCommand = property(get_SecondaryButtonCommand, put_SecondaryButtonCommand)
    SecondaryButtonCommandParameter = property(get_SecondaryButtonCommandParameter, put_SecondaryButtonCommandParameter)
    SecondaryButtonStyle = property(get_SecondaryButtonStyle, put_SecondaryButtonStyle)
    SecondaryButtonText = property(get_SecondaryButtonText, put_SecondaryButtonText)
    Title = property(get_Title, put_Title)
    TitleTemplate = property(get_TitleTemplate, put_TitleTemplate)
    CloseButtonClick = event(add_CloseButtonClick, remove_CloseButtonClick)
    Closed = event(add_Closed, remove_Closed)
    Closing = event(add_Closing, remove_Closing)
    Opened = event(add_Opened, remove_Opened)
    PrimaryButtonClick = event(add_PrimaryButtonClick, remove_PrimaryButtonClick)
    SecondaryButtonClick = event(add_SecondaryButtonClick, remove_SecondaryButtonClick)
class IContentDialogButtonClickDeferral(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IContentDialogButtonClickDeferral'
    _iid_ = Guid('{ddca6d2e-a81a-5f61-8b87-e4b6ec5fa398}')
    @winrt_commethod(6)
    def Complete(self) -> Void: ...
class IContentDialogButtonClickEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IContentDialogButtonClickEventArgs'
    _iid_ = Guid('{bae6261c-362f-5342-ba26-5f6990ef726c}')
    @winrt_commethod(6)
    def get_Cancel(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_Cancel(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def GetDeferral(self) -> win32more.Microsoft.UI.Xaml.Controls.ContentDialogButtonClickDeferral: ...
    Cancel = property(get_Cancel, put_Cancel)
class IContentDialogClosedEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IContentDialogClosedEventArgs'
    _iid_ = Guid('{9b84e681-1ab6-5485-88b2-d0d3c05b29f3}')
    @winrt_commethod(6)
    def get_Result(self) -> win32more.Microsoft.UI.Xaml.Controls.ContentDialogResult: ...
    Result = property(get_Result, None)
class IContentDialogClosingDeferral(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IContentDialogClosingDeferral'
    _iid_ = Guid('{9d74ecc1-67d3-5f02-9b30-56f3b2e8b0a6}')
    @winrt_commethod(6)
    def Complete(self) -> Void: ...
class IContentDialogClosingEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IContentDialogClosingEventArgs'
    _iid_ = Guid('{12782103-3b80-511c-9128-12cb8cdac444}')
    @winrt_commethod(6)
    def get_Result(self) -> win32more.Microsoft.UI.Xaml.Controls.ContentDialogResult: ...
    @winrt_commethod(7)
    def get_Cancel(self) -> Boolean: ...
    @winrt_commethod(8)
    def put_Cancel(self, value: Boolean) -> Void: ...
    @winrt_commethod(9)
    def GetDeferral(self) -> win32more.Microsoft.UI.Xaml.Controls.ContentDialogClosingDeferral: ...
    Cancel = property(get_Cancel, put_Cancel)
    Result = property(get_Result, None)
class IContentDialogFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IContentDialogFactory'
    _iid_ = Guid('{a05b3ad7-c60e-545a-9ee4-f098220ed816}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.ContentDialog: ...
class IContentDialogOpenedEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IContentDialogOpenedEventArgs'
    _iid_ = Guid('{d1355ed8-64ed-5bbc-9411-5f4dbca7d93f}')
class IContentDialogStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IContentDialogStatics'
    _iid_ = Guid('{397b18dd-6964-5056-97c3-d69cd7716a4b}')
    @winrt_commethod(6)
    def get_TitleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_TitleTemplateProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_FullSizeDesiredProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_PrimaryButtonTextProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_SecondaryButtonTextProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_CloseButtonTextProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_PrimaryButtonCommandProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_SecondaryButtonCommandProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(14)
    def get_CloseButtonCommandProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(15)
    def get_PrimaryButtonCommandParameterProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(16)
    def get_SecondaryButtonCommandParameterProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(17)
    def get_CloseButtonCommandParameterProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(18)
    def get_IsPrimaryButtonEnabledProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(19)
    def get_IsSecondaryButtonEnabledProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(20)
    def get_PrimaryButtonStyleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(21)
    def get_SecondaryButtonStyleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(22)
    def get_CloseButtonStyleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(23)
    def get_DefaultButtonProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    CloseButtonCommandParameterProperty = property(get_CloseButtonCommandParameterProperty, None)
    CloseButtonCommandProperty = property(get_CloseButtonCommandProperty, None)
    CloseButtonStyleProperty = property(get_CloseButtonStyleProperty, None)
    CloseButtonTextProperty = property(get_CloseButtonTextProperty, None)
    DefaultButtonProperty = property(get_DefaultButtonProperty, None)
    FullSizeDesiredProperty = property(get_FullSizeDesiredProperty, None)
    IsPrimaryButtonEnabledProperty = property(get_IsPrimaryButtonEnabledProperty, None)
    IsSecondaryButtonEnabledProperty = property(get_IsSecondaryButtonEnabledProperty, None)
    PrimaryButtonCommandParameterProperty = property(get_PrimaryButtonCommandParameterProperty, None)
    PrimaryButtonCommandProperty = property(get_PrimaryButtonCommandProperty, None)
    PrimaryButtonStyleProperty = property(get_PrimaryButtonStyleProperty, None)
    PrimaryButtonTextProperty = property(get_PrimaryButtonTextProperty, None)
    SecondaryButtonCommandParameterProperty = property(get_SecondaryButtonCommandParameterProperty, None)
    SecondaryButtonCommandProperty = property(get_SecondaryButtonCommandProperty, None)
    SecondaryButtonStyleProperty = property(get_SecondaryButtonStyleProperty, None)
    SecondaryButtonTextProperty = property(get_SecondaryButtonTextProperty, None)
    TitleProperty = property(get_TitleProperty, None)
    TitleTemplateProperty = property(get_TitleTemplateProperty, None)
class IContentPresenter(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IContentPresenter'
    _iid_ = Guid('{075e6ca8-da46-5ec6-8c64-03b3ddeaf74f}')
    @winrt_commethod(6)
    def get_Content(self) -> IInspectable: ...
    @winrt_commethod(7)
    def put_Content(self, value: IInspectable) -> Void: ...
    @winrt_commethod(8)
    def get_ContentTemplate(self) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_commethod(9)
    def put_ContentTemplate(self, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_commethod(10)
    def get_ContentTemplateSelector(self) -> win32more.Microsoft.UI.Xaml.Controls.DataTemplateSelector: ...
    @winrt_commethod(11)
    def put_ContentTemplateSelector(self, value: win32more.Microsoft.UI.Xaml.Controls.DataTemplateSelector) -> Void: ...
    @winrt_commethod(12)
    def get_ContentTransitions(self) -> win32more.Microsoft.UI.Xaml.Media.Animation.TransitionCollection: ...
    @winrt_commethod(13)
    def put_ContentTransitions(self, value: win32more.Microsoft.UI.Xaml.Media.Animation.TransitionCollection) -> Void: ...
    @winrt_commethod(14)
    def get_FontSize(self) -> Double: ...
    @winrt_commethod(15)
    def put_FontSize(self, value: Double) -> Void: ...
    @winrt_commethod(16)
    def get_FontFamily(self) -> win32more.Microsoft.UI.Xaml.Media.FontFamily: ...
    @winrt_commethod(17)
    def put_FontFamily(self, value: win32more.Microsoft.UI.Xaml.Media.FontFamily) -> Void: ...
    @winrt_commethod(18)
    def get_FontWeight(self) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_commethod(19)
    def put_FontWeight(self, value: win32more.Windows.UI.Text.FontWeight) -> Void: ...
    @winrt_commethod(20)
    def get_FontStyle(self) -> win32more.Windows.UI.Text.FontStyle: ...
    @winrt_commethod(21)
    def put_FontStyle(self, value: win32more.Windows.UI.Text.FontStyle) -> Void: ...
    @winrt_commethod(22)
    def get_FontStretch(self) -> win32more.Windows.UI.Text.FontStretch: ...
    @winrt_commethod(23)
    def put_FontStretch(self, value: win32more.Windows.UI.Text.FontStretch) -> Void: ...
    @winrt_commethod(24)
    def get_CharacterSpacing(self) -> Int32: ...
    @winrt_commethod(25)
    def put_CharacterSpacing(self, value: Int32) -> Void: ...
    @winrt_commethod(26)
    def get_Foreground(self) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_commethod(27)
    def put_Foreground(self, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(28)
    def get_OpticalMarginAlignment(self) -> win32more.Microsoft.UI.Xaml.OpticalMarginAlignment: ...
    @winrt_commethod(29)
    def put_OpticalMarginAlignment(self, value: win32more.Microsoft.UI.Xaml.OpticalMarginAlignment) -> Void: ...
    @winrt_commethod(30)
    def get_TextLineBounds(self) -> win32more.Microsoft.UI.Xaml.TextLineBounds: ...
    @winrt_commethod(31)
    def put_TextLineBounds(self, value: win32more.Microsoft.UI.Xaml.TextLineBounds) -> Void: ...
    @winrt_commethod(32)
    def get_IsTextScaleFactorEnabled(self) -> Boolean: ...
    @winrt_commethod(33)
    def put_IsTextScaleFactorEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(34)
    def get_BackgroundTransition(self) -> win32more.Microsoft.UI.Xaml.BrushTransition: ...
    @winrt_commethod(35)
    def put_BackgroundTransition(self, value: win32more.Microsoft.UI.Xaml.BrushTransition) -> Void: ...
    @winrt_commethod(36)
    def get_TextWrapping(self) -> win32more.Microsoft.UI.Xaml.TextWrapping: ...
    @winrt_commethod(37)
    def put_TextWrapping(self, value: win32more.Microsoft.UI.Xaml.TextWrapping) -> Void: ...
    @winrt_commethod(38)
    def get_MaxLines(self) -> Int32: ...
    @winrt_commethod(39)
    def put_MaxLines(self, value: Int32) -> Void: ...
    @winrt_commethod(40)
    def get_LineStackingStrategy(self) -> win32more.Microsoft.UI.Xaml.LineStackingStrategy: ...
    @winrt_commethod(41)
    def put_LineStackingStrategy(self, value: win32more.Microsoft.UI.Xaml.LineStackingStrategy) -> Void: ...
    @winrt_commethod(42)
    def get_LineHeight(self) -> Double: ...
    @winrt_commethod(43)
    def put_LineHeight(self, value: Double) -> Void: ...
    @winrt_commethod(44)
    def get_BorderBrush(self) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_commethod(45)
    def put_BorderBrush(self, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(46)
    def get_BorderThickness(self) -> win32more.Microsoft.UI.Xaml.Thickness: ...
    @winrt_commethod(47)
    def put_BorderThickness(self, value: win32more.Microsoft.UI.Xaml.Thickness) -> Void: ...
    @winrt_commethod(48)
    def get_CornerRadius(self) -> win32more.Microsoft.UI.Xaml.CornerRadius: ...
    @winrt_commethod(49)
    def put_CornerRadius(self, value: win32more.Microsoft.UI.Xaml.CornerRadius) -> Void: ...
    @winrt_commethod(50)
    def get_Padding(self) -> win32more.Microsoft.UI.Xaml.Thickness: ...
    @winrt_commethod(51)
    def put_Padding(self, value: win32more.Microsoft.UI.Xaml.Thickness) -> Void: ...
    @winrt_commethod(52)
    def get_Background(self) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_commethod(53)
    def put_Background(self, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(54)
    def get_BackgroundSizing(self) -> win32more.Microsoft.UI.Xaml.Controls.BackgroundSizing: ...
    @winrt_commethod(55)
    def put_BackgroundSizing(self, value: win32more.Microsoft.UI.Xaml.Controls.BackgroundSizing) -> Void: ...
    @winrt_commethod(56)
    def get_HorizontalContentAlignment(self) -> win32more.Microsoft.UI.Xaml.HorizontalAlignment: ...
    @winrt_commethod(57)
    def put_HorizontalContentAlignment(self, value: win32more.Microsoft.UI.Xaml.HorizontalAlignment) -> Void: ...
    @winrt_commethod(58)
    def get_VerticalContentAlignment(self) -> win32more.Microsoft.UI.Xaml.VerticalAlignment: ...
    @winrt_commethod(59)
    def put_VerticalContentAlignment(self, value: win32more.Microsoft.UI.Xaml.VerticalAlignment) -> Void: ...
    Background = property(get_Background, put_Background)
    BackgroundSizing = property(get_BackgroundSizing, put_BackgroundSizing)
    BackgroundTransition = property(get_BackgroundTransition, put_BackgroundTransition)
    BorderBrush = property(get_BorderBrush, put_BorderBrush)
    BorderThickness = property(get_BorderThickness, put_BorderThickness)
    CharacterSpacing = property(get_CharacterSpacing, put_CharacterSpacing)
    Content = property(get_Content, put_Content)
    ContentTemplate = property(get_ContentTemplate, put_ContentTemplate)
    ContentTemplateSelector = property(get_ContentTemplateSelector, put_ContentTemplateSelector)
    ContentTransitions = property(get_ContentTransitions, put_ContentTransitions)
    CornerRadius = property(get_CornerRadius, put_CornerRadius)
    FontFamily = property(get_FontFamily, put_FontFamily)
    FontSize = property(get_FontSize, put_FontSize)
    FontStretch = property(get_FontStretch, put_FontStretch)
    FontStyle = property(get_FontStyle, put_FontStyle)
    FontWeight = property(get_FontWeight, put_FontWeight)
    Foreground = property(get_Foreground, put_Foreground)
    HorizontalContentAlignment = property(get_HorizontalContentAlignment, put_HorizontalContentAlignment)
    IsTextScaleFactorEnabled = property(get_IsTextScaleFactorEnabled, put_IsTextScaleFactorEnabled)
    LineHeight = property(get_LineHeight, put_LineHeight)
    LineStackingStrategy = property(get_LineStackingStrategy, put_LineStackingStrategy)
    MaxLines = property(get_MaxLines, put_MaxLines)
    OpticalMarginAlignment = property(get_OpticalMarginAlignment, put_OpticalMarginAlignment)
    Padding = property(get_Padding, put_Padding)
    TextLineBounds = property(get_TextLineBounds, put_TextLineBounds)
    TextWrapping = property(get_TextWrapping, put_TextWrapping)
    VerticalContentAlignment = property(get_VerticalContentAlignment, put_VerticalContentAlignment)
class IContentPresenterFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IContentPresenterFactory'
    _iid_ = Guid('{730b1d5e-2540-5a3d-a6c7-888aa8614610}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.ContentPresenter: ...
class IContentPresenterOverrides(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IContentPresenterOverrides'
    _iid_ = Guid('{00e96954-d6e0-510f-a2d2-38a032b96236}')
    @winrt_commethod(6)
    def OnContentTemplateChanged(self, oldContentTemplate: win32more.Microsoft.UI.Xaml.DataTemplate, newContentTemplate: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_commethod(7)
    def OnContentTemplateSelectorChanged(self, oldContentTemplateSelector: win32more.Microsoft.UI.Xaml.Controls.DataTemplateSelector, newContentTemplateSelector: win32more.Microsoft.UI.Xaml.Controls.DataTemplateSelector) -> Void: ...
class IContentPresenterStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IContentPresenterStatics'
    _iid_ = Guid('{c3e55f6c-7abe-568f-b67b-8ebd3274f33e}')
    @winrt_commethod(6)
    def get_ContentProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_ContentTemplateProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_ContentTemplateSelectorProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_ContentTransitionsProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_FontSizeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_FontFamilyProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_FontWeightProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_FontStyleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(14)
    def get_FontStretchProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(15)
    def get_CharacterSpacingProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(16)
    def get_ForegroundProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(17)
    def get_OpticalMarginAlignmentProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(18)
    def get_TextLineBoundsProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(19)
    def get_IsTextScaleFactorEnabledProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(20)
    def get_TextWrappingProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(21)
    def get_MaxLinesProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(22)
    def get_LineStackingStrategyProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(23)
    def get_LineHeightProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(24)
    def get_BorderBrushProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(25)
    def get_BorderThicknessProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(26)
    def get_CornerRadiusProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(27)
    def get_PaddingProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(28)
    def get_BackgroundProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(29)
    def get_BackgroundSizingProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(30)
    def get_HorizontalContentAlignmentProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(31)
    def get_VerticalContentAlignmentProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    BackgroundProperty = property(get_BackgroundProperty, None)
    BackgroundSizingProperty = property(get_BackgroundSizingProperty, None)
    BorderBrushProperty = property(get_BorderBrushProperty, None)
    BorderThicknessProperty = property(get_BorderThicknessProperty, None)
    CharacterSpacingProperty = property(get_CharacterSpacingProperty, None)
    ContentProperty = property(get_ContentProperty, None)
    ContentTemplateProperty = property(get_ContentTemplateProperty, None)
    ContentTemplateSelectorProperty = property(get_ContentTemplateSelectorProperty, None)
    ContentTransitionsProperty = property(get_ContentTransitionsProperty, None)
    CornerRadiusProperty = property(get_CornerRadiusProperty, None)
    FontFamilyProperty = property(get_FontFamilyProperty, None)
    FontSizeProperty = property(get_FontSizeProperty, None)
    FontStretchProperty = property(get_FontStretchProperty, None)
    FontStyleProperty = property(get_FontStyleProperty, None)
    FontWeightProperty = property(get_FontWeightProperty, None)
    ForegroundProperty = property(get_ForegroundProperty, None)
    HorizontalContentAlignmentProperty = property(get_HorizontalContentAlignmentProperty, None)
    IsTextScaleFactorEnabledProperty = property(get_IsTextScaleFactorEnabledProperty, None)
    LineHeightProperty = property(get_LineHeightProperty, None)
    LineStackingStrategyProperty = property(get_LineStackingStrategyProperty, None)
    MaxLinesProperty = property(get_MaxLinesProperty, None)
    OpticalMarginAlignmentProperty = property(get_OpticalMarginAlignmentProperty, None)
    PaddingProperty = property(get_PaddingProperty, None)
    TextLineBoundsProperty = property(get_TextLineBoundsProperty, None)
    TextWrappingProperty = property(get_TextWrappingProperty, None)
    VerticalContentAlignmentProperty = property(get_VerticalContentAlignmentProperty, None)
class IContextMenuEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IContextMenuEventArgs'
    _iid_ = Guid('{65637bb3-e279-5507-bd16-6f7ba6705f31}')
    @winrt_commethod(6)
    def get_Handled(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_Handled(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def get_CursorLeft(self) -> Double: ...
    @winrt_commethod(9)
    def get_CursorTop(self) -> Double: ...
    CursorLeft = property(get_CursorLeft, None)
    CursorTop = property(get_CursorTop, None)
    Handled = property(get_Handled, put_Handled)
class IControl(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IControl'
    _iid_ = Guid('{857d6e8a-d45a-5c69-a99c-bf6a5c54fb38}')
    @winrt_commethod(6)
    def get_IsFocusEngagementEnabled(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_IsFocusEngagementEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def get_IsFocusEngaged(self) -> Boolean: ...
    @winrt_commethod(9)
    def put_IsFocusEngaged(self, value: Boolean) -> Void: ...
    @winrt_commethod(10)
    def get_RequiresPointer(self) -> win32more.Microsoft.UI.Xaml.Controls.RequiresPointer: ...
    @winrt_commethod(11)
    def put_RequiresPointer(self, value: win32more.Microsoft.UI.Xaml.Controls.RequiresPointer) -> Void: ...
    @winrt_commethod(12)
    def get_FontSize(self) -> Double: ...
    @winrt_commethod(13)
    def put_FontSize(self, value: Double) -> Void: ...
    @winrt_commethod(14)
    def get_FontFamily(self) -> win32more.Microsoft.UI.Xaml.Media.FontFamily: ...
    @winrt_commethod(15)
    def put_FontFamily(self, value: win32more.Microsoft.UI.Xaml.Media.FontFamily) -> Void: ...
    @winrt_commethod(16)
    def get_FontWeight(self) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_commethod(17)
    def put_FontWeight(self, value: win32more.Windows.UI.Text.FontWeight) -> Void: ...
    @winrt_commethod(18)
    def get_FontStyle(self) -> win32more.Windows.UI.Text.FontStyle: ...
    @winrt_commethod(19)
    def put_FontStyle(self, value: win32more.Windows.UI.Text.FontStyle) -> Void: ...
    @winrt_commethod(20)
    def get_FontStretch(self) -> win32more.Windows.UI.Text.FontStretch: ...
    @winrt_commethod(21)
    def put_FontStretch(self, value: win32more.Windows.UI.Text.FontStretch) -> Void: ...
    @winrt_commethod(22)
    def get_CharacterSpacing(self) -> Int32: ...
    @winrt_commethod(23)
    def put_CharacterSpacing(self, value: Int32) -> Void: ...
    @winrt_commethod(24)
    def get_Foreground(self) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_commethod(25)
    def put_Foreground(self, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(26)
    def get_IsTextScaleFactorEnabled(self) -> Boolean: ...
    @winrt_commethod(27)
    def put_IsTextScaleFactorEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(28)
    def get_IsEnabled(self) -> Boolean: ...
    @winrt_commethod(29)
    def put_IsEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(30)
    def get_TabNavigation(self) -> win32more.Microsoft.UI.Xaml.Input.KeyboardNavigationMode: ...
    @winrt_commethod(31)
    def put_TabNavigation(self, value: win32more.Microsoft.UI.Xaml.Input.KeyboardNavigationMode) -> Void: ...
    @winrt_commethod(32)
    def get_Template(self) -> win32more.Microsoft.UI.Xaml.Controls.ControlTemplate: ...
    @winrt_commethod(33)
    def put_Template(self, value: win32more.Microsoft.UI.Xaml.Controls.ControlTemplate) -> Void: ...
    @winrt_commethod(34)
    def get_Padding(self) -> win32more.Microsoft.UI.Xaml.Thickness: ...
    @winrt_commethod(35)
    def put_Padding(self, value: win32more.Microsoft.UI.Xaml.Thickness) -> Void: ...
    @winrt_commethod(36)
    def get_HorizontalContentAlignment(self) -> win32more.Microsoft.UI.Xaml.HorizontalAlignment: ...
    @winrt_commethod(37)
    def put_HorizontalContentAlignment(self, value: win32more.Microsoft.UI.Xaml.HorizontalAlignment) -> Void: ...
    @winrt_commethod(38)
    def get_VerticalContentAlignment(self) -> win32more.Microsoft.UI.Xaml.VerticalAlignment: ...
    @winrt_commethod(39)
    def put_VerticalContentAlignment(self, value: win32more.Microsoft.UI.Xaml.VerticalAlignment) -> Void: ...
    @winrt_commethod(40)
    def get_Background(self) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_commethod(41)
    def put_Background(self, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(42)
    def get_BackgroundSizing(self) -> win32more.Microsoft.UI.Xaml.Controls.BackgroundSizing: ...
    @winrt_commethod(43)
    def put_BackgroundSizing(self, value: win32more.Microsoft.UI.Xaml.Controls.BackgroundSizing) -> Void: ...
    @winrt_commethod(44)
    def get_BorderThickness(self) -> win32more.Microsoft.UI.Xaml.Thickness: ...
    @winrt_commethod(45)
    def put_BorderThickness(self, value: win32more.Microsoft.UI.Xaml.Thickness) -> Void: ...
    @winrt_commethod(46)
    def get_BorderBrush(self) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_commethod(47)
    def put_BorderBrush(self, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(48)
    def get_DefaultStyleResourceUri(self) -> win32more.Windows.Foundation.Uri: ...
    @winrt_commethod(49)
    def put_DefaultStyleResourceUri(self, value: win32more.Windows.Foundation.Uri) -> Void: ...
    @winrt_commethod(50)
    def get_ElementSoundMode(self) -> win32more.Microsoft.UI.Xaml.ElementSoundMode: ...
    @winrt_commethod(51)
    def put_ElementSoundMode(self, value: win32more.Microsoft.UI.Xaml.ElementSoundMode) -> Void: ...
    @winrt_commethod(52)
    def get_CornerRadius(self) -> win32more.Microsoft.UI.Xaml.CornerRadius: ...
    @winrt_commethod(53)
    def put_CornerRadius(self, value: win32more.Microsoft.UI.Xaml.CornerRadius) -> Void: ...
    @winrt_commethod(54)
    def add_FocusEngaged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.Control, win32more.Microsoft.UI.Xaml.Controls.FocusEngagedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(55)
    def remove_FocusEngaged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(56)
    def add_FocusDisengaged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.Control, win32more.Microsoft.UI.Xaml.Controls.FocusDisengagedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(57)
    def remove_FocusDisengaged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(58)
    def add_IsEnabledChanged(self, handler: win32more.Microsoft.UI.Xaml.DependencyPropertyChangedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(59)
    def remove_IsEnabledChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(60)
    def RemoveFocusEngagement(self) -> Void: ...
    @winrt_commethod(61)
    def ApplyTemplate(self) -> Boolean: ...
    Background = property(get_Background, put_Background)
    BackgroundSizing = property(get_BackgroundSizing, put_BackgroundSizing)
    BorderBrush = property(get_BorderBrush, put_BorderBrush)
    BorderThickness = property(get_BorderThickness, put_BorderThickness)
    CharacterSpacing = property(get_CharacterSpacing, put_CharacterSpacing)
    CornerRadius = property(get_CornerRadius, put_CornerRadius)
    DefaultStyleResourceUri = property(get_DefaultStyleResourceUri, put_DefaultStyleResourceUri)
    ElementSoundMode = property(get_ElementSoundMode, put_ElementSoundMode)
    FontFamily = property(get_FontFamily, put_FontFamily)
    FontSize = property(get_FontSize, put_FontSize)
    FontStretch = property(get_FontStretch, put_FontStretch)
    FontStyle = property(get_FontStyle, put_FontStyle)
    FontWeight = property(get_FontWeight, put_FontWeight)
    Foreground = property(get_Foreground, put_Foreground)
    HorizontalContentAlignment = property(get_HorizontalContentAlignment, put_HorizontalContentAlignment)
    IsEnabled = property(get_IsEnabled, put_IsEnabled)
    IsFocusEngaged = property(get_IsFocusEngaged, put_IsFocusEngaged)
    IsFocusEngagementEnabled = property(get_IsFocusEngagementEnabled, put_IsFocusEngagementEnabled)
    IsTextScaleFactorEnabled = property(get_IsTextScaleFactorEnabled, put_IsTextScaleFactorEnabled)
    Padding = property(get_Padding, put_Padding)
    RequiresPointer = property(get_RequiresPointer, put_RequiresPointer)
    TabNavigation = property(get_TabNavigation, put_TabNavigation)
    Template = property(get_Template, put_Template)
    VerticalContentAlignment = property(get_VerticalContentAlignment, put_VerticalContentAlignment)
    FocusDisengaged = event(add_FocusDisengaged, remove_FocusDisengaged)
    FocusEngaged = event(add_FocusEngaged, remove_FocusEngaged)
    IsEnabledChanged = event(add_IsEnabledChanged, remove_IsEnabledChanged)
class IControlFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IControlFactory'
    _iid_ = Guid('{25159233-9438-5534-aeb9-00eb059cf73f}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.Control: ...
class IControlOverrides(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IControlOverrides'
    _iid_ = Guid('{5f644395-2177-5161-9f87-c6c749c73a03}')
    @winrt_commethod(6)
    def OnPointerEntered(self, e: win32more.Microsoft.UI.Xaml.Input.PointerRoutedEventArgs) -> Void: ...
    @winrt_commethod(7)
    def OnPointerPressed(self, e: win32more.Microsoft.UI.Xaml.Input.PointerRoutedEventArgs) -> Void: ...
    @winrt_commethod(8)
    def OnPointerMoved(self, e: win32more.Microsoft.UI.Xaml.Input.PointerRoutedEventArgs) -> Void: ...
    @winrt_commethod(9)
    def OnPointerReleased(self, e: win32more.Microsoft.UI.Xaml.Input.PointerRoutedEventArgs) -> Void: ...
    @winrt_commethod(10)
    def OnPointerExited(self, e: win32more.Microsoft.UI.Xaml.Input.PointerRoutedEventArgs) -> Void: ...
    @winrt_commethod(11)
    def OnPointerCaptureLost(self, e: win32more.Microsoft.UI.Xaml.Input.PointerRoutedEventArgs) -> Void: ...
    @winrt_commethod(12)
    def OnPointerCanceled(self, e: win32more.Microsoft.UI.Xaml.Input.PointerRoutedEventArgs) -> Void: ...
    @winrt_commethod(13)
    def OnPointerWheelChanged(self, e: win32more.Microsoft.UI.Xaml.Input.PointerRoutedEventArgs) -> Void: ...
    @winrt_commethod(14)
    def OnTapped(self, e: win32more.Microsoft.UI.Xaml.Input.TappedRoutedEventArgs) -> Void: ...
    @winrt_commethod(15)
    def OnDoubleTapped(self, e: win32more.Microsoft.UI.Xaml.Input.DoubleTappedRoutedEventArgs) -> Void: ...
    @winrt_commethod(16)
    def OnHolding(self, e: win32more.Microsoft.UI.Xaml.Input.HoldingRoutedEventArgs) -> Void: ...
    @winrt_commethod(17)
    def OnRightTapped(self, e: win32more.Microsoft.UI.Xaml.Input.RightTappedRoutedEventArgs) -> Void: ...
    @winrt_commethod(18)
    def OnManipulationStarting(self, e: win32more.Microsoft.UI.Xaml.Input.ManipulationStartingRoutedEventArgs) -> Void: ...
    @winrt_commethod(19)
    def OnManipulationInertiaStarting(self, e: win32more.Microsoft.UI.Xaml.Input.ManipulationInertiaStartingRoutedEventArgs) -> Void: ...
    @winrt_commethod(20)
    def OnManipulationStarted(self, e: win32more.Microsoft.UI.Xaml.Input.ManipulationStartedRoutedEventArgs) -> Void: ...
    @winrt_commethod(21)
    def OnManipulationDelta(self, e: win32more.Microsoft.UI.Xaml.Input.ManipulationDeltaRoutedEventArgs) -> Void: ...
    @winrt_commethod(22)
    def OnManipulationCompleted(self, e: win32more.Microsoft.UI.Xaml.Input.ManipulationCompletedRoutedEventArgs) -> Void: ...
    @winrt_commethod(23)
    def OnKeyUp(self, e: win32more.Microsoft.UI.Xaml.Input.KeyRoutedEventArgs) -> Void: ...
    @winrt_commethod(24)
    def OnKeyDown(self, e: win32more.Microsoft.UI.Xaml.Input.KeyRoutedEventArgs) -> Void: ...
    @winrt_commethod(25)
    def OnPreviewKeyDown(self, e: win32more.Microsoft.UI.Xaml.Input.KeyRoutedEventArgs) -> Void: ...
    @winrt_commethod(26)
    def OnPreviewKeyUp(self, e: win32more.Microsoft.UI.Xaml.Input.KeyRoutedEventArgs) -> Void: ...
    @winrt_commethod(27)
    def OnGotFocus(self, e: win32more.Microsoft.UI.Xaml.RoutedEventArgs) -> Void: ...
    @winrt_commethod(28)
    def OnLostFocus(self, e: win32more.Microsoft.UI.Xaml.RoutedEventArgs) -> Void: ...
    @winrt_commethod(29)
    def OnCharacterReceived(self, e: win32more.Microsoft.UI.Xaml.Input.CharacterReceivedRoutedEventArgs) -> Void: ...
    @winrt_commethod(30)
    def OnDragEnter(self, e: win32more.Microsoft.UI.Xaml.DragEventArgs) -> Void: ...
    @winrt_commethod(31)
    def OnDragLeave(self, e: win32more.Microsoft.UI.Xaml.DragEventArgs) -> Void: ...
    @winrt_commethod(32)
    def OnDragOver(self, e: win32more.Microsoft.UI.Xaml.DragEventArgs) -> Void: ...
    @winrt_commethod(33)
    def OnDrop(self, e: win32more.Microsoft.UI.Xaml.DragEventArgs) -> Void: ...
class IControlProtected(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IControlProtected'
    _iid_ = Guid('{5c750339-1789-5095-a214-dd9d0564e579}')
    @winrt_commethod(6)
    def get_DefaultStyleKey(self) -> IInspectable: ...
    @winrt_commethod(7)
    def put_DefaultStyleKey(self, value: IInspectable) -> Void: ...
    @winrt_commethod(8)
    def GetTemplateChild(self, childName: hstr) -> win32more.Microsoft.UI.Xaml.DependencyObject: ...
    DefaultStyleKey = property(get_DefaultStyleKey, put_DefaultStyleKey)
class IControlStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IControlStatics'
    _iid_ = Guid('{c3ae388d-aa36-5e10-acac-98415f47bcc7}')
    @winrt_commethod(6)
    def get_IsFocusEngagementEnabledProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_IsFocusEngagedProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_RequiresPointerProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_FontSizeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_FontFamilyProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_FontWeightProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_FontStyleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_FontStretchProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(14)
    def get_CharacterSpacingProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(15)
    def get_ForegroundProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(16)
    def get_IsTextScaleFactorEnabledProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(17)
    def get_IsEnabledProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(18)
    def get_TabNavigationProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(19)
    def get_TemplateProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(20)
    def get_PaddingProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(21)
    def get_HorizontalContentAlignmentProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(22)
    def get_VerticalContentAlignmentProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(23)
    def get_BackgroundProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(24)
    def get_BackgroundSizingProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(25)
    def get_BorderThicknessProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(26)
    def get_BorderBrushProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(27)
    def get_DefaultStyleKeyProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(28)
    def get_DefaultStyleResourceUriProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(29)
    def get_ElementSoundModeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(30)
    def get_CornerRadiusProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(31)
    def get_IsTemplateFocusTargetProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(32)
    def GetIsTemplateFocusTarget(self, element: win32more.Microsoft.UI.Xaml.FrameworkElement) -> Boolean: ...
    @winrt_commethod(33)
    def SetIsTemplateFocusTarget(self, element: win32more.Microsoft.UI.Xaml.FrameworkElement, value: Boolean) -> Void: ...
    @winrt_commethod(34)
    def get_IsTemplateKeyTipTargetProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(35)
    def GetIsTemplateKeyTipTarget(self, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_commethod(36)
    def SetIsTemplateKeyTipTarget(self, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: Boolean) -> Void: ...
    BackgroundProperty = property(get_BackgroundProperty, None)
    BackgroundSizingProperty = property(get_BackgroundSizingProperty, None)
    BorderBrushProperty = property(get_BorderBrushProperty, None)
    BorderThicknessProperty = property(get_BorderThicknessProperty, None)
    CharacterSpacingProperty = property(get_CharacterSpacingProperty, None)
    CornerRadiusProperty = property(get_CornerRadiusProperty, None)
    DefaultStyleKeyProperty = property(get_DefaultStyleKeyProperty, None)
    DefaultStyleResourceUriProperty = property(get_DefaultStyleResourceUriProperty, None)
    ElementSoundModeProperty = property(get_ElementSoundModeProperty, None)
    FontFamilyProperty = property(get_FontFamilyProperty, None)
    FontSizeProperty = property(get_FontSizeProperty, None)
    FontStretchProperty = property(get_FontStretchProperty, None)
    FontStyleProperty = property(get_FontStyleProperty, None)
    FontWeightProperty = property(get_FontWeightProperty, None)
    ForegroundProperty = property(get_ForegroundProperty, None)
    HorizontalContentAlignmentProperty = property(get_HorizontalContentAlignmentProperty, None)
    IsEnabledProperty = property(get_IsEnabledProperty, None)
    IsFocusEngagedProperty = property(get_IsFocusEngagedProperty, None)
    IsFocusEngagementEnabledProperty = property(get_IsFocusEngagementEnabledProperty, None)
    IsTemplateFocusTargetProperty = property(get_IsTemplateFocusTargetProperty, None)
    IsTemplateKeyTipTargetProperty = property(get_IsTemplateKeyTipTargetProperty, None)
    IsTextScaleFactorEnabledProperty = property(get_IsTextScaleFactorEnabledProperty, None)
    PaddingProperty = property(get_PaddingProperty, None)
    RequiresPointerProperty = property(get_RequiresPointerProperty, None)
    TabNavigationProperty = property(get_TabNavigationProperty, None)
    TemplateProperty = property(get_TemplateProperty, None)
    VerticalContentAlignmentProperty = property(get_VerticalContentAlignmentProperty, None)
class IControlTemplate(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IControlTemplate'
    _iid_ = Guid('{3a192751-2106-547a-aca0-f15ae8926ea0}')
    @winrt_commethod(6)
    def get_TargetType(self) -> win32more.Windows.UI.Xaml.Interop.TypeName: ...
    @winrt_commethod(7)
    def put_TargetType(self, value: win32more.Windows.UI.Xaml.Interop.TypeName) -> Void: ...
    TargetType = property(get_TargetType, put_TargetType)
class ICoreWebView2InitializedEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ICoreWebView2InitializedEventArgs'
    _iid_ = Guid('{ee59d277-8b2e-57ab-8631-91d27b12ebd9}')
    @winrt_commethod(6)
    def get_Exception(self) -> win32more.Windows.Foundation.HResult: ...
    Exception = property(get_Exception, None)
class IDataTemplateSelector(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IDataTemplateSelector'
    _iid_ = Guid('{86ca4fa4-7de0-5049-82f5-39ec78569028}')
    @winrt_commethod(6)
    def SelectTemplate(self, item: IInspectable, container: win32more.Microsoft.UI.Xaml.DependencyObject) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_commethod(7)
    def SelectTemplateForItem(self, item: IInspectable) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
class IDataTemplateSelectorFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IDataTemplateSelectorFactory'
    _iid_ = Guid('{43217eda-6f7f-5b80-a70b-944511b354ab}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.DataTemplateSelector: ...
class IDataTemplateSelectorOverrides(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IDataTemplateSelectorOverrides'
    _iid_ = Guid('{980448cc-c114-5b89-8e09-61b0f264e592}')
    @winrt_commethod(6)
    def SelectTemplateCore(self, item: IInspectable, container: win32more.Microsoft.UI.Xaml.DependencyObject) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_commethod(7)
    def SelectTemplateForItemCore(self, item: IInspectable) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
class IDatePickedEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IDatePickedEventArgs'
    _iid_ = Guid('{001f5d4c-4ac2-5e0c-9673-e413c4bd60f3}')
    @winrt_commethod(6)
    def get_OldDate(self) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_commethod(7)
    def get_NewDate(self) -> win32more.Windows.Foundation.DateTime: ...
    NewDate = property(get_NewDate, None)
    OldDate = property(get_OldDate, None)
class IDatePicker(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IDatePicker'
    _iid_ = Guid('{ca1dc351-3ae3-5247-8263-16bd516c6e72}')
    @winrt_commethod(6)
    def get_Header(self) -> IInspectable: ...
    @winrt_commethod(7)
    def put_Header(self, value: IInspectable) -> Void: ...
    @winrt_commethod(8)
    def get_HeaderTemplate(self) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_commethod(9)
    def put_HeaderTemplate(self, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_commethod(10)
    def get_CalendarIdentifier(self) -> hstr: ...
    @winrt_commethod(11)
    def put_CalendarIdentifier(self, value: hstr) -> Void: ...
    @winrt_commethod(12)
    def get_Date(self) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_commethod(13)
    def put_Date(self, value: win32more.Windows.Foundation.DateTime) -> Void: ...
    @winrt_commethod(14)
    def get_DayVisible(self) -> Boolean: ...
    @winrt_commethod(15)
    def put_DayVisible(self, value: Boolean) -> Void: ...
    @winrt_commethod(16)
    def get_MonthVisible(self) -> Boolean: ...
    @winrt_commethod(17)
    def put_MonthVisible(self, value: Boolean) -> Void: ...
    @winrt_commethod(18)
    def get_YearVisible(self) -> Boolean: ...
    @winrt_commethod(19)
    def put_YearVisible(self, value: Boolean) -> Void: ...
    @winrt_commethod(20)
    def get_DayFormat(self) -> hstr: ...
    @winrt_commethod(21)
    def put_DayFormat(self, value: hstr) -> Void: ...
    @winrt_commethod(22)
    def get_MonthFormat(self) -> hstr: ...
    @winrt_commethod(23)
    def put_MonthFormat(self, value: hstr) -> Void: ...
    @winrt_commethod(24)
    def get_YearFormat(self) -> hstr: ...
    @winrt_commethod(25)
    def put_YearFormat(self, value: hstr) -> Void: ...
    @winrt_commethod(26)
    def get_MinYear(self) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_commethod(27)
    def put_MinYear(self, value: win32more.Windows.Foundation.DateTime) -> Void: ...
    @winrt_commethod(28)
    def get_MaxYear(self) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_commethod(29)
    def put_MaxYear(self, value: win32more.Windows.Foundation.DateTime) -> Void: ...
    @winrt_commethod(30)
    def get_Orientation(self) -> win32more.Microsoft.UI.Xaml.Controls.Orientation: ...
    @winrt_commethod(31)
    def put_Orientation(self, value: win32more.Microsoft.UI.Xaml.Controls.Orientation) -> Void: ...
    @winrt_commethod(32)
    def get_LightDismissOverlayMode(self) -> win32more.Microsoft.UI.Xaml.Controls.LightDismissOverlayMode: ...
    @winrt_commethod(33)
    def put_LightDismissOverlayMode(self, value: win32more.Microsoft.UI.Xaml.Controls.LightDismissOverlayMode) -> Void: ...
    @winrt_commethod(34)
    def get_SelectedDate(self) -> win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.DateTime]: ...
    @winrt_commethod(35)
    def put_SelectedDate(self, value: win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.DateTime]) -> Void: ...
    @winrt_commethod(36)
    def add_DateChanged(self, handler: win32more.Windows.Foundation.EventHandler[win32more.Microsoft.UI.Xaml.Controls.DatePickerValueChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(37)
    def remove_DateChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(38)
    def add_SelectedDateChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.DatePicker, win32more.Microsoft.UI.Xaml.Controls.DatePickerSelectedValueChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(39)
    def remove_SelectedDateChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    CalendarIdentifier = property(get_CalendarIdentifier, put_CalendarIdentifier)
    Date = property(get_Date, put_Date)
    DayFormat = property(get_DayFormat, put_DayFormat)
    DayVisible = property(get_DayVisible, put_DayVisible)
    Header = property(get_Header, put_Header)
    HeaderTemplate = property(get_HeaderTemplate, put_HeaderTemplate)
    LightDismissOverlayMode = property(get_LightDismissOverlayMode, put_LightDismissOverlayMode)
    MaxYear = property(get_MaxYear, put_MaxYear)
    MinYear = property(get_MinYear, put_MinYear)
    MonthFormat = property(get_MonthFormat, put_MonthFormat)
    MonthVisible = property(get_MonthVisible, put_MonthVisible)
    Orientation = property(get_Orientation, put_Orientation)
    SelectedDate = property(get_SelectedDate, put_SelectedDate)
    YearFormat = property(get_YearFormat, put_YearFormat)
    YearVisible = property(get_YearVisible, put_YearVisible)
    DateChanged = event(add_DateChanged, remove_DateChanged)
    SelectedDateChanged = event(add_SelectedDateChanged, remove_SelectedDateChanged)
class IDatePickerFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IDatePickerFactory'
    _iid_ = Guid('{a16bea02-b3e0-5fdc-b5bb-25f794dc483b}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.DatePicker: ...
class IDatePickerFlyout(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IDatePickerFlyout'
    _iid_ = Guid('{ba7ecf3c-edb1-593b-a4ac-c09802eace99}')
    @winrt_commethod(6)
    def get_CalendarIdentifier(self) -> hstr: ...
    @winrt_commethod(7)
    def put_CalendarIdentifier(self, value: hstr) -> Void: ...
    @winrt_commethod(8)
    def get_Date(self) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_commethod(9)
    def put_Date(self, value: win32more.Windows.Foundation.DateTime) -> Void: ...
    @winrt_commethod(10)
    def get_DayVisible(self) -> Boolean: ...
    @winrt_commethod(11)
    def put_DayVisible(self, value: Boolean) -> Void: ...
    @winrt_commethod(12)
    def get_MonthVisible(self) -> Boolean: ...
    @winrt_commethod(13)
    def put_MonthVisible(self, value: Boolean) -> Void: ...
    @winrt_commethod(14)
    def get_YearVisible(self) -> Boolean: ...
    @winrt_commethod(15)
    def put_YearVisible(self, value: Boolean) -> Void: ...
    @winrt_commethod(16)
    def get_MinYear(self) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_commethod(17)
    def put_MinYear(self, value: win32more.Windows.Foundation.DateTime) -> Void: ...
    @winrt_commethod(18)
    def get_MaxYear(self) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_commethod(19)
    def put_MaxYear(self, value: win32more.Windows.Foundation.DateTime) -> Void: ...
    @winrt_commethod(20)
    def get_DayFormat(self) -> hstr: ...
    @winrt_commethod(21)
    def put_DayFormat(self, value: hstr) -> Void: ...
    @winrt_commethod(22)
    def get_MonthFormat(self) -> hstr: ...
    @winrt_commethod(23)
    def put_MonthFormat(self, value: hstr) -> Void: ...
    @winrt_commethod(24)
    def get_YearFormat(self) -> hstr: ...
    @winrt_commethod(25)
    def put_YearFormat(self, value: hstr) -> Void: ...
    @winrt_commethod(26)
    def add_DatePicked(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.DatePickerFlyout, win32more.Microsoft.UI.Xaml.Controls.DatePickedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(27)
    def remove_DatePicked(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(28)
    def ShowAtAsync(self, target: win32more.Microsoft.UI.Xaml.FrameworkElement) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.DateTime]]: ...
    CalendarIdentifier = property(get_CalendarIdentifier, put_CalendarIdentifier)
    Date = property(get_Date, put_Date)
    DayFormat = property(get_DayFormat, put_DayFormat)
    DayVisible = property(get_DayVisible, put_DayVisible)
    MaxYear = property(get_MaxYear, put_MaxYear)
    MinYear = property(get_MinYear, put_MinYear)
    MonthFormat = property(get_MonthFormat, put_MonthFormat)
    MonthVisible = property(get_MonthVisible, put_MonthVisible)
    YearFormat = property(get_YearFormat, put_YearFormat)
    YearVisible = property(get_YearVisible, put_YearVisible)
    DatePicked = event(add_DatePicked, remove_DatePicked)
class IDatePickerFlyoutItem(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IDatePickerFlyoutItem'
    _iid_ = Guid('{eb7d591e-1314-5409-9231-5b8e3be187a7}')
    @winrt_commethod(6)
    def get_PrimaryText(self) -> hstr: ...
    @winrt_commethod(7)
    def put_PrimaryText(self, value: hstr) -> Void: ...
    @winrt_commethod(8)
    def get_SecondaryText(self) -> hstr: ...
    @winrt_commethod(9)
    def put_SecondaryText(self, value: hstr) -> Void: ...
    PrimaryText = property(get_PrimaryText, put_PrimaryText)
    SecondaryText = property(get_SecondaryText, put_SecondaryText)
class IDatePickerFlyoutItemStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IDatePickerFlyoutItemStatics'
    _iid_ = Guid('{da7140fc-5613-5ab2-9aab-36cf396ef56c}')
    @winrt_commethod(6)
    def get_PrimaryTextProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_SecondaryTextProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    PrimaryTextProperty = property(get_PrimaryTextProperty, None)
    SecondaryTextProperty = property(get_SecondaryTextProperty, None)
class IDatePickerFlyoutPresenter(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IDatePickerFlyoutPresenter'
    _iid_ = Guid('{1adfda34-60f5-501b-b8e2-73a49cad6712}')
    @winrt_commethod(6)
    def get_IsDefaultShadowEnabled(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_IsDefaultShadowEnabled(self, value: Boolean) -> Void: ...
    IsDefaultShadowEnabled = property(get_IsDefaultShadowEnabled, put_IsDefaultShadowEnabled)
class IDatePickerFlyoutPresenterStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IDatePickerFlyoutPresenterStatics'
    _iid_ = Guid('{611359b5-1aa8-528c-8e57-0378a9e71c57}')
    @winrt_commethod(6)
    def get_IsDefaultShadowEnabledProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    IsDefaultShadowEnabledProperty = property(get_IsDefaultShadowEnabledProperty, None)
class IDatePickerFlyoutStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IDatePickerFlyoutStatics'
    _iid_ = Guid('{6a22ef58-7a7c-5883-8834-a6584585af03}')
    @winrt_commethod(6)
    def get_CalendarIdentifierProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_DateProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_DayVisibleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_MonthVisibleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_YearVisibleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_MinYearProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_MaxYearProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_DayFormatProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(14)
    def get_MonthFormatProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(15)
    def get_YearFormatProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    CalendarIdentifierProperty = property(get_CalendarIdentifierProperty, None)
    DateProperty = property(get_DateProperty, None)
    DayFormatProperty = property(get_DayFormatProperty, None)
    DayVisibleProperty = property(get_DayVisibleProperty, None)
    MaxYearProperty = property(get_MaxYearProperty, None)
    MinYearProperty = property(get_MinYearProperty, None)
    MonthFormatProperty = property(get_MonthFormatProperty, None)
    MonthVisibleProperty = property(get_MonthVisibleProperty, None)
    YearFormatProperty = property(get_YearFormatProperty, None)
    YearVisibleProperty = property(get_YearVisibleProperty, None)
class IDatePickerSelectedValueChangedEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IDatePickerSelectedValueChangedEventArgs'
    _iid_ = Guid('{305ed436-370f-5e82-acf2-f1413e8f9ec4}')
    @winrt_commethod(6)
    def get_OldDate(self) -> win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.DateTime]: ...
    @winrt_commethod(7)
    def get_NewDate(self) -> win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.DateTime]: ...
    NewDate = property(get_NewDate, None)
    OldDate = property(get_OldDate, None)
class IDatePickerStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IDatePickerStatics'
    _iid_ = Guid('{4d810253-aae7-5be1-b7a8-af451ca433e1}')
    @winrt_commethod(6)
    def get_HeaderProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_HeaderTemplateProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_CalendarIdentifierProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_DateProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_DayVisibleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_MonthVisibleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_YearVisibleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_DayFormatProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(14)
    def get_MonthFormatProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(15)
    def get_YearFormatProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(16)
    def get_MinYearProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(17)
    def get_MaxYearProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(18)
    def get_OrientationProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(19)
    def get_LightDismissOverlayModeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(20)
    def get_SelectedDateProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    CalendarIdentifierProperty = property(get_CalendarIdentifierProperty, None)
    DateProperty = property(get_DateProperty, None)
    DayFormatProperty = property(get_DayFormatProperty, None)
    DayVisibleProperty = property(get_DayVisibleProperty, None)
    HeaderProperty = property(get_HeaderProperty, None)
    HeaderTemplateProperty = property(get_HeaderTemplateProperty, None)
    LightDismissOverlayModeProperty = property(get_LightDismissOverlayModeProperty, None)
    MaxYearProperty = property(get_MaxYearProperty, None)
    MinYearProperty = property(get_MinYearProperty, None)
    MonthFormatProperty = property(get_MonthFormatProperty, None)
    MonthVisibleProperty = property(get_MonthVisibleProperty, None)
    OrientationProperty = property(get_OrientationProperty, None)
    SelectedDateProperty = property(get_SelectedDateProperty, None)
    YearFormatProperty = property(get_YearFormatProperty, None)
    YearVisibleProperty = property(get_YearVisibleProperty, None)
class IDatePickerValueChangedEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IDatePickerValueChangedEventArgs'
    _iid_ = Guid('{bd4e36ca-f6ab-57cf-84f0-75d024084f20}')
    @winrt_commethod(6)
    def get_OldDate(self) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_commethod(7)
    def get_NewDate(self) -> win32more.Windows.Foundation.DateTime: ...
    NewDate = property(get_NewDate, None)
    OldDate = property(get_OldDate, None)
class IDragItemsCompletedEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IDragItemsCompletedEventArgs'
    _iid_ = Guid('{c0138552-f467-5c3e-8af4-593607762844}')
    @winrt_commethod(6)
    def get_Items(self) -> win32more.Windows.Foundation.Collections.IVectorView[IInspectable]: ...
    @winrt_commethod(7)
    def get_DropResult(self) -> win32more.Windows.ApplicationModel.DataTransfer.DataPackageOperation: ...
    DropResult = property(get_DropResult, None)
    Items = property(get_Items, None)
class IDragItemsStartingEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IDragItemsStartingEventArgs'
    _iid_ = Guid('{a6938886-20df-558e-ac74-bb5b7f2f7e90}')
    @winrt_commethod(6)
    def get_Cancel(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_Cancel(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def get_Items(self) -> win32more.Windows.Foundation.Collections.IVector[IInspectable]: ...
    @winrt_commethod(9)
    def get_Data(self) -> win32more.Windows.ApplicationModel.DataTransfer.DataPackage: ...
    Cancel = property(get_Cancel, put_Cancel)
    Data = property(get_Data, None)
    Items = property(get_Items, None)
class IDropDownButton(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IDropDownButton'
    _iid_ = Guid('{c1e9fa91-4f95-5796-8a7b-3b7594a12c69}')
class IDropDownButtonFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IDropDownButtonFactory'
    _iid_ = Guid('{7cf3e13b-668d-57e7-b5d6-f5ca3dbc80bd}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.DropDownButton: ...
class IDynamicAnimatedVisualSource(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IDynamicAnimatedVisualSource'
    _iid_ = Guid('{ab00e5cf-1be6-559c-ad5b-0253bb17c0f7}')
    @winrt_commethod(6)
    def add_AnimatedVisualInvalidated(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.IDynamicAnimatedVisualSource, IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(7)
    def remove_AnimatedVisualInvalidated(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    AnimatedVisualInvalidated = event(add_AnimatedVisualInvalidated, remove_AnimatedVisualInvalidated)
class IDynamicOverflowItemsChangingEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IDynamicOverflowItemsChangingEventArgs'
    _iid_ = Guid('{bf64c37f-6332-541d-80f1-876c5bb9b196}')
    @winrt_commethod(6)
    def get_Action(self) -> win32more.Microsoft.UI.Xaml.Controls.CommandBarDynamicOverflowAction: ...
    Action = property(get_Action, None)
class IExpander(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IExpander'
    _iid_ = Guid('{ca633942-e584-55c2-b7ee-cffc73c8127a}')
    @winrt_commethod(6)
    def get_Header(self) -> IInspectable: ...
    @winrt_commethod(7)
    def put_Header(self, value: IInspectable) -> Void: ...
    @winrt_commethod(8)
    def get_HeaderTemplate(self) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_commethod(9)
    def put_HeaderTemplate(self, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_commethod(10)
    def get_HeaderTemplateSelector(self) -> win32more.Microsoft.UI.Xaml.Controls.DataTemplateSelector: ...
    @winrt_commethod(11)
    def put_HeaderTemplateSelector(self, value: win32more.Microsoft.UI.Xaml.Controls.DataTemplateSelector) -> Void: ...
    @winrt_commethod(12)
    def get_IsExpanded(self) -> Boolean: ...
    @winrt_commethod(13)
    def put_IsExpanded(self, value: Boolean) -> Void: ...
    @winrt_commethod(14)
    def get_ExpandDirection(self) -> win32more.Microsoft.UI.Xaml.Controls.ExpandDirection: ...
    @winrt_commethod(15)
    def put_ExpandDirection(self, value: win32more.Microsoft.UI.Xaml.Controls.ExpandDirection) -> Void: ...
    @winrt_commethod(16)
    def add_Expanding(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.Expander, win32more.Microsoft.UI.Xaml.Controls.ExpanderExpandingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(17)
    def remove_Expanding(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(18)
    def add_Collapsed(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.Expander, win32more.Microsoft.UI.Xaml.Controls.ExpanderCollapsedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(19)
    def remove_Collapsed(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(20)
    def get_TemplateSettings(self) -> win32more.Microsoft.UI.Xaml.Controls.ExpanderTemplateSettings: ...
    ExpandDirection = property(get_ExpandDirection, put_ExpandDirection)
    Header = property(get_Header, put_Header)
    HeaderTemplate = property(get_HeaderTemplate, put_HeaderTemplate)
    HeaderTemplateSelector = property(get_HeaderTemplateSelector, put_HeaderTemplateSelector)
    IsExpanded = property(get_IsExpanded, put_IsExpanded)
    TemplateSettings = property(get_TemplateSettings, None)
    Collapsed = event(add_Collapsed, remove_Collapsed)
    Expanding = event(add_Expanding, remove_Expanding)
class IExpanderCollapsedEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IExpanderCollapsedEventArgs'
    _iid_ = Guid('{968a6870-7426-535e-a526-279e6eedecd0}')
class IExpanderExpandingEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IExpanderExpandingEventArgs'
    _iid_ = Guid('{433f2e36-19e7-579c-b4ce-9ce5d510d001}')
class IExpanderFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IExpanderFactory'
    _iid_ = Guid('{51a5afc2-b16d-516e-83ae-5a10476b13af}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.Expander: ...
class IExpanderStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IExpanderStatics'
    _iid_ = Guid('{b742c27b-c023-5096-8c2a-717d324afb7e}')
    @winrt_commethod(6)
    def get_HeaderProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_HeaderTemplateProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_HeaderTemplateSelectorProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_IsExpandedProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_ExpandDirectionProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    ExpandDirectionProperty = property(get_ExpandDirectionProperty, None)
    HeaderProperty = property(get_HeaderProperty, None)
    HeaderTemplateProperty = property(get_HeaderTemplateProperty, None)
    HeaderTemplateSelectorProperty = property(get_HeaderTemplateSelectorProperty, None)
    IsExpandedProperty = property(get_IsExpandedProperty, None)
class IExpanderTemplateSettings(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IExpanderTemplateSettings'
    _iid_ = Guid('{8f959018-f6b8-5c02-be08-cd196c9fcd2d}')
    @winrt_commethod(6)
    def get_ContentHeight(self) -> Double: ...
    @winrt_commethod(7)
    def get_NegativeContentHeight(self) -> Double: ...
    ContentHeight = property(get_ContentHeight, None)
    NegativeContentHeight = property(get_NegativeContentHeight, None)
class IFlipView(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IFlipView'
    _iid_ = Guid('{96c35e7f-cc48-5acc-b3b4-8ab4bdf1fe17}')
    @winrt_commethod(6)
    def get_UseTouchAnimationsForAllNavigation(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_UseTouchAnimationsForAllNavigation(self, value: Boolean) -> Void: ...
    UseTouchAnimationsForAllNavigation = property(get_UseTouchAnimationsForAllNavigation, put_UseTouchAnimationsForAllNavigation)
class IFlipViewFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IFlipViewFactory'
    _iid_ = Guid('{f3a89be6-81e3-53c4-9dc9-98a5a4e79b13}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.FlipView: ...
class IFlipViewItem(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IFlipViewItem'
    _iid_ = Guid('{516f2058-af67-5eb3-b796-e75b34f3fd92}')
class IFlipViewItemFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IFlipViewItemFactory'
    _iid_ = Guid('{deb2cd5f-9d76-5678-b1ca-0267757c4fed}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.FlipViewItem: ...
class IFlipViewStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IFlipViewStatics'
    _iid_ = Guid('{1e98fc86-2bc1-5c89-8305-251ad56a9cdb}')
    @winrt_commethod(6)
    def get_UseTouchAnimationsForAllNavigationProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    UseTouchAnimationsForAllNavigationProperty = property(get_UseTouchAnimationsForAllNavigationProperty, None)
class IFlyout(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IFlyout'
    _iid_ = Guid('{d4a1eb7d-59b8-5df9-87c3-bd5e3856923f}')
    @winrt_commethod(6)
    def get_Content(self) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_commethod(7)
    def put_Content(self, value: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    @winrt_commethod(8)
    def get_FlyoutPresenterStyle(self) -> win32more.Microsoft.UI.Xaml.Style: ...
    @winrt_commethod(9)
    def put_FlyoutPresenterStyle(self, value: win32more.Microsoft.UI.Xaml.Style) -> Void: ...
    Content = property(get_Content, put_Content)
    FlyoutPresenterStyle = property(get_FlyoutPresenterStyle, put_FlyoutPresenterStyle)
class IFlyoutFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IFlyoutFactory'
    _iid_ = Guid('{fd19002e-66b3-5656-b49c-b2aca11e9602}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.Flyout: ...
class IFlyoutPresenter(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IFlyoutPresenter'
    _iid_ = Guid('{70259825-7f56-5107-917e-7194b1ef1b81}')
    @winrt_commethod(6)
    def get_IsDefaultShadowEnabled(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_IsDefaultShadowEnabled(self, value: Boolean) -> Void: ...
    IsDefaultShadowEnabled = property(get_IsDefaultShadowEnabled, put_IsDefaultShadowEnabled)
class IFlyoutPresenterFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IFlyoutPresenterFactory'
    _iid_ = Guid('{e9539a80-74ed-5158-9f93-893669cb046f}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.FlyoutPresenter: ...
class IFlyoutPresenterStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IFlyoutPresenterStatics'
    _iid_ = Guid('{b415a2ec-1bdd-5f94-9500-257223646469}')
    @winrt_commethod(6)
    def get_IsDefaultShadowEnabledProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    IsDefaultShadowEnabledProperty = property(get_IsDefaultShadowEnabledProperty, None)
class IFlyoutStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IFlyoutStatics'
    _iid_ = Guid('{23ae001a-aaa6-5d19-9947-917ecbd883ca}')
    @winrt_commethod(6)
    def get_ContentProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_FlyoutPresenterStyleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    ContentProperty = property(get_ContentProperty, None)
    FlyoutPresenterStyleProperty = property(get_FlyoutPresenterStyleProperty, None)
class IFocusDisengagedEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IFocusDisengagedEventArgs'
    _iid_ = Guid('{c0b4b88c-c195-5064-84c7-33cb262cb240}')
class IFocusEngagedEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IFocusEngagedEventArgs'
    _iid_ = Guid('{1e71e8e4-74b2-50a1-8f2b-42c0118ab0ea}')
    @winrt_commethod(6)
    def get_Handled(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_Handled(self, value: Boolean) -> Void: ...
    Handled = property(get_Handled, put_Handled)
class IFontIcon(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IFontIcon'
    _iid_ = Guid('{6eba5ed9-d233-5f5e-91a8-f5134292658a}')
    @winrt_commethod(6)
    def get_Glyph(self) -> hstr: ...
    @winrt_commethod(7)
    def put_Glyph(self, value: hstr) -> Void: ...
    @winrt_commethod(8)
    def get_FontSize(self) -> Double: ...
    @winrt_commethod(9)
    def put_FontSize(self, value: Double) -> Void: ...
    @winrt_commethod(10)
    def get_FontFamily(self) -> win32more.Microsoft.UI.Xaml.Media.FontFamily: ...
    @winrt_commethod(11)
    def put_FontFamily(self, value: win32more.Microsoft.UI.Xaml.Media.FontFamily) -> Void: ...
    @winrt_commethod(12)
    def get_FontWeight(self) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_commethod(13)
    def put_FontWeight(self, value: win32more.Windows.UI.Text.FontWeight) -> Void: ...
    @winrt_commethod(14)
    def get_FontStyle(self) -> win32more.Windows.UI.Text.FontStyle: ...
    @winrt_commethod(15)
    def put_FontStyle(self, value: win32more.Windows.UI.Text.FontStyle) -> Void: ...
    @winrt_commethod(16)
    def get_IsTextScaleFactorEnabled(self) -> Boolean: ...
    @winrt_commethod(17)
    def put_IsTextScaleFactorEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(18)
    def get_MirroredWhenRightToLeft(self) -> Boolean: ...
    @winrt_commethod(19)
    def put_MirroredWhenRightToLeft(self, value: Boolean) -> Void: ...
    FontFamily = property(get_FontFamily, put_FontFamily)
    FontSize = property(get_FontSize, put_FontSize)
    FontStyle = property(get_FontStyle, put_FontStyle)
    FontWeight = property(get_FontWeight, put_FontWeight)
    Glyph = property(get_Glyph, put_Glyph)
    IsTextScaleFactorEnabled = property(get_IsTextScaleFactorEnabled, put_IsTextScaleFactorEnabled)
    MirroredWhenRightToLeft = property(get_MirroredWhenRightToLeft, put_MirroredWhenRightToLeft)
class IFontIconFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IFontIconFactory'
    _iid_ = Guid('{aa9a24fe-bef8-564a-b200-694cd6f6ba4e}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.FontIcon: ...
class IFontIconSource(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IFontIconSource'
    _iid_ = Guid('{b89d614c-e9b5-5b6a-9bec-ad78b1a14b74}')
    @winrt_commethod(6)
    def get_Glyph(self) -> hstr: ...
    @winrt_commethod(7)
    def put_Glyph(self, value: hstr) -> Void: ...
    @winrt_commethod(8)
    def get_FontSize(self) -> Double: ...
    @winrt_commethod(9)
    def put_FontSize(self, value: Double) -> Void: ...
    @winrt_commethod(10)
    def get_FontFamily(self) -> win32more.Microsoft.UI.Xaml.Media.FontFamily: ...
    @winrt_commethod(11)
    def put_FontFamily(self, value: win32more.Microsoft.UI.Xaml.Media.FontFamily) -> Void: ...
    @winrt_commethod(12)
    def get_FontWeight(self) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_commethod(13)
    def put_FontWeight(self, value: win32more.Windows.UI.Text.FontWeight) -> Void: ...
    @winrt_commethod(14)
    def get_FontStyle(self) -> win32more.Windows.UI.Text.FontStyle: ...
    @winrt_commethod(15)
    def put_FontStyle(self, value: win32more.Windows.UI.Text.FontStyle) -> Void: ...
    @winrt_commethod(16)
    def get_IsTextScaleFactorEnabled(self) -> Boolean: ...
    @winrt_commethod(17)
    def put_IsTextScaleFactorEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(18)
    def get_MirroredWhenRightToLeft(self) -> Boolean: ...
    @winrt_commethod(19)
    def put_MirroredWhenRightToLeft(self, value: Boolean) -> Void: ...
    FontFamily = property(get_FontFamily, put_FontFamily)
    FontSize = property(get_FontSize, put_FontSize)
    FontStyle = property(get_FontStyle, put_FontStyle)
    FontWeight = property(get_FontWeight, put_FontWeight)
    Glyph = property(get_Glyph, put_Glyph)
    IsTextScaleFactorEnabled = property(get_IsTextScaleFactorEnabled, put_IsTextScaleFactorEnabled)
    MirroredWhenRightToLeft = property(get_MirroredWhenRightToLeft, put_MirroredWhenRightToLeft)
class IFontIconSourceFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IFontIconSourceFactory'
    _iid_ = Guid('{bb40eeee-64d1-5133-b1d6-ae13c21b6678}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.FontIconSource: ...
class IFontIconSourceStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IFontIconSourceStatics'
    _iid_ = Guid('{c309c231-f7bf-5c06-a2d2-56502cfd33e5}')
    @winrt_commethod(6)
    def get_GlyphProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_FontSizeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_FontFamilyProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_FontWeightProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_FontStyleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_IsTextScaleFactorEnabledProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_MirroredWhenRightToLeftProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    FontFamilyProperty = property(get_FontFamilyProperty, None)
    FontSizeProperty = property(get_FontSizeProperty, None)
    FontStyleProperty = property(get_FontStyleProperty, None)
    FontWeightProperty = property(get_FontWeightProperty, None)
    GlyphProperty = property(get_GlyphProperty, None)
    IsTextScaleFactorEnabledProperty = property(get_IsTextScaleFactorEnabledProperty, None)
    MirroredWhenRightToLeftProperty = property(get_MirroredWhenRightToLeftProperty, None)
class IFontIconStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IFontIconStatics'
    _iid_ = Guid('{55564030-2f80-5be5-8c2a-ebb6ecba07e8}')
    @winrt_commethod(6)
    def get_GlyphProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_FontSizeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_FontFamilyProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_FontWeightProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_FontStyleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_IsTextScaleFactorEnabledProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_MirroredWhenRightToLeftProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    FontFamilyProperty = property(get_FontFamilyProperty, None)
    FontSizeProperty = property(get_FontSizeProperty, None)
    FontStyleProperty = property(get_FontStyleProperty, None)
    FontWeightProperty = property(get_FontWeightProperty, None)
    GlyphProperty = property(get_GlyphProperty, None)
    IsTextScaleFactorEnabledProperty = property(get_IsTextScaleFactorEnabledProperty, None)
    MirroredWhenRightToLeftProperty = property(get_MirroredWhenRightToLeftProperty, None)
class IFrame(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IFrame'
    _iid_ = Guid('{e6d50443-621e-5360-856a-75b01e1fcd22}')
    @winrt_commethod(6)
    def get_CacheSize(self) -> Int32: ...
    @winrt_commethod(7)
    def put_CacheSize(self, value: Int32) -> Void: ...
    @winrt_commethod(8)
    def get_CanGoBack(self) -> Boolean: ...
    @winrt_commethod(9)
    def get_CanGoForward(self) -> Boolean: ...
    @winrt_commethod(10)
    def get_CurrentSourcePageType(self) -> win32more.Windows.UI.Xaml.Interop.TypeName: ...
    @winrt_commethod(11)
    def get_SourcePageType(self) -> win32more.Windows.UI.Xaml.Interop.TypeName: ...
    @winrt_commethod(12)
    def put_SourcePageType(self, value: win32more.Windows.UI.Xaml.Interop.TypeName) -> Void: ...
    @winrt_commethod(13)
    def get_BackStackDepth(self) -> Int32: ...
    @winrt_commethod(14)
    def get_BackStack(self) -> win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Navigation.PageStackEntry]: ...
    @winrt_commethod(15)
    def get_ForwardStack(self) -> win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Navigation.PageStackEntry]: ...
    @winrt_commethod(16)
    def get_IsNavigationStackEnabled(self) -> Boolean: ...
    @winrt_commethod(17)
    def put_IsNavigationStackEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(18)
    def add_Navigated(self, handler: win32more.Microsoft.UI.Xaml.Navigation.NavigatedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(19)
    def remove_Navigated(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(20)
    def add_Navigating(self, handler: win32more.Microsoft.UI.Xaml.Navigation.NavigatingCancelEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(21)
    def remove_Navigating(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(22)
    def add_NavigationFailed(self, handler: win32more.Microsoft.UI.Xaml.Navigation.NavigationFailedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(23)
    def remove_NavigationFailed(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(24)
    def add_NavigationStopped(self, handler: win32more.Microsoft.UI.Xaml.Navigation.NavigationStoppedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(25)
    def remove_NavigationStopped(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(26)
    def GoBack(self) -> Void: ...
    @winrt_commethod(27)
    def GoBackWithTransitionInfo(self, transitionInfoOverride: win32more.Microsoft.UI.Xaml.Media.Animation.NavigationTransitionInfo) -> Void: ...
    @winrt_commethod(28)
    def GoForward(self) -> Void: ...
    @winrt_commethod(29)
    def Navigate(self, sourcePageType: win32more.Windows.UI.Xaml.Interop.TypeName, parameter: IInspectable) -> Boolean: ...
    @winrt_commethod(30)
    def NavigateWithTransitionInfo(self, sourcePageType: win32more.Windows.UI.Xaml.Interop.TypeName, parameter: IInspectable, infoOverride: win32more.Microsoft.UI.Xaml.Media.Animation.NavigationTransitionInfo) -> Boolean: ...
    @winrt_commethod(31)
    def NavigateToType(self, sourcePageType: win32more.Windows.UI.Xaml.Interop.TypeName, parameter: IInspectable, navigationOptions: win32more.Microsoft.UI.Xaml.Navigation.FrameNavigationOptions) -> Boolean: ...
    @winrt_commethod(32)
    def GetNavigationState(self) -> hstr: ...
    @winrt_commethod(33)
    def SetNavigationState(self, navigationState: hstr) -> Void: ...
    @winrt_commethod(34)
    def SetNavigationStateWithNavigationControl(self, navigationState: hstr, suppressNavigate: Boolean) -> Void: ...
    BackStack = property(get_BackStack, None)
    BackStackDepth = property(get_BackStackDepth, None)
    CacheSize = property(get_CacheSize, put_CacheSize)
    CanGoBack = property(get_CanGoBack, None)
    CanGoForward = property(get_CanGoForward, None)
    CurrentSourcePageType = property(get_CurrentSourcePageType, None)
    ForwardStack = property(get_ForwardStack, None)
    IsNavigationStackEnabled = property(get_IsNavigationStackEnabled, put_IsNavigationStackEnabled)
    SourcePageType = property(get_SourcePageType, put_SourcePageType)
    Navigated = event(add_Navigated, remove_Navigated)
    Navigating = event(add_Navigating, remove_Navigating)
    NavigationFailed = event(add_NavigationFailed, remove_NavigationFailed)
    NavigationStopped = event(add_NavigationStopped, remove_NavigationStopped)
class IFrameFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IFrameFactory'
    _iid_ = Guid('{53a3070f-19d9-59bc-bdd6-4dbf139e7da5}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.Frame: ...
class IFrameStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IFrameStatics'
    _iid_ = Guid('{8a974d00-8da2-588a-a182-1f7621ee650b}')
    @winrt_commethod(6)
    def get_CacheSizeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_CanGoBackProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_CanGoForwardProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_CurrentSourcePageTypeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_SourcePageTypeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_BackStackDepthProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_BackStackProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_ForwardStackProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(14)
    def get_IsNavigationStackEnabledProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    BackStackDepthProperty = property(get_BackStackDepthProperty, None)
    BackStackProperty = property(get_BackStackProperty, None)
    CacheSizeProperty = property(get_CacheSizeProperty, None)
    CanGoBackProperty = property(get_CanGoBackProperty, None)
    CanGoForwardProperty = property(get_CanGoForwardProperty, None)
    CurrentSourcePageTypeProperty = property(get_CurrentSourcePageTypeProperty, None)
    ForwardStackProperty = property(get_ForwardStackProperty, None)
    IsNavigationStackEnabledProperty = property(get_IsNavigationStackEnabledProperty, None)
    SourcePageTypeProperty = property(get_SourcePageTypeProperty, None)
class IGrid(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IGrid'
    _iid_ = Guid('{c4496219-9014-58a1-b4ad-c5044913a5bb}')
    @winrt_commethod(6)
    def get_RowDefinitions(self) -> win32more.Microsoft.UI.Xaml.Controls.RowDefinitionCollection: ...
    @winrt_commethod(7)
    def get_ColumnDefinitions(self) -> win32more.Microsoft.UI.Xaml.Controls.ColumnDefinitionCollection: ...
    @winrt_commethod(8)
    def get_BackgroundSizing(self) -> win32more.Microsoft.UI.Xaml.Controls.BackgroundSizing: ...
    @winrt_commethod(9)
    def put_BackgroundSizing(self, value: win32more.Microsoft.UI.Xaml.Controls.BackgroundSizing) -> Void: ...
    @winrt_commethod(10)
    def get_BorderBrush(self) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_commethod(11)
    def put_BorderBrush(self, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(12)
    def get_BorderThickness(self) -> win32more.Microsoft.UI.Xaml.Thickness: ...
    @winrt_commethod(13)
    def put_BorderThickness(self, value: win32more.Microsoft.UI.Xaml.Thickness) -> Void: ...
    @winrt_commethod(14)
    def get_CornerRadius(self) -> win32more.Microsoft.UI.Xaml.CornerRadius: ...
    @winrt_commethod(15)
    def put_CornerRadius(self, value: win32more.Microsoft.UI.Xaml.CornerRadius) -> Void: ...
    @winrt_commethod(16)
    def get_Padding(self) -> win32more.Microsoft.UI.Xaml.Thickness: ...
    @winrt_commethod(17)
    def put_Padding(self, value: win32more.Microsoft.UI.Xaml.Thickness) -> Void: ...
    @winrt_commethod(18)
    def get_RowSpacing(self) -> Double: ...
    @winrt_commethod(19)
    def put_RowSpacing(self, value: Double) -> Void: ...
    @winrt_commethod(20)
    def get_ColumnSpacing(self) -> Double: ...
    @winrt_commethod(21)
    def put_ColumnSpacing(self, value: Double) -> Void: ...
    BackgroundSizing = property(get_BackgroundSizing, put_BackgroundSizing)
    BorderBrush = property(get_BorderBrush, put_BorderBrush)
    BorderThickness = property(get_BorderThickness, put_BorderThickness)
    ColumnDefinitions = property(get_ColumnDefinitions, None)
    ColumnSpacing = property(get_ColumnSpacing, put_ColumnSpacing)
    CornerRadius = property(get_CornerRadius, put_CornerRadius)
    Padding = property(get_Padding, put_Padding)
    RowDefinitions = property(get_RowDefinitions, None)
    RowSpacing = property(get_RowSpacing, put_RowSpacing)
class IGridFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IGridFactory'
    _iid_ = Guid('{b16bf561-fc6c-57c6-8ebc-0b06ce4513aa}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.Grid: ...
class IGridStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IGridStatics'
    _iid_ = Guid('{ef9cf81d-a431-50f4-abf5-3023fe447704}')
    @winrt_commethod(6)
    def get_BackgroundSizingProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_BorderBrushProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_BorderThicknessProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_CornerRadiusProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_PaddingProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_RowSpacingProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_ColumnSpacingProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_RowProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(14)
    def GetRow(self, element: win32more.Microsoft.UI.Xaml.FrameworkElement) -> Int32: ...
    @winrt_commethod(15)
    def SetRow(self, element: win32more.Microsoft.UI.Xaml.FrameworkElement, value: Int32) -> Void: ...
    @winrt_commethod(16)
    def get_ColumnProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(17)
    def GetColumn(self, element: win32more.Microsoft.UI.Xaml.FrameworkElement) -> Int32: ...
    @winrt_commethod(18)
    def SetColumn(self, element: win32more.Microsoft.UI.Xaml.FrameworkElement, value: Int32) -> Void: ...
    @winrt_commethod(19)
    def get_RowSpanProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(20)
    def GetRowSpan(self, element: win32more.Microsoft.UI.Xaml.FrameworkElement) -> Int32: ...
    @winrt_commethod(21)
    def SetRowSpan(self, element: win32more.Microsoft.UI.Xaml.FrameworkElement, value: Int32) -> Void: ...
    @winrt_commethod(22)
    def get_ColumnSpanProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(23)
    def GetColumnSpan(self, element: win32more.Microsoft.UI.Xaml.FrameworkElement) -> Int32: ...
    @winrt_commethod(24)
    def SetColumnSpan(self, element: win32more.Microsoft.UI.Xaml.FrameworkElement, value: Int32) -> Void: ...
    BackgroundSizingProperty = property(get_BackgroundSizingProperty, None)
    BorderBrushProperty = property(get_BorderBrushProperty, None)
    BorderThicknessProperty = property(get_BorderThicknessProperty, None)
    ColumnProperty = property(get_ColumnProperty, None)
    ColumnSpacingProperty = property(get_ColumnSpacingProperty, None)
    ColumnSpanProperty = property(get_ColumnSpanProperty, None)
    CornerRadiusProperty = property(get_CornerRadiusProperty, None)
    PaddingProperty = property(get_PaddingProperty, None)
    RowProperty = property(get_RowProperty, None)
    RowSpacingProperty = property(get_RowSpacingProperty, None)
    RowSpanProperty = property(get_RowSpanProperty, None)
class IGridView(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IGridView'
    _iid_ = Guid('{d495f2fa-594d-5170-b1e8-8629a179f9fb}')
class IGridViewFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IGridViewFactory'
    _iid_ = Guid('{892947ea-6b86-5f17-a9b8-2121b2251271}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.GridView: ...
class IGridViewHeaderItem(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IGridViewHeaderItem'
    _iid_ = Guid('{2c90c3e0-3245-55d6-9d98-0fd9540e920f}')
class IGridViewHeaderItemFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IGridViewHeaderItemFactory'
    _iid_ = Guid('{2518f012-54df-587e-92b3-bd86075b71cf}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.GridViewHeaderItem: ...
class IGridViewItem(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IGridViewItem'
    _iid_ = Guid('{9debb4a5-e7b7-5a41-a1ee-f77d8a7b0023}')
    @winrt_commethod(6)
    def get_TemplateSettings(self) -> win32more.Microsoft.UI.Xaml.Controls.Primitives.GridViewItemTemplateSettings: ...
    TemplateSettings = property(get_TemplateSettings, None)
class IGridViewItemFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IGridViewItemFactory'
    _iid_ = Guid('{96a56215-230c-5efb-8401-0ce01617c657}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.GridViewItem: ...
class IGroupItem(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IGroupItem'
    _iid_ = Guid('{60e5a62b-9df9-5dbd-9551-1d9e0f6cc3c3}')
class IGroupItemFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IGroupItemFactory'
    _iid_ = Guid('{7c1d5f85-12a6-5e54-8c3d-ef44dd40f1bd}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.GroupItem: ...
class IGroupStyle(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IGroupStyle'
    _iid_ = Guid('{a77d937e-0188-584c-ab1d-9df1916edc75}')
    @winrt_commethod(6)
    def get_Panel(self) -> win32more.Microsoft.UI.Xaml.Controls.ItemsPanelTemplate: ...
    @winrt_commethod(7)
    def put_Panel(self, value: win32more.Microsoft.UI.Xaml.Controls.ItemsPanelTemplate) -> Void: ...
    @winrt_commethod(8)
    def get_ContainerStyle(self) -> win32more.Microsoft.UI.Xaml.Style: ...
    @winrt_commethod(9)
    def put_ContainerStyle(self, value: win32more.Microsoft.UI.Xaml.Style) -> Void: ...
    @winrt_commethod(10)
    def get_HeaderContainerStyle(self) -> win32more.Microsoft.UI.Xaml.Style: ...
    @winrt_commethod(11)
    def put_HeaderContainerStyle(self, value: win32more.Microsoft.UI.Xaml.Style) -> Void: ...
    @winrt_commethod(12)
    def get_ContainerStyleSelector(self) -> win32more.Microsoft.UI.Xaml.Controls.StyleSelector: ...
    @winrt_commethod(13)
    def put_ContainerStyleSelector(self, value: win32more.Microsoft.UI.Xaml.Controls.StyleSelector) -> Void: ...
    @winrt_commethod(14)
    def get_HeaderTemplate(self) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_commethod(15)
    def put_HeaderTemplate(self, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_commethod(16)
    def get_HeaderTemplateSelector(self) -> win32more.Microsoft.UI.Xaml.Controls.DataTemplateSelector: ...
    @winrt_commethod(17)
    def put_HeaderTemplateSelector(self, value: win32more.Microsoft.UI.Xaml.Controls.DataTemplateSelector) -> Void: ...
    @winrt_commethod(18)
    def get_HidesIfEmpty(self) -> Boolean: ...
    @winrt_commethod(19)
    def put_HidesIfEmpty(self, value: Boolean) -> Void: ...
    ContainerStyle = property(get_ContainerStyle, put_ContainerStyle)
    ContainerStyleSelector = property(get_ContainerStyleSelector, put_ContainerStyleSelector)
    HeaderContainerStyle = property(get_HeaderContainerStyle, put_HeaderContainerStyle)
    HeaderTemplate = property(get_HeaderTemplate, put_HeaderTemplate)
    HeaderTemplateSelector = property(get_HeaderTemplateSelector, put_HeaderTemplateSelector)
    HidesIfEmpty = property(get_HidesIfEmpty, put_HidesIfEmpty)
    Panel = property(get_Panel, put_Panel)
class IGroupStyleFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IGroupStyleFactory'
    _iid_ = Guid('{dc884aa2-e2a8-57ab-8cbc-b1d8ec540b0c}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.GroupStyle: ...
class IGroupStyleSelector(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IGroupStyleSelector'
    _iid_ = Guid('{524f5086-3e02-5b71-be7c-8a8fa0feaa2c}')
    @winrt_commethod(6)
    def SelectGroupStyle(self, group: IInspectable, level: UInt32) -> win32more.Microsoft.UI.Xaml.Controls.GroupStyle: ...
class IGroupStyleSelectorFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IGroupStyleSelectorFactory'
    _iid_ = Guid('{0e0699be-50c2-5c15-aed3-e7bd663e5fad}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.GroupStyleSelector: ...
class IGroupStyleSelectorOverrides(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IGroupStyleSelectorOverrides'
    _iid_ = Guid('{80594304-ebeb-5a5d-a794-acdc214cbc94}')
    @winrt_commethod(6)
    def SelectGroupStyleCore(self, group: IInspectable, level: UInt32) -> win32more.Microsoft.UI.Xaml.Controls.GroupStyle: ...
class IHasValidationErrorsChangedEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IHasValidationErrorsChangedEventArgs'
    _iid_ = Guid('{e1f0f2cf-b0ef-5f56-b597-f0771f5cffd2}')
    @winrt_commethod(6)
    def get_NewValue(self) -> Boolean: ...
    NewValue = property(get_NewValue, None)
class IHub(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IHub'
    _iid_ = Guid('{b867e995-0f2e-51a6-a090-e0be2e7cf3ec}')
    @winrt_commethod(6)
    def get_Header(self) -> IInspectable: ...
    @winrt_commethod(7)
    def put_Header(self, value: IInspectable) -> Void: ...
    @winrt_commethod(8)
    def get_HeaderTemplate(self) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_commethod(9)
    def put_HeaderTemplate(self, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_commethod(10)
    def get_Orientation(self) -> win32more.Microsoft.UI.Xaml.Controls.Orientation: ...
    @winrt_commethod(11)
    def put_Orientation(self, value: win32more.Microsoft.UI.Xaml.Controls.Orientation) -> Void: ...
    @winrt_commethod(12)
    def get_DefaultSectionIndex(self) -> Int32: ...
    @winrt_commethod(13)
    def put_DefaultSectionIndex(self, value: Int32) -> Void: ...
    @winrt_commethod(14)
    def get_Sections(self) -> win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.HubSection]: ...
    @winrt_commethod(15)
    def get_SectionsInView(self) -> win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.HubSection]: ...
    @winrt_commethod(16)
    def get_SectionHeaders(self) -> win32more.Windows.Foundation.Collections.IObservableVector[IInspectable]: ...
    @winrt_commethod(17)
    def add_SectionHeaderClick(self, handler: win32more.Microsoft.UI.Xaml.Controls.HubSectionHeaderClickEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(18)
    def remove_SectionHeaderClick(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(19)
    def add_SectionsInViewChanged(self, handler: win32more.Microsoft.UI.Xaml.Controls.SectionsInViewChangedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(20)
    def remove_SectionsInViewChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(21)
    def ScrollToSection(self, section: win32more.Microsoft.UI.Xaml.Controls.HubSection) -> Void: ...
    DefaultSectionIndex = property(get_DefaultSectionIndex, put_DefaultSectionIndex)
    Header = property(get_Header, put_Header)
    HeaderTemplate = property(get_HeaderTemplate, put_HeaderTemplate)
    Orientation = property(get_Orientation, put_Orientation)
    SectionHeaders = property(get_SectionHeaders, None)
    Sections = property(get_Sections, None)
    SectionsInView = property(get_SectionsInView, None)
    SectionHeaderClick = event(add_SectionHeaderClick, remove_SectionHeaderClick)
    SectionsInViewChanged = event(add_SectionsInViewChanged, remove_SectionsInViewChanged)
class IHubFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IHubFactory'
    _iid_ = Guid('{520d3572-f141-58bd-b2a7-3352630fc1e2}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.Hub: ...
class IHubSection(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IHubSection'
    _iid_ = Guid('{9904a65b-89ff-5644-8961-9adbd0135324}')
    @winrt_commethod(6)
    def get_Header(self) -> IInspectable: ...
    @winrt_commethod(7)
    def put_Header(self, value: IInspectable) -> Void: ...
    @winrt_commethod(8)
    def get_HeaderTemplate(self) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_commethod(9)
    def put_HeaderTemplate(self, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_commethod(10)
    def get_ContentTemplate(self) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_commethod(11)
    def put_ContentTemplate(self, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_commethod(12)
    def get_IsHeaderInteractive(self) -> Boolean: ...
    @winrt_commethod(13)
    def put_IsHeaderInteractive(self, value: Boolean) -> Void: ...
    ContentTemplate = property(get_ContentTemplate, put_ContentTemplate)
    Header = property(get_Header, put_Header)
    HeaderTemplate = property(get_HeaderTemplate, put_HeaderTemplate)
    IsHeaderInteractive = property(get_IsHeaderInteractive, put_IsHeaderInteractive)
class IHubSectionFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IHubSectionFactory'
    _iid_ = Guid('{63ce16f2-fb52-5818-836f-c097aa9c072d}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.HubSection: ...
class IHubSectionHeaderClickEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IHubSectionHeaderClickEventArgs'
    _iid_ = Guid('{b5343aab-37b2-5cdc-9543-118e3ace48b2}')
    @winrt_commethod(6)
    def get_Section(self) -> win32more.Microsoft.UI.Xaml.Controls.HubSection: ...
    Section = property(get_Section, None)
class IHubSectionStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IHubSectionStatics'
    _iid_ = Guid('{d22016d3-fb4a-5bd8-a108-e59f7c475927}')
    @winrt_commethod(6)
    def get_HeaderProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_HeaderTemplateProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_ContentTemplateProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_IsHeaderInteractiveProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    ContentTemplateProperty = property(get_ContentTemplateProperty, None)
    HeaderProperty = property(get_HeaderProperty, None)
    HeaderTemplateProperty = property(get_HeaderTemplateProperty, None)
    IsHeaderInteractiveProperty = property(get_IsHeaderInteractiveProperty, None)
class IHubStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IHubStatics'
    _iid_ = Guid('{2834e932-abf1-5e07-aeae-633b726b78cb}')
    @winrt_commethod(6)
    def get_HeaderProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_HeaderTemplateProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_OrientationProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_DefaultSectionIndexProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_SemanticZoomOwnerProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_IsActiveViewProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_IsZoomedInViewProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    DefaultSectionIndexProperty = property(get_DefaultSectionIndexProperty, None)
    HeaderProperty = property(get_HeaderProperty, None)
    HeaderTemplateProperty = property(get_HeaderTemplateProperty, None)
    IsActiveViewProperty = property(get_IsActiveViewProperty, None)
    IsZoomedInViewProperty = property(get_IsZoomedInViewProperty, None)
    OrientationProperty = property(get_OrientationProperty, None)
    SemanticZoomOwnerProperty = property(get_SemanticZoomOwnerProperty, None)
class IHyperlinkButton(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IHyperlinkButton'
    _iid_ = Guid('{6dbee605-8df0-50cc-9a42-250eb138f0c6}')
    @winrt_commethod(6)
    def get_NavigateUri(self) -> win32more.Windows.Foundation.Uri: ...
    @winrt_commethod(7)
    def put_NavigateUri(self, value: win32more.Windows.Foundation.Uri) -> Void: ...
    NavigateUri = property(get_NavigateUri, put_NavigateUri)
class IHyperlinkButtonFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IHyperlinkButtonFactory'
    _iid_ = Guid('{01f775ea-c5ed-514a-a23d-89c494a8f09d}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.HyperlinkButton: ...
class IHyperlinkButtonStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IHyperlinkButtonStatics'
    _iid_ = Guid('{ab5c7b77-7c4c-5b26-9c7c-763f8d95258e}')
    @winrt_commethod(6)
    def get_NavigateUriProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    NavigateUriProperty = property(get_NavigateUriProperty, None)
class IIconElement(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IIconElement'
    _iid_ = Guid('{18f69350-279e-50ea-8d23-138e717ed939}')
    @winrt_commethod(6)
    def get_Foreground(self) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_commethod(7)
    def put_Foreground(self, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    Foreground = property(get_Foreground, put_Foreground)
class IIconElementFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IIconElementFactory'
    _iid_ = Guid('{7161eeff-2cc3-59c9-b355-f752ef2030fb}')
class IIconElementStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IIconElementStatics'
    _iid_ = Guid('{4ccfdc81-9d9d-5a02-b95b-ad1add921750}')
    @winrt_commethod(6)
    def get_ForegroundProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    ForegroundProperty = property(get_ForegroundProperty, None)
class IIconSource(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IIconSource'
    _iid_ = Guid('{39e6b320-a2af-5ee3-b7e9-4ba4aa80541a}')
    @winrt_commethod(6)
    def get_Foreground(self) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_commethod(7)
    def put_Foreground(self, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(8)
    def CreateIconElement(self) -> win32more.Microsoft.UI.Xaml.Controls.IconElement: ...
    Foreground = property(get_Foreground, put_Foreground)
class IIconSourceElement(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IIconSourceElement'
    _iid_ = Guid('{ab6f4473-1f6b-5b24-8259-1d38e90a110a}')
    @winrt_commethod(6)
    def get_IconSource(self) -> win32more.Microsoft.UI.Xaml.Controls.IconSource: ...
    @winrt_commethod(7)
    def put_IconSource(self, value: win32more.Microsoft.UI.Xaml.Controls.IconSource) -> Void: ...
    IconSource = property(get_IconSource, put_IconSource)
class IIconSourceElementFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IIconSourceElementFactory'
    _iid_ = Guid('{13e1a240-ad47-51ae-9632-715f4b7ea52e}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.IconSourceElement: ...
class IIconSourceElementStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IIconSourceElementStatics'
    _iid_ = Guid('{2cc2539f-69fc-5160-ab84-37e7e04e2691}')
    @winrt_commethod(6)
    def get_IconSourceProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    IconSourceProperty = property(get_IconSourceProperty, None)
class IIconSourceFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IIconSourceFactory'
    _iid_ = Guid('{e8bc19c6-9a64-5c54-9338-e18e076875bf}')
class IIconSourceOverrides(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IIconSourceOverrides'
    _iid_ = Guid('{9a02d369-1c79-5a81-871b-0b90946ba7f0}')
    @winrt_commethod(6)
    def CreateIconElementCore(self) -> win32more.Microsoft.UI.Xaml.Controls.IconElement: ...
    @winrt_commethod(7)
    def GetIconElementPropertyCore(self, iconSourceProperty: win32more.Microsoft.UI.Xaml.DependencyProperty) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
class IIconSourceStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IIconSourceStatics'
    _iid_ = Guid('{eed55973-7e15-575f-af8e-ae2b9b975dd7}')
    @winrt_commethod(6)
    def get_ForegroundProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    ForegroundProperty = property(get_ForegroundProperty, None)
class IImage(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IImage'
    _iid_ = Guid('{220d3d8d-66de-53a1-a215-ba9c165565ab}')
    @winrt_commethod(6)
    def get_Source(self) -> win32more.Microsoft.UI.Xaml.Media.ImageSource: ...
    @winrt_commethod(7)
    def put_Source(self, value: win32more.Microsoft.UI.Xaml.Media.ImageSource) -> Void: ...
    @winrt_commethod(8)
    def get_Stretch(self) -> win32more.Microsoft.UI.Xaml.Media.Stretch: ...
    @winrt_commethod(9)
    def put_Stretch(self, value: win32more.Microsoft.UI.Xaml.Media.Stretch) -> Void: ...
    @winrt_commethod(10)
    def get_NineGrid(self) -> win32more.Microsoft.UI.Xaml.Thickness: ...
    @winrt_commethod(11)
    def put_NineGrid(self, value: win32more.Microsoft.UI.Xaml.Thickness) -> Void: ...
    @winrt_commethod(12)
    def add_ImageFailed(self, handler: win32more.Microsoft.UI.Xaml.ExceptionRoutedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(13)
    def remove_ImageFailed(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(14)
    def add_ImageOpened(self, handler: win32more.Microsoft.UI.Xaml.RoutedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(15)
    def remove_ImageOpened(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(16)
    def GetAsCastingSource(self) -> win32more.Windows.Media.Casting.CastingSource: ...
    @winrt_commethod(17)
    def GetAlphaMask(self) -> win32more.Microsoft.UI.Composition.CompositionBrush: ...
    NineGrid = property(get_NineGrid, put_NineGrid)
    Source = property(get_Source, put_Source)
    Stretch = property(get_Stretch, put_Stretch)
    ImageFailed = event(add_ImageFailed, remove_ImageFailed)
    ImageOpened = event(add_ImageOpened, remove_ImageOpened)
class IImageIcon(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IImageIcon'
    _iid_ = Guid('{78a7b526-e635-59c6-93a1-d7e3c2fac6d5}')
    @winrt_commethod(6)
    def get_Source(self) -> win32more.Microsoft.UI.Xaml.Media.ImageSource: ...
    @winrt_commethod(7)
    def put_Source(self, value: win32more.Microsoft.UI.Xaml.Media.ImageSource) -> Void: ...
    Source = property(get_Source, put_Source)
class IImageIconFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IImageIconFactory'
    _iid_ = Guid('{235e0279-a7d0-5fda-a308-9b7cb9c4c912}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.ImageIcon: ...
class IImageIconSource(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IImageIconSource'
    _iid_ = Guid('{67f75be0-c84d-57ff-9f68-039c81ea7896}')
    @winrt_commethod(6)
    def get_ImageSource(self) -> win32more.Microsoft.UI.Xaml.Media.ImageSource: ...
    @winrt_commethod(7)
    def put_ImageSource(self, value: win32more.Microsoft.UI.Xaml.Media.ImageSource) -> Void: ...
    ImageSource = property(get_ImageSource, put_ImageSource)
class IImageIconSourceFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IImageIconSourceFactory'
    _iid_ = Guid('{24f76321-71bd-530a-8cc8-3f615cd1437a}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.ImageIconSource: ...
class IImageIconSourceStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IImageIconSourceStatics'
    _iid_ = Guid('{3aae805c-c128-5f0d-ae43-1b158891a1dd}')
    @winrt_commethod(6)
    def get_ImageSourceProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    ImageSourceProperty = property(get_ImageSourceProperty, None)
class IImageIconStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IImageIconStatics'
    _iid_ = Guid('{6bd31828-f8f9-5d86-80d5-e7423546da7d}')
    @winrt_commethod(6)
    def get_SourceProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    SourceProperty = property(get_SourceProperty, None)
class IImageStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IImageStatics'
    _iid_ = Guid('{cb5378a8-996b-547e-9c4c-7bbfd9dbe7dc}')
    @winrt_commethod(6)
    def get_SourceProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_StretchProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_NineGridProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    NineGridProperty = property(get_NineGridProperty, None)
    SourceProperty = property(get_SourceProperty, None)
    StretchProperty = property(get_StretchProperty, None)
class IInfoBadge(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IInfoBadge'
    _iid_ = Guid('{82104d7f-03d4-5ea4-872e-f9ecab758601}')
    @winrt_commethod(6)
    def get_Value(self) -> Int32: ...
    @winrt_commethod(7)
    def put_Value(self, value: Int32) -> Void: ...
    @winrt_commethod(8)
    def get_IconSource(self) -> win32more.Microsoft.UI.Xaml.Controls.IconSource: ...
    @winrt_commethod(9)
    def put_IconSource(self, value: win32more.Microsoft.UI.Xaml.Controls.IconSource) -> Void: ...
    @winrt_commethod(10)
    def get_TemplateSettings(self) -> win32more.Microsoft.UI.Xaml.Controls.InfoBadgeTemplateSettings: ...
    IconSource = property(get_IconSource, put_IconSource)
    TemplateSettings = property(get_TemplateSettings, None)
    Value = property(get_Value, put_Value)
class IInfoBadgeFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IInfoBadgeFactory'
    _iid_ = Guid('{fb498205-2de0-5986-8aec-2c46ac235087}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.InfoBadge: ...
class IInfoBadgeStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IInfoBadgeStatics'
    _iid_ = Guid('{b0160061-b463-54de-81ac-64f390d4f25d}')
    @winrt_commethod(6)
    def get_ValueProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_IconSourceProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_TemplateSettingsProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    IconSourceProperty = property(get_IconSourceProperty, None)
    TemplateSettingsProperty = property(get_TemplateSettingsProperty, None)
    ValueProperty = property(get_ValueProperty, None)
class IInfoBadgeTemplateSettings(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IInfoBadgeTemplateSettings'
    _iid_ = Guid('{ce810f86-d4bb-51bd-bf7d-dfd1e6c85f4a}')
    @winrt_commethod(6)
    def get_InfoBadgeCornerRadius(self) -> win32more.Microsoft.UI.Xaml.CornerRadius: ...
    @winrt_commethod(7)
    def put_InfoBadgeCornerRadius(self, value: win32more.Microsoft.UI.Xaml.CornerRadius) -> Void: ...
    @winrt_commethod(8)
    def get_IconElement(self) -> win32more.Microsoft.UI.Xaml.Controls.IconElement: ...
    @winrt_commethod(9)
    def put_IconElement(self, value: win32more.Microsoft.UI.Xaml.Controls.IconElement) -> Void: ...
    IconElement = property(get_IconElement, put_IconElement)
    InfoBadgeCornerRadius = property(get_InfoBadgeCornerRadius, put_InfoBadgeCornerRadius)
class IInfoBadgeTemplateSettingsFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IInfoBadgeTemplateSettingsFactory'
    _iid_ = Guid('{5d366775-1f6e-558c-aab4-667704b3070c}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.InfoBadgeTemplateSettings: ...
class IInfoBadgeTemplateSettingsStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IInfoBadgeTemplateSettingsStatics'
    _iid_ = Guid('{10959133-64ce-586f-a252-9e26fc1ad9ba}')
    @winrt_commethod(6)
    def get_InfoBadgeCornerRadiusProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_IconElementProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    IconElementProperty = property(get_IconElementProperty, None)
    InfoBadgeCornerRadiusProperty = property(get_InfoBadgeCornerRadiusProperty, None)
class IInfoBar(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IInfoBar'
    _iid_ = Guid('{c1c3a438-dd79-5d22-9e42-5a3cdf8113a9}')
    @winrt_commethod(6)
    def get_IsOpen(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_IsOpen(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def get_Title(self) -> hstr: ...
    @winrt_commethod(9)
    def put_Title(self, value: hstr) -> Void: ...
    @winrt_commethod(10)
    def get_Message(self) -> hstr: ...
    @winrt_commethod(11)
    def put_Message(self, value: hstr) -> Void: ...
    @winrt_commethod(12)
    def get_Severity(self) -> win32more.Microsoft.UI.Xaml.Controls.InfoBarSeverity: ...
    @winrt_commethod(13)
    def put_Severity(self, value: win32more.Microsoft.UI.Xaml.Controls.InfoBarSeverity) -> Void: ...
    @winrt_commethod(14)
    def get_IconSource(self) -> win32more.Microsoft.UI.Xaml.Controls.IconSource: ...
    @winrt_commethod(15)
    def put_IconSource(self, value: win32more.Microsoft.UI.Xaml.Controls.IconSource) -> Void: ...
    @winrt_commethod(16)
    def get_IsIconVisible(self) -> Boolean: ...
    @winrt_commethod(17)
    def put_IsIconVisible(self, value: Boolean) -> Void: ...
    @winrt_commethod(18)
    def get_IsClosable(self) -> Boolean: ...
    @winrt_commethod(19)
    def put_IsClosable(self, value: Boolean) -> Void: ...
    @winrt_commethod(20)
    def get_CloseButtonStyle(self) -> win32more.Microsoft.UI.Xaml.Style: ...
    @winrt_commethod(21)
    def put_CloseButtonStyle(self, value: win32more.Microsoft.UI.Xaml.Style) -> Void: ...
    @winrt_commethod(22)
    def get_CloseButtonCommand(self) -> win32more.Microsoft.UI.Xaml.Input.ICommand: ...
    @winrt_commethod(23)
    def put_CloseButtonCommand(self, value: win32more.Microsoft.UI.Xaml.Input.ICommand) -> Void: ...
    @winrt_commethod(24)
    def get_CloseButtonCommandParameter(self) -> IInspectable: ...
    @winrt_commethod(25)
    def put_CloseButtonCommandParameter(self, value: IInspectable) -> Void: ...
    @winrt_commethod(26)
    def get_ActionButton(self) -> win32more.Microsoft.UI.Xaml.Controls.Primitives.ButtonBase: ...
    @winrt_commethod(27)
    def put_ActionButton(self, value: win32more.Microsoft.UI.Xaml.Controls.Primitives.ButtonBase) -> Void: ...
    @winrt_commethod(28)
    def get_Content(self) -> IInspectable: ...
    @winrt_commethod(29)
    def put_Content(self, value: IInspectable) -> Void: ...
    @winrt_commethod(30)
    def get_ContentTemplate(self) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_commethod(31)
    def put_ContentTemplate(self, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_commethod(32)
    def get_TemplateSettings(self) -> win32more.Microsoft.UI.Xaml.Controls.InfoBarTemplateSettings: ...
    @winrt_commethod(33)
    def add_CloseButtonClick(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.InfoBar, IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(34)
    def remove_CloseButtonClick(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(35)
    def add_Closing(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.InfoBar, win32more.Microsoft.UI.Xaml.Controls.InfoBarClosingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(36)
    def remove_Closing(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(37)
    def add_Closed(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.InfoBar, win32more.Microsoft.UI.Xaml.Controls.InfoBarClosedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(38)
    def remove_Closed(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    ActionButton = property(get_ActionButton, put_ActionButton)
    CloseButtonCommand = property(get_CloseButtonCommand, put_CloseButtonCommand)
    CloseButtonCommandParameter = property(get_CloseButtonCommandParameter, put_CloseButtonCommandParameter)
    CloseButtonStyle = property(get_CloseButtonStyle, put_CloseButtonStyle)
    Content = property(get_Content, put_Content)
    ContentTemplate = property(get_ContentTemplate, put_ContentTemplate)
    IconSource = property(get_IconSource, put_IconSource)
    IsClosable = property(get_IsClosable, put_IsClosable)
    IsIconVisible = property(get_IsIconVisible, put_IsIconVisible)
    IsOpen = property(get_IsOpen, put_IsOpen)
    Message = property(get_Message, put_Message)
    Severity = property(get_Severity, put_Severity)
    TemplateSettings = property(get_TemplateSettings, None)
    Title = property(get_Title, put_Title)
    CloseButtonClick = event(add_CloseButtonClick, remove_CloseButtonClick)
    Closed = event(add_Closed, remove_Closed)
    Closing = event(add_Closing, remove_Closing)
class IInfoBarClosedEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IInfoBarClosedEventArgs'
    _iid_ = Guid('{593af0b3-bded-53da-8f56-80ed3c64322c}')
    @winrt_commethod(6)
    def get_Reason(self) -> win32more.Microsoft.UI.Xaml.Controls.InfoBarCloseReason: ...
    Reason = property(get_Reason, None)
class IInfoBarClosedEventArgsFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IInfoBarClosedEventArgsFactory'
    _iid_ = Guid('{42fe1f7e-6d68-5a85-8a5c-abb7effcdf26}')
class IInfoBarClosingEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IInfoBarClosingEventArgs'
    _iid_ = Guid('{062d01d6-61af-5435-8c4b-c51106583b5b}')
    @winrt_commethod(6)
    def get_Reason(self) -> win32more.Microsoft.UI.Xaml.Controls.InfoBarCloseReason: ...
    @winrt_commethod(7)
    def get_Cancel(self) -> Boolean: ...
    @winrt_commethod(8)
    def put_Cancel(self, value: Boolean) -> Void: ...
    Cancel = property(get_Cancel, put_Cancel)
    Reason = property(get_Reason, None)
class IInfoBarClosingEventArgsFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IInfoBarClosingEventArgsFactory'
    _iid_ = Guid('{d6cfcc14-5206-5c9d-801c-3a90b4e2ebe4}')
class IInfoBarFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IInfoBarFactory'
    _iid_ = Guid('{60618a60-9be7-5df5-be0d-933d34ddb44c}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.InfoBar: ...
class IInfoBarStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IInfoBarStatics'
    _iid_ = Guid('{5fb1e80d-ea5d-57ba-9915-b6782b982aca}')
    @winrt_commethod(6)
    def get_IsOpenProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_TitleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_MessageProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_SeverityProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_IconSourceProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_IsIconVisibleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_IsClosableProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_CloseButtonStyleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(14)
    def get_CloseButtonCommandProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(15)
    def get_CloseButtonCommandParameterProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(16)
    def get_ActionButtonProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(17)
    def get_ContentProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(18)
    def get_ContentTemplateProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(19)
    def get_TemplateSettingsProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    ActionButtonProperty = property(get_ActionButtonProperty, None)
    CloseButtonCommandParameterProperty = property(get_CloseButtonCommandParameterProperty, None)
    CloseButtonCommandProperty = property(get_CloseButtonCommandProperty, None)
    CloseButtonStyleProperty = property(get_CloseButtonStyleProperty, None)
    ContentProperty = property(get_ContentProperty, None)
    ContentTemplateProperty = property(get_ContentTemplateProperty, None)
    IconSourceProperty = property(get_IconSourceProperty, None)
    IsClosableProperty = property(get_IsClosableProperty, None)
    IsIconVisibleProperty = property(get_IsIconVisibleProperty, None)
    IsOpenProperty = property(get_IsOpenProperty, None)
    MessageProperty = property(get_MessageProperty, None)
    SeverityProperty = property(get_SeverityProperty, None)
    TemplateSettingsProperty = property(get_TemplateSettingsProperty, None)
    TitleProperty = property(get_TitleProperty, None)
class IInfoBarTemplateSettings(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IInfoBarTemplateSettings'
    _iid_ = Guid('{926f7292-9882-5056-8097-6da2a7ea27cd}')
    @winrt_commethod(6)
    def get_IconElement(self) -> win32more.Microsoft.UI.Xaml.Controls.IconElement: ...
    @winrt_commethod(7)
    def put_IconElement(self, value: win32more.Microsoft.UI.Xaml.Controls.IconElement) -> Void: ...
    IconElement = property(get_IconElement, put_IconElement)
class IInfoBarTemplateSettingsFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IInfoBarTemplateSettingsFactory'
    _iid_ = Guid('{29517daf-c763-56ce-8d54-eefcaf7f2e01}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.InfoBarTemplateSettings: ...
class IInfoBarTemplateSettingsStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IInfoBarTemplateSettingsStatics'
    _iid_ = Guid('{57671639-43e8-506d-b9a7-539a605a1c67}')
    @winrt_commethod(6)
    def get_IconElementProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    IconElementProperty = property(get_IconElementProperty, None)
class IInsertionPanel(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IInsertionPanel'
    _iid_ = Guid('{84e13e27-2d24-59c4-a00e-16c7255901e2}')
    @winrt_commethod(6)
    def GetInsertionIndexes(self, position: win32more.Windows.Foundation.Point, first: POINTER(Int32), second: POINTER(Int32)) -> Void: ...
class IIsTextTrimmedChangedEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IIsTextTrimmedChangedEventArgs'
    _iid_ = Guid('{3c709b2f-16ba-55d2-b6f6-dfc54a1ed021}')
class IItemClickEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IItemClickEventArgs'
    _iid_ = Guid('{1cf87a70-6348-57ec-9eac-fa0565adc60f}')
    @winrt_commethod(6)
    def get_ClickedItem(self) -> IInspectable: ...
    ClickedItem = property(get_ClickedItem, None)
class IItemCollectionTransition(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IItemCollectionTransition'
    _iid_ = Guid('{63a8d310-4d8a-515e-a900-0416d9374575}')
    @winrt_commethod(6)
    def get_Operation(self) -> win32more.Microsoft.UI.Xaml.Controls.ItemCollectionTransitionOperation: ...
    @winrt_commethod(7)
    def get_Triggers(self) -> win32more.Microsoft.UI.Xaml.Controls.ItemCollectionTransitionTriggers: ...
    @winrt_commethod(8)
    def get_OldBounds(self) -> win32more.Windows.Foundation.Rect: ...
    @winrt_commethod(9)
    def get_NewBounds(self) -> win32more.Windows.Foundation.Rect: ...
    @winrt_commethod(10)
    def get_HasStarted(self) -> Boolean: ...
    @winrt_commethod(11)
    def Start(self) -> win32more.Microsoft.UI.Xaml.Controls.ItemCollectionTransitionProgress: ...
    HasStarted = property(get_HasStarted, None)
    NewBounds = property(get_NewBounds, None)
    OldBounds = property(get_OldBounds, None)
    Operation = property(get_Operation, None)
    Triggers = property(get_Triggers, None)
class IItemCollectionTransitionCompletedEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IItemCollectionTransitionCompletedEventArgs'
    _iid_ = Guid('{b43ca4f6-7ae5-576f-b74d-ec70b1c58488}')
    @winrt_commethod(6)
    def get_Transition(self) -> win32more.Microsoft.UI.Xaml.Controls.ItemCollectionTransition: ...
    @winrt_commethod(7)
    def get_Element(self) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    Element = property(get_Element, None)
    Transition = property(get_Transition, None)
class IItemCollectionTransitionProgress(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IItemCollectionTransitionProgress'
    _iid_ = Guid('{4da82dde-c778-57f6-a0e7-a767ef08591d}')
    @winrt_commethod(6)
    def get_Transition(self) -> win32more.Microsoft.UI.Xaml.Controls.ItemCollectionTransition: ...
    @winrt_commethod(7)
    def get_Element(self) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_commethod(8)
    def Complete(self) -> Void: ...
    Element = property(get_Element, None)
    Transition = property(get_Transition, None)
class IItemCollectionTransitionProvider(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IItemCollectionTransitionProvider'
    _iid_ = Guid('{32132262-e07d-51f7-a688-9528042f7e0b}')
    @winrt_commethod(6)
    def ShouldAnimate(self, transition: win32more.Microsoft.UI.Xaml.Controls.ItemCollectionTransition) -> Boolean: ...
    @winrt_commethod(7)
    def QueueTransition(self, transition: win32more.Microsoft.UI.Xaml.Controls.ItemCollectionTransition) -> Void: ...
    @winrt_commethod(8)
    def add_TransitionCompleted(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.ItemCollectionTransitionProvider, win32more.Microsoft.UI.Xaml.Controls.ItemCollectionTransitionCompletedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(9)
    def remove_TransitionCompleted(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    TransitionCompleted = event(add_TransitionCompleted, remove_TransitionCompleted)
class IItemCollectionTransitionProviderFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IItemCollectionTransitionProviderFactory'
    _iid_ = Guid('{f1b53104-24be-510d-9eb1-3401de361dbc}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.ItemCollectionTransitionProvider: ...
class IItemCollectionTransitionProviderOverrides(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IItemCollectionTransitionProviderOverrides'
    _iid_ = Guid('{6935222b-ef83-5872-a9d4-8319bcd67a67}')
    @winrt_commethod(6)
    def ShouldAnimateCore(self, transition: win32more.Microsoft.UI.Xaml.Controls.ItemCollectionTransition) -> Boolean: ...
    @winrt_commethod(7)
    def StartTransitions(self, transitions: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.ItemCollectionTransition]) -> Void: ...
class IItemContainer(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IItemContainer'
    _iid_ = Guid('{6332a67f-7fd9-53c7-afd8-cfa1237cf6d1}')
    @winrt_commethod(6)
    def get_Child(self) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_commethod(7)
    def put_Child(self, value: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    @winrt_commethod(8)
    def get_IsSelected(self) -> Boolean: ...
    @winrt_commethod(9)
    def put_IsSelected(self, value: Boolean) -> Void: ...
    Child = property(get_Child, put_Child)
    IsSelected = property(get_IsSelected, put_IsSelected)
class IItemContainerFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IItemContainerFactory'
    _iid_ = Guid('{ee1cc57c-6bf2-5ee9-a943-c95ca775edb4}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.ItemContainer: ...
class IItemContainerGenerator(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IItemContainerGenerator'
    _iid_ = Guid('{c4c5d5ae-ed98-510f-afae-8a0ac6067a3b}')
    @winrt_commethod(6)
    def add_ItemsChanged(self, handler: win32more.Microsoft.UI.Xaml.Controls.Primitives.ItemsChangedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(7)
    def remove_ItemsChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(8)
    def ItemFromContainer(self, container: win32more.Microsoft.UI.Xaml.DependencyObject) -> IInspectable: ...
    @winrt_commethod(9)
    def ContainerFromItem(self, item: IInspectable) -> win32more.Microsoft.UI.Xaml.DependencyObject: ...
    @winrt_commethod(10)
    def IndexFromContainer(self, container: win32more.Microsoft.UI.Xaml.DependencyObject) -> Int32: ...
    @winrt_commethod(11)
    def ContainerFromIndex(self, index: Int32) -> win32more.Microsoft.UI.Xaml.DependencyObject: ...
    @winrt_commethod(12)
    def GetItemContainerGeneratorForPanel(self, panel: win32more.Microsoft.UI.Xaml.Controls.Panel) -> win32more.Microsoft.UI.Xaml.Controls.ItemContainerGenerator: ...
    @winrt_commethod(13)
    def StartAt(self, position: win32more.Microsoft.UI.Xaml.Controls.Primitives.GeneratorPosition, direction: win32more.Microsoft.UI.Xaml.Controls.Primitives.GeneratorDirection, allowStartAtRealizedItem: Boolean) -> Void: ...
    @winrt_commethod(14)
    def Stop(self) -> Void: ...
    @winrt_commethod(15)
    def GenerateNext(self, isNewlyRealized: POINTER(Boolean)) -> win32more.Microsoft.UI.Xaml.DependencyObject: ...
    @winrt_commethod(16)
    def PrepareItemContainer(self, container: win32more.Microsoft.UI.Xaml.DependencyObject) -> Void: ...
    @winrt_commethod(17)
    def RemoveAll(self) -> Void: ...
    @winrt_commethod(18)
    def Remove(self, position: win32more.Microsoft.UI.Xaml.Controls.Primitives.GeneratorPosition, count: Int32) -> Void: ...
    @winrt_commethod(19)
    def GeneratorPositionFromIndex(self, itemIndex: Int32) -> win32more.Microsoft.UI.Xaml.Controls.Primitives.GeneratorPosition: ...
    @winrt_commethod(20)
    def IndexFromGeneratorPosition(self, position: win32more.Microsoft.UI.Xaml.Controls.Primitives.GeneratorPosition) -> Int32: ...
    @winrt_commethod(21)
    def Recycle(self, position: win32more.Microsoft.UI.Xaml.Controls.Primitives.GeneratorPosition, count: Int32) -> Void: ...
    ItemsChanged = event(add_ItemsChanged, remove_ItemsChanged)
class IItemContainerMapping(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IItemContainerMapping'
    _iid_ = Guid('{b3e03a32-ea83-5626-bfda-d327a1c7550c}')
    @winrt_commethod(6)
    def ItemFromContainer(self, container: win32more.Microsoft.UI.Xaml.DependencyObject) -> IInspectable: ...
    @winrt_commethod(7)
    def ContainerFromItem(self, item: IInspectable) -> win32more.Microsoft.UI.Xaml.DependencyObject: ...
    @winrt_commethod(8)
    def IndexFromContainer(self, container: win32more.Microsoft.UI.Xaml.DependencyObject) -> Int32: ...
    @winrt_commethod(9)
    def ContainerFromIndex(self, index: Int32) -> win32more.Microsoft.UI.Xaml.DependencyObject: ...
class IItemContainerStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IItemContainerStatics'
    _iid_ = Guid('{e26e121d-b7bf-5632-85a2-f36040e649f8}')
    @winrt_commethod(6)
    def get_ChildProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_IsSelectedProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    ChildProperty = property(get_ChildProperty, None)
    IsSelectedProperty = property(get_IsSelectedProperty, None)
class IItemsControl(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IItemsControl'
    _iid_ = Guid('{bf1ccb54-83e2-5b98-acbc-736f876c3d35}')
    @winrt_commethod(6)
    def get_ItemsSource(self) -> IInspectable: ...
    @winrt_commethod(7)
    def put_ItemsSource(self, value: IInspectable) -> Void: ...
    @winrt_commethod(8)
    def get_Items(self) -> win32more.Microsoft.UI.Xaml.Controls.ItemCollection: ...
    @winrt_commethod(9)
    def get_ItemTemplate(self) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_commethod(10)
    def put_ItemTemplate(self, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_commethod(11)
    def get_ItemTemplateSelector(self) -> win32more.Microsoft.UI.Xaml.Controls.DataTemplateSelector: ...
    @winrt_commethod(12)
    def put_ItemTemplateSelector(self, value: win32more.Microsoft.UI.Xaml.Controls.DataTemplateSelector) -> Void: ...
    @winrt_commethod(13)
    def get_ItemsPanel(self) -> win32more.Microsoft.UI.Xaml.Controls.ItemsPanelTemplate: ...
    @winrt_commethod(14)
    def put_ItemsPanel(self, value: win32more.Microsoft.UI.Xaml.Controls.ItemsPanelTemplate) -> Void: ...
    @winrt_commethod(15)
    def get_DisplayMemberPath(self) -> hstr: ...
    @winrt_commethod(16)
    def put_DisplayMemberPath(self, value: hstr) -> Void: ...
    @winrt_commethod(17)
    def get_ItemsPanelRoot(self) -> win32more.Microsoft.UI.Xaml.Controls.Panel: ...
    @winrt_commethod(18)
    def get_ItemContainerStyle(self) -> win32more.Microsoft.UI.Xaml.Style: ...
    @winrt_commethod(19)
    def put_ItemContainerStyle(self, value: win32more.Microsoft.UI.Xaml.Style) -> Void: ...
    @winrt_commethod(20)
    def get_ItemContainerStyleSelector(self) -> win32more.Microsoft.UI.Xaml.Controls.StyleSelector: ...
    @winrt_commethod(21)
    def put_ItemContainerStyleSelector(self, value: win32more.Microsoft.UI.Xaml.Controls.StyleSelector) -> Void: ...
    @winrt_commethod(22)
    def get_ItemContainerGenerator(self) -> win32more.Microsoft.UI.Xaml.Controls.ItemContainerGenerator: ...
    @winrt_commethod(23)
    def get_ItemContainerTransitions(self) -> win32more.Microsoft.UI.Xaml.Media.Animation.TransitionCollection: ...
    @winrt_commethod(24)
    def put_ItemContainerTransitions(self, value: win32more.Microsoft.UI.Xaml.Media.Animation.TransitionCollection) -> Void: ...
    @winrt_commethod(25)
    def get_GroupStyle(self) -> win32more.Windows.Foundation.Collections.IObservableVector[win32more.Microsoft.UI.Xaml.Controls.GroupStyle]: ...
    @winrt_commethod(26)
    def get_GroupStyleSelector(self) -> win32more.Microsoft.UI.Xaml.Controls.GroupStyleSelector: ...
    @winrt_commethod(27)
    def put_GroupStyleSelector(self, value: win32more.Microsoft.UI.Xaml.Controls.GroupStyleSelector) -> Void: ...
    @winrt_commethod(28)
    def get_IsGrouping(self) -> Boolean: ...
    @winrt_commethod(29)
    def GroupHeaderContainerFromItemContainer(self, itemContainer: win32more.Microsoft.UI.Xaml.DependencyObject) -> win32more.Microsoft.UI.Xaml.DependencyObject: ...
    DisplayMemberPath = property(get_DisplayMemberPath, put_DisplayMemberPath)
    GroupStyle = property(get_GroupStyle, None)
    GroupStyleSelector = property(get_GroupStyleSelector, put_GroupStyleSelector)
    IsGrouping = property(get_IsGrouping, None)
    ItemContainerGenerator = property(get_ItemContainerGenerator, None)
    ItemContainerStyle = property(get_ItemContainerStyle, put_ItemContainerStyle)
    ItemContainerStyleSelector = property(get_ItemContainerStyleSelector, put_ItemContainerStyleSelector)
    ItemContainerTransitions = property(get_ItemContainerTransitions, put_ItemContainerTransitions)
    ItemTemplate = property(get_ItemTemplate, put_ItemTemplate)
    ItemTemplateSelector = property(get_ItemTemplateSelector, put_ItemTemplateSelector)
    Items = property(get_Items, None)
    ItemsPanel = property(get_ItemsPanel, put_ItemsPanel)
    ItemsPanelRoot = property(get_ItemsPanelRoot, None)
    ItemsSource = property(get_ItemsSource, put_ItemsSource)
class IItemsControlFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IItemsControlFactory'
    _iid_ = Guid('{b2686273-2dd3-5454-9f25-247e66270336}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.ItemsControl: ...
class IItemsControlOverrides(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IItemsControlOverrides'
    _iid_ = Guid('{285c215f-64b2-5f7d-88d2-56c6658f73ee}')
    @winrt_commethod(6)
    def IsItemItsOwnContainerOverride(self, item: IInspectable) -> Boolean: ...
    @winrt_commethod(7)
    def GetContainerForItemOverride(self) -> win32more.Microsoft.UI.Xaml.DependencyObject: ...
    @winrt_commethod(8)
    def ClearContainerForItemOverride(self, element: win32more.Microsoft.UI.Xaml.DependencyObject, item: IInspectable) -> Void: ...
    @winrt_commethod(9)
    def PrepareContainerForItemOverride(self, element: win32more.Microsoft.UI.Xaml.DependencyObject, item: IInspectable) -> Void: ...
    @winrt_commethod(10)
    def OnItemsChanged(self, e: IInspectable) -> Void: ...
    @winrt_commethod(11)
    def OnItemContainerStyleChanged(self, oldItemContainerStyle: win32more.Microsoft.UI.Xaml.Style, newItemContainerStyle: win32more.Microsoft.UI.Xaml.Style) -> Void: ...
    @winrt_commethod(12)
    def OnItemContainerStyleSelectorChanged(self, oldItemContainerStyleSelector: win32more.Microsoft.UI.Xaml.Controls.StyleSelector, newItemContainerStyleSelector: win32more.Microsoft.UI.Xaml.Controls.StyleSelector) -> Void: ...
    @winrt_commethod(13)
    def OnItemTemplateChanged(self, oldItemTemplate: win32more.Microsoft.UI.Xaml.DataTemplate, newItemTemplate: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_commethod(14)
    def OnItemTemplateSelectorChanged(self, oldItemTemplateSelector: win32more.Microsoft.UI.Xaml.Controls.DataTemplateSelector, newItemTemplateSelector: win32more.Microsoft.UI.Xaml.Controls.DataTemplateSelector) -> Void: ...
    @winrt_commethod(15)
    def OnGroupStyleSelectorChanged(self, oldGroupStyleSelector: win32more.Microsoft.UI.Xaml.Controls.GroupStyleSelector, newGroupStyleSelector: win32more.Microsoft.UI.Xaml.Controls.GroupStyleSelector) -> Void: ...
class IItemsControlStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IItemsControlStatics'
    _iid_ = Guid('{4fb961e1-5f91-5585-a692-6825cde3ed1e}')
    @winrt_commethod(6)
    def get_ItemsSourceProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_ItemTemplateProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_ItemTemplateSelectorProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_ItemsPanelProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_DisplayMemberPathProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_ItemContainerStyleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_ItemContainerStyleSelectorProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_ItemContainerTransitionsProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(14)
    def get_GroupStyleSelectorProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(15)
    def get_IsGroupingProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(16)
    def GetItemsOwner(self, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> win32more.Microsoft.UI.Xaml.Controls.ItemsControl: ...
    @winrt_commethod(17)
    def ItemsControlFromItemContainer(self, container: win32more.Microsoft.UI.Xaml.DependencyObject) -> win32more.Microsoft.UI.Xaml.Controls.ItemsControl: ...
    DisplayMemberPathProperty = property(get_DisplayMemberPathProperty, None)
    GroupStyleSelectorProperty = property(get_GroupStyleSelectorProperty, None)
    IsGroupingProperty = property(get_IsGroupingProperty, None)
    ItemContainerStyleProperty = property(get_ItemContainerStyleProperty, None)
    ItemContainerStyleSelectorProperty = property(get_ItemContainerStyleSelectorProperty, None)
    ItemContainerTransitionsProperty = property(get_ItemContainerTransitionsProperty, None)
    ItemTemplateProperty = property(get_ItemTemplateProperty, None)
    ItemTemplateSelectorProperty = property(get_ItemTemplateSelectorProperty, None)
    ItemsPanelProperty = property(get_ItemsPanelProperty, None)
    ItemsSourceProperty = property(get_ItemsSourceProperty, None)
class IItemsPanelTemplate(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IItemsPanelTemplate'
    _iid_ = Guid('{6153af2f-f095-5e8c-89d4-9e03203b9cc2}')
class IItemsPickedEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IItemsPickedEventArgs'
    _iid_ = Guid('{c6e93908-e20d-5614-988a-362d7937d276}')
    @winrt_commethod(6)
    def get_AddedItems(self) -> win32more.Windows.Foundation.Collections.IVector[IInspectable]: ...
    @winrt_commethod(7)
    def get_RemovedItems(self) -> win32more.Windows.Foundation.Collections.IVector[IInspectable]: ...
    AddedItems = property(get_AddedItems, None)
    RemovedItems = property(get_RemovedItems, None)
class IItemsPresenter(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IItemsPresenter'
    _iid_ = Guid('{0b0fbb88-6cb3-5f4e-99bd-879916b460df}')
    @winrt_commethod(6)
    def get_Header(self) -> IInspectable: ...
    @winrt_commethod(7)
    def put_Header(self, value: IInspectable) -> Void: ...
    @winrt_commethod(8)
    def get_HeaderTemplate(self) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_commethod(9)
    def put_HeaderTemplate(self, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_commethod(10)
    def get_HeaderTransitions(self) -> win32more.Microsoft.UI.Xaml.Media.Animation.TransitionCollection: ...
    @winrt_commethod(11)
    def put_HeaderTransitions(self, value: win32more.Microsoft.UI.Xaml.Media.Animation.TransitionCollection) -> Void: ...
    @winrt_commethod(12)
    def get_Footer(self) -> IInspectable: ...
    @winrt_commethod(13)
    def put_Footer(self, value: IInspectable) -> Void: ...
    @winrt_commethod(14)
    def get_FooterTemplate(self) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_commethod(15)
    def put_FooterTemplate(self, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_commethod(16)
    def get_FooterTransitions(self) -> win32more.Microsoft.UI.Xaml.Media.Animation.TransitionCollection: ...
    @winrt_commethod(17)
    def put_FooterTransitions(self, value: win32more.Microsoft.UI.Xaml.Media.Animation.TransitionCollection) -> Void: ...
    @winrt_commethod(18)
    def get_Padding(self) -> win32more.Microsoft.UI.Xaml.Thickness: ...
    @winrt_commethod(19)
    def put_Padding(self, value: win32more.Microsoft.UI.Xaml.Thickness) -> Void: ...
    Footer = property(get_Footer, put_Footer)
    FooterTemplate = property(get_FooterTemplate, put_FooterTemplate)
    FooterTransitions = property(get_FooterTransitions, put_FooterTransitions)
    Header = property(get_Header, put_Header)
    HeaderTemplate = property(get_HeaderTemplate, put_HeaderTemplate)
    HeaderTransitions = property(get_HeaderTransitions, put_HeaderTransitions)
    Padding = property(get_Padding, put_Padding)
class IItemsPresenterStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IItemsPresenterStatics'
    _iid_ = Guid('{6fa047c0-e510-52b0-8da2-c76eedc864a0}')
    @winrt_commethod(6)
    def get_HeaderProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_HeaderTemplateProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_HeaderTransitionsProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_FooterProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_FooterTemplateProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_FooterTransitionsProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_PaddingProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    FooterProperty = property(get_FooterProperty, None)
    FooterTemplateProperty = property(get_FooterTemplateProperty, None)
    FooterTransitionsProperty = property(get_FooterTransitionsProperty, None)
    HeaderProperty = property(get_HeaderProperty, None)
    HeaderTemplateProperty = property(get_HeaderTemplateProperty, None)
    HeaderTransitionsProperty = property(get_HeaderTransitionsProperty, None)
    PaddingProperty = property(get_PaddingProperty, None)
class IItemsRepeater(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IItemsRepeater'
    _iid_ = Guid('{9dabac84-fe81-53d1-a041-7a3befea505f}')
    @winrt_commethod(6)
    def get_ItemsSource(self) -> IInspectable: ...
    @winrt_commethod(7)
    def put_ItemsSource(self, value: IInspectable) -> Void: ...
    @winrt_commethod(8)
    def get_ItemsSourceView(self) -> win32more.Microsoft.UI.Xaml.Controls.ItemsSourceView: ...
    @winrt_commethod(9)
    def get_ItemTemplate(self) -> IInspectable: ...
    @winrt_commethod(10)
    def put_ItemTemplate(self, value: IInspectable) -> Void: ...
    @winrt_commethod(11)
    def get_Layout(self) -> win32more.Microsoft.UI.Xaml.Controls.Layout: ...
    @winrt_commethod(12)
    def put_Layout(self, value: win32more.Microsoft.UI.Xaml.Controls.Layout) -> Void: ...
    @winrt_commethod(13)
    def get_HorizontalCacheLength(self) -> Double: ...
    @winrt_commethod(14)
    def put_HorizontalCacheLength(self, value: Double) -> Void: ...
    @winrt_commethod(15)
    def get_VerticalCacheLength(self) -> Double: ...
    @winrt_commethod(16)
    def put_VerticalCacheLength(self, value: Double) -> Void: ...
    @winrt_commethod(17)
    def get_Background(self) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_commethod(18)
    def put_Background(self, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(19)
    def GetElementIndex(self, element: win32more.Microsoft.UI.Xaml.UIElement) -> Int32: ...
    @winrt_commethod(20)
    def TryGetElement(self, index: Int32) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_commethod(21)
    def GetOrCreateElement(self, index: Int32) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_commethod(22)
    def add_ElementPrepared(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.ItemsRepeater, win32more.Microsoft.UI.Xaml.Controls.ItemsRepeaterElementPreparedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(23)
    def remove_ElementPrepared(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(24)
    def add_ElementClearing(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.ItemsRepeater, win32more.Microsoft.UI.Xaml.Controls.ItemsRepeaterElementClearingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(25)
    def remove_ElementClearing(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(26)
    def add_ElementIndexChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.ItemsRepeater, win32more.Microsoft.UI.Xaml.Controls.ItemsRepeaterElementIndexChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(27)
    def remove_ElementIndexChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    Background = property(get_Background, put_Background)
    HorizontalCacheLength = property(get_HorizontalCacheLength, put_HorizontalCacheLength)
    ItemTemplate = property(get_ItemTemplate, put_ItemTemplate)
    ItemsSource = property(get_ItemsSource, put_ItemsSource)
    ItemsSourceView = property(get_ItemsSourceView, None)
    Layout = property(get_Layout, put_Layout)
    VerticalCacheLength = property(get_VerticalCacheLength, put_VerticalCacheLength)
    ElementClearing = event(add_ElementClearing, remove_ElementClearing)
    ElementIndexChanged = event(add_ElementIndexChanged, remove_ElementIndexChanged)
    ElementPrepared = event(add_ElementPrepared, remove_ElementPrepared)
class IItemsRepeater2(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IItemsRepeater2'
    _iid_ = Guid('{265e249a-2812-55b6-a191-cb96089b51ac}')
    @winrt_commethod(6)
    def get_ItemTransitionProvider(self) -> win32more.Microsoft.UI.Xaml.Controls.ItemCollectionTransitionProvider: ...
    @winrt_commethod(7)
    def put_ItemTransitionProvider(self, value: win32more.Microsoft.UI.Xaml.Controls.ItemCollectionTransitionProvider) -> Void: ...
    ItemTransitionProvider = property(get_ItemTransitionProvider, put_ItemTransitionProvider)
class IItemsRepeaterElementClearingEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IItemsRepeaterElementClearingEventArgs'
    _iid_ = Guid('{8f394a59-07c6-54ce-80d1-bb0b71daefa0}')
    @winrt_commethod(6)
    def get_Element(self) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    Element = property(get_Element, None)
class IItemsRepeaterElementIndexChangedEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IItemsRepeaterElementIndexChangedEventArgs'
    _iid_ = Guid('{38e3d613-48fb-5906-bf18-f7130301fcc3}')
    @winrt_commethod(6)
    def get_Element(self) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_commethod(7)
    def get_OldIndex(self) -> Int32: ...
    @winrt_commethod(8)
    def get_NewIndex(self) -> Int32: ...
    Element = property(get_Element, None)
    NewIndex = property(get_NewIndex, None)
    OldIndex = property(get_OldIndex, None)
class IItemsRepeaterElementPreparedEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IItemsRepeaterElementPreparedEventArgs'
    _iid_ = Guid('{612db572-c2e7-58fc-948a-b7dc0e1fc13a}')
    @winrt_commethod(6)
    def get_Element(self) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_commethod(7)
    def get_Index(self) -> Int32: ...
    Element = property(get_Element, None)
    Index = property(get_Index, None)
class IItemsRepeaterFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IItemsRepeaterFactory'
    _iid_ = Guid('{c3c1f244-67a8-568f-a6f7-5da8b0eadd49}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.ItemsRepeater: ...
class IItemsRepeaterScrollHost(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IItemsRepeaterScrollHost'
    _iid_ = Guid('{6f3cee8e-078a-59b4-931f-faa891c8c073}')
    @winrt_commethod(6)
    def get_ScrollViewer(self) -> win32more.Microsoft.UI.Xaml.Controls.ScrollViewer: ...
    @winrt_commethod(7)
    def put_ScrollViewer(self, value: win32more.Microsoft.UI.Xaml.Controls.ScrollViewer) -> Void: ...
    @winrt_commethod(8)
    def get_CurrentAnchor(self) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_commethod(9)
    def get_HorizontalAnchorRatio(self) -> Double: ...
    @winrt_commethod(10)
    def put_HorizontalAnchorRatio(self, value: Double) -> Void: ...
    @winrt_commethod(11)
    def get_VerticalAnchorRatio(self) -> Double: ...
    @winrt_commethod(12)
    def put_VerticalAnchorRatio(self, value: Double) -> Void: ...
    CurrentAnchor = property(get_CurrentAnchor, None)
    HorizontalAnchorRatio = property(get_HorizontalAnchorRatio, put_HorizontalAnchorRatio)
    ScrollViewer = property(get_ScrollViewer, put_ScrollViewer)
    VerticalAnchorRatio = property(get_VerticalAnchorRatio, put_VerticalAnchorRatio)
class IItemsRepeaterStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IItemsRepeaterStatics'
    _iid_ = Guid('{ed8c4cb7-2edc-5416-afbf-87a9aa2af26e}')
    @winrt_commethod(6)
    def get_ItemsSourceProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_ItemTemplateProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_LayoutProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_HorizontalCacheLengthProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_VerticalCacheLengthProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_BackgroundProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    BackgroundProperty = property(get_BackgroundProperty, None)
    HorizontalCacheLengthProperty = property(get_HorizontalCacheLengthProperty, None)
    ItemTemplateProperty = property(get_ItemTemplateProperty, None)
    ItemsSourceProperty = property(get_ItemsSourceProperty, None)
    LayoutProperty = property(get_LayoutProperty, None)
    VerticalCacheLengthProperty = property(get_VerticalCacheLengthProperty, None)
class IItemsRepeaterStatics2(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IItemsRepeaterStatics2'
    _iid_ = Guid('{83d8b5ea-ca31-5192-b9a9-2a62e60194e7}')
    @winrt_commethod(6)
    def get_ItemTransitionProviderProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    ItemTransitionProviderProperty = property(get_ItemTransitionProviderProperty, None)
class IItemsSourceView(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IItemsSourceView'
    _iid_ = Guid('{f7f802de-e79c-5c5f-abf8-ccbd486b89d6}')
    @winrt_commethod(6)
    def get_Count(self) -> Int32: ...
    @winrt_commethod(7)
    def GetAt(self, index: Int32) -> IInspectable: ...
    @winrt_commethod(8)
    def get_HasKeyIndexMapping(self) -> Boolean: ...
    @winrt_commethod(9)
    def KeyFromIndex(self, index: Int32) -> hstr: ...
    @winrt_commethod(10)
    def IndexFromKey(self, key: hstr) -> Int32: ...
    @winrt_commethod(11)
    def IndexOf(self, item: IInspectable) -> Int32: ...
    Count = property(get_Count, None)
    HasKeyIndexMapping = property(get_HasKeyIndexMapping, None)
class IItemsSourceViewFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IItemsSourceViewFactory'
    _iid_ = Guid('{aadc6fdd-eb00-5e58-b95d-120f891d733f}')
    @winrt_commethod(6)
    def CreateInstance(self, source: IInspectable, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.ItemsSourceView: ...
class IItemsStackPanel(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IItemsStackPanel'
    _iid_ = Guid('{f7e52fdf-4779-5f63-9999-7d677e3fd2c1}')
    @winrt_commethod(6)
    def get_GroupPadding(self) -> win32more.Microsoft.UI.Xaml.Thickness: ...
    @winrt_commethod(7)
    def put_GroupPadding(self, value: win32more.Microsoft.UI.Xaml.Thickness) -> Void: ...
    @winrt_commethod(8)
    def get_Orientation(self) -> win32more.Microsoft.UI.Xaml.Controls.Orientation: ...
    @winrt_commethod(9)
    def put_Orientation(self, value: win32more.Microsoft.UI.Xaml.Controls.Orientation) -> Void: ...
    @winrt_commethod(10)
    def get_FirstCacheIndex(self) -> Int32: ...
    @winrt_commethod(11)
    def get_FirstVisibleIndex(self) -> Int32: ...
    @winrt_commethod(12)
    def get_LastVisibleIndex(self) -> Int32: ...
    @winrt_commethod(13)
    def get_LastCacheIndex(self) -> Int32: ...
    @winrt_commethod(14)
    def get_ScrollingDirection(self) -> win32more.Microsoft.UI.Xaml.Controls.PanelScrollingDirection: ...
    @winrt_commethod(15)
    def get_GroupHeaderPlacement(self) -> win32more.Microsoft.UI.Xaml.Controls.Primitives.GroupHeaderPlacement: ...
    @winrt_commethod(16)
    def put_GroupHeaderPlacement(self, value: win32more.Microsoft.UI.Xaml.Controls.Primitives.GroupHeaderPlacement) -> Void: ...
    @winrt_commethod(17)
    def get_ItemsUpdatingScrollMode(self) -> win32more.Microsoft.UI.Xaml.Controls.ItemsUpdatingScrollMode: ...
    @winrt_commethod(18)
    def put_ItemsUpdatingScrollMode(self, value: win32more.Microsoft.UI.Xaml.Controls.ItemsUpdatingScrollMode) -> Void: ...
    @winrt_commethod(19)
    def get_CacheLength(self) -> Double: ...
    @winrt_commethod(20)
    def put_CacheLength(self, value: Double) -> Void: ...
    @winrt_commethod(21)
    def get_AreStickyGroupHeadersEnabled(self) -> Boolean: ...
    @winrt_commethod(22)
    def put_AreStickyGroupHeadersEnabled(self, value: Boolean) -> Void: ...
    AreStickyGroupHeadersEnabled = property(get_AreStickyGroupHeadersEnabled, put_AreStickyGroupHeadersEnabled)
    CacheLength = property(get_CacheLength, put_CacheLength)
    FirstCacheIndex = property(get_FirstCacheIndex, None)
    FirstVisibleIndex = property(get_FirstVisibleIndex, None)
    GroupHeaderPlacement = property(get_GroupHeaderPlacement, put_GroupHeaderPlacement)
    GroupPadding = property(get_GroupPadding, put_GroupPadding)
    ItemsUpdatingScrollMode = property(get_ItemsUpdatingScrollMode, put_ItemsUpdatingScrollMode)
    LastCacheIndex = property(get_LastCacheIndex, None)
    LastVisibleIndex = property(get_LastVisibleIndex, None)
    Orientation = property(get_Orientation, put_Orientation)
    ScrollingDirection = property(get_ScrollingDirection, None)
class IItemsStackPanelStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IItemsStackPanelStatics'
    _iid_ = Guid('{7ca08d59-be10-5d61-abe2-089ad44db1d6}')
    @winrt_commethod(6)
    def get_GroupPaddingProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_OrientationProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_GroupHeaderPlacementProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_CacheLengthProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_AreStickyGroupHeadersEnabledProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    AreStickyGroupHeadersEnabledProperty = property(get_AreStickyGroupHeadersEnabledProperty, None)
    CacheLengthProperty = property(get_CacheLengthProperty, None)
    GroupHeaderPlacementProperty = property(get_GroupHeaderPlacementProperty, None)
    GroupPaddingProperty = property(get_GroupPaddingProperty, None)
    OrientationProperty = property(get_OrientationProperty, None)
class IItemsView(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IItemsView'
    _iid_ = Guid('{bbb195d8-6a7f-5a42-9866-25fd5a4473ab}')
    @winrt_commethod(6)
    def get_ItemsSource(self) -> IInspectable: ...
    @winrt_commethod(7)
    def put_ItemsSource(self, value: IInspectable) -> Void: ...
    @winrt_commethod(8)
    def get_ScrollView(self) -> win32more.Microsoft.UI.Xaml.Controls.ScrollView: ...
    @winrt_commethod(9)
    def get_VerticalScrollController(self) -> win32more.Microsoft.UI.Xaml.Controls.Primitives.IScrollController: ...
    @winrt_commethod(10)
    def put_VerticalScrollController(self, value: win32more.Microsoft.UI.Xaml.Controls.Primitives.IScrollController) -> Void: ...
    @winrt_commethod(11)
    def get_ItemTemplate(self) -> win32more.Microsoft.UI.Xaml.IElementFactory: ...
    @winrt_commethod(12)
    def put_ItemTemplate(self, value: win32more.Microsoft.UI.Xaml.IElementFactory) -> Void: ...
    @winrt_commethod(13)
    def get_Layout(self) -> win32more.Microsoft.UI.Xaml.Controls.Layout: ...
    @winrt_commethod(14)
    def put_Layout(self, value: win32more.Microsoft.UI.Xaml.Controls.Layout) -> Void: ...
    @winrt_commethod(15)
    def get_IsItemInvokedEnabled(self) -> Boolean: ...
    @winrt_commethod(16)
    def put_IsItemInvokedEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(17)
    def get_SelectionMode(self) -> win32more.Microsoft.UI.Xaml.Controls.ItemsViewSelectionMode: ...
    @winrt_commethod(18)
    def put_SelectionMode(self, value: win32more.Microsoft.UI.Xaml.Controls.ItemsViewSelectionMode) -> Void: ...
    @winrt_commethod(19)
    def get_ItemTransitionProvider(self) -> win32more.Microsoft.UI.Xaml.Controls.ItemCollectionTransitionProvider: ...
    @winrt_commethod(20)
    def put_ItemTransitionProvider(self, value: win32more.Microsoft.UI.Xaml.Controls.ItemCollectionTransitionProvider) -> Void: ...
    @winrt_commethod(21)
    def get_CurrentItemIndex(self) -> Int32: ...
    @winrt_commethod(22)
    def get_SelectedItem(self) -> IInspectable: ...
    @winrt_commethod(23)
    def get_SelectedItems(self) -> win32more.Windows.Foundation.Collections.IVectorView[IInspectable]: ...
    @winrt_commethod(24)
    def TryGetItemIndex(self, horizontalViewportRatio: Double, verticalViewportRatio: Double, index: POINTER(Int32)) -> Boolean: ...
    @winrt_commethod(25)
    def StartBringItemIntoView(self, index: Int32, options: win32more.Microsoft.UI.Xaml.BringIntoViewOptions) -> Void: ...
    @winrt_commethod(26)
    def Select(self, itemIndex: Int32) -> Void: ...
    @winrt_commethod(27)
    def Deselect(self, itemIndex: Int32) -> Void: ...
    @winrt_commethod(28)
    def IsSelected(self, itemIndex: Int32) -> Boolean: ...
    @winrt_commethod(29)
    def SelectAll(self) -> Void: ...
    @winrt_commethod(30)
    def DeselectAll(self) -> Void: ...
    @winrt_commethod(31)
    def InvertSelection(self) -> Void: ...
    @winrt_commethod(32)
    def add_ItemInvoked(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.ItemsView, win32more.Microsoft.UI.Xaml.Controls.ItemsViewItemInvokedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(33)
    def remove_ItemInvoked(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(34)
    def add_SelectionChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.ItemsView, win32more.Microsoft.UI.Xaml.Controls.ItemsViewSelectionChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(35)
    def remove_SelectionChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    CurrentItemIndex = property(get_CurrentItemIndex, None)
    IsItemInvokedEnabled = property(get_IsItemInvokedEnabled, put_IsItemInvokedEnabled)
    ItemTemplate = property(get_ItemTemplate, put_ItemTemplate)
    ItemTransitionProvider = property(get_ItemTransitionProvider, put_ItemTransitionProvider)
    ItemsSource = property(get_ItemsSource, put_ItemsSource)
    Layout = property(get_Layout, put_Layout)
    ScrollView = property(get_ScrollView, None)
    SelectedItem = property(get_SelectedItem, None)
    SelectedItems = property(get_SelectedItems, None)
    SelectionMode = property(get_SelectionMode, put_SelectionMode)
    VerticalScrollController = property(get_VerticalScrollController, put_VerticalScrollController)
    ItemInvoked = event(add_ItemInvoked, remove_ItemInvoked)
    SelectionChanged = event(add_SelectionChanged, remove_SelectionChanged)
class IItemsViewFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IItemsViewFactory'
    _iid_ = Guid('{aeeec7b9-3cc8-52df-8e2e-99a295c253aa}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.ItemsView: ...
class IItemsViewItemInvokedEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IItemsViewItemInvokedEventArgs'
    _iid_ = Guid('{5a2386e8-15b8-5f25-874b-7912f633ce21}')
    @winrt_commethod(6)
    def get_InvokedItem(self) -> IInspectable: ...
    InvokedItem = property(get_InvokedItem, None)
class IItemsViewSelectionChangedEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IItemsViewSelectionChangedEventArgs'
    _iid_ = Guid('{9cd1690f-6c9d-543c-82f2-30cd37d765b3}')
class IItemsViewStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IItemsViewStatics'
    _iid_ = Guid('{c64f1948-77d3-5df5-8d33-c58602d4cfb9}')
    @winrt_commethod(6)
    def get_IsItemInvokedEnabledProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_ItemsSourceProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_ItemTemplateProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_LayoutProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_SelectionModeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_ItemTransitionProviderProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_CurrentItemIndexProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_SelectedItemProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(14)
    def get_ScrollViewProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(15)
    def get_VerticalScrollControllerProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    CurrentItemIndexProperty = property(get_CurrentItemIndexProperty, None)
    IsItemInvokedEnabledProperty = property(get_IsItemInvokedEnabledProperty, None)
    ItemTemplateProperty = property(get_ItemTemplateProperty, None)
    ItemTransitionProviderProperty = property(get_ItemTransitionProviderProperty, None)
    ItemsSourceProperty = property(get_ItemsSourceProperty, None)
    LayoutProperty = property(get_LayoutProperty, None)
    ScrollViewProperty = property(get_ScrollViewProperty, None)
    SelectedItemProperty = property(get_SelectedItemProperty, None)
    SelectionModeProperty = property(get_SelectionModeProperty, None)
    VerticalScrollControllerProperty = property(get_VerticalScrollControllerProperty, None)
class IItemsWrapGrid(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IItemsWrapGrid'
    _iid_ = Guid('{29910bc5-b305-5529-b88c-776c66e1b3ba}')
    @winrt_commethod(6)
    def get_GroupPadding(self) -> win32more.Microsoft.UI.Xaml.Thickness: ...
    @winrt_commethod(7)
    def put_GroupPadding(self, value: win32more.Microsoft.UI.Xaml.Thickness) -> Void: ...
    @winrt_commethod(8)
    def get_Orientation(self) -> win32more.Microsoft.UI.Xaml.Controls.Orientation: ...
    @winrt_commethod(9)
    def put_Orientation(self, value: win32more.Microsoft.UI.Xaml.Controls.Orientation) -> Void: ...
    @winrt_commethod(10)
    def get_MaximumRowsOrColumns(self) -> Int32: ...
    @winrt_commethod(11)
    def put_MaximumRowsOrColumns(self, value: Int32) -> Void: ...
    @winrt_commethod(12)
    def get_ItemWidth(self) -> Double: ...
    @winrt_commethod(13)
    def put_ItemWidth(self, value: Double) -> Void: ...
    @winrt_commethod(14)
    def get_ItemHeight(self) -> Double: ...
    @winrt_commethod(15)
    def put_ItemHeight(self, value: Double) -> Void: ...
    @winrt_commethod(16)
    def get_FirstCacheIndex(self) -> Int32: ...
    @winrt_commethod(17)
    def get_FirstVisibleIndex(self) -> Int32: ...
    @winrt_commethod(18)
    def get_LastVisibleIndex(self) -> Int32: ...
    @winrt_commethod(19)
    def get_LastCacheIndex(self) -> Int32: ...
    @winrt_commethod(20)
    def get_ScrollingDirection(self) -> win32more.Microsoft.UI.Xaml.Controls.PanelScrollingDirection: ...
    @winrt_commethod(21)
    def get_GroupHeaderPlacement(self) -> win32more.Microsoft.UI.Xaml.Controls.Primitives.GroupHeaderPlacement: ...
    @winrt_commethod(22)
    def put_GroupHeaderPlacement(self, value: win32more.Microsoft.UI.Xaml.Controls.Primitives.GroupHeaderPlacement) -> Void: ...
    @winrt_commethod(23)
    def get_CacheLength(self) -> Double: ...
    @winrt_commethod(24)
    def put_CacheLength(self, value: Double) -> Void: ...
    @winrt_commethod(25)
    def get_AreStickyGroupHeadersEnabled(self) -> Boolean: ...
    @winrt_commethod(26)
    def put_AreStickyGroupHeadersEnabled(self, value: Boolean) -> Void: ...
    AreStickyGroupHeadersEnabled = property(get_AreStickyGroupHeadersEnabled, put_AreStickyGroupHeadersEnabled)
    CacheLength = property(get_CacheLength, put_CacheLength)
    FirstCacheIndex = property(get_FirstCacheIndex, None)
    FirstVisibleIndex = property(get_FirstVisibleIndex, None)
    GroupHeaderPlacement = property(get_GroupHeaderPlacement, put_GroupHeaderPlacement)
    GroupPadding = property(get_GroupPadding, put_GroupPadding)
    ItemHeight = property(get_ItemHeight, put_ItemHeight)
    ItemWidth = property(get_ItemWidth, put_ItemWidth)
    LastCacheIndex = property(get_LastCacheIndex, None)
    LastVisibleIndex = property(get_LastVisibleIndex, None)
    MaximumRowsOrColumns = property(get_MaximumRowsOrColumns, put_MaximumRowsOrColumns)
    Orientation = property(get_Orientation, put_Orientation)
    ScrollingDirection = property(get_ScrollingDirection, None)
class IItemsWrapGridStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IItemsWrapGridStatics'
    _iid_ = Guid('{f757d5cb-3bf2-5a23-968f-045bc80d57ce}')
    @winrt_commethod(6)
    def get_GroupPaddingProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_OrientationProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_MaximumRowsOrColumnsProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_ItemWidthProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_ItemHeightProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_GroupHeaderPlacementProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_CacheLengthProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_AreStickyGroupHeadersEnabledProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    AreStickyGroupHeadersEnabledProperty = property(get_AreStickyGroupHeadersEnabledProperty, None)
    CacheLengthProperty = property(get_CacheLengthProperty, None)
    GroupHeaderPlacementProperty = property(get_GroupHeaderPlacementProperty, None)
    GroupPaddingProperty = property(get_GroupPaddingProperty, None)
    ItemHeightProperty = property(get_ItemHeightProperty, None)
    ItemWidthProperty = property(get_ItemWidthProperty, None)
    MaximumRowsOrColumnsProperty = property(get_MaximumRowsOrColumnsProperty, None)
    OrientationProperty = property(get_OrientationProperty, None)
class IKeyIndexMapping(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IKeyIndexMapping'
    _iid_ = Guid('{b1f3bba0-108e-560d-9681-26391b4bc30d}')
    @winrt_commethod(6)
    def KeyFromIndex(self, index: Int32) -> hstr: ...
    @winrt_commethod(7)
    def IndexFromKey(self, key: hstr) -> Int32: ...
class ILayout(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ILayout'
    _iid_ = Guid('{24e50c1c-9c51-5144-9ddc-3f500191c262}')
    @winrt_commethod(6)
    def InitializeForContext(self, context: win32more.Microsoft.UI.Xaml.Controls.LayoutContext) -> Void: ...
    @winrt_commethod(7)
    def UninitializeForContext(self, context: win32more.Microsoft.UI.Xaml.Controls.LayoutContext) -> Void: ...
    @winrt_commethod(8)
    def Measure(self, context: win32more.Microsoft.UI.Xaml.Controls.LayoutContext, availableSize: win32more.Windows.Foundation.Size) -> win32more.Windows.Foundation.Size: ...
    @winrt_commethod(9)
    def Arrange(self, context: win32more.Microsoft.UI.Xaml.Controls.LayoutContext, finalSize: win32more.Windows.Foundation.Size) -> win32more.Windows.Foundation.Size: ...
    @winrt_commethod(10)
    def add_MeasureInvalidated(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.Layout, IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(11)
    def remove_MeasureInvalidated(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(12)
    def add_ArrangeInvalidated(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.Layout, IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(13)
    def remove_ArrangeInvalidated(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    ArrangeInvalidated = event(add_ArrangeInvalidated, remove_ArrangeInvalidated)
    MeasureInvalidated = event(add_MeasureInvalidated, remove_MeasureInvalidated)
class ILayout2(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ILayout2'
    _iid_ = Guid('{cc545ff5-0c41-5c14-9565-2557ccc84132}')
    @winrt_commethod(6)
    def get_IndexBasedLayoutOrientation(self) -> win32more.Microsoft.UI.Xaml.Controls.IndexBasedLayoutOrientation: ...
    IndexBasedLayoutOrientation = property(get_IndexBasedLayoutOrientation, None)
class ILayoutContext(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ILayoutContext'
    _iid_ = Guid('{b45a2e55-2ecc-5462-bb26-d47c455bb48e}')
    @winrt_commethod(6)
    def get_LayoutState(self) -> IInspectable: ...
    @winrt_commethod(7)
    def put_LayoutState(self, value: IInspectable) -> Void: ...
    LayoutState = property(get_LayoutState, put_LayoutState)
class ILayoutContextFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ILayoutContextFactory'
    _iid_ = Guid('{f7664771-9242-599e-a7dd-0705565def98}')
class ILayoutContextOverrides(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ILayoutContextOverrides'
    _iid_ = Guid('{fda70e44-6526-5535-be2b-ec2743670ae2}')
    @winrt_commethod(6)
    def get_LayoutStateCore(self) -> IInspectable: ...
    @winrt_commethod(7)
    def put_LayoutStateCore(self, value: IInspectable) -> Void: ...
    LayoutStateCore = property(get_LayoutStateCore, put_LayoutStateCore)
class ILayoutFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ILayoutFactory'
    _iid_ = Guid('{eaf956b4-59c9-5e13-a49d-f35b171d8fc9}')
class ILayoutOverrides(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ILayoutOverrides'
    _iid_ = Guid('{441d00c3-dd50-5348-852d-85608cc7dce1}')
    @winrt_commethod(6)
    def CreateDefaultItemTransitionProvider(self) -> win32more.Microsoft.UI.Xaml.Controls.ItemCollectionTransitionProvider: ...
class ILayoutProtected(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ILayoutProtected'
    _iid_ = Guid('{e46ff416-741e-5176-a1d4-5718d2342243}')
    @winrt_commethod(6)
    def InvalidateMeasure(self) -> Void: ...
    @winrt_commethod(7)
    def InvalidateArrange(self) -> Void: ...
class ILayoutProtected2(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ILayoutProtected2'
    _iid_ = Guid('{3fffe35f-6f2e-501f-a2ad-e75a4e1cd592}')
    @winrt_commethod(6)
    def SetIndexBasedLayoutOrientation(self, orientation: win32more.Microsoft.UI.Xaml.Controls.IndexBasedLayoutOrientation) -> Void: ...
class ILinedFlowLayout(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ILinedFlowLayout'
    _iid_ = Guid('{f887a64b-b146-540c-8953-d8184b79ba6e}')
    @winrt_commethod(6)
    def add_ItemsInfoRequested(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.LinedFlowLayout, win32more.Microsoft.UI.Xaml.Controls.LinedFlowLayoutItemsInfoRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(7)
    def remove_ItemsInfoRequested(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(8)
    def add_ItemsUnlocked(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.LinedFlowLayout, IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(9)
    def remove_ItemsUnlocked(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(10)
    def get_ItemsJustification(self) -> win32more.Microsoft.UI.Xaml.Controls.LinedFlowLayoutItemsJustification: ...
    @winrt_commethod(11)
    def put_ItemsJustification(self, value: win32more.Microsoft.UI.Xaml.Controls.LinedFlowLayoutItemsJustification) -> Void: ...
    @winrt_commethod(12)
    def get_ItemsStretch(self) -> win32more.Microsoft.UI.Xaml.Controls.LinedFlowLayoutItemsStretch: ...
    @winrt_commethod(13)
    def put_ItemsStretch(self, value: win32more.Microsoft.UI.Xaml.Controls.LinedFlowLayoutItemsStretch) -> Void: ...
    @winrt_commethod(14)
    def get_MinItemSpacing(self) -> Double: ...
    @winrt_commethod(15)
    def put_MinItemSpacing(self, value: Double) -> Void: ...
    @winrt_commethod(16)
    def get_LineSpacing(self) -> Double: ...
    @winrt_commethod(17)
    def put_LineSpacing(self, value: Double) -> Void: ...
    @winrt_commethod(18)
    def get_LineHeight(self) -> Double: ...
    @winrt_commethod(19)
    def put_LineHeight(self, value: Double) -> Void: ...
    @winrt_commethod(20)
    def get_ActualLineHeight(self) -> Double: ...
    @winrt_commethod(21)
    def get_RequestedRangeStartIndex(self) -> Int32: ...
    @winrt_commethod(22)
    def get_RequestedRangeLength(self) -> Int32: ...
    @winrt_commethod(23)
    def InvalidateItemsInfo(self) -> Void: ...
    @winrt_commethod(24)
    def LockItemToLine(self, itemIndex: Int32) -> Int32: ...
    ActualLineHeight = property(get_ActualLineHeight, None)
    ItemsJustification = property(get_ItemsJustification, put_ItemsJustification)
    ItemsStretch = property(get_ItemsStretch, put_ItemsStretch)
    LineHeight = property(get_LineHeight, put_LineHeight)
    LineSpacing = property(get_LineSpacing, put_LineSpacing)
    MinItemSpacing = property(get_MinItemSpacing, put_MinItemSpacing)
    RequestedRangeLength = property(get_RequestedRangeLength, None)
    RequestedRangeStartIndex = property(get_RequestedRangeStartIndex, None)
    ItemsInfoRequested = event(add_ItemsInfoRequested, remove_ItemsInfoRequested)
    ItemsUnlocked = event(add_ItemsUnlocked, remove_ItemsUnlocked)
class ILinedFlowLayoutFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ILinedFlowLayoutFactory'
    _iid_ = Guid('{507b841e-fcdf-5cea-b271-94d7a6af355f}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.LinedFlowLayout: ...
class ILinedFlowLayoutItemCollectionTransitionProvider(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ILinedFlowLayoutItemCollectionTransitionProvider'
    _iid_ = Guid('{a7c000de-2543-5dc2-a36d-5d69f4f55d61}')
class ILinedFlowLayoutItemCollectionTransitionProviderFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ILinedFlowLayoutItemCollectionTransitionProviderFactory'
    _iid_ = Guid('{e915c9fc-ba75-581e-9b96-20edd8befcc4}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.LinedFlowLayoutItemCollectionTransitionProvider: ...
class ILinedFlowLayoutItemsInfoRequestedEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ILinedFlowLayoutItemsInfoRequestedEventArgs'
    _iid_ = Guid('{d69a3096-c1d3-57e5-8af7-3f7088b1958b}')
    @winrt_commethod(6)
    def get_ItemsRangeStartIndex(self) -> Int32: ...
    @winrt_commethod(7)
    def put_ItemsRangeStartIndex(self, value: Int32) -> Void: ...
    @winrt_commethod(8)
    def get_ItemsRangeRequestedLength(self) -> Int32: ...
    @winrt_commethod(9)
    def get_MinWidth(self) -> Double: ...
    @winrt_commethod(10)
    def put_MinWidth(self, value: Double) -> Void: ...
    @winrt_commethod(11)
    def get_MaxWidth(self) -> Double: ...
    @winrt_commethod(12)
    def put_MaxWidth(self, value: Double) -> Void: ...
    @winrt_commethod(13)
    def SetDesiredAspectRatios(self, values: PassArray[Double]) -> Void: ...
    @winrt_commethod(14)
    def SetMinWidths(self, values: PassArray[Double]) -> Void: ...
    @winrt_commethod(15)
    def SetMaxWidths(self, values: PassArray[Double]) -> Void: ...
    ItemsRangeRequestedLength = property(get_ItemsRangeRequestedLength, None)
    ItemsRangeStartIndex = property(get_ItemsRangeStartIndex, put_ItemsRangeStartIndex)
    MaxWidth = property(get_MaxWidth, put_MaxWidth)
    MinWidth = property(get_MinWidth, put_MinWidth)
class ILinedFlowLayoutStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ILinedFlowLayoutStatics'
    _iid_ = Guid('{e5ed0928-228f-5a4e-8011-bd9cda24dca2}')
    @winrt_commethod(6)
    def get_ItemsJustificationProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_ItemsStretchProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_MinItemSpacingProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_LineSpacingProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_LineHeightProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_ActualLineHeightProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    ActualLineHeightProperty = property(get_ActualLineHeightProperty, None)
    ItemsJustificationProperty = property(get_ItemsJustificationProperty, None)
    ItemsStretchProperty = property(get_ItemsStretchProperty, None)
    LineHeightProperty = property(get_LineHeightProperty, None)
    LineSpacingProperty = property(get_LineSpacingProperty, None)
    MinItemSpacingProperty = property(get_MinItemSpacingProperty, None)
class IListBox(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IListBox'
    _iid_ = Guid('{f3e7dedf-7a3c-59f1-9e05-ae5026b54293}')
    @winrt_commethod(6)
    def get_SelectedItems(self) -> win32more.Windows.Foundation.Collections.IVector[IInspectable]: ...
    @winrt_commethod(7)
    def get_SelectionMode(self) -> win32more.Microsoft.UI.Xaml.Controls.SelectionMode: ...
    @winrt_commethod(8)
    def put_SelectionMode(self, value: win32more.Microsoft.UI.Xaml.Controls.SelectionMode) -> Void: ...
    @winrt_commethod(9)
    def get_SingleSelectionFollowsFocus(self) -> Boolean: ...
    @winrt_commethod(10)
    def put_SingleSelectionFollowsFocus(self, value: Boolean) -> Void: ...
    @winrt_commethod(11)
    def ScrollIntoView(self, item: IInspectable) -> Void: ...
    @winrt_commethod(12)
    def SelectAll(self) -> Void: ...
    SelectedItems = property(get_SelectedItems, None)
    SelectionMode = property(get_SelectionMode, put_SelectionMode)
    SingleSelectionFollowsFocus = property(get_SingleSelectionFollowsFocus, put_SingleSelectionFollowsFocus)
class IListBoxFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IListBoxFactory'
    _iid_ = Guid('{d048e0bc-4692-5c60-b2e9-07c4433ce050}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.ListBox: ...
class IListBoxItem(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IListBoxItem'
    _iid_ = Guid('{cc67fb35-04f1-5ead-96c5-b2ea67b225c6}')
class IListBoxItemFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IListBoxItemFactory'
    _iid_ = Guid('{8e9e0e6d-4597-5efa-94bc-7ffadc264c28}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.ListBoxItem: ...
class IListBoxStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IListBoxStatics'
    _iid_ = Guid('{763a4986-db3a-5a94-8505-aee2f229af85}')
    @winrt_commethod(6)
    def get_SelectionModeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_SingleSelectionFollowsFocusProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    SelectionModeProperty = property(get_SelectionModeProperty, None)
    SingleSelectionFollowsFocusProperty = property(get_SingleSelectionFollowsFocusProperty, None)
class IListPickerFlyout(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IListPickerFlyout'
    _iid_ = Guid('{b0154a37-07c1-50ed-834c-32d3fbda5c5f}')
    @winrt_commethod(6)
    def get_ItemsSource(self) -> IInspectable: ...
    @winrt_commethod(7)
    def put_ItemsSource(self, value: IInspectable) -> Void: ...
    @winrt_commethod(8)
    def get_ItemTemplate(self) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_commethod(9)
    def put_ItemTemplate(self, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_commethod(10)
    def get_DisplayMemberPath(self) -> hstr: ...
    @winrt_commethod(11)
    def put_DisplayMemberPath(self, value: hstr) -> Void: ...
    @winrt_commethod(12)
    def get_SelectionMode(self) -> win32more.Microsoft.UI.Xaml.Controls.ListPickerFlyoutSelectionMode: ...
    @winrt_commethod(13)
    def put_SelectionMode(self, value: win32more.Microsoft.UI.Xaml.Controls.ListPickerFlyoutSelectionMode) -> Void: ...
    @winrt_commethod(14)
    def get_SelectedIndex(self) -> Int32: ...
    @winrt_commethod(15)
    def put_SelectedIndex(self, value: Int32) -> Void: ...
    @winrt_commethod(16)
    def get_SelectedItem(self) -> IInspectable: ...
    @winrt_commethod(17)
    def put_SelectedItem(self, value: IInspectable) -> Void: ...
    @winrt_commethod(18)
    def get_SelectedValue(self) -> IInspectable: ...
    @winrt_commethod(19)
    def put_SelectedValue(self, value: IInspectable) -> Void: ...
    @winrt_commethod(20)
    def get_SelectedValuePath(self) -> hstr: ...
    @winrt_commethod(21)
    def put_SelectedValuePath(self, value: hstr) -> Void: ...
    @winrt_commethod(22)
    def get_SelectedItems(self) -> win32more.Windows.Foundation.Collections.IVector[IInspectable]: ...
    @winrt_commethod(23)
    def add_ItemsPicked(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.ListPickerFlyout, win32more.Microsoft.UI.Xaml.Controls.ItemsPickedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(24)
    def remove_ItemsPicked(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(25)
    def ShowAtAsync(self, target: win32more.Microsoft.UI.Xaml.FrameworkElement) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[IInspectable]]: ...
    DisplayMemberPath = property(get_DisplayMemberPath, put_DisplayMemberPath)
    ItemTemplate = property(get_ItemTemplate, put_ItemTemplate)
    ItemsSource = property(get_ItemsSource, put_ItemsSource)
    SelectedIndex = property(get_SelectedIndex, put_SelectedIndex)
    SelectedItem = property(get_SelectedItem, put_SelectedItem)
    SelectedItems = property(get_SelectedItems, None)
    SelectedValue = property(get_SelectedValue, put_SelectedValue)
    SelectedValuePath = property(get_SelectedValuePath, put_SelectedValuePath)
    SelectionMode = property(get_SelectionMode, put_SelectionMode)
    ItemsPicked = event(add_ItemsPicked, remove_ItemsPicked)
class IListPickerFlyoutPresenter(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IListPickerFlyoutPresenter'
    _iid_ = Guid('{7dcc91ab-8694-517b-a4e6-04767410c60b}')
class IListPickerFlyoutStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IListPickerFlyoutStatics'
    _iid_ = Guid('{9e485154-489d-5542-8e62-3c91a11814b5}')
    @winrt_commethod(6)
    def get_ItemsSourceProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_ItemTemplateProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_DisplayMemberPathProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_SelectionModeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_SelectedIndexProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_SelectedItemProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_SelectedValueProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_SelectedValuePathProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    DisplayMemberPathProperty = property(get_DisplayMemberPathProperty, None)
    ItemTemplateProperty = property(get_ItemTemplateProperty, None)
    ItemsSourceProperty = property(get_ItemsSourceProperty, None)
    SelectedIndexProperty = property(get_SelectedIndexProperty, None)
    SelectedItemProperty = property(get_SelectedItemProperty, None)
    SelectedValuePathProperty = property(get_SelectedValuePathProperty, None)
    SelectedValueProperty = property(get_SelectedValueProperty, None)
    SelectionModeProperty = property(get_SelectionModeProperty, None)
class IListView(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IListView'
    _iid_ = Guid('{f6015db1-df63-52fd-a164-0df44715ee0a}')
class IListViewBase(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IListViewBase'
    _iid_ = Guid('{775c57ac-abce-5beb-8e34-3b8158aedd80}')
    @winrt_commethod(6)
    def get_SelectedItems(self) -> win32more.Windows.Foundation.Collections.IVector[IInspectable]: ...
    @winrt_commethod(7)
    def get_SelectionMode(self) -> win32more.Microsoft.UI.Xaml.Controls.ListViewSelectionMode: ...
    @winrt_commethod(8)
    def put_SelectionMode(self, value: win32more.Microsoft.UI.Xaml.Controls.ListViewSelectionMode) -> Void: ...
    @winrt_commethod(9)
    def get_IsSwipeEnabled(self) -> Boolean: ...
    @winrt_commethod(10)
    def put_IsSwipeEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(11)
    def get_CanDragItems(self) -> Boolean: ...
    @winrt_commethod(12)
    def put_CanDragItems(self, value: Boolean) -> Void: ...
    @winrt_commethod(13)
    def get_CanReorderItems(self) -> Boolean: ...
    @winrt_commethod(14)
    def put_CanReorderItems(self, value: Boolean) -> Void: ...
    @winrt_commethod(15)
    def get_IsItemClickEnabled(self) -> Boolean: ...
    @winrt_commethod(16)
    def put_IsItemClickEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(17)
    def get_DataFetchSize(self) -> Double: ...
    @winrt_commethod(18)
    def put_DataFetchSize(self, value: Double) -> Void: ...
    @winrt_commethod(19)
    def get_IncrementalLoadingThreshold(self) -> Double: ...
    @winrt_commethod(20)
    def put_IncrementalLoadingThreshold(self, value: Double) -> Void: ...
    @winrt_commethod(21)
    def get_IncrementalLoadingTrigger(self) -> win32more.Microsoft.UI.Xaml.Controls.IncrementalLoadingTrigger: ...
    @winrt_commethod(22)
    def put_IncrementalLoadingTrigger(self, value: win32more.Microsoft.UI.Xaml.Controls.IncrementalLoadingTrigger) -> Void: ...
    @winrt_commethod(23)
    def get_ShowsScrollingPlaceholders(self) -> Boolean: ...
    @winrt_commethod(24)
    def put_ShowsScrollingPlaceholders(self, value: Boolean) -> Void: ...
    @winrt_commethod(25)
    def get_ReorderMode(self) -> win32more.Microsoft.UI.Xaml.Controls.ListViewReorderMode: ...
    @winrt_commethod(26)
    def put_ReorderMode(self, value: win32more.Microsoft.UI.Xaml.Controls.ListViewReorderMode) -> Void: ...
    @winrt_commethod(27)
    def get_SelectedRanges(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Microsoft.UI.Xaml.Data.ItemIndexRange]: ...
    @winrt_commethod(28)
    def get_IsMultiSelectCheckBoxEnabled(self) -> Boolean: ...
    @winrt_commethod(29)
    def put_IsMultiSelectCheckBoxEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(30)
    def get_SingleSelectionFollowsFocus(self) -> Boolean: ...
    @winrt_commethod(31)
    def put_SingleSelectionFollowsFocus(self, value: Boolean) -> Void: ...
    @winrt_commethod(32)
    def add_ItemClick(self, handler: win32more.Microsoft.UI.Xaml.Controls.ItemClickEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(33)
    def remove_ItemClick(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(34)
    def add_DragItemsStarting(self, handler: win32more.Microsoft.UI.Xaml.Controls.DragItemsStartingEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(35)
    def remove_DragItemsStarting(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(36)
    def add_DragItemsCompleted(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.ListViewBase, win32more.Microsoft.UI.Xaml.Controls.DragItemsCompletedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(37)
    def remove_DragItemsCompleted(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(38)
    def add_ContainerContentChanging(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.ListViewBase, win32more.Microsoft.UI.Xaml.Controls.ContainerContentChangingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(39)
    def remove_ContainerContentChanging(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(40)
    def add_ChoosingItemContainer(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.ListViewBase, win32more.Microsoft.UI.Xaml.Controls.ChoosingItemContainerEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(41)
    def remove_ChoosingItemContainer(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(42)
    def add_ChoosingGroupHeaderContainer(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.ListViewBase, win32more.Microsoft.UI.Xaml.Controls.ChoosingGroupHeaderContainerEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(43)
    def remove_ChoosingGroupHeaderContainer(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(44)
    def ScrollIntoView(self, item: IInspectable) -> Void: ...
    @winrt_commethod(45)
    def SelectAll(self) -> Void: ...
    @winrt_commethod(46)
    def LoadMoreItemsAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Microsoft.UI.Xaml.Data.LoadMoreItemsResult]: ...
    @winrt_commethod(47)
    def ScrollIntoViewWithAlignment(self, item: IInspectable, alignment: win32more.Microsoft.UI.Xaml.Controls.ScrollIntoViewAlignment) -> Void: ...
    @winrt_commethod(48)
    def SetDesiredContainerUpdateDuration(self, duration: win32more.Windows.Foundation.TimeSpan) -> Void: ...
    @winrt_commethod(49)
    def SelectRange(self, itemIndexRange: win32more.Microsoft.UI.Xaml.Data.ItemIndexRange) -> Void: ...
    @winrt_commethod(50)
    def DeselectRange(self, itemIndexRange: win32more.Microsoft.UI.Xaml.Data.ItemIndexRange) -> Void: ...
    @winrt_commethod(51)
    def IsDragSource(self) -> Boolean: ...
    @winrt_commethod(52)
    def TryStartConnectedAnimationAsync(self, animation: win32more.Microsoft.UI.Xaml.Media.Animation.ConnectedAnimation, item: IInspectable, elementName: hstr) -> win32more.Windows.Foundation.IAsyncOperation[Boolean]: ...
    @winrt_commethod(53)
    def PrepareConnectedAnimation(self, key: hstr, item: IInspectable, elementName: hstr) -> win32more.Microsoft.UI.Xaml.Media.Animation.ConnectedAnimation: ...
    @winrt_commethod(54)
    def get_Header(self) -> IInspectable: ...
    @winrt_commethod(55)
    def put_Header(self, value: IInspectable) -> Void: ...
    @winrt_commethod(56)
    def get_HeaderTemplate(self) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_commethod(57)
    def put_HeaderTemplate(self, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_commethod(58)
    def get_HeaderTransitions(self) -> win32more.Microsoft.UI.Xaml.Media.Animation.TransitionCollection: ...
    @winrt_commethod(59)
    def put_HeaderTransitions(self, value: win32more.Microsoft.UI.Xaml.Media.Animation.TransitionCollection) -> Void: ...
    @winrt_commethod(60)
    def get_Footer(self) -> IInspectable: ...
    @winrt_commethod(61)
    def put_Footer(self, value: IInspectable) -> Void: ...
    @winrt_commethod(62)
    def get_FooterTemplate(self) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_commethod(63)
    def put_FooterTemplate(self, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_commethod(64)
    def get_FooterTransitions(self) -> win32more.Microsoft.UI.Xaml.Media.Animation.TransitionCollection: ...
    @winrt_commethod(65)
    def put_FooterTransitions(self, value: win32more.Microsoft.UI.Xaml.Media.Animation.TransitionCollection) -> Void: ...
    CanDragItems = property(get_CanDragItems, put_CanDragItems)
    CanReorderItems = property(get_CanReorderItems, put_CanReorderItems)
    DataFetchSize = property(get_DataFetchSize, put_DataFetchSize)
    Footer = property(get_Footer, put_Footer)
    FooterTemplate = property(get_FooterTemplate, put_FooterTemplate)
    FooterTransitions = property(get_FooterTransitions, put_FooterTransitions)
    Header = property(get_Header, put_Header)
    HeaderTemplate = property(get_HeaderTemplate, put_HeaderTemplate)
    HeaderTransitions = property(get_HeaderTransitions, put_HeaderTransitions)
    IncrementalLoadingThreshold = property(get_IncrementalLoadingThreshold, put_IncrementalLoadingThreshold)
    IncrementalLoadingTrigger = property(get_IncrementalLoadingTrigger, put_IncrementalLoadingTrigger)
    IsItemClickEnabled = property(get_IsItemClickEnabled, put_IsItemClickEnabled)
    IsMultiSelectCheckBoxEnabled = property(get_IsMultiSelectCheckBoxEnabled, put_IsMultiSelectCheckBoxEnabled)
    IsSwipeEnabled = property(get_IsSwipeEnabled, put_IsSwipeEnabled)
    ReorderMode = property(get_ReorderMode, put_ReorderMode)
    SelectedItems = property(get_SelectedItems, None)
    SelectedRanges = property(get_SelectedRanges, None)
    SelectionMode = property(get_SelectionMode, put_SelectionMode)
    ShowsScrollingPlaceholders = property(get_ShowsScrollingPlaceholders, put_ShowsScrollingPlaceholders)
    SingleSelectionFollowsFocus = property(get_SingleSelectionFollowsFocus, put_SingleSelectionFollowsFocus)
    ChoosingGroupHeaderContainer = event(add_ChoosingGroupHeaderContainer, remove_ChoosingGroupHeaderContainer)
    ChoosingItemContainer = event(add_ChoosingItemContainer, remove_ChoosingItemContainer)
    ContainerContentChanging = event(add_ContainerContentChanging, remove_ContainerContentChanging)
    DragItemsCompleted = event(add_DragItemsCompleted, remove_DragItemsCompleted)
    DragItemsStarting = event(add_DragItemsStarting, remove_DragItemsStarting)
    ItemClick = event(add_ItemClick, remove_ItemClick)
class IListViewBaseFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IListViewBaseFactory'
    _iid_ = Guid('{44092863-c09e-551e-85bf-951b552950c8}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.ListViewBase: ...
class IListViewBaseHeaderItem(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IListViewBaseHeaderItem'
    _iid_ = Guid('{9220c4ff-1974-53fd-ad74-c29e7b360a06}')
class IListViewBaseHeaderItemFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IListViewBaseHeaderItemFactory'
    _iid_ = Guid('{228fc10a-b86f-5b57-96f4-34d9f9fb8711}')
class IListViewBaseStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IListViewBaseStatics'
    _iid_ = Guid('{b8487e94-010f-56d4-9f76-94bf8c462745}')
    @winrt_commethod(6)
    def get_SelectionModeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_IsSwipeEnabledProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_CanDragItemsProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_CanReorderItemsProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_IsItemClickEnabledProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_DataFetchSizeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_IncrementalLoadingThresholdProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_IncrementalLoadingTriggerProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(14)
    def get_ShowsScrollingPlaceholdersProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(15)
    def get_ReorderModeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(16)
    def get_IsMultiSelectCheckBoxEnabledProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(17)
    def get_SingleSelectionFollowsFocusProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(18)
    def get_SemanticZoomOwnerProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(19)
    def get_IsActiveViewProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(20)
    def get_IsZoomedInViewProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(21)
    def get_HeaderProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(22)
    def get_HeaderTemplateProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(23)
    def get_HeaderTransitionsProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(24)
    def get_FooterProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(25)
    def get_FooterTemplateProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(26)
    def get_FooterTransitionsProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    CanDragItemsProperty = property(get_CanDragItemsProperty, None)
    CanReorderItemsProperty = property(get_CanReorderItemsProperty, None)
    DataFetchSizeProperty = property(get_DataFetchSizeProperty, None)
    FooterProperty = property(get_FooterProperty, None)
    FooterTemplateProperty = property(get_FooterTemplateProperty, None)
    FooterTransitionsProperty = property(get_FooterTransitionsProperty, None)
    HeaderProperty = property(get_HeaderProperty, None)
    HeaderTemplateProperty = property(get_HeaderTemplateProperty, None)
    HeaderTransitionsProperty = property(get_HeaderTransitionsProperty, None)
    IncrementalLoadingThresholdProperty = property(get_IncrementalLoadingThresholdProperty, None)
    IncrementalLoadingTriggerProperty = property(get_IncrementalLoadingTriggerProperty, None)
    IsActiveViewProperty = property(get_IsActiveViewProperty, None)
    IsItemClickEnabledProperty = property(get_IsItemClickEnabledProperty, None)
    IsMultiSelectCheckBoxEnabledProperty = property(get_IsMultiSelectCheckBoxEnabledProperty, None)
    IsSwipeEnabledProperty = property(get_IsSwipeEnabledProperty, None)
    IsZoomedInViewProperty = property(get_IsZoomedInViewProperty, None)
    ReorderModeProperty = property(get_ReorderModeProperty, None)
    SelectionModeProperty = property(get_SelectionModeProperty, None)
    SemanticZoomOwnerProperty = property(get_SemanticZoomOwnerProperty, None)
    ShowsScrollingPlaceholdersProperty = property(get_ShowsScrollingPlaceholdersProperty, None)
    SingleSelectionFollowsFocusProperty = property(get_SingleSelectionFollowsFocusProperty, None)
class IListViewFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IListViewFactory'
    _iid_ = Guid('{03ebefb8-f64a-5bf9-9570-cb09eeea2335}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.ListView: ...
class IListViewHeaderItem(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IListViewHeaderItem'
    _iid_ = Guid('{e94366c8-64f5-5930-a325-b23aacdbce89}')
class IListViewHeaderItemFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IListViewHeaderItemFactory'
    _iid_ = Guid('{78f29d6a-c5a4-5d86-9962-91020ce61313}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.ListViewHeaderItem: ...
class IListViewItem(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IListViewItem'
    _iid_ = Guid('{05fe41c2-0451-5d38-9c55-5d10cfd08889}')
    @winrt_commethod(6)
    def get_TemplateSettings(self) -> win32more.Microsoft.UI.Xaml.Controls.Primitives.ListViewItemTemplateSettings: ...
    TemplateSettings = property(get_TemplateSettings, None)
class IListViewItemFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IListViewItemFactory'
    _iid_ = Guid('{d9f4d0b8-ee59-5036-bd7a-7c89cf0bc2ac}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.ListViewItem: ...
class IListViewPersistenceHelper(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IListViewPersistenceHelper'
    _iid_ = Guid('{07de9ad4-ed8e-5e05-9039-031b4ddf7237}')
class IListViewPersistenceHelperStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IListViewPersistenceHelperStatics'
    _iid_ = Guid('{36b862bb-3882-59d8-9118-904de3fe00c2}')
    @winrt_commethod(6)
    def GetRelativeScrollPosition(self, listViewBase: win32more.Microsoft.UI.Xaml.Controls.ListViewBase, itemToKeyHandler: win32more.Microsoft.UI.Xaml.Controls.ListViewItemToKeyHandler) -> hstr: ...
    @winrt_commethod(7)
    def SetRelativeScrollPositionAsync(self, listViewBase: win32more.Microsoft.UI.Xaml.Controls.ListViewBase, relativeScrollPosition: hstr, keyToItemHandler: win32more.Microsoft.UI.Xaml.Controls.ListViewKeyToItemHandler) -> win32more.Windows.Foundation.IAsyncAction: ...
class IMapControl(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IMapControl'
    _iid_ = Guid('{85c67af2-2b9c-55ab-ae1f-635da713d68f}')
    @winrt_commethod(6)
    def get_MapServiceToken(self) -> hstr: ...
    @winrt_commethod(7)
    def put_MapServiceToken(self, value: hstr) -> Void: ...
    @winrt_commethod(8)
    def get_Center(self) -> win32more.Windows.Devices.Geolocation.Geopoint: ...
    @winrt_commethod(9)
    def put_Center(self, value: win32more.Windows.Devices.Geolocation.Geopoint) -> Void: ...
    @winrt_commethod(10)
    def get_Layers(self) -> win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.MapLayer]: ...
    @winrt_commethod(11)
    def put_Layers(self, value: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.MapLayer]) -> Void: ...
    @winrt_commethod(12)
    def get_ZoomLevel(self) -> Double: ...
    @winrt_commethod(13)
    def put_ZoomLevel(self, value: Double) -> Void: ...
    @winrt_commethod(14)
    def get_InteractiveControlsVisible(self) -> Boolean: ...
    @winrt_commethod(15)
    def put_InteractiveControlsVisible(self, value: Boolean) -> Void: ...
    @winrt_commethod(16)
    def add_MapElementClick(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.MapControl, win32more.Microsoft.UI.Xaml.Controls.MapElementClickEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(17)
    def remove_MapElementClick(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(18)
    def add_MapServiceErrorOccurred(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.MapControl, win32more.Microsoft.UI.Xaml.Controls.MapControlMapServiceErrorOccurredEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(19)
    def remove_MapServiceErrorOccurred(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    Center = property(get_Center, put_Center)
    InteractiveControlsVisible = property(get_InteractiveControlsVisible, put_InteractiveControlsVisible)
    Layers = property(get_Layers, put_Layers)
    MapServiceToken = property(get_MapServiceToken, put_MapServiceToken)
    ZoomLevel = property(get_ZoomLevel, put_ZoomLevel)
    MapElementClick = event(add_MapElementClick, remove_MapElementClick)
    MapServiceErrorOccurred = event(add_MapServiceErrorOccurred, remove_MapServiceErrorOccurred)
class IMapControlFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IMapControlFactory'
    _iid_ = Guid('{edf8c301-8e9a-59b1-9179-99d41bec90d9}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.MapControl: ...
class IMapControlMapServiceErrorOccurredEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IMapControlMapServiceErrorOccurredEventArgs'
    _iid_ = Guid('{b5493c70-799c-59c0-b823-aed5268194a9}')
    @winrt_commethod(6)
    def get_DiagnosticMessage(self) -> hstr: ...
    DiagnosticMessage = property(get_DiagnosticMessage, None)
class IMapControlStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IMapControlStatics'
    _iid_ = Guid('{56e19652-9c6a-5dcd-850e-97d3725e7423}')
    @winrt_commethod(6)
    def get_LayersProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_MapServiceTokenProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_CenterProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_ZoomLevelProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_InteractiveControlsVisibleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    CenterProperty = property(get_CenterProperty, None)
    InteractiveControlsVisibleProperty = property(get_InteractiveControlsVisibleProperty, None)
    LayersProperty = property(get_LayersProperty, None)
    MapServiceTokenProperty = property(get_MapServiceTokenProperty, None)
    ZoomLevelProperty = property(get_ZoomLevelProperty, None)
class IMapElement(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IMapElement'
    _iid_ = Guid('{106fe452-6421-5f74-b94b-df95b5d44474}')
class IMapElementClickEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IMapElementClickEventArgs'
    _iid_ = Guid('{24a3fd85-fdea-591e-92ef-3d56179b1b19}')
    @winrt_commethod(6)
    def get_Location(self) -> win32more.Windows.Devices.Geolocation.Geopoint: ...
    @winrt_commethod(7)
    def get_Element(self) -> win32more.Microsoft.UI.Xaml.Controls.MapElement: ...
    Element = property(get_Element, None)
    Location = property(get_Location, None)
class IMapElementFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IMapElementFactory'
    _iid_ = Guid('{3688073b-c481-5254-af83-4b928f3b5806}')
class IMapElementsLayer(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IMapElementsLayer'
    _iid_ = Guid('{623e70e1-d55d-594a-a3e2-97b6c897d6c0}')
    @winrt_commethod(6)
    def get_MapElements(self) -> win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.MapElement]: ...
    @winrt_commethod(7)
    def put_MapElements(self, value: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.MapElement]) -> Void: ...
    @winrt_commethod(8)
    def add_MapElementClick(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.MapElementsLayer, win32more.Microsoft.UI.Xaml.Controls.MapElementClickEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(9)
    def remove_MapElementClick(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    MapElements = property(get_MapElements, put_MapElements)
    MapElementClick = event(add_MapElementClick, remove_MapElementClick)
class IMapElementsLayerFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IMapElementsLayerFactory'
    _iid_ = Guid('{bff4c348-ee22-56b0-b89f-a1a12539850e}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.MapElementsLayer: ...
class IMapElementsLayerStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IMapElementsLayerStatics'
    _iid_ = Guid('{0f07c4b8-f7d8-5ac9-b23b-6c19c49541dc}')
    @winrt_commethod(6)
    def get_MapElementsProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    MapElementsProperty = property(get_MapElementsProperty, None)
class IMapIcon(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IMapIcon'
    _iid_ = Guid('{e54fcfca-360b-5bef-a7f5-b1baa43f12f4}')
    @winrt_commethod(6)
    def get_Location(self) -> win32more.Windows.Devices.Geolocation.Geopoint: ...
    @winrt_commethod(7)
    def put_Location(self, value: win32more.Windows.Devices.Geolocation.Geopoint) -> Void: ...
    Location = property(get_Location, put_Location)
class IMapIconFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IMapIconFactory'
    _iid_ = Guid('{daee9683-7218-548f-aeac-a13610e09129}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.MapIcon: ...
class IMapIconStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IMapIconStatics'
    _iid_ = Guid('{b8b61be8-e767-50a5-8de8-6f3ac2decda7}')
    @winrt_commethod(6)
    def get_LocationProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    LocationProperty = property(get_LocationProperty, None)
class IMapLayer(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IMapLayer'
    _iid_ = Guid('{88dce7f9-df75-5549-8ab8-03765c34b449}')
class IMapLayerFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IMapLayerFactory'
    _iid_ = Guid('{2b44c746-d7ba-583e-a238-78564c1dd329}')
class IMediaPlayerElement(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IMediaPlayerElement'
    _iid_ = Guid('{c314a38c-780c-558a-98cd-0a8deb467fcf}')
    @winrt_commethod(6)
    def get_Source(self) -> win32more.Windows.Media.Playback.IMediaPlaybackSource: ...
    @winrt_commethod(7)
    def put_Source(self, value: win32more.Windows.Media.Playback.IMediaPlaybackSource) -> Void: ...
    @winrt_commethod(8)
    def get_TransportControls(self) -> win32more.Microsoft.UI.Xaml.Controls.MediaTransportControls: ...
    @winrt_commethod(9)
    def put_TransportControls(self, value: win32more.Microsoft.UI.Xaml.Controls.MediaTransportControls) -> Void: ...
    @winrt_commethod(10)
    def get_AreTransportControlsEnabled(self) -> Boolean: ...
    @winrt_commethod(11)
    def put_AreTransportControlsEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(12)
    def get_PosterSource(self) -> win32more.Microsoft.UI.Xaml.Media.ImageSource: ...
    @winrt_commethod(13)
    def put_PosterSource(self, value: win32more.Microsoft.UI.Xaml.Media.ImageSource) -> Void: ...
    @winrt_commethod(14)
    def get_Stretch(self) -> win32more.Microsoft.UI.Xaml.Media.Stretch: ...
    @winrt_commethod(15)
    def put_Stretch(self, value: win32more.Microsoft.UI.Xaml.Media.Stretch) -> Void: ...
    @winrt_commethod(16)
    def get_AutoPlay(self) -> Boolean: ...
    @winrt_commethod(17)
    def put_AutoPlay(self, value: Boolean) -> Void: ...
    @winrt_commethod(18)
    def get_IsFullWindow(self) -> Boolean: ...
    @winrt_commethod(19)
    def put_IsFullWindow(self, value: Boolean) -> Void: ...
    @winrt_commethod(20)
    def get_MediaPlayer(self) -> win32more.Windows.Media.Playback.MediaPlayer: ...
    @winrt_commethod(21)
    def SetMediaPlayer(self, mediaPlayer: win32more.Windows.Media.Playback.MediaPlayer) -> Void: ...
    AreTransportControlsEnabled = property(get_AreTransportControlsEnabled, put_AreTransportControlsEnabled)
    AutoPlay = property(get_AutoPlay, put_AutoPlay)
    IsFullWindow = property(get_IsFullWindow, put_IsFullWindow)
    MediaPlayer = property(get_MediaPlayer, None)
    PosterSource = property(get_PosterSource, put_PosterSource)
    Source = property(get_Source, put_Source)
    Stretch = property(get_Stretch, put_Stretch)
    TransportControls = property(get_TransportControls, put_TransportControls)
class IMediaPlayerElementFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IMediaPlayerElementFactory'
    _iid_ = Guid('{51aca342-65a0-5db6-8082-bd54a8d14999}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.MediaPlayerElement: ...
class IMediaPlayerElementStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IMediaPlayerElementStatics'
    _iid_ = Guid('{6f77bba8-fb23-5e27-97c1-16d437d0702f}')
    @winrt_commethod(6)
    def get_SourceProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_AreTransportControlsEnabledProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_PosterSourceProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_StretchProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_AutoPlayProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_IsFullWindowProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_MediaPlayerProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    AreTransportControlsEnabledProperty = property(get_AreTransportControlsEnabledProperty, None)
    AutoPlayProperty = property(get_AutoPlayProperty, None)
    IsFullWindowProperty = property(get_IsFullWindowProperty, None)
    MediaPlayerProperty = property(get_MediaPlayerProperty, None)
    PosterSourceProperty = property(get_PosterSourceProperty, None)
    SourceProperty = property(get_SourceProperty, None)
    StretchProperty = property(get_StretchProperty, None)
class IMediaPlayerPresenter(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IMediaPlayerPresenter'
    _iid_ = Guid('{b6a01245-a73c-51ba-8e1a-3447bb277e40}')
    @winrt_commethod(6)
    def get_MediaPlayer(self) -> win32more.Windows.Media.Playback.MediaPlayer: ...
    @winrt_commethod(7)
    def put_MediaPlayer(self, value: win32more.Windows.Media.Playback.MediaPlayer) -> Void: ...
    @winrt_commethod(8)
    def get_Stretch(self) -> win32more.Microsoft.UI.Xaml.Media.Stretch: ...
    @winrt_commethod(9)
    def put_Stretch(self, value: win32more.Microsoft.UI.Xaml.Media.Stretch) -> Void: ...
    @winrt_commethod(10)
    def get_IsFullWindow(self) -> Boolean: ...
    @winrt_commethod(11)
    def put_IsFullWindow(self, value: Boolean) -> Void: ...
    IsFullWindow = property(get_IsFullWindow, put_IsFullWindow)
    MediaPlayer = property(get_MediaPlayer, put_MediaPlayer)
    Stretch = property(get_Stretch, put_Stretch)
class IMediaPlayerPresenterFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IMediaPlayerPresenterFactory'
    _iid_ = Guid('{3a96e3f8-ec04-5922-901c-11ba3607cf93}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.MediaPlayerPresenter: ...
class IMediaPlayerPresenterStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IMediaPlayerPresenterStatics'
    _iid_ = Guid('{5a14b68f-1e03-5604-bcd6-7c7403619513}')
    @winrt_commethod(6)
    def get_MediaPlayerProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_StretchProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_IsFullWindowProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    IsFullWindowProperty = property(get_IsFullWindowProperty, None)
    MediaPlayerProperty = property(get_MediaPlayerProperty, None)
    StretchProperty = property(get_StretchProperty, None)
class IMediaTransportControls(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IMediaTransportControls'
    _iid_ = Guid('{c99c110b-9dee-5a6b-bb9e-61bfcaaafa3e}')
    @winrt_commethod(6)
    def get_IsZoomButtonVisible(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_IsZoomButtonVisible(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def get_IsZoomEnabled(self) -> Boolean: ...
    @winrt_commethod(9)
    def put_IsZoomEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(10)
    def get_IsFastForwardButtonVisible(self) -> Boolean: ...
    @winrt_commethod(11)
    def put_IsFastForwardButtonVisible(self, value: Boolean) -> Void: ...
    @winrt_commethod(12)
    def get_IsFastForwardEnabled(self) -> Boolean: ...
    @winrt_commethod(13)
    def put_IsFastForwardEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(14)
    def get_IsFastRewindButtonVisible(self) -> Boolean: ...
    @winrt_commethod(15)
    def put_IsFastRewindButtonVisible(self, value: Boolean) -> Void: ...
    @winrt_commethod(16)
    def get_IsFastRewindEnabled(self) -> Boolean: ...
    @winrt_commethod(17)
    def put_IsFastRewindEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(18)
    def get_IsStopButtonVisible(self) -> Boolean: ...
    @winrt_commethod(19)
    def put_IsStopButtonVisible(self, value: Boolean) -> Void: ...
    @winrt_commethod(20)
    def get_IsStopEnabled(self) -> Boolean: ...
    @winrt_commethod(21)
    def put_IsStopEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(22)
    def get_IsVolumeButtonVisible(self) -> Boolean: ...
    @winrt_commethod(23)
    def put_IsVolumeButtonVisible(self, value: Boolean) -> Void: ...
    @winrt_commethod(24)
    def get_IsVolumeEnabled(self) -> Boolean: ...
    @winrt_commethod(25)
    def put_IsVolumeEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(26)
    def get_IsPlaybackRateButtonVisible(self) -> Boolean: ...
    @winrt_commethod(27)
    def put_IsPlaybackRateButtonVisible(self, value: Boolean) -> Void: ...
    @winrt_commethod(28)
    def get_IsPlaybackRateEnabled(self) -> Boolean: ...
    @winrt_commethod(29)
    def put_IsPlaybackRateEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(30)
    def get_IsSeekBarVisible(self) -> Boolean: ...
    @winrt_commethod(31)
    def put_IsSeekBarVisible(self, value: Boolean) -> Void: ...
    @winrt_commethod(32)
    def get_IsSeekEnabled(self) -> Boolean: ...
    @winrt_commethod(33)
    def put_IsSeekEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(34)
    def get_IsCompact(self) -> Boolean: ...
    @winrt_commethod(35)
    def put_IsCompact(self, value: Boolean) -> Void: ...
    @winrt_commethod(36)
    def get_IsSkipForwardButtonVisible(self) -> Boolean: ...
    @winrt_commethod(37)
    def put_IsSkipForwardButtonVisible(self, value: Boolean) -> Void: ...
    @winrt_commethod(38)
    def get_IsSkipForwardEnabled(self) -> Boolean: ...
    @winrt_commethod(39)
    def put_IsSkipForwardEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(40)
    def get_IsSkipBackwardButtonVisible(self) -> Boolean: ...
    @winrt_commethod(41)
    def put_IsSkipBackwardButtonVisible(self, value: Boolean) -> Void: ...
    @winrt_commethod(42)
    def get_IsSkipBackwardEnabled(self) -> Boolean: ...
    @winrt_commethod(43)
    def put_IsSkipBackwardEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(44)
    def get_IsNextTrackButtonVisible(self) -> Boolean: ...
    @winrt_commethod(45)
    def put_IsNextTrackButtonVisible(self, value: Boolean) -> Void: ...
    @winrt_commethod(46)
    def get_IsPreviousTrackButtonVisible(self) -> Boolean: ...
    @winrt_commethod(47)
    def put_IsPreviousTrackButtonVisible(self, value: Boolean) -> Void: ...
    @winrt_commethod(48)
    def get_FastPlayFallbackBehaviour(self) -> win32more.Microsoft.UI.Xaml.Media.FastPlayFallbackBehaviour: ...
    @winrt_commethod(49)
    def put_FastPlayFallbackBehaviour(self, value: win32more.Microsoft.UI.Xaml.Media.FastPlayFallbackBehaviour) -> Void: ...
    @winrt_commethod(50)
    def get_ShowAndHideAutomatically(self) -> Boolean: ...
    @winrt_commethod(51)
    def put_ShowAndHideAutomatically(self, value: Boolean) -> Void: ...
    @winrt_commethod(52)
    def get_IsRepeatEnabled(self) -> Boolean: ...
    @winrt_commethod(53)
    def put_IsRepeatEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(54)
    def get_IsRepeatButtonVisible(self) -> Boolean: ...
    @winrt_commethod(55)
    def put_IsRepeatButtonVisible(self, value: Boolean) -> Void: ...
    @winrt_commethod(56)
    def add_ThumbnailRequested(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.MediaTransportControls, win32more.Microsoft.UI.Xaml.Media.MediaTransportControlsThumbnailRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(57)
    def remove_ThumbnailRequested(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(58)
    def Show(self) -> Void: ...
    @winrt_commethod(59)
    def Hide(self) -> Void: ...
    FastPlayFallbackBehaviour = property(get_FastPlayFallbackBehaviour, put_FastPlayFallbackBehaviour)
    IsCompact = property(get_IsCompact, put_IsCompact)
    IsFastForwardButtonVisible = property(get_IsFastForwardButtonVisible, put_IsFastForwardButtonVisible)
    IsFastForwardEnabled = property(get_IsFastForwardEnabled, put_IsFastForwardEnabled)
    IsFastRewindButtonVisible = property(get_IsFastRewindButtonVisible, put_IsFastRewindButtonVisible)
    IsFastRewindEnabled = property(get_IsFastRewindEnabled, put_IsFastRewindEnabled)
    IsNextTrackButtonVisible = property(get_IsNextTrackButtonVisible, put_IsNextTrackButtonVisible)
    IsPlaybackRateButtonVisible = property(get_IsPlaybackRateButtonVisible, put_IsPlaybackRateButtonVisible)
    IsPlaybackRateEnabled = property(get_IsPlaybackRateEnabled, put_IsPlaybackRateEnabled)
    IsPreviousTrackButtonVisible = property(get_IsPreviousTrackButtonVisible, put_IsPreviousTrackButtonVisible)
    IsRepeatButtonVisible = property(get_IsRepeatButtonVisible, put_IsRepeatButtonVisible)
    IsRepeatEnabled = property(get_IsRepeatEnabled, put_IsRepeatEnabled)
    IsSeekBarVisible = property(get_IsSeekBarVisible, put_IsSeekBarVisible)
    IsSeekEnabled = property(get_IsSeekEnabled, put_IsSeekEnabled)
    IsSkipBackwardButtonVisible = property(get_IsSkipBackwardButtonVisible, put_IsSkipBackwardButtonVisible)
    IsSkipBackwardEnabled = property(get_IsSkipBackwardEnabled, put_IsSkipBackwardEnabled)
    IsSkipForwardButtonVisible = property(get_IsSkipForwardButtonVisible, put_IsSkipForwardButtonVisible)
    IsSkipForwardEnabled = property(get_IsSkipForwardEnabled, put_IsSkipForwardEnabled)
    IsStopButtonVisible = property(get_IsStopButtonVisible, put_IsStopButtonVisible)
    IsStopEnabled = property(get_IsStopEnabled, put_IsStopEnabled)
    IsVolumeButtonVisible = property(get_IsVolumeButtonVisible, put_IsVolumeButtonVisible)
    IsVolumeEnabled = property(get_IsVolumeEnabled, put_IsVolumeEnabled)
    IsZoomButtonVisible = property(get_IsZoomButtonVisible, put_IsZoomButtonVisible)
    IsZoomEnabled = property(get_IsZoomEnabled, put_IsZoomEnabled)
    ShowAndHideAutomatically = property(get_ShowAndHideAutomatically, put_ShowAndHideAutomatically)
    ThumbnailRequested = event(add_ThumbnailRequested, remove_ThumbnailRequested)
class IMediaTransportControlsFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IMediaTransportControlsFactory'
    _iid_ = Guid('{a3f9a254-1bcf-57b5-9481-c19c4583ac0e}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.MediaTransportControls: ...
class IMediaTransportControlsHelper(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IMediaTransportControlsHelper'
    _iid_ = Guid('{89d393ba-0e04-5e24-b456-ab05429591e4}')
class IMediaTransportControlsHelperStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IMediaTransportControlsHelperStatics'
    _iid_ = Guid('{f1bf86f5-bc62-5722-bebd-a00102d857d3}')
    @winrt_commethod(6)
    def get_DropoutOrderProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def GetDropoutOrder(self, element: win32more.Microsoft.UI.Xaml.UIElement) -> win32more.Windows.Foundation.IReference[Int32]: ...
    @winrt_commethod(8)
    def SetDropoutOrder(self, element: win32more.Microsoft.UI.Xaml.UIElement, value: win32more.Windows.Foundation.IReference[Int32]) -> Void: ...
    DropoutOrderProperty = property(get_DropoutOrderProperty, None)
class IMediaTransportControlsStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IMediaTransportControlsStatics'
    _iid_ = Guid('{f497067e-7c41-5083-96c5-b6881d88b187}')
    @winrt_commethod(6)
    def get_IsZoomButtonVisibleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_IsZoomEnabledProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_IsFastForwardButtonVisibleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_IsFastForwardEnabledProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_IsFastRewindButtonVisibleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_IsFastRewindEnabledProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_IsStopButtonVisibleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_IsStopEnabledProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(14)
    def get_IsVolumeButtonVisibleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(15)
    def get_IsVolumeEnabledProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(16)
    def get_IsPlaybackRateButtonVisibleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(17)
    def get_IsPlaybackRateEnabledProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(18)
    def get_IsSeekBarVisibleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(19)
    def get_IsSeekEnabledProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(20)
    def get_IsCompactProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(21)
    def get_IsSkipForwardButtonVisibleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(22)
    def get_IsSkipForwardEnabledProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(23)
    def get_IsSkipBackwardButtonVisibleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(24)
    def get_IsSkipBackwardEnabledProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(25)
    def get_IsNextTrackButtonVisibleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(26)
    def get_IsPreviousTrackButtonVisibleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(27)
    def get_FastPlayFallbackBehaviourProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(28)
    def get_ShowAndHideAutomaticallyProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(29)
    def get_IsRepeatEnabledProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(30)
    def get_IsRepeatButtonVisibleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    FastPlayFallbackBehaviourProperty = property(get_FastPlayFallbackBehaviourProperty, None)
    IsCompactProperty = property(get_IsCompactProperty, None)
    IsFastForwardButtonVisibleProperty = property(get_IsFastForwardButtonVisibleProperty, None)
    IsFastForwardEnabledProperty = property(get_IsFastForwardEnabledProperty, None)
    IsFastRewindButtonVisibleProperty = property(get_IsFastRewindButtonVisibleProperty, None)
    IsFastRewindEnabledProperty = property(get_IsFastRewindEnabledProperty, None)
    IsNextTrackButtonVisibleProperty = property(get_IsNextTrackButtonVisibleProperty, None)
    IsPlaybackRateButtonVisibleProperty = property(get_IsPlaybackRateButtonVisibleProperty, None)
    IsPlaybackRateEnabledProperty = property(get_IsPlaybackRateEnabledProperty, None)
    IsPreviousTrackButtonVisibleProperty = property(get_IsPreviousTrackButtonVisibleProperty, None)
    IsRepeatButtonVisibleProperty = property(get_IsRepeatButtonVisibleProperty, None)
    IsRepeatEnabledProperty = property(get_IsRepeatEnabledProperty, None)
    IsSeekBarVisibleProperty = property(get_IsSeekBarVisibleProperty, None)
    IsSeekEnabledProperty = property(get_IsSeekEnabledProperty, None)
    IsSkipBackwardButtonVisibleProperty = property(get_IsSkipBackwardButtonVisibleProperty, None)
    IsSkipBackwardEnabledProperty = property(get_IsSkipBackwardEnabledProperty, None)
    IsSkipForwardButtonVisibleProperty = property(get_IsSkipForwardButtonVisibleProperty, None)
    IsSkipForwardEnabledProperty = property(get_IsSkipForwardEnabledProperty, None)
    IsStopButtonVisibleProperty = property(get_IsStopButtonVisibleProperty, None)
    IsStopEnabledProperty = property(get_IsStopEnabledProperty, None)
    IsVolumeButtonVisibleProperty = property(get_IsVolumeButtonVisibleProperty, None)
    IsVolumeEnabledProperty = property(get_IsVolumeEnabledProperty, None)
    IsZoomButtonVisibleProperty = property(get_IsZoomButtonVisibleProperty, None)
    IsZoomEnabledProperty = property(get_IsZoomEnabledProperty, None)
    ShowAndHideAutomaticallyProperty = property(get_ShowAndHideAutomaticallyProperty, None)
class IMenuBar(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IMenuBar'
    _iid_ = Guid('{ba97f337-8f1e-5141-b53f-e77a8ba3ebbd}')
    @winrt_commethod(6)
    def get_Items(self) -> win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.MenuBarItem]: ...
    Items = property(get_Items, None)
class IMenuBarFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IMenuBarFactory'
    _iid_ = Guid('{76aa8759-04ee-5a4c-b98c-d03742d47cdb}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.MenuBar: ...
class IMenuBarItem(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IMenuBarItem'
    _iid_ = Guid('{a7900980-51cc-531d-97c5-356b13573398}')
    @winrt_commethod(6)
    def get_Title(self) -> hstr: ...
    @winrt_commethod(7)
    def put_Title(self, value: hstr) -> Void: ...
    @winrt_commethod(8)
    def get_Items(self) -> win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.MenuFlyoutItemBase]: ...
    Items = property(get_Items, None)
    Title = property(get_Title, put_Title)
class IMenuBarItemFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IMenuBarItemFactory'
    _iid_ = Guid('{87d02172-83cb-5459-940f-173f7501b300}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.MenuBarItem: ...
class IMenuBarItemFlyout(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IMenuBarItemFlyout'
    _iid_ = Guid('{a412ae4f-c3bc-5679-8d5f-865eb97e83cd}')
class IMenuBarItemFlyoutFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IMenuBarItemFlyoutFactory'
    _iid_ = Guid('{f895123e-ed54-5a96-8418-f35e48505d43}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.MenuBarItemFlyout: ...
class IMenuBarItemStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IMenuBarItemStatics'
    _iid_ = Guid('{c8a33f46-2e1c-5ce0-bc09-4524e68941c8}')
    @winrt_commethod(6)
    def get_TitleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_ItemsProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    ItemsProperty = property(get_ItemsProperty, None)
    TitleProperty = property(get_TitleProperty, None)
class IMenuBarStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IMenuBarStatics'
    _iid_ = Guid('{79aa0b84-5554-5f7c-80d9-7970aa030125}')
    @winrt_commethod(6)
    def get_ItemsProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    ItemsProperty = property(get_ItemsProperty, None)
class IMenuFlyout(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IMenuFlyout'
    _iid_ = Guid('{f4c77c6c-1fa5-5d85-8559-5d02b7d4e5e7}')
    @winrt_commethod(6)
    def get_Items(self) -> win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.MenuFlyoutItemBase]: ...
    @winrt_commethod(7)
    def get_MenuFlyoutPresenterStyle(self) -> win32more.Microsoft.UI.Xaml.Style: ...
    @winrt_commethod(8)
    def put_MenuFlyoutPresenterStyle(self, value: win32more.Microsoft.UI.Xaml.Style) -> Void: ...
    @winrt_commethod(9)
    def ShowAt(self, targetElement: win32more.Microsoft.UI.Xaml.UIElement, point: win32more.Windows.Foundation.Point) -> Void: ...
    Items = property(get_Items, None)
    MenuFlyoutPresenterStyle = property(get_MenuFlyoutPresenterStyle, put_MenuFlyoutPresenterStyle)
class IMenuFlyoutFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IMenuFlyoutFactory'
    _iid_ = Guid('{a3d225de-6b35-5442-b6c9-06fd24139a63}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.MenuFlyout: ...
class IMenuFlyoutItem(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IMenuFlyoutItem'
    _iid_ = Guid('{4252df5a-44f9-5ee8-b1cc-53de9aaa4095}')
    @winrt_commethod(6)
    def get_Text(self) -> hstr: ...
    @winrt_commethod(7)
    def put_Text(self, value: hstr) -> Void: ...
    @winrt_commethod(8)
    def get_Command(self) -> win32more.Microsoft.UI.Xaml.Input.ICommand: ...
    @winrt_commethod(9)
    def put_Command(self, value: win32more.Microsoft.UI.Xaml.Input.ICommand) -> Void: ...
    @winrt_commethod(10)
    def get_CommandParameter(self) -> IInspectable: ...
    @winrt_commethod(11)
    def put_CommandParameter(self, value: IInspectable) -> Void: ...
    @winrt_commethod(12)
    def get_Icon(self) -> win32more.Microsoft.UI.Xaml.Controls.IconElement: ...
    @winrt_commethod(13)
    def put_Icon(self, value: win32more.Microsoft.UI.Xaml.Controls.IconElement) -> Void: ...
    @winrt_commethod(14)
    def get_KeyboardAcceleratorTextOverride(self) -> hstr: ...
    @winrt_commethod(15)
    def put_KeyboardAcceleratorTextOverride(self, value: hstr) -> Void: ...
    @winrt_commethod(16)
    def get_TemplateSettings(self) -> win32more.Microsoft.UI.Xaml.Controls.Primitives.MenuFlyoutItemTemplateSettings: ...
    @winrt_commethod(17)
    def add_Click(self, handler: win32more.Microsoft.UI.Xaml.RoutedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(18)
    def remove_Click(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    Command = property(get_Command, put_Command)
    CommandParameter = property(get_CommandParameter, put_CommandParameter)
    Icon = property(get_Icon, put_Icon)
    KeyboardAcceleratorTextOverride = property(get_KeyboardAcceleratorTextOverride, put_KeyboardAcceleratorTextOverride)
    TemplateSettings = property(get_TemplateSettings, None)
    Text = property(get_Text, put_Text)
    Click = event(add_Click, remove_Click)
class IMenuFlyoutItemBase(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IMenuFlyoutItemBase'
    _iid_ = Guid('{4bee2715-44a1-5f94-86e8-02ddbe3dc6b9}')
class IMenuFlyoutItemBaseFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IMenuFlyoutItemBaseFactory'
    _iid_ = Guid('{33f4ead3-ab54-505d-bc5f-45e7c35f20f8}')
class IMenuFlyoutItemFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IMenuFlyoutItemFactory'
    _iid_ = Guid('{9c3c9a1f-89af-521a-81a5-8a01db7a79af}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.MenuFlyoutItem: ...
class IMenuFlyoutItemStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IMenuFlyoutItemStatics'
    _iid_ = Guid('{9d7953d6-e6a6-5154-91f4-67f4d6042a4f}')
    @winrt_commethod(6)
    def get_TextProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_CommandProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_CommandParameterProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_IconProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_KeyboardAcceleratorTextOverrideProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    CommandParameterProperty = property(get_CommandParameterProperty, None)
    CommandProperty = property(get_CommandProperty, None)
    IconProperty = property(get_IconProperty, None)
    KeyboardAcceleratorTextOverrideProperty = property(get_KeyboardAcceleratorTextOverrideProperty, None)
    TextProperty = property(get_TextProperty, None)
class IMenuFlyoutPresenter(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IMenuFlyoutPresenter'
    _iid_ = Guid('{5c9b4644-e292-5436-86ec-1c0e29f94c2d}')
    @winrt_commethod(6)
    def get_TemplateSettings(self) -> win32more.Microsoft.UI.Xaml.Controls.Primitives.MenuFlyoutPresenterTemplateSettings: ...
    @winrt_commethod(7)
    def get_IsDefaultShadowEnabled(self) -> Boolean: ...
    @winrt_commethod(8)
    def put_IsDefaultShadowEnabled(self, value: Boolean) -> Void: ...
    IsDefaultShadowEnabled = property(get_IsDefaultShadowEnabled, put_IsDefaultShadowEnabled)
    TemplateSettings = property(get_TemplateSettings, None)
class IMenuFlyoutPresenter2(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IMenuFlyoutPresenter2'
    _iid_ = Guid('{3e3aaf6b-0cc9-5d5c-86c1-05f53fab67e8}')
    @winrt_commethod(6)
    def get_SystemBackdrop(self) -> win32more.Microsoft.UI.Xaml.Media.SystemBackdrop: ...
    @winrt_commethod(7)
    def put_SystemBackdrop(self, value: win32more.Microsoft.UI.Xaml.Media.SystemBackdrop) -> Void: ...
    SystemBackdrop = property(get_SystemBackdrop, put_SystemBackdrop)
class IMenuFlyoutPresenterFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IMenuFlyoutPresenterFactory'
    _iid_ = Guid('{0dfb684d-c60d-5771-b490-2c8612c48400}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.MenuFlyoutPresenter: ...
class IMenuFlyoutPresenterStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IMenuFlyoutPresenterStatics'
    _iid_ = Guid('{7de3d28d-bd8b-5fed-a2e2-b9beae56ff24}')
    @winrt_commethod(6)
    def get_IsDefaultShadowEnabledProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    IsDefaultShadowEnabledProperty = property(get_IsDefaultShadowEnabledProperty, None)
class IMenuFlyoutPresenterStatics2(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IMenuFlyoutPresenterStatics2'
    _iid_ = Guid('{61153ddf-024d-50b8-9684-b15b8b756943}')
    @winrt_commethod(6)
    def get_SystemBackdropProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    SystemBackdropProperty = property(get_SystemBackdropProperty, None)
class IMenuFlyoutSeparator(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IMenuFlyoutSeparator'
    _iid_ = Guid('{3eaf5fd5-935e-5ed7-8d05-f6bafa936d25}')
class IMenuFlyoutSeparatorFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IMenuFlyoutSeparatorFactory'
    _iid_ = Guid('{26156c9c-95ef-5e55-8342-773fc43baac3}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.MenuFlyoutSeparator: ...
class IMenuFlyoutStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IMenuFlyoutStatics'
    _iid_ = Guid('{6959e683-16f6-5208-84e0-b0be92d9f6dd}')
    @winrt_commethod(6)
    def get_MenuFlyoutPresenterStyleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    MenuFlyoutPresenterStyleProperty = property(get_MenuFlyoutPresenterStyleProperty, None)
class IMenuFlyoutSubItem(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IMenuFlyoutSubItem'
    _iid_ = Guid('{6b0688c1-47b0-53b5-b6f9-5ec5d6623b84}')
    @winrt_commethod(6)
    def get_Items(self) -> win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.MenuFlyoutItemBase]: ...
    @winrt_commethod(7)
    def get_Text(self) -> hstr: ...
    @winrt_commethod(8)
    def put_Text(self, value: hstr) -> Void: ...
    @winrt_commethod(9)
    def get_Icon(self) -> win32more.Microsoft.UI.Xaml.Controls.IconElement: ...
    @winrt_commethod(10)
    def put_Icon(self, value: win32more.Microsoft.UI.Xaml.Controls.IconElement) -> Void: ...
    Icon = property(get_Icon, put_Icon)
    Items = property(get_Items, None)
    Text = property(get_Text, put_Text)
class IMenuFlyoutSubItemStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IMenuFlyoutSubItemStatics'
    _iid_ = Guid('{f59a8ddf-804b-5f56-bc42-f27f987db291}')
    @winrt_commethod(6)
    def get_TextProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_IconProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    IconProperty = property(get_IconProperty, None)
    TextProperty = property(get_TextProperty, None)
class INavigate(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.INavigate'
    _iid_ = Guid('{dd06f030-5d47-533c-95cf-de256a0f373a}')
    @winrt_commethod(6)
    def Navigate(self, sourcePageType: win32more.Windows.UI.Xaml.Interop.TypeName) -> Boolean: ...
class INavigationView(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.INavigationView'
    _iid_ = Guid('{e77a4b36-3dd1-53d9-9f97-65dccaa74a5c}')
    @winrt_commethod(6)
    def get_IsPaneOpen(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_IsPaneOpen(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def get_CompactModeThresholdWidth(self) -> Double: ...
    @winrt_commethod(9)
    def put_CompactModeThresholdWidth(self, value: Double) -> Void: ...
    @winrt_commethod(10)
    def get_ExpandedModeThresholdWidth(self) -> Double: ...
    @winrt_commethod(11)
    def put_ExpandedModeThresholdWidth(self, value: Double) -> Void: ...
    @winrt_commethod(12)
    def get_FooterMenuItems(self) -> win32more.Windows.Foundation.Collections.IVector[IInspectable]: ...
    @winrt_commethod(13)
    def get_FooterMenuItemsSource(self) -> IInspectable: ...
    @winrt_commethod(14)
    def put_FooterMenuItemsSource(self, value: IInspectable) -> Void: ...
    @winrt_commethod(15)
    def get_PaneFooter(self) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_commethod(16)
    def put_PaneFooter(self, value: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    @winrt_commethod(17)
    def get_Header(self) -> IInspectable: ...
    @winrt_commethod(18)
    def put_Header(self, value: IInspectable) -> Void: ...
    @winrt_commethod(19)
    def get_HeaderTemplate(self) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_commethod(20)
    def put_HeaderTemplate(self, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_commethod(21)
    def get_DisplayMode(self) -> win32more.Microsoft.UI.Xaml.Controls.NavigationViewDisplayMode: ...
    @winrt_commethod(22)
    def get_IsSettingsVisible(self) -> Boolean: ...
    @winrt_commethod(23)
    def put_IsSettingsVisible(self, value: Boolean) -> Void: ...
    @winrt_commethod(24)
    def get_IsPaneToggleButtonVisible(self) -> Boolean: ...
    @winrt_commethod(25)
    def put_IsPaneToggleButtonVisible(self, value: Boolean) -> Void: ...
    @winrt_commethod(26)
    def get_AlwaysShowHeader(self) -> Boolean: ...
    @winrt_commethod(27)
    def put_AlwaysShowHeader(self, value: Boolean) -> Void: ...
    @winrt_commethod(28)
    def get_CompactPaneLength(self) -> Double: ...
    @winrt_commethod(29)
    def put_CompactPaneLength(self, value: Double) -> Void: ...
    @winrt_commethod(30)
    def get_OpenPaneLength(self) -> Double: ...
    @winrt_commethod(31)
    def put_OpenPaneLength(self, value: Double) -> Void: ...
    @winrt_commethod(32)
    def get_PaneToggleButtonStyle(self) -> win32more.Microsoft.UI.Xaml.Style: ...
    @winrt_commethod(33)
    def put_PaneToggleButtonStyle(self, value: win32more.Microsoft.UI.Xaml.Style) -> Void: ...
    @winrt_commethod(34)
    def get_SelectedItem(self) -> IInspectable: ...
    @winrt_commethod(35)
    def put_SelectedItem(self, value: IInspectable) -> Void: ...
    @winrt_commethod(36)
    def get_MenuItems(self) -> win32more.Windows.Foundation.Collections.IVector[IInspectable]: ...
    @winrt_commethod(37)
    def get_MenuItemsSource(self) -> IInspectable: ...
    @winrt_commethod(38)
    def put_MenuItemsSource(self, value: IInspectable) -> Void: ...
    @winrt_commethod(39)
    def get_SettingsItem(self) -> IInspectable: ...
    @winrt_commethod(40)
    def get_AutoSuggestBox(self) -> win32more.Microsoft.UI.Xaml.Controls.AutoSuggestBox: ...
    @winrt_commethod(41)
    def put_AutoSuggestBox(self, value: win32more.Microsoft.UI.Xaml.Controls.AutoSuggestBox) -> Void: ...
    @winrt_commethod(42)
    def get_MenuItemTemplate(self) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_commethod(43)
    def put_MenuItemTemplate(self, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_commethod(44)
    def get_MenuItemTemplateSelector(self) -> win32more.Microsoft.UI.Xaml.Controls.DataTemplateSelector: ...
    @winrt_commethod(45)
    def put_MenuItemTemplateSelector(self, value: win32more.Microsoft.UI.Xaml.Controls.DataTemplateSelector) -> Void: ...
    @winrt_commethod(46)
    def get_MenuItemContainerStyle(self) -> win32more.Microsoft.UI.Xaml.Style: ...
    @winrt_commethod(47)
    def put_MenuItemContainerStyle(self, value: win32more.Microsoft.UI.Xaml.Style) -> Void: ...
    @winrt_commethod(48)
    def get_MenuItemContainerStyleSelector(self) -> win32more.Microsoft.UI.Xaml.Controls.StyleSelector: ...
    @winrt_commethod(49)
    def put_MenuItemContainerStyleSelector(self, value: win32more.Microsoft.UI.Xaml.Controls.StyleSelector) -> Void: ...
    @winrt_commethod(50)
    def MenuItemFromContainer(self, container: win32more.Microsoft.UI.Xaml.DependencyObject) -> IInspectable: ...
    @winrt_commethod(51)
    def ContainerFromMenuItem(self, item: IInspectable) -> win32more.Microsoft.UI.Xaml.DependencyObject: ...
    @winrt_commethod(52)
    def add_SelectionChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.NavigationView, win32more.Microsoft.UI.Xaml.Controls.NavigationViewSelectionChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(53)
    def remove_SelectionChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(54)
    def add_ItemInvoked(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.NavigationView, win32more.Microsoft.UI.Xaml.Controls.NavigationViewItemInvokedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(55)
    def remove_ItemInvoked(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(56)
    def add_DisplayModeChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.NavigationView, win32more.Microsoft.UI.Xaml.Controls.NavigationViewDisplayModeChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(57)
    def remove_DisplayModeChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(58)
    def get_IsTitleBarAutoPaddingEnabled(self) -> Boolean: ...
    @winrt_commethod(59)
    def put_IsTitleBarAutoPaddingEnabled(self, value: Boolean) -> Void: ...
    AlwaysShowHeader = property(get_AlwaysShowHeader, put_AlwaysShowHeader)
    AutoSuggestBox = property(get_AutoSuggestBox, put_AutoSuggestBox)
    CompactModeThresholdWidth = property(get_CompactModeThresholdWidth, put_CompactModeThresholdWidth)
    CompactPaneLength = property(get_CompactPaneLength, put_CompactPaneLength)
    DisplayMode = property(get_DisplayMode, None)
    ExpandedModeThresholdWidth = property(get_ExpandedModeThresholdWidth, put_ExpandedModeThresholdWidth)
    FooterMenuItems = property(get_FooterMenuItems, None)
    FooterMenuItemsSource = property(get_FooterMenuItemsSource, put_FooterMenuItemsSource)
    Header = property(get_Header, put_Header)
    HeaderTemplate = property(get_HeaderTemplate, put_HeaderTemplate)
    IsPaneOpen = property(get_IsPaneOpen, put_IsPaneOpen)
    IsPaneToggleButtonVisible = property(get_IsPaneToggleButtonVisible, put_IsPaneToggleButtonVisible)
    IsSettingsVisible = property(get_IsSettingsVisible, put_IsSettingsVisible)
    IsTitleBarAutoPaddingEnabled = property(get_IsTitleBarAutoPaddingEnabled, put_IsTitleBarAutoPaddingEnabled)
    MenuItemContainerStyle = property(get_MenuItemContainerStyle, put_MenuItemContainerStyle)
    MenuItemContainerStyleSelector = property(get_MenuItemContainerStyleSelector, put_MenuItemContainerStyleSelector)
    MenuItemTemplate = property(get_MenuItemTemplate, put_MenuItemTemplate)
    MenuItemTemplateSelector = property(get_MenuItemTemplateSelector, put_MenuItemTemplateSelector)
    MenuItems = property(get_MenuItems, None)
    MenuItemsSource = property(get_MenuItemsSource, put_MenuItemsSource)
    OpenPaneLength = property(get_OpenPaneLength, put_OpenPaneLength)
    PaneFooter = property(get_PaneFooter, put_PaneFooter)
    PaneToggleButtonStyle = property(get_PaneToggleButtonStyle, put_PaneToggleButtonStyle)
    SelectedItem = property(get_SelectedItem, put_SelectedItem)
    SettingsItem = property(get_SettingsItem, None)
    DisplayModeChanged = event(add_DisplayModeChanged, remove_DisplayModeChanged)
    ItemInvoked = event(add_ItemInvoked, remove_ItemInvoked)
    SelectionChanged = event(add_SelectionChanged, remove_SelectionChanged)
class INavigationView2(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.INavigationView2'
    _iid_ = Guid('{05b428cf-014c-56dd-896a-a3e7089d73b5}')
    @winrt_commethod(6)
    def get_IsBackButtonVisible(self) -> win32more.Microsoft.UI.Xaml.Controls.NavigationViewBackButtonVisible: ...
    @winrt_commethod(7)
    def put_IsBackButtonVisible(self, value: win32more.Microsoft.UI.Xaml.Controls.NavigationViewBackButtonVisible) -> Void: ...
    @winrt_commethod(8)
    def get_IsBackEnabled(self) -> Boolean: ...
    @winrt_commethod(9)
    def put_IsBackEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(10)
    def get_PaneTitle(self) -> hstr: ...
    @winrt_commethod(11)
    def put_PaneTitle(self, value: hstr) -> Void: ...
    @winrt_commethod(12)
    def add_BackRequested(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.NavigationView, win32more.Microsoft.UI.Xaml.Controls.NavigationViewBackRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(13)
    def remove_BackRequested(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(14)
    def add_PaneClosed(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.NavigationView, IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(15)
    def remove_PaneClosed(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(16)
    def add_PaneClosing(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.NavigationView, win32more.Microsoft.UI.Xaml.Controls.NavigationViewPaneClosingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(17)
    def remove_PaneClosing(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(18)
    def add_PaneOpened(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.NavigationView, IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(19)
    def remove_PaneOpened(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(20)
    def add_PaneOpening(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.NavigationView, IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(21)
    def remove_PaneOpening(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(22)
    def get_PaneDisplayMode(self) -> win32more.Microsoft.UI.Xaml.Controls.NavigationViewPaneDisplayMode: ...
    @winrt_commethod(23)
    def put_PaneDisplayMode(self, value: win32more.Microsoft.UI.Xaml.Controls.NavigationViewPaneDisplayMode) -> Void: ...
    @winrt_commethod(24)
    def get_PaneHeader(self) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_commethod(25)
    def put_PaneHeader(self, value: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    @winrt_commethod(26)
    def get_PaneCustomContent(self) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_commethod(27)
    def put_PaneCustomContent(self, value: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    @winrt_commethod(28)
    def get_ContentOverlay(self) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_commethod(29)
    def put_ContentOverlay(self, value: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    @winrt_commethod(30)
    def get_IsPaneVisible(self) -> Boolean: ...
    @winrt_commethod(31)
    def put_IsPaneVisible(self, value: Boolean) -> Void: ...
    @winrt_commethod(32)
    def get_SelectionFollowsFocus(self) -> win32more.Microsoft.UI.Xaml.Controls.NavigationViewSelectionFollowsFocus: ...
    @winrt_commethod(33)
    def put_SelectionFollowsFocus(self, value: win32more.Microsoft.UI.Xaml.Controls.NavigationViewSelectionFollowsFocus) -> Void: ...
    @winrt_commethod(34)
    def get_TemplateSettings(self) -> win32more.Microsoft.UI.Xaml.Controls.NavigationViewTemplateSettings: ...
    @winrt_commethod(35)
    def get_ShoulderNavigationEnabled(self) -> win32more.Microsoft.UI.Xaml.Controls.NavigationViewShoulderNavigationEnabled: ...
    @winrt_commethod(36)
    def put_ShoulderNavigationEnabled(self, value: win32more.Microsoft.UI.Xaml.Controls.NavigationViewShoulderNavigationEnabled) -> Void: ...
    @winrt_commethod(37)
    def get_OverflowLabelMode(self) -> win32more.Microsoft.UI.Xaml.Controls.NavigationViewOverflowLabelMode: ...
    @winrt_commethod(38)
    def put_OverflowLabelMode(self, value: win32more.Microsoft.UI.Xaml.Controls.NavigationViewOverflowLabelMode) -> Void: ...
    @winrt_commethod(39)
    def add_Expanding(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.NavigationView, win32more.Microsoft.UI.Xaml.Controls.NavigationViewItemExpandingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(40)
    def remove_Expanding(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(41)
    def add_Collapsed(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.NavigationView, win32more.Microsoft.UI.Xaml.Controls.NavigationViewItemCollapsedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(42)
    def remove_Collapsed(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(43)
    def Expand(self, item: win32more.Microsoft.UI.Xaml.Controls.NavigationViewItem) -> Void: ...
    @winrt_commethod(44)
    def Collapse(self, item: win32more.Microsoft.UI.Xaml.Controls.NavigationViewItem) -> Void: ...
    ContentOverlay = property(get_ContentOverlay, put_ContentOverlay)
    IsBackButtonVisible = property(get_IsBackButtonVisible, put_IsBackButtonVisible)
    IsBackEnabled = property(get_IsBackEnabled, put_IsBackEnabled)
    IsPaneVisible = property(get_IsPaneVisible, put_IsPaneVisible)
    OverflowLabelMode = property(get_OverflowLabelMode, put_OverflowLabelMode)
    PaneCustomContent = property(get_PaneCustomContent, put_PaneCustomContent)
    PaneDisplayMode = property(get_PaneDisplayMode, put_PaneDisplayMode)
    PaneHeader = property(get_PaneHeader, put_PaneHeader)
    PaneTitle = property(get_PaneTitle, put_PaneTitle)
    SelectionFollowsFocus = property(get_SelectionFollowsFocus, put_SelectionFollowsFocus)
    ShoulderNavigationEnabled = property(get_ShoulderNavigationEnabled, put_ShoulderNavigationEnabled)
    TemplateSettings = property(get_TemplateSettings, None)
    BackRequested = event(add_BackRequested, remove_BackRequested)
    Collapsed = event(add_Collapsed, remove_Collapsed)
    Expanding = event(add_Expanding, remove_Expanding)
    PaneClosed = event(add_PaneClosed, remove_PaneClosed)
    PaneClosing = event(add_PaneClosing, remove_PaneClosing)
    PaneOpened = event(add_PaneOpened, remove_PaneOpened)
    PaneOpening = event(add_PaneOpening, remove_PaneOpening)
class INavigationViewBackRequestedEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.INavigationViewBackRequestedEventArgs'
    _iid_ = Guid('{ae752207-bd1b-5afa-a872-e9bbaeea0ede}')
class INavigationViewDisplayModeChangedEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.INavigationViewDisplayModeChangedEventArgs'
    _iid_ = Guid('{58dcf1ea-9e56-522c-b3f8-34bd55ecaca4}')
    @winrt_commethod(6)
    def get_DisplayMode(self) -> win32more.Microsoft.UI.Xaml.Controls.NavigationViewDisplayMode: ...
    DisplayMode = property(get_DisplayMode, None)
class INavigationViewFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.INavigationViewFactory'
    _iid_ = Guid('{ffea1ada-9232-5507-a320-ed2fadbe6127}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.NavigationView: ...
class INavigationViewItem(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.INavigationViewItem'
    _iid_ = Guid('{3ab3d503-a37c-5836-8adb-2882062e73a1}')
    @winrt_commethod(6)
    def get_Icon(self) -> win32more.Microsoft.UI.Xaml.Controls.IconElement: ...
    @winrt_commethod(7)
    def put_Icon(self, value: win32more.Microsoft.UI.Xaml.Controls.IconElement) -> Void: ...
    @winrt_commethod(8)
    def get_CompactPaneLength(self) -> Double: ...
    CompactPaneLength = property(get_CompactPaneLength, None)
    Icon = property(get_Icon, put_Icon)
class INavigationViewItem2(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.INavigationViewItem2'
    _iid_ = Guid('{2d5bd889-9dac-5675-b254-68226f077a61}')
    @winrt_commethod(6)
    def get_SelectsOnInvoked(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_SelectsOnInvoked(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def get_IsExpanded(self) -> Boolean: ...
    @winrt_commethod(9)
    def put_IsExpanded(self, value: Boolean) -> Void: ...
    @winrt_commethod(10)
    def get_HasUnrealizedChildren(self) -> Boolean: ...
    @winrt_commethod(11)
    def put_HasUnrealizedChildren(self, value: Boolean) -> Void: ...
    @winrt_commethod(12)
    def get_IsChildSelected(self) -> Boolean: ...
    @winrt_commethod(13)
    def put_IsChildSelected(self, value: Boolean) -> Void: ...
    @winrt_commethod(14)
    def get_MenuItems(self) -> win32more.Windows.Foundation.Collections.IVector[IInspectable]: ...
    @winrt_commethod(15)
    def get_MenuItemsSource(self) -> IInspectable: ...
    @winrt_commethod(16)
    def put_MenuItemsSource(self, value: IInspectable) -> Void: ...
    HasUnrealizedChildren = property(get_HasUnrealizedChildren, put_HasUnrealizedChildren)
    IsChildSelected = property(get_IsChildSelected, put_IsChildSelected)
    IsExpanded = property(get_IsExpanded, put_IsExpanded)
    MenuItems = property(get_MenuItems, None)
    MenuItemsSource = property(get_MenuItemsSource, put_MenuItemsSource)
    SelectsOnInvoked = property(get_SelectsOnInvoked, put_SelectsOnInvoked)
class INavigationViewItem3(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.INavigationViewItem3'
    _iid_ = Guid('{c6aa3120-d888-5c32-8bb7-490ec91b1aec}')
    @winrt_commethod(6)
    def get_InfoBadge(self) -> win32more.Microsoft.UI.Xaml.Controls.InfoBadge: ...
    @winrt_commethod(7)
    def put_InfoBadge(self, value: win32more.Microsoft.UI.Xaml.Controls.InfoBadge) -> Void: ...
    InfoBadge = property(get_InfoBadge, put_InfoBadge)
class INavigationViewItemBase(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.INavigationViewItemBase'
    _iid_ = Guid('{33586494-af48-513f-be4d-f645e8c89005}')
class INavigationViewItemBase2(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.INavigationViewItemBase2'
    _iid_ = Guid('{d94ee683-d437-5523-9c5c-11d4804e471e}')
    @winrt_commethod(6)
    def get_IsSelected(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_IsSelected(self, value: Boolean) -> Void: ...
    IsSelected = property(get_IsSelected, put_IsSelected)
class INavigationViewItemBaseFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.INavigationViewItemBaseFactory'
    _iid_ = Guid('{31b9d7b1-7c38-5916-99c6-c71f6b012b1b}')
class INavigationViewItemBaseStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.INavigationViewItemBaseStatics'
    _iid_ = Guid('{71a0c438-f0c2-5093-8906-c1c3c02de791}')
    @winrt_commethod(6)
    def get_IsSelectedProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    IsSelectedProperty = property(get_IsSelectedProperty, None)
class INavigationViewItemCollapsedEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.INavigationViewItemCollapsedEventArgs'
    _iid_ = Guid('{b546f6a1-c66f-5ded-b5d7-bed0a26197e3}')
    @winrt_commethod(6)
    def get_CollapsedItemContainer(self) -> win32more.Microsoft.UI.Xaml.Controls.NavigationViewItemBase: ...
    @winrt_commethod(7)
    def get_CollapsedItem(self) -> IInspectable: ...
    CollapsedItem = property(get_CollapsedItem, None)
    CollapsedItemContainer = property(get_CollapsedItemContainer, None)
class INavigationViewItemExpandingEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.INavigationViewItemExpandingEventArgs'
    _iid_ = Guid('{6f0941be-e991-52f8-8315-f08389497976}')
    @winrt_commethod(6)
    def get_ExpandingItemContainer(self) -> win32more.Microsoft.UI.Xaml.Controls.NavigationViewItemBase: ...
    @winrt_commethod(7)
    def get_ExpandingItem(self) -> IInspectable: ...
    ExpandingItem = property(get_ExpandingItem, None)
    ExpandingItemContainer = property(get_ExpandingItemContainer, None)
class INavigationViewItemFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.INavigationViewItemFactory'
    _iid_ = Guid('{de60a001-9385-5535-80e1-2b68f4bfde26}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.NavigationViewItem: ...
class INavigationViewItemHeader(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.INavigationViewItemHeader'
    _iid_ = Guid('{432bc062-45bc-57ef-a2d3-11851a56a882}')
class INavigationViewItemHeaderFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.INavigationViewItemHeaderFactory'
    _iid_ = Guid('{6a5447cd-2918-5fe3-899b-93d6961285e6}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.NavigationViewItemHeader: ...
class INavigationViewItemInvokedEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.INavigationViewItemInvokedEventArgs'
    _iid_ = Guid('{074cebaa-5d05-547b-8cd6-d19ac2d9bb3b}')
    @winrt_commethod(6)
    def get_InvokedItem(self) -> IInspectable: ...
    @winrt_commethod(7)
    def get_IsSettingsInvoked(self) -> Boolean: ...
    InvokedItem = property(get_InvokedItem, None)
    IsSettingsInvoked = property(get_IsSettingsInvoked, None)
class INavigationViewItemInvokedEventArgs2(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.INavigationViewItemInvokedEventArgs2'
    _iid_ = Guid('{e1cbb99f-19eb-5c7b-b982-854bb08d5eb7}')
    @winrt_commethod(6)
    def get_InvokedItemContainer(self) -> win32more.Microsoft.UI.Xaml.Controls.NavigationViewItemBase: ...
    @winrt_commethod(7)
    def get_RecommendedNavigationTransitionInfo(self) -> win32more.Microsoft.UI.Xaml.Media.Animation.NavigationTransitionInfo: ...
    InvokedItemContainer = property(get_InvokedItemContainer, None)
    RecommendedNavigationTransitionInfo = property(get_RecommendedNavigationTransitionInfo, None)
class INavigationViewItemSeparator(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.INavigationViewItemSeparator'
    _iid_ = Guid('{e3c35630-1d5f-5689-a0cb-8794485caacf}')
class INavigationViewItemSeparatorFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.INavigationViewItemSeparatorFactory'
    _iid_ = Guid('{181266a1-d4f8-5af7-810b-aee8a1d452ed}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.NavigationViewItemSeparator: ...
class INavigationViewItemStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.INavigationViewItemStatics'
    _iid_ = Guid('{7b6198e5-0714-531c-a056-21b3ca40ec1a}')
    @winrt_commethod(6)
    def get_IconProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_CompactPaneLengthProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    CompactPaneLengthProperty = property(get_CompactPaneLengthProperty, None)
    IconProperty = property(get_IconProperty, None)
class INavigationViewItemStatics2(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.INavigationViewItemStatics2'
    _iid_ = Guid('{d49d016f-abd0-51f3-acf0-118ecceea760}')
    @winrt_commethod(6)
    def get_SelectsOnInvokedProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_IsExpandedProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_HasUnrealizedChildrenProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_IsChildSelectedProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_MenuItemsProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_MenuItemsSourceProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    HasUnrealizedChildrenProperty = property(get_HasUnrealizedChildrenProperty, None)
    IsChildSelectedProperty = property(get_IsChildSelectedProperty, None)
    IsExpandedProperty = property(get_IsExpandedProperty, None)
    MenuItemsProperty = property(get_MenuItemsProperty, None)
    MenuItemsSourceProperty = property(get_MenuItemsSourceProperty, None)
    SelectsOnInvokedProperty = property(get_SelectsOnInvokedProperty, None)
class INavigationViewItemStatics3(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.INavigationViewItemStatics3'
    _iid_ = Guid('{957beb66-d33a-53aa-a518-7d426bb9b177}')
    @winrt_commethod(6)
    def get_InfoBadgeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    InfoBadgeProperty = property(get_InfoBadgeProperty, None)
class INavigationViewPaneClosingEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.INavigationViewPaneClosingEventArgs'
    _iid_ = Guid('{e8643304-6db4-5af5-bac2-62733ca037da}')
    @winrt_commethod(6)
    def get_Cancel(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_Cancel(self, value: Boolean) -> Void: ...
    Cancel = property(get_Cancel, put_Cancel)
class INavigationViewSelectionChangedEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.INavigationViewSelectionChangedEventArgs'
    _iid_ = Guid('{14a064a5-c79d-5f63-ac6e-1c313fe63566}')
    @winrt_commethod(6)
    def get_SelectedItem(self) -> IInspectable: ...
    @winrt_commethod(7)
    def get_IsSettingsSelected(self) -> Boolean: ...
    IsSettingsSelected = property(get_IsSettingsSelected, None)
    SelectedItem = property(get_SelectedItem, None)
class INavigationViewSelectionChangedEventArgs2(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.INavigationViewSelectionChangedEventArgs2'
    _iid_ = Guid('{e9b5191f-1ad1-5366-bc1a-90b96076d49e}')
    @winrt_commethod(6)
    def get_SelectedItemContainer(self) -> win32more.Microsoft.UI.Xaml.Controls.NavigationViewItemBase: ...
    @winrt_commethod(7)
    def get_RecommendedNavigationTransitionInfo(self) -> win32more.Microsoft.UI.Xaml.Media.Animation.NavigationTransitionInfo: ...
    RecommendedNavigationTransitionInfo = property(get_RecommendedNavigationTransitionInfo, None)
    SelectedItemContainer = property(get_SelectedItemContainer, None)
class INavigationViewStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.INavigationViewStatics'
    _iid_ = Guid('{dcd04caf-1904-564b-b0de-babaff9962f5}')
    @winrt_commethod(6)
    def get_IsPaneOpenProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_CompactModeThresholdWidthProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_ExpandedModeThresholdWidthProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_FooterMenuItemsProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_FooterMenuItemsSourceProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_PaneFooterProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_HeaderProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_HeaderTemplateProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(14)
    def get_DisplayModeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(15)
    def get_IsSettingsVisibleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(16)
    def get_IsPaneToggleButtonVisibleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(17)
    def get_AlwaysShowHeaderProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(18)
    def get_CompactPaneLengthProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(19)
    def get_OpenPaneLengthProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(20)
    def get_PaneToggleButtonStyleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(21)
    def get_MenuItemsProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(22)
    def get_MenuItemsSourceProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(23)
    def get_SelectedItemProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(24)
    def get_SettingsItemProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(25)
    def get_AutoSuggestBoxProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(26)
    def get_MenuItemTemplateProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(27)
    def get_MenuItemTemplateSelectorProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(28)
    def get_MenuItemContainerStyleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(29)
    def get_MenuItemContainerStyleSelectorProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(30)
    def get_IsTitleBarAutoPaddingEnabledProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    AlwaysShowHeaderProperty = property(get_AlwaysShowHeaderProperty, None)
    AutoSuggestBoxProperty = property(get_AutoSuggestBoxProperty, None)
    CompactModeThresholdWidthProperty = property(get_CompactModeThresholdWidthProperty, None)
    CompactPaneLengthProperty = property(get_CompactPaneLengthProperty, None)
    DisplayModeProperty = property(get_DisplayModeProperty, None)
    ExpandedModeThresholdWidthProperty = property(get_ExpandedModeThresholdWidthProperty, None)
    FooterMenuItemsProperty = property(get_FooterMenuItemsProperty, None)
    FooterMenuItemsSourceProperty = property(get_FooterMenuItemsSourceProperty, None)
    HeaderProperty = property(get_HeaderProperty, None)
    HeaderTemplateProperty = property(get_HeaderTemplateProperty, None)
    IsPaneOpenProperty = property(get_IsPaneOpenProperty, None)
    IsPaneToggleButtonVisibleProperty = property(get_IsPaneToggleButtonVisibleProperty, None)
    IsSettingsVisibleProperty = property(get_IsSettingsVisibleProperty, None)
    IsTitleBarAutoPaddingEnabledProperty = property(get_IsTitleBarAutoPaddingEnabledProperty, None)
    MenuItemContainerStyleProperty = property(get_MenuItemContainerStyleProperty, None)
    MenuItemContainerStyleSelectorProperty = property(get_MenuItemContainerStyleSelectorProperty, None)
    MenuItemTemplateProperty = property(get_MenuItemTemplateProperty, None)
    MenuItemTemplateSelectorProperty = property(get_MenuItemTemplateSelectorProperty, None)
    MenuItemsProperty = property(get_MenuItemsProperty, None)
    MenuItemsSourceProperty = property(get_MenuItemsSourceProperty, None)
    OpenPaneLengthProperty = property(get_OpenPaneLengthProperty, None)
    PaneFooterProperty = property(get_PaneFooterProperty, None)
    PaneToggleButtonStyleProperty = property(get_PaneToggleButtonStyleProperty, None)
    SelectedItemProperty = property(get_SelectedItemProperty, None)
    SettingsItemProperty = property(get_SettingsItemProperty, None)
class INavigationViewStatics2(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.INavigationViewStatics2'
    _iid_ = Guid('{79588150-4a1b-5e7c-9f8a-ebc814ce773d}')
    @winrt_commethod(6)
    def get_IsBackButtonVisibleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_IsBackEnabledProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_PaneTitleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_PaneDisplayModeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_PaneHeaderProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_PaneCustomContentProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_ContentOverlayProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_IsPaneVisibleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(14)
    def get_SelectionFollowsFocusProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(15)
    def get_TemplateSettingsProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(16)
    def get_ShoulderNavigationEnabledProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(17)
    def get_OverflowLabelModeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    ContentOverlayProperty = property(get_ContentOverlayProperty, None)
    IsBackButtonVisibleProperty = property(get_IsBackButtonVisibleProperty, None)
    IsBackEnabledProperty = property(get_IsBackEnabledProperty, None)
    IsPaneVisibleProperty = property(get_IsPaneVisibleProperty, None)
    OverflowLabelModeProperty = property(get_OverflowLabelModeProperty, None)
    PaneCustomContentProperty = property(get_PaneCustomContentProperty, None)
    PaneDisplayModeProperty = property(get_PaneDisplayModeProperty, None)
    PaneHeaderProperty = property(get_PaneHeaderProperty, None)
    PaneTitleProperty = property(get_PaneTitleProperty, None)
    SelectionFollowsFocusProperty = property(get_SelectionFollowsFocusProperty, None)
    ShoulderNavigationEnabledProperty = property(get_ShoulderNavigationEnabledProperty, None)
    TemplateSettingsProperty = property(get_TemplateSettingsProperty, None)
class INavigationViewTemplateSettings(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.INavigationViewTemplateSettings'
    _iid_ = Guid('{bbd25fa5-9c08-5f10-be20-cb4c1899bd9d}')
    @winrt_commethod(6)
    def get_TopPadding(self) -> Double: ...
    @winrt_commethod(7)
    def get_OverflowButtonVisibility(self) -> win32more.Microsoft.UI.Xaml.Visibility: ...
    @winrt_commethod(8)
    def get_PaneToggleButtonVisibility(self) -> win32more.Microsoft.UI.Xaml.Visibility: ...
    @winrt_commethod(9)
    def get_BackButtonVisibility(self) -> win32more.Microsoft.UI.Xaml.Visibility: ...
    @winrt_commethod(10)
    def get_TopPaneVisibility(self) -> win32more.Microsoft.UI.Xaml.Visibility: ...
    @winrt_commethod(11)
    def get_LeftPaneVisibility(self) -> win32more.Microsoft.UI.Xaml.Visibility: ...
    @winrt_commethod(12)
    def get_SingleSelectionFollowsFocus(self) -> Boolean: ...
    @winrt_commethod(13)
    def get_PaneToggleButtonWidth(self) -> Double: ...
    @winrt_commethod(14)
    def get_SmallerPaneToggleButtonWidth(self) -> Double: ...
    BackButtonVisibility = property(get_BackButtonVisibility, None)
    LeftPaneVisibility = property(get_LeftPaneVisibility, None)
    OverflowButtonVisibility = property(get_OverflowButtonVisibility, None)
    PaneToggleButtonVisibility = property(get_PaneToggleButtonVisibility, None)
    PaneToggleButtonWidth = property(get_PaneToggleButtonWidth, None)
    SingleSelectionFollowsFocus = property(get_SingleSelectionFollowsFocus, None)
    SmallerPaneToggleButtonWidth = property(get_SmallerPaneToggleButtonWidth, None)
    TopPadding = property(get_TopPadding, None)
    TopPaneVisibility = property(get_TopPaneVisibility, None)
class INavigationViewTemplateSettings2(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.INavigationViewTemplateSettings2'
    _iid_ = Guid('{56bec72f-1de1-5060-a44c-187885df2973}')
    @winrt_commethod(6)
    def get_OpenPaneLength(self) -> Double: ...
    OpenPaneLength = property(get_OpenPaneLength, None)
class INavigationViewTemplateSettingsFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.INavigationViewTemplateSettingsFactory'
    _iid_ = Guid('{34ff6c94-6465-5f3e-b0a5-4f1eea48e743}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.NavigationViewTemplateSettings: ...
class INavigationViewTemplateSettingsStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.INavigationViewTemplateSettingsStatics'
    _iid_ = Guid('{be3a88d6-d19b-5543-8b72-d42b459e72ed}')
    @winrt_commethod(6)
    def get_TopPaddingProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_OverflowButtonVisibilityProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_PaneToggleButtonVisibilityProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_BackButtonVisibilityProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_TopPaneVisibilityProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_LeftPaneVisibilityProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_SingleSelectionFollowsFocusProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_PaneToggleButtonWidthProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(14)
    def get_SmallerPaneToggleButtonWidthProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    BackButtonVisibilityProperty = property(get_BackButtonVisibilityProperty, None)
    LeftPaneVisibilityProperty = property(get_LeftPaneVisibilityProperty, None)
    OverflowButtonVisibilityProperty = property(get_OverflowButtonVisibilityProperty, None)
    PaneToggleButtonVisibilityProperty = property(get_PaneToggleButtonVisibilityProperty, None)
    PaneToggleButtonWidthProperty = property(get_PaneToggleButtonWidthProperty, None)
    SingleSelectionFollowsFocusProperty = property(get_SingleSelectionFollowsFocusProperty, None)
    SmallerPaneToggleButtonWidthProperty = property(get_SmallerPaneToggleButtonWidthProperty, None)
    TopPaddingProperty = property(get_TopPaddingProperty, None)
    TopPaneVisibilityProperty = property(get_TopPaneVisibilityProperty, None)
class INavigationViewTemplateSettingsStatics2(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.INavigationViewTemplateSettingsStatics2'
    _iid_ = Guid('{c0c06be3-9203-5eea-91dc-5d812a9702a6}')
    @winrt_commethod(6)
    def get_OpenPaneLengthProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    OpenPaneLengthProperty = property(get_OpenPaneLengthProperty, None)
class INonVirtualizingLayout(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.INonVirtualizingLayout'
    _iid_ = Guid('{0c24defd-f68f-51d9-998e-4cbad48be012}')
class INonVirtualizingLayoutContext(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.INonVirtualizingLayoutContext'
    _iid_ = Guid('{1e378538-f33c-5410-82cc-ca6f06d5e259}')
    @winrt_commethod(6)
    def get_Children(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Microsoft.UI.Xaml.UIElement]: ...
    Children = property(get_Children, None)
class INonVirtualizingLayoutContextFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.INonVirtualizingLayoutContextFactory'
    _iid_ = Guid('{dabac020-189c-5bbf-a4dc-97da1199f577}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.NonVirtualizingLayoutContext: ...
class INonVirtualizingLayoutContextOverrides(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.INonVirtualizingLayoutContextOverrides'
    _iid_ = Guid('{995cf544-5d3f-5f44-b537-fd13650c745c}')
    @winrt_commethod(6)
    def get_ChildrenCore(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Microsoft.UI.Xaml.UIElement]: ...
    ChildrenCore = property(get_ChildrenCore, None)
class INonVirtualizingLayoutFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.INonVirtualizingLayoutFactory'
    _iid_ = Guid('{a16d2d12-dbac-5ce0-aef5-09171a4d3571}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.NonVirtualizingLayout: ...
class INonVirtualizingLayoutOverrides(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.INonVirtualizingLayoutOverrides'
    _iid_ = Guid('{3c28b831-35c1-5182-a843-a43f339b6687}')
    @winrt_commethod(6)
    def InitializeForContextCore(self, context: win32more.Microsoft.UI.Xaml.Controls.NonVirtualizingLayoutContext) -> Void: ...
    @winrt_commethod(7)
    def UninitializeForContextCore(self, context: win32more.Microsoft.UI.Xaml.Controls.NonVirtualizingLayoutContext) -> Void: ...
    @winrt_commethod(8)
    def MeasureOverride(self, context: win32more.Microsoft.UI.Xaml.Controls.NonVirtualizingLayoutContext, availableSize: win32more.Windows.Foundation.Size) -> win32more.Windows.Foundation.Size: ...
    @winrt_commethod(9)
    def ArrangeOverride(self, context: win32more.Microsoft.UI.Xaml.Controls.NonVirtualizingLayoutContext, finalSize: win32more.Windows.Foundation.Size) -> win32more.Windows.Foundation.Size: ...
class INumberBox(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.INumberBox'
    _iid_ = Guid('{c18eb0e9-29fb-525d-abbc-d6b2110f542e}')
    @winrt_commethod(6)
    def get_Minimum(self) -> Double: ...
    @winrt_commethod(7)
    def put_Minimum(self, value: Double) -> Void: ...
    @winrt_commethod(8)
    def get_Maximum(self) -> Double: ...
    @winrt_commethod(9)
    def put_Maximum(self, value: Double) -> Void: ...
    @winrt_commethod(10)
    def get_Value(self) -> Double: ...
    @winrt_commethod(11)
    def put_Value(self, value: Double) -> Void: ...
    @winrt_commethod(12)
    def get_SmallChange(self) -> Double: ...
    @winrt_commethod(13)
    def put_SmallChange(self, value: Double) -> Void: ...
    @winrt_commethod(14)
    def get_LargeChange(self) -> Double: ...
    @winrt_commethod(15)
    def put_LargeChange(self, value: Double) -> Void: ...
    @winrt_commethod(16)
    def get_Text(self) -> hstr: ...
    @winrt_commethod(17)
    def put_Text(self, value: hstr) -> Void: ...
    @winrt_commethod(18)
    def get_Header(self) -> IInspectable: ...
    @winrt_commethod(19)
    def put_Header(self, value: IInspectable) -> Void: ...
    @winrt_commethod(20)
    def get_HeaderTemplate(self) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_commethod(21)
    def put_HeaderTemplate(self, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_commethod(22)
    def get_PlaceholderText(self) -> hstr: ...
    @winrt_commethod(23)
    def put_PlaceholderText(self, value: hstr) -> Void: ...
    @winrt_commethod(24)
    def get_SelectionFlyout(self) -> win32more.Microsoft.UI.Xaml.Controls.Primitives.FlyoutBase: ...
    @winrt_commethod(25)
    def put_SelectionFlyout(self, value: win32more.Microsoft.UI.Xaml.Controls.Primitives.FlyoutBase) -> Void: ...
    @winrt_commethod(26)
    def get_SelectionHighlightColor(self) -> win32more.Microsoft.UI.Xaml.Media.SolidColorBrush: ...
    @winrt_commethod(27)
    def put_SelectionHighlightColor(self, value: win32more.Microsoft.UI.Xaml.Media.SolidColorBrush) -> Void: ...
    @winrt_commethod(28)
    def get_TextReadingOrder(self) -> win32more.Microsoft.UI.Xaml.TextReadingOrder: ...
    @winrt_commethod(29)
    def put_TextReadingOrder(self, value: win32more.Microsoft.UI.Xaml.TextReadingOrder) -> Void: ...
    @winrt_commethod(30)
    def get_PreventKeyboardDisplayOnProgrammaticFocus(self) -> Boolean: ...
    @winrt_commethod(31)
    def put_PreventKeyboardDisplayOnProgrammaticFocus(self, value: Boolean) -> Void: ...
    @winrt_commethod(32)
    def get_Description(self) -> IInspectable: ...
    @winrt_commethod(33)
    def put_Description(self, value: IInspectable) -> Void: ...
    @winrt_commethod(34)
    def get_ValidationMode(self) -> win32more.Microsoft.UI.Xaml.Controls.NumberBoxValidationMode: ...
    @winrt_commethod(35)
    def put_ValidationMode(self, value: win32more.Microsoft.UI.Xaml.Controls.NumberBoxValidationMode) -> Void: ...
    @winrt_commethod(36)
    def get_SpinButtonPlacementMode(self) -> win32more.Microsoft.UI.Xaml.Controls.NumberBoxSpinButtonPlacementMode: ...
    @winrt_commethod(37)
    def put_SpinButtonPlacementMode(self, value: win32more.Microsoft.UI.Xaml.Controls.NumberBoxSpinButtonPlacementMode) -> Void: ...
    @winrt_commethod(38)
    def get_IsWrapEnabled(self) -> Boolean: ...
    @winrt_commethod(39)
    def put_IsWrapEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(40)
    def get_AcceptsExpression(self) -> Boolean: ...
    @winrt_commethod(41)
    def put_AcceptsExpression(self, value: Boolean) -> Void: ...
    @winrt_commethod(42)
    def get_NumberFormatter(self) -> win32more.Windows.Globalization.NumberFormatting.INumberFormatter2: ...
    @winrt_commethod(43)
    def put_NumberFormatter(self, value: win32more.Windows.Globalization.NumberFormatting.INumberFormatter2) -> Void: ...
    @winrt_commethod(44)
    def add_ValueChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.NumberBox, win32more.Microsoft.UI.Xaml.Controls.NumberBoxValueChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(45)
    def remove_ValueChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    AcceptsExpression = property(get_AcceptsExpression, put_AcceptsExpression)
    Description = property(get_Description, put_Description)
    Header = property(get_Header, put_Header)
    HeaderTemplate = property(get_HeaderTemplate, put_HeaderTemplate)
    IsWrapEnabled = property(get_IsWrapEnabled, put_IsWrapEnabled)
    LargeChange = property(get_LargeChange, put_LargeChange)
    Maximum = property(get_Maximum, put_Maximum)
    Minimum = property(get_Minimum, put_Minimum)
    NumberFormatter = property(get_NumberFormatter, put_NumberFormatter)
    PlaceholderText = property(get_PlaceholderText, put_PlaceholderText)
    PreventKeyboardDisplayOnProgrammaticFocus = property(get_PreventKeyboardDisplayOnProgrammaticFocus, put_PreventKeyboardDisplayOnProgrammaticFocus)
    SelectionFlyout = property(get_SelectionFlyout, put_SelectionFlyout)
    SelectionHighlightColor = property(get_SelectionHighlightColor, put_SelectionHighlightColor)
    SmallChange = property(get_SmallChange, put_SmallChange)
    SpinButtonPlacementMode = property(get_SpinButtonPlacementMode, put_SpinButtonPlacementMode)
    Text = property(get_Text, put_Text)
    TextReadingOrder = property(get_TextReadingOrder, put_TextReadingOrder)
    ValidationMode = property(get_ValidationMode, put_ValidationMode)
    Value = property(get_Value, put_Value)
    ValueChanged = event(add_ValueChanged, remove_ValueChanged)
class INumberBoxFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.INumberBoxFactory'
    _iid_ = Guid('{6b81f3cb-45a4-5d19-9bbb-a9fe4656ac4d}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.NumberBox: ...
class INumberBoxStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.INumberBoxStatics'
    _iid_ = Guid('{251ec05c-a77c-5540-be39-6053f797cde7}')
    @winrt_commethod(6)
    def get_MinimumProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_MaximumProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_ValueProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_SmallChangeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_LargeChangeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_TextProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_HeaderProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_HeaderTemplateProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(14)
    def get_PlaceholderTextProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(15)
    def get_SelectionFlyoutProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(16)
    def get_SelectionHighlightColorProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(17)
    def get_TextReadingOrderProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(18)
    def get_PreventKeyboardDisplayOnProgrammaticFocusProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(19)
    def get_DescriptionProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(20)
    def get_ValidationModeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(21)
    def get_SpinButtonPlacementModeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(22)
    def get_IsWrapEnabledProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(23)
    def get_AcceptsExpressionProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(24)
    def get_NumberFormatterProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    AcceptsExpressionProperty = property(get_AcceptsExpressionProperty, None)
    DescriptionProperty = property(get_DescriptionProperty, None)
    HeaderProperty = property(get_HeaderProperty, None)
    HeaderTemplateProperty = property(get_HeaderTemplateProperty, None)
    IsWrapEnabledProperty = property(get_IsWrapEnabledProperty, None)
    LargeChangeProperty = property(get_LargeChangeProperty, None)
    MaximumProperty = property(get_MaximumProperty, None)
    MinimumProperty = property(get_MinimumProperty, None)
    NumberFormatterProperty = property(get_NumberFormatterProperty, None)
    PlaceholderTextProperty = property(get_PlaceholderTextProperty, None)
    PreventKeyboardDisplayOnProgrammaticFocusProperty = property(get_PreventKeyboardDisplayOnProgrammaticFocusProperty, None)
    SelectionFlyoutProperty = property(get_SelectionFlyoutProperty, None)
    SelectionHighlightColorProperty = property(get_SelectionHighlightColorProperty, None)
    SmallChangeProperty = property(get_SmallChangeProperty, None)
    SpinButtonPlacementModeProperty = property(get_SpinButtonPlacementModeProperty, None)
    TextProperty = property(get_TextProperty, None)
    TextReadingOrderProperty = property(get_TextReadingOrderProperty, None)
    ValidationModeProperty = property(get_ValidationModeProperty, None)
    ValueProperty = property(get_ValueProperty, None)
class INumberBoxValueChangedEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.INumberBoxValueChangedEventArgs'
    _iid_ = Guid('{c66cf16e-7c8a-532e-9d23-058c1c98dd50}')
    @winrt_commethod(6)
    def get_OldValue(self) -> Double: ...
    @winrt_commethod(7)
    def get_NewValue(self) -> Double: ...
    NewValue = property(get_NewValue, None)
    OldValue = property(get_OldValue, None)
class IPage(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IPage'
    _iid_ = Guid('{eb42988e-6cb5-5dd6-9e59-4c04e5caec6d}')
    @winrt_commethod(6)
    def get_Frame(self) -> win32more.Microsoft.UI.Xaml.Controls.Frame: ...
    @winrt_commethod(7)
    def get_NavigationCacheMode(self) -> win32more.Microsoft.UI.Xaml.Navigation.NavigationCacheMode: ...
    @winrt_commethod(8)
    def put_NavigationCacheMode(self, value: win32more.Microsoft.UI.Xaml.Navigation.NavigationCacheMode) -> Void: ...
    @winrt_commethod(9)
    def get_TopAppBar(self) -> win32more.Microsoft.UI.Xaml.Controls.AppBar: ...
    @winrt_commethod(10)
    def put_TopAppBar(self, value: win32more.Microsoft.UI.Xaml.Controls.AppBar) -> Void: ...
    @winrt_commethod(11)
    def get_BottomAppBar(self) -> win32more.Microsoft.UI.Xaml.Controls.AppBar: ...
    @winrt_commethod(12)
    def put_BottomAppBar(self, value: win32more.Microsoft.UI.Xaml.Controls.AppBar) -> Void: ...
    BottomAppBar = property(get_BottomAppBar, put_BottomAppBar)
    Frame = property(get_Frame, None)
    NavigationCacheMode = property(get_NavigationCacheMode, put_NavigationCacheMode)
    TopAppBar = property(get_TopAppBar, put_TopAppBar)
class IPageFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IPageFactory'
    _iid_ = Guid('{ff4357d5-ddcd-5129-9d0f-d8aed2adc1a9}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.Page: ...
class IPageOverrides(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IPageOverrides'
    _iid_ = Guid('{9b8445f7-d938-5626-850a-86e91ca89e98}')
    @winrt_commethod(6)
    def OnNavigatedFrom(self, e: win32more.Microsoft.UI.Xaml.Navigation.NavigationEventArgs) -> Void: ...
    @winrt_commethod(7)
    def OnNavigatedTo(self, e: win32more.Microsoft.UI.Xaml.Navigation.NavigationEventArgs) -> Void: ...
    @winrt_commethod(8)
    def OnNavigatingFrom(self, e: win32more.Microsoft.UI.Xaml.Navigation.NavigatingCancelEventArgs) -> Void: ...
class IPageStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IPageStatics'
    _iid_ = Guid('{b6241486-a374-5d09-a01f-9abe311c0884}')
    @winrt_commethod(6)
    def get_FrameProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_TopAppBarProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_BottomAppBarProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    BottomAppBarProperty = property(get_BottomAppBarProperty, None)
    FrameProperty = property(get_FrameProperty, None)
    TopAppBarProperty = property(get_TopAppBarProperty, None)
class IPanel(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IPanel'
    _iid_ = Guid('{27a1b418-56f3-525e-b883-cefed905eed3}')
    @winrt_commethod(6)
    def get_Children(self) -> win32more.Microsoft.UI.Xaml.Controls.UIElementCollection: ...
    @winrt_commethod(7)
    def get_Background(self) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_commethod(8)
    def put_Background(self, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(9)
    def get_IsItemsHost(self) -> Boolean: ...
    @winrt_commethod(10)
    def get_ChildrenTransitions(self) -> win32more.Microsoft.UI.Xaml.Media.Animation.TransitionCollection: ...
    @winrt_commethod(11)
    def put_ChildrenTransitions(self, value: win32more.Microsoft.UI.Xaml.Media.Animation.TransitionCollection) -> Void: ...
    @winrt_commethod(12)
    def get_BackgroundTransition(self) -> win32more.Microsoft.UI.Xaml.BrushTransition: ...
    @winrt_commethod(13)
    def put_BackgroundTransition(self, value: win32more.Microsoft.UI.Xaml.BrushTransition) -> Void: ...
    Background = property(get_Background, put_Background)
    BackgroundTransition = property(get_BackgroundTransition, put_BackgroundTransition)
    Children = property(get_Children, None)
    ChildrenTransitions = property(get_ChildrenTransitions, put_ChildrenTransitions)
    IsItemsHost = property(get_IsItemsHost, None)
class IPanelFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IPanelFactory'
    _iid_ = Guid('{f5e7e21c-4c97-5d20-bee6-3e4fc6ab14e9}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.Panel: ...
class IPanelStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IPanelStatics'
    _iid_ = Guid('{76a9caa7-a5d4-5061-a325-17c76f66de51}')
    @winrt_commethod(6)
    def get_BackgroundProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_IsItemsHostProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_ChildrenTransitionsProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    BackgroundProperty = property(get_BackgroundProperty, None)
    ChildrenTransitionsProperty = property(get_ChildrenTransitionsProperty, None)
    IsItemsHostProperty = property(get_IsItemsHostProperty, None)
class IParallaxView(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IParallaxView'
    _iid_ = Guid('{e6f4a919-1116-53ae-96c6-efddc59786f3}')
    @winrt_commethod(6)
    def get_Child(self) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_commethod(7)
    def put_Child(self, value: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    @winrt_commethod(8)
    def get_HorizontalShift(self) -> Double: ...
    @winrt_commethod(9)
    def put_HorizontalShift(self, value: Double) -> Void: ...
    @winrt_commethod(10)
    def get_HorizontalSourceEndOffset(self) -> Double: ...
    @winrt_commethod(11)
    def put_HorizontalSourceEndOffset(self, value: Double) -> Void: ...
    @winrt_commethod(12)
    def get_HorizontalSourceOffsetKind(self) -> win32more.Microsoft.UI.Xaml.Controls.ParallaxSourceOffsetKind: ...
    @winrt_commethod(13)
    def put_HorizontalSourceOffsetKind(self, value: win32more.Microsoft.UI.Xaml.Controls.ParallaxSourceOffsetKind) -> Void: ...
    @winrt_commethod(14)
    def get_HorizontalSourceStartOffset(self) -> Double: ...
    @winrt_commethod(15)
    def put_HorizontalSourceStartOffset(self, value: Double) -> Void: ...
    @winrt_commethod(16)
    def get_IsHorizontalShiftClamped(self) -> Boolean: ...
    @winrt_commethod(17)
    def put_IsHorizontalShiftClamped(self, value: Boolean) -> Void: ...
    @winrt_commethod(18)
    def get_IsVerticalShiftClamped(self) -> Boolean: ...
    @winrt_commethod(19)
    def put_IsVerticalShiftClamped(self, value: Boolean) -> Void: ...
    @winrt_commethod(20)
    def get_MaxHorizontalShiftRatio(self) -> Double: ...
    @winrt_commethod(21)
    def put_MaxHorizontalShiftRatio(self, value: Double) -> Void: ...
    @winrt_commethod(22)
    def get_MaxVerticalShiftRatio(self) -> Double: ...
    @winrt_commethod(23)
    def put_MaxVerticalShiftRatio(self, value: Double) -> Void: ...
    @winrt_commethod(24)
    def get_Source(self) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_commethod(25)
    def put_Source(self, value: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    @winrt_commethod(26)
    def get_VerticalShift(self) -> Double: ...
    @winrt_commethod(27)
    def put_VerticalShift(self, value: Double) -> Void: ...
    @winrt_commethod(28)
    def get_VerticalSourceEndOffset(self) -> Double: ...
    @winrt_commethod(29)
    def put_VerticalSourceEndOffset(self, value: Double) -> Void: ...
    @winrt_commethod(30)
    def get_VerticalSourceOffsetKind(self) -> win32more.Microsoft.UI.Xaml.Controls.ParallaxSourceOffsetKind: ...
    @winrt_commethod(31)
    def put_VerticalSourceOffsetKind(self, value: win32more.Microsoft.UI.Xaml.Controls.ParallaxSourceOffsetKind) -> Void: ...
    @winrt_commethod(32)
    def get_VerticalSourceStartOffset(self) -> Double: ...
    @winrt_commethod(33)
    def put_VerticalSourceStartOffset(self, value: Double) -> Void: ...
    @winrt_commethod(34)
    def RefreshAutomaticHorizontalOffsets(self) -> Void: ...
    @winrt_commethod(35)
    def RefreshAutomaticVerticalOffsets(self) -> Void: ...
    Child = property(get_Child, put_Child)
    HorizontalShift = property(get_HorizontalShift, put_HorizontalShift)
    HorizontalSourceEndOffset = property(get_HorizontalSourceEndOffset, put_HorizontalSourceEndOffset)
    HorizontalSourceOffsetKind = property(get_HorizontalSourceOffsetKind, put_HorizontalSourceOffsetKind)
    HorizontalSourceStartOffset = property(get_HorizontalSourceStartOffset, put_HorizontalSourceStartOffset)
    IsHorizontalShiftClamped = property(get_IsHorizontalShiftClamped, put_IsHorizontalShiftClamped)
    IsVerticalShiftClamped = property(get_IsVerticalShiftClamped, put_IsVerticalShiftClamped)
    MaxHorizontalShiftRatio = property(get_MaxHorizontalShiftRatio, put_MaxHorizontalShiftRatio)
    MaxVerticalShiftRatio = property(get_MaxVerticalShiftRatio, put_MaxVerticalShiftRatio)
    Source = property(get_Source, put_Source)
    VerticalShift = property(get_VerticalShift, put_VerticalShift)
    VerticalSourceEndOffset = property(get_VerticalSourceEndOffset, put_VerticalSourceEndOffset)
    VerticalSourceOffsetKind = property(get_VerticalSourceOffsetKind, put_VerticalSourceOffsetKind)
    VerticalSourceStartOffset = property(get_VerticalSourceStartOffset, put_VerticalSourceStartOffset)
class IParallaxViewFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IParallaxViewFactory'
    _iid_ = Guid('{61dc973d-c595-5261-a9b7-35f41042eb00}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.ParallaxView: ...
class IParallaxViewStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IParallaxViewStatics'
    _iid_ = Guid('{69211861-40ba-5083-8835-416f40d4c5eb}')
    @winrt_commethod(6)
    def get_ChildProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_HorizontalSourceEndOffsetProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_HorizontalSourceOffsetKindProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_HorizontalSourceStartOffsetProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_MaxHorizontalShiftRatioProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_HorizontalShiftProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_IsHorizontalShiftClampedProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_IsVerticalShiftClampedProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(14)
    def get_SourceProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(15)
    def get_VerticalSourceEndOffsetProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(16)
    def get_VerticalSourceOffsetKindProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(17)
    def get_VerticalSourceStartOffsetProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(18)
    def get_MaxVerticalShiftRatioProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(19)
    def get_VerticalShiftProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    ChildProperty = property(get_ChildProperty, None)
    HorizontalShiftProperty = property(get_HorizontalShiftProperty, None)
    HorizontalSourceEndOffsetProperty = property(get_HorizontalSourceEndOffsetProperty, None)
    HorizontalSourceOffsetKindProperty = property(get_HorizontalSourceOffsetKindProperty, None)
    HorizontalSourceStartOffsetProperty = property(get_HorizontalSourceStartOffsetProperty, None)
    IsHorizontalShiftClampedProperty = property(get_IsHorizontalShiftClampedProperty, None)
    IsVerticalShiftClampedProperty = property(get_IsVerticalShiftClampedProperty, None)
    MaxHorizontalShiftRatioProperty = property(get_MaxHorizontalShiftRatioProperty, None)
    MaxVerticalShiftRatioProperty = property(get_MaxVerticalShiftRatioProperty, None)
    SourceProperty = property(get_SourceProperty, None)
    VerticalShiftProperty = property(get_VerticalShiftProperty, None)
    VerticalSourceEndOffsetProperty = property(get_VerticalSourceEndOffsetProperty, None)
    VerticalSourceOffsetKindProperty = property(get_VerticalSourceOffsetKindProperty, None)
    VerticalSourceStartOffsetProperty = property(get_VerticalSourceStartOffsetProperty, None)
class IPasswordBox(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IPasswordBox'
    _iid_ = Guid('{6d3ccff7-aaee-5adc-8298-33300fa119da}')
    @winrt_commethod(6)
    def get_Password(self) -> hstr: ...
    @winrt_commethod(7)
    def put_Password(self, value: hstr) -> Void: ...
    @winrt_commethod(8)
    def get_PasswordChar(self) -> hstr: ...
    @winrt_commethod(9)
    def put_PasswordChar(self, value: hstr) -> Void: ...
    @winrt_commethod(10)
    def get_IsPasswordRevealButtonEnabled(self) -> Boolean: ...
    @winrt_commethod(11)
    def put_IsPasswordRevealButtonEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(12)
    def get_MaxLength(self) -> Int32: ...
    @winrt_commethod(13)
    def put_MaxLength(self, value: Int32) -> Void: ...
    @winrt_commethod(14)
    def get_Header(self) -> IInspectable: ...
    @winrt_commethod(15)
    def put_Header(self, value: IInspectable) -> Void: ...
    @winrt_commethod(16)
    def get_HeaderTemplate(self) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_commethod(17)
    def put_HeaderTemplate(self, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_commethod(18)
    def get_PlaceholderText(self) -> hstr: ...
    @winrt_commethod(19)
    def put_PlaceholderText(self, value: hstr) -> Void: ...
    @winrt_commethod(20)
    def get_SelectionHighlightColor(self) -> win32more.Microsoft.UI.Xaml.Media.SolidColorBrush: ...
    @winrt_commethod(21)
    def put_SelectionHighlightColor(self, value: win32more.Microsoft.UI.Xaml.Media.SolidColorBrush) -> Void: ...
    @winrt_commethod(22)
    def get_PreventKeyboardDisplayOnProgrammaticFocus(self) -> Boolean: ...
    @winrt_commethod(23)
    def put_PreventKeyboardDisplayOnProgrammaticFocus(self, value: Boolean) -> Void: ...
    @winrt_commethod(24)
    def get_PasswordRevealMode(self) -> win32more.Microsoft.UI.Xaml.Controls.PasswordRevealMode: ...
    @winrt_commethod(25)
    def put_PasswordRevealMode(self, value: win32more.Microsoft.UI.Xaml.Controls.PasswordRevealMode) -> Void: ...
    @winrt_commethod(26)
    def get_TextReadingOrder(self) -> win32more.Microsoft.UI.Xaml.TextReadingOrder: ...
    @winrt_commethod(27)
    def put_TextReadingOrder(self, value: win32more.Microsoft.UI.Xaml.TextReadingOrder) -> Void: ...
    @winrt_commethod(28)
    def get_InputScope(self) -> win32more.Microsoft.UI.Xaml.Input.InputScope: ...
    @winrt_commethod(29)
    def put_InputScope(self, value: win32more.Microsoft.UI.Xaml.Input.InputScope) -> Void: ...
    @winrt_commethod(30)
    def get_CanPasteClipboardContent(self) -> Boolean: ...
    @winrt_commethod(31)
    def get_SelectionFlyout(self) -> win32more.Microsoft.UI.Xaml.Controls.Primitives.FlyoutBase: ...
    @winrt_commethod(32)
    def put_SelectionFlyout(self, value: win32more.Microsoft.UI.Xaml.Controls.Primitives.FlyoutBase) -> Void: ...
    @winrt_commethod(33)
    def get_Description(self) -> IInspectable: ...
    @winrt_commethod(34)
    def put_Description(self, value: IInspectable) -> Void: ...
    @winrt_commethod(35)
    def add_PasswordChanged(self, handler: win32more.Microsoft.UI.Xaml.RoutedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(36)
    def remove_PasswordChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(37)
    def add_ContextMenuOpening(self, handler: win32more.Microsoft.UI.Xaml.Controls.ContextMenuOpeningEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(38)
    def remove_ContextMenuOpening(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(39)
    def add_Paste(self, handler: win32more.Microsoft.UI.Xaml.Controls.TextControlPasteEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(40)
    def remove_Paste(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(41)
    def add_PasswordChanging(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.PasswordBox, win32more.Microsoft.UI.Xaml.Controls.PasswordBoxPasswordChangingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(42)
    def remove_PasswordChanging(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(43)
    def SelectAll(self) -> Void: ...
    @winrt_commethod(44)
    def PasteFromClipboard(self) -> Void: ...
    CanPasteClipboardContent = property(get_CanPasteClipboardContent, None)
    Description = property(get_Description, put_Description)
    Header = property(get_Header, put_Header)
    HeaderTemplate = property(get_HeaderTemplate, put_HeaderTemplate)
    InputScope = property(get_InputScope, put_InputScope)
    IsPasswordRevealButtonEnabled = property(get_IsPasswordRevealButtonEnabled, put_IsPasswordRevealButtonEnabled)
    MaxLength = property(get_MaxLength, put_MaxLength)
    Password = property(get_Password, put_Password)
    PasswordChar = property(get_PasswordChar, put_PasswordChar)
    PasswordRevealMode = property(get_PasswordRevealMode, put_PasswordRevealMode)
    PlaceholderText = property(get_PlaceholderText, put_PlaceholderText)
    PreventKeyboardDisplayOnProgrammaticFocus = property(get_PreventKeyboardDisplayOnProgrammaticFocus, put_PreventKeyboardDisplayOnProgrammaticFocus)
    SelectionFlyout = property(get_SelectionFlyout, put_SelectionFlyout)
    SelectionHighlightColor = property(get_SelectionHighlightColor, put_SelectionHighlightColor)
    TextReadingOrder = property(get_TextReadingOrder, put_TextReadingOrder)
    ContextMenuOpening = event(add_ContextMenuOpening, remove_ContextMenuOpening)
    PasswordChanged = event(add_PasswordChanged, remove_PasswordChanged)
    PasswordChanging = event(add_PasswordChanging, remove_PasswordChanging)
    Paste = event(add_Paste, remove_Paste)
class IPasswordBoxPasswordChangingEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IPasswordBoxPasswordChangingEventArgs'
    _iid_ = Guid('{9a2f3b79-c00c-5d27-bb67-92cab3db0477}')
    @winrt_commethod(6)
    def get_IsContentChanging(self) -> Boolean: ...
    IsContentChanging = property(get_IsContentChanging, None)
class IPasswordBoxStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IPasswordBoxStatics'
    _iid_ = Guid('{90e6559c-5f74-5cd1-87b6-c0514085ab42}')
    @winrt_commethod(6)
    def get_PasswordProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_PasswordCharProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_IsPasswordRevealButtonEnabledProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_MaxLengthProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_HeaderProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_HeaderTemplateProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_PlaceholderTextProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_SelectionHighlightColorProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(14)
    def get_PreventKeyboardDisplayOnProgrammaticFocusProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(15)
    def get_PasswordRevealModeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(16)
    def get_TextReadingOrderProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(17)
    def get_InputScopeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(18)
    def get_CanPasteClipboardContentProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(19)
    def get_SelectionFlyoutProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(20)
    def get_DescriptionProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    CanPasteClipboardContentProperty = property(get_CanPasteClipboardContentProperty, None)
    DescriptionProperty = property(get_DescriptionProperty, None)
    HeaderProperty = property(get_HeaderProperty, None)
    HeaderTemplateProperty = property(get_HeaderTemplateProperty, None)
    InputScopeProperty = property(get_InputScopeProperty, None)
    IsPasswordRevealButtonEnabledProperty = property(get_IsPasswordRevealButtonEnabledProperty, None)
    MaxLengthProperty = property(get_MaxLengthProperty, None)
    PasswordCharProperty = property(get_PasswordCharProperty, None)
    PasswordProperty = property(get_PasswordProperty, None)
    PasswordRevealModeProperty = property(get_PasswordRevealModeProperty, None)
    PlaceholderTextProperty = property(get_PlaceholderTextProperty, None)
    PreventKeyboardDisplayOnProgrammaticFocusProperty = property(get_PreventKeyboardDisplayOnProgrammaticFocusProperty, None)
    SelectionFlyoutProperty = property(get_SelectionFlyoutProperty, None)
    SelectionHighlightColorProperty = property(get_SelectionHighlightColorProperty, None)
    TextReadingOrderProperty = property(get_TextReadingOrderProperty, None)
class IPathIcon(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IPathIcon'
    _iid_ = Guid('{5c8229db-51cd-5a3b-88ef-1d9a8ac97683}')
    @winrt_commethod(6)
    def get_Data(self) -> win32more.Microsoft.UI.Xaml.Media.Geometry: ...
    @winrt_commethod(7)
    def put_Data(self, value: win32more.Microsoft.UI.Xaml.Media.Geometry) -> Void: ...
    Data = property(get_Data, put_Data)
class IPathIconFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IPathIconFactory'
    _iid_ = Guid('{8e88f087-f2cd-581c-91ca-a99335ca9599}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.PathIcon: ...
class IPathIconSource(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IPathIconSource'
    _iid_ = Guid('{7acdc6a5-f9aa-5d7e-8645-3c48989433a0}')
    @winrt_commethod(6)
    def get_Data(self) -> win32more.Microsoft.UI.Xaml.Media.Geometry: ...
    @winrt_commethod(7)
    def put_Data(self, value: win32more.Microsoft.UI.Xaml.Media.Geometry) -> Void: ...
    Data = property(get_Data, put_Data)
class IPathIconSourceFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IPathIconSourceFactory'
    _iid_ = Guid('{9fefe31e-5ab6-5394-a6ef-672f174d333b}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.PathIconSource: ...
class IPathIconSourceStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IPathIconSourceStatics'
    _iid_ = Guid('{95df636b-0dc3-5c94-ba43-8980fd030840}')
    @winrt_commethod(6)
    def get_DataProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    DataProperty = property(get_DataProperty, None)
class IPathIconStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IPathIconStatics'
    _iid_ = Guid('{72bba29a-0595-5f6d-a8df-2a0580a2cd78}')
    @winrt_commethod(6)
    def get_DataProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    DataProperty = property(get_DataProperty, None)
class IPersonPicture(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IPersonPicture'
    _iid_ = Guid('{30ec982c-0efa-5538-a356-e9ebd5aa363c}')
    @winrt_commethod(6)
    def get_BadgeNumber(self) -> Int32: ...
    @winrt_commethod(7)
    def put_BadgeNumber(self, value: Int32) -> Void: ...
    @winrt_commethod(8)
    def get_BadgeGlyph(self) -> hstr: ...
    @winrt_commethod(9)
    def put_BadgeGlyph(self, value: hstr) -> Void: ...
    @winrt_commethod(10)
    def get_BadgeImageSource(self) -> win32more.Microsoft.UI.Xaml.Media.ImageSource: ...
    @winrt_commethod(11)
    def put_BadgeImageSource(self, value: win32more.Microsoft.UI.Xaml.Media.ImageSource) -> Void: ...
    @winrt_commethod(12)
    def get_BadgeText(self) -> hstr: ...
    @winrt_commethod(13)
    def put_BadgeText(self, value: hstr) -> Void: ...
    @winrt_commethod(14)
    def get_IsGroup(self) -> Boolean: ...
    @winrt_commethod(15)
    def put_IsGroup(self, value: Boolean) -> Void: ...
    @winrt_commethod(16)
    def get_Contact(self) -> win32more.Windows.ApplicationModel.Contacts.Contact: ...
    @winrt_commethod(17)
    def put_Contact(self, value: win32more.Windows.ApplicationModel.Contacts.Contact) -> Void: ...
    @winrt_commethod(18)
    def get_DisplayName(self) -> hstr: ...
    @winrt_commethod(19)
    def put_DisplayName(self, value: hstr) -> Void: ...
    @winrt_commethod(20)
    def get_Initials(self) -> hstr: ...
    @winrt_commethod(21)
    def put_Initials(self, value: hstr) -> Void: ...
    @winrt_commethod(22)
    def get_PreferSmallImage(self) -> Boolean: ...
    @winrt_commethod(23)
    def put_PreferSmallImage(self, value: Boolean) -> Void: ...
    @winrt_commethod(24)
    def get_ProfilePicture(self) -> win32more.Microsoft.UI.Xaml.Media.ImageSource: ...
    @winrt_commethod(25)
    def put_ProfilePicture(self, value: win32more.Microsoft.UI.Xaml.Media.ImageSource) -> Void: ...
    @winrt_commethod(26)
    def get_TemplateSettings(self) -> win32more.Microsoft.UI.Xaml.Controls.PersonPictureTemplateSettings: ...
    BadgeGlyph = property(get_BadgeGlyph, put_BadgeGlyph)
    BadgeImageSource = property(get_BadgeImageSource, put_BadgeImageSource)
    BadgeNumber = property(get_BadgeNumber, put_BadgeNumber)
    BadgeText = property(get_BadgeText, put_BadgeText)
    Contact = property(get_Contact, put_Contact)
    DisplayName = property(get_DisplayName, put_DisplayName)
    Initials = property(get_Initials, put_Initials)
    IsGroup = property(get_IsGroup, put_IsGroup)
    PreferSmallImage = property(get_PreferSmallImage, put_PreferSmallImage)
    ProfilePicture = property(get_ProfilePicture, put_ProfilePicture)
    TemplateSettings = property(get_TemplateSettings, None)
class IPersonPictureFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IPersonPictureFactory'
    _iid_ = Guid('{7ec0794c-f2cc-5282-a89d-cd3bb765b71a}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.PersonPicture: ...
class IPersonPictureStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IPersonPictureStatics'
    _iid_ = Guid('{3c769423-9b05-56c1-a169-098493c21f91}')
    @winrt_commethod(6)
    def get_BadgeNumberProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_BadgeGlyphProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_BadgeImageSourceProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_BadgeTextProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_IsGroupProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_ContactProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_DisplayNameProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_InitialsProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(14)
    def get_PreferSmallImageProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(15)
    def get_ProfilePictureProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    BadgeGlyphProperty = property(get_BadgeGlyphProperty, None)
    BadgeImageSourceProperty = property(get_BadgeImageSourceProperty, None)
    BadgeNumberProperty = property(get_BadgeNumberProperty, None)
    BadgeTextProperty = property(get_BadgeTextProperty, None)
    ContactProperty = property(get_ContactProperty, None)
    DisplayNameProperty = property(get_DisplayNameProperty, None)
    InitialsProperty = property(get_InitialsProperty, None)
    IsGroupProperty = property(get_IsGroupProperty, None)
    PreferSmallImageProperty = property(get_PreferSmallImageProperty, None)
    ProfilePictureProperty = property(get_ProfilePictureProperty, None)
class IPersonPictureTemplateSettings(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IPersonPictureTemplateSettings'
    _iid_ = Guid('{e16df12f-c3c0-5f26-a381-08f2df052f29}')
    @winrt_commethod(6)
    def get_ActualInitials(self) -> hstr: ...
    @winrt_commethod(7)
    def get_ActualImageBrush(self) -> win32more.Microsoft.UI.Xaml.Media.ImageBrush: ...
    ActualImageBrush = property(get_ActualImageBrush, None)
    ActualInitials = property(get_ActualInitials, None)
class IPickerConfirmedEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IPickerConfirmedEventArgs'
    _iid_ = Guid('{002ac84d-4cb1-5a84-9460-7b9fb716500b}')
class IPickerFlyout(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IPickerFlyout'
    _iid_ = Guid('{f73f69a0-92d3-5144-8459-a7a05a53bcd2}')
    @winrt_commethod(6)
    def get_Content(self) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_commethod(7)
    def put_Content(self, value: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    @winrt_commethod(8)
    def get_ConfirmationButtonsVisible(self) -> Boolean: ...
    @winrt_commethod(9)
    def put_ConfirmationButtonsVisible(self, value: Boolean) -> Void: ...
    @winrt_commethod(10)
    def add_Confirmed(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.PickerFlyout, win32more.Microsoft.UI.Xaml.Controls.PickerConfirmedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(11)
    def remove_Confirmed(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(12)
    def ShowAtAsync(self, target: win32more.Microsoft.UI.Xaml.FrameworkElement) -> win32more.Windows.Foundation.IAsyncOperation[Boolean]: ...
    ConfirmationButtonsVisible = property(get_ConfirmationButtonsVisible, put_ConfirmationButtonsVisible)
    Content = property(get_Content, put_Content)
    Confirmed = event(add_Confirmed, remove_Confirmed)
class IPickerFlyoutPresenter(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IPickerFlyoutPresenter'
    _iid_ = Guid('{2181b3f9-9f94-5ebe-9b56-aa106b7e02cd}')
class IPickerFlyoutStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IPickerFlyoutStatics'
    _iid_ = Guid('{a8d33e85-aeaa-5079-983b-ce45e468672a}')
    @winrt_commethod(6)
    def get_ContentProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_ConfirmationButtonsVisibleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    ConfirmationButtonsVisibleProperty = property(get_ConfirmationButtonsVisibleProperty, None)
    ContentProperty = property(get_ContentProperty, None)
class IPipsPager(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IPipsPager'
    _iid_ = Guid('{de7fc5d5-9446-5693-bbf3-fd7f943a567c}')
    @winrt_commethod(6)
    def get_NumberOfPages(self) -> Int32: ...
    @winrt_commethod(7)
    def put_NumberOfPages(self, value: Int32) -> Void: ...
    @winrt_commethod(8)
    def get_SelectedPageIndex(self) -> Int32: ...
    @winrt_commethod(9)
    def put_SelectedPageIndex(self, value: Int32) -> Void: ...
    @winrt_commethod(10)
    def get_MaxVisiblePips(self) -> Int32: ...
    @winrt_commethod(11)
    def put_MaxVisiblePips(self, value: Int32) -> Void: ...
    @winrt_commethod(12)
    def get_Orientation(self) -> win32more.Microsoft.UI.Xaml.Controls.Orientation: ...
    @winrt_commethod(13)
    def put_Orientation(self, value: win32more.Microsoft.UI.Xaml.Controls.Orientation) -> Void: ...
    @winrt_commethod(14)
    def get_PreviousButtonVisibility(self) -> win32more.Microsoft.UI.Xaml.Controls.PipsPagerButtonVisibility: ...
    @winrt_commethod(15)
    def put_PreviousButtonVisibility(self, value: win32more.Microsoft.UI.Xaml.Controls.PipsPagerButtonVisibility) -> Void: ...
    @winrt_commethod(16)
    def get_NextButtonVisibility(self) -> win32more.Microsoft.UI.Xaml.Controls.PipsPagerButtonVisibility: ...
    @winrt_commethod(17)
    def put_NextButtonVisibility(self, value: win32more.Microsoft.UI.Xaml.Controls.PipsPagerButtonVisibility) -> Void: ...
    @winrt_commethod(18)
    def get_PreviousButtonStyle(self) -> win32more.Microsoft.UI.Xaml.Style: ...
    @winrt_commethod(19)
    def put_PreviousButtonStyle(self, value: win32more.Microsoft.UI.Xaml.Style) -> Void: ...
    @winrt_commethod(20)
    def get_NextButtonStyle(self) -> win32more.Microsoft.UI.Xaml.Style: ...
    @winrt_commethod(21)
    def put_NextButtonStyle(self, value: win32more.Microsoft.UI.Xaml.Style) -> Void: ...
    @winrt_commethod(22)
    def get_SelectedPipStyle(self) -> win32more.Microsoft.UI.Xaml.Style: ...
    @winrt_commethod(23)
    def put_SelectedPipStyle(self, value: win32more.Microsoft.UI.Xaml.Style) -> Void: ...
    @winrt_commethod(24)
    def get_NormalPipStyle(self) -> win32more.Microsoft.UI.Xaml.Style: ...
    @winrt_commethod(25)
    def put_NormalPipStyle(self, value: win32more.Microsoft.UI.Xaml.Style) -> Void: ...
    @winrt_commethod(26)
    def add_SelectedIndexChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.PipsPager, win32more.Microsoft.UI.Xaml.Controls.PipsPagerSelectedIndexChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(27)
    def remove_SelectedIndexChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(28)
    def get_TemplateSettings(self) -> win32more.Microsoft.UI.Xaml.Controls.PipsPagerTemplateSettings: ...
    MaxVisiblePips = property(get_MaxVisiblePips, put_MaxVisiblePips)
    NextButtonStyle = property(get_NextButtonStyle, put_NextButtonStyle)
    NextButtonVisibility = property(get_NextButtonVisibility, put_NextButtonVisibility)
    NormalPipStyle = property(get_NormalPipStyle, put_NormalPipStyle)
    NumberOfPages = property(get_NumberOfPages, put_NumberOfPages)
    Orientation = property(get_Orientation, put_Orientation)
    PreviousButtonStyle = property(get_PreviousButtonStyle, put_PreviousButtonStyle)
    PreviousButtonVisibility = property(get_PreviousButtonVisibility, put_PreviousButtonVisibility)
    SelectedPageIndex = property(get_SelectedPageIndex, put_SelectedPageIndex)
    SelectedPipStyle = property(get_SelectedPipStyle, put_SelectedPipStyle)
    TemplateSettings = property(get_TemplateSettings, None)
    SelectedIndexChanged = event(add_SelectedIndexChanged, remove_SelectedIndexChanged)
class IPipsPagerFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IPipsPagerFactory'
    _iid_ = Guid('{020722cd-813a-5165-a899-3df9adcd805e}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.PipsPager: ...
class IPipsPagerSelectedIndexChangedEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IPipsPagerSelectedIndexChangedEventArgs'
    _iid_ = Guid('{6c2ce4fc-bf52-5ca6-9da4-b0bd5b928d97}')
class IPipsPagerStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IPipsPagerStatics'
    _iid_ = Guid('{37714cd8-fba6-5d98-a395-0a7a3ea64867}')
    @winrt_commethod(6)
    def get_NumberOfPagesProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_SelectedPageIndexProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_MaxVisiblePipsProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_OrientationProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_PreviousButtonVisibilityProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_NextButtonVisibilityProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_PreviousButtonStyleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_NextButtonStyleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(14)
    def get_SelectedPipStyleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(15)
    def get_NormalPipStyleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    MaxVisiblePipsProperty = property(get_MaxVisiblePipsProperty, None)
    NextButtonStyleProperty = property(get_NextButtonStyleProperty, None)
    NextButtonVisibilityProperty = property(get_NextButtonVisibilityProperty, None)
    NormalPipStyleProperty = property(get_NormalPipStyleProperty, None)
    NumberOfPagesProperty = property(get_NumberOfPagesProperty, None)
    OrientationProperty = property(get_OrientationProperty, None)
    PreviousButtonStyleProperty = property(get_PreviousButtonStyleProperty, None)
    PreviousButtonVisibilityProperty = property(get_PreviousButtonVisibilityProperty, None)
    SelectedPageIndexProperty = property(get_SelectedPageIndexProperty, None)
    SelectedPipStyleProperty = property(get_SelectedPipStyleProperty, None)
class IPipsPagerTemplateSettings(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IPipsPagerTemplateSettings'
    _iid_ = Guid('{9d8c1252-56c5-57af-9a3a-08e9b947e5fa}')
    @winrt_commethod(6)
    def get_PipsPagerItems(self) -> win32more.Windows.Foundation.Collections.IVector[Int32]: ...
    PipsPagerItems = property(get_PipsPagerItems, None)
class IPivot(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IPivot'
    _iid_ = Guid('{1c6438e5-ecac-5fb6-8e8e-00de7e922303}')
    @winrt_commethod(6)
    def get_Title(self) -> IInspectable: ...
    @winrt_commethod(7)
    def put_Title(self, value: IInspectable) -> Void: ...
    @winrt_commethod(8)
    def get_TitleTemplate(self) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_commethod(9)
    def put_TitleTemplate(self, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_commethod(10)
    def get_LeftHeader(self) -> IInspectable: ...
    @winrt_commethod(11)
    def put_LeftHeader(self, value: IInspectable) -> Void: ...
    @winrt_commethod(12)
    def get_LeftHeaderTemplate(self) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_commethod(13)
    def put_LeftHeaderTemplate(self, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_commethod(14)
    def get_RightHeader(self) -> IInspectable: ...
    @winrt_commethod(15)
    def put_RightHeader(self, value: IInspectable) -> Void: ...
    @winrt_commethod(16)
    def get_RightHeaderTemplate(self) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_commethod(17)
    def put_RightHeaderTemplate(self, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_commethod(18)
    def get_HeaderTemplate(self) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_commethod(19)
    def put_HeaderTemplate(self, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_commethod(20)
    def get_SelectedIndex(self) -> Int32: ...
    @winrt_commethod(21)
    def put_SelectedIndex(self, value: Int32) -> Void: ...
    @winrt_commethod(22)
    def get_SelectedItem(self) -> IInspectable: ...
    @winrt_commethod(23)
    def put_SelectedItem(self, value: IInspectable) -> Void: ...
    @winrt_commethod(24)
    def get_IsLocked(self) -> Boolean: ...
    @winrt_commethod(25)
    def put_IsLocked(self, value: Boolean) -> Void: ...
    @winrt_commethod(26)
    def get_HeaderFocusVisualPlacement(self) -> win32more.Microsoft.UI.Xaml.Controls.PivotHeaderFocusVisualPlacement: ...
    @winrt_commethod(27)
    def put_HeaderFocusVisualPlacement(self, value: win32more.Microsoft.UI.Xaml.Controls.PivotHeaderFocusVisualPlacement) -> Void: ...
    @winrt_commethod(28)
    def get_IsHeaderItemsCarouselEnabled(self) -> Boolean: ...
    @winrt_commethod(29)
    def put_IsHeaderItemsCarouselEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(30)
    def add_SelectionChanged(self, handler: win32more.Microsoft.UI.Xaml.Controls.SelectionChangedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(31)
    def remove_SelectionChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(32)
    def add_PivotItemLoading(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.Pivot, win32more.Microsoft.UI.Xaml.Controls.PivotItemEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(33)
    def remove_PivotItemLoading(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(34)
    def add_PivotItemLoaded(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.Pivot, win32more.Microsoft.UI.Xaml.Controls.PivotItemEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(35)
    def remove_PivotItemLoaded(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(36)
    def add_PivotItemUnloading(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.Pivot, win32more.Microsoft.UI.Xaml.Controls.PivotItemEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(37)
    def remove_PivotItemUnloading(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(38)
    def add_PivotItemUnloaded(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.Pivot, win32more.Microsoft.UI.Xaml.Controls.PivotItemEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(39)
    def remove_PivotItemUnloaded(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    HeaderFocusVisualPlacement = property(get_HeaderFocusVisualPlacement, put_HeaderFocusVisualPlacement)
    HeaderTemplate = property(get_HeaderTemplate, put_HeaderTemplate)
    IsHeaderItemsCarouselEnabled = property(get_IsHeaderItemsCarouselEnabled, put_IsHeaderItemsCarouselEnabled)
    IsLocked = property(get_IsLocked, put_IsLocked)
    LeftHeader = property(get_LeftHeader, put_LeftHeader)
    LeftHeaderTemplate = property(get_LeftHeaderTemplate, put_LeftHeaderTemplate)
    RightHeader = property(get_RightHeader, put_RightHeader)
    RightHeaderTemplate = property(get_RightHeaderTemplate, put_RightHeaderTemplate)
    SelectedIndex = property(get_SelectedIndex, put_SelectedIndex)
    SelectedItem = property(get_SelectedItem, put_SelectedItem)
    Title = property(get_Title, put_Title)
    TitleTemplate = property(get_TitleTemplate, put_TitleTemplate)
    PivotItemLoaded = event(add_PivotItemLoaded, remove_PivotItemLoaded)
    PivotItemLoading = event(add_PivotItemLoading, remove_PivotItemLoading)
    PivotItemUnloaded = event(add_PivotItemUnloaded, remove_PivotItemUnloaded)
    PivotItemUnloading = event(add_PivotItemUnloading, remove_PivotItemUnloading)
    SelectionChanged = event(add_SelectionChanged, remove_SelectionChanged)
class IPivotFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IPivotFactory'
    _iid_ = Guid('{da9d033c-4782-5a69-90af-076ccdf071ae}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.Pivot: ...
class IPivotItem(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IPivotItem'
    _iid_ = Guid('{8108c195-63f5-5df9-abcf-418fa2dbfbec}')
    @winrt_commethod(6)
    def get_Header(self) -> IInspectable: ...
    @winrt_commethod(7)
    def put_Header(self, value: IInspectable) -> Void: ...
    Header = property(get_Header, put_Header)
class IPivotItemEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IPivotItemEventArgs'
    _iid_ = Guid('{e42c62c2-0cb9-5e5b-8148-8d80a3838de9}')
    @winrt_commethod(6)
    def get_Item(self) -> win32more.Microsoft.UI.Xaml.Controls.PivotItem: ...
    @winrt_commethod(7)
    def put_Item(self, value: win32more.Microsoft.UI.Xaml.Controls.PivotItem) -> Void: ...
    Item = property(get_Item, put_Item)
class IPivotItemFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IPivotItemFactory'
    _iid_ = Guid('{9149a2ab-606c-55a9-8786-801d55ca8ed6}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.PivotItem: ...
class IPivotItemStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IPivotItemStatics'
    _iid_ = Guid('{e2ebe630-6629-5b7b-8666-fdeb9b98db2c}')
    @winrt_commethod(6)
    def get_HeaderProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    HeaderProperty = property(get_HeaderProperty, None)
class IPivotStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IPivotStatics'
    _iid_ = Guid('{619cc35f-b97b-5e32-885e-70949ed97eeb}')
    @winrt_commethod(6)
    def get_TitleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_TitleTemplateProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_LeftHeaderProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_LeftHeaderTemplateProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_RightHeaderProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_RightHeaderTemplateProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_HeaderTemplateProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_SelectedIndexProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(14)
    def get_SelectedItemProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(15)
    def get_IsLockedProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(16)
    def get_HeaderFocusVisualPlacementProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(17)
    def get_IsHeaderItemsCarouselEnabledProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(18)
    def get_SlideInAnimationGroupProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(19)
    def GetSlideInAnimationGroup(self, element: win32more.Microsoft.UI.Xaml.FrameworkElement) -> win32more.Microsoft.UI.Xaml.Controls.PivotSlideInAnimationGroup: ...
    @winrt_commethod(20)
    def SetSlideInAnimationGroup(self, element: win32more.Microsoft.UI.Xaml.FrameworkElement, value: win32more.Microsoft.UI.Xaml.Controls.PivotSlideInAnimationGroup) -> Void: ...
    HeaderFocusVisualPlacementProperty = property(get_HeaderFocusVisualPlacementProperty, None)
    HeaderTemplateProperty = property(get_HeaderTemplateProperty, None)
    IsHeaderItemsCarouselEnabledProperty = property(get_IsHeaderItemsCarouselEnabledProperty, None)
    IsLockedProperty = property(get_IsLockedProperty, None)
    LeftHeaderProperty = property(get_LeftHeaderProperty, None)
    LeftHeaderTemplateProperty = property(get_LeftHeaderTemplateProperty, None)
    RightHeaderProperty = property(get_RightHeaderProperty, None)
    RightHeaderTemplateProperty = property(get_RightHeaderTemplateProperty, None)
    SelectedIndexProperty = property(get_SelectedIndexProperty, None)
    SelectedItemProperty = property(get_SelectedItemProperty, None)
    SlideInAnimationGroupProperty = property(get_SlideInAnimationGroupProperty, None)
    TitleProperty = property(get_TitleProperty, None)
    TitleTemplateProperty = property(get_TitleTemplateProperty, None)
class IProgressBar(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IProgressBar'
    _iid_ = Guid('{87555c8c-0aaf-52c1-8390-0db17f40438e}')
    @winrt_commethod(6)
    def get_IsIndeterminate(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_IsIndeterminate(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def get_ShowError(self) -> Boolean: ...
    @winrt_commethod(9)
    def put_ShowError(self, value: Boolean) -> Void: ...
    @winrt_commethod(10)
    def get_ShowPaused(self) -> Boolean: ...
    @winrt_commethod(11)
    def put_ShowPaused(self, value: Boolean) -> Void: ...
    @winrt_commethod(12)
    def get_TemplateSettings(self) -> win32more.Microsoft.UI.Xaml.Controls.ProgressBarTemplateSettings: ...
    IsIndeterminate = property(get_IsIndeterminate, put_IsIndeterminate)
    ShowError = property(get_ShowError, put_ShowError)
    ShowPaused = property(get_ShowPaused, put_ShowPaused)
    TemplateSettings = property(get_TemplateSettings, None)
class IProgressBarFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IProgressBarFactory'
    _iid_ = Guid('{189826ad-f6f2-533e-9ddb-b6600e88675b}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.ProgressBar: ...
class IProgressBarStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IProgressBarStatics'
    _iid_ = Guid('{61bbb127-e4c4-5e22-a8dc-cfcf957236d0}')
    @winrt_commethod(6)
    def get_IsIndeterminateProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_ShowErrorProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_ShowPausedProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    IsIndeterminateProperty = property(get_IsIndeterminateProperty, None)
    ShowErrorProperty = property(get_ShowErrorProperty, None)
    ShowPausedProperty = property(get_ShowPausedProperty, None)
class IProgressBarTemplateSettings(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IProgressBarTemplateSettings'
    _iid_ = Guid('{fbea95c9-9ef9-5e79-af54-44ded28035d5}')
    @winrt_commethod(6)
    def get_ContainerAnimationStartPosition(self) -> Double: ...
    @winrt_commethod(7)
    def get_ContainerAnimationEndPosition(self) -> Double: ...
    @winrt_commethod(8)
    def get_Container2AnimationStartPosition(self) -> Double: ...
    @winrt_commethod(9)
    def get_Container2AnimationEndPosition(self) -> Double: ...
    @winrt_commethod(10)
    def get_ContainerAnimationMidPosition(self) -> Double: ...
    @winrt_commethod(11)
    def get_IndicatorLengthDelta(self) -> Double: ...
    @winrt_commethod(12)
    def get_ClipRect(self) -> win32more.Microsoft.UI.Xaml.Media.RectangleGeometry: ...
    @winrt_commethod(13)
    def get_EllipseAnimationEndPosition(self) -> Double: ...
    @winrt_commethod(14)
    def get_EllipseAnimationWellPosition(self) -> Double: ...
    @winrt_commethod(15)
    def get_EllipseDiameter(self) -> Double: ...
    @winrt_commethod(16)
    def get_EllipseOffset(self) -> Double: ...
    ClipRect = property(get_ClipRect, None)
    Container2AnimationEndPosition = property(get_Container2AnimationEndPosition, None)
    Container2AnimationStartPosition = property(get_Container2AnimationStartPosition, None)
    ContainerAnimationEndPosition = property(get_ContainerAnimationEndPosition, None)
    ContainerAnimationMidPosition = property(get_ContainerAnimationMidPosition, None)
    ContainerAnimationStartPosition = property(get_ContainerAnimationStartPosition, None)
    EllipseAnimationEndPosition = property(get_EllipseAnimationEndPosition, None)
    EllipseAnimationWellPosition = property(get_EllipseAnimationWellPosition, None)
    EllipseDiameter = property(get_EllipseDiameter, None)
    EllipseOffset = property(get_EllipseOffset, None)
    IndicatorLengthDelta = property(get_IndicatorLengthDelta, None)
class IProgressRing(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IProgressRing'
    _iid_ = Guid('{2670d03f-e28c-5652-bee2-b5212ebdf7ff}')
    @winrt_commethod(6)
    def get_IsActive(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_IsActive(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def get_IsIndeterminate(self) -> Boolean: ...
    @winrt_commethod(9)
    def put_IsIndeterminate(self, value: Boolean) -> Void: ...
    @winrt_commethod(10)
    def get_TemplateSettings(self) -> win32more.Microsoft.UI.Xaml.Controls.ProgressRingTemplateSettings: ...
    @winrt_commethod(11)
    def get_Value(self) -> Double: ...
    @winrt_commethod(12)
    def put_Value(self, value: Double) -> Void: ...
    @winrt_commethod(13)
    def get_Minimum(self) -> Double: ...
    @winrt_commethod(14)
    def put_Minimum(self, value: Double) -> Void: ...
    @winrt_commethod(15)
    def get_Maximum(self) -> Double: ...
    @winrt_commethod(16)
    def put_Maximum(self, value: Double) -> Void: ...
    IsActive = property(get_IsActive, put_IsActive)
    IsIndeterminate = property(get_IsIndeterminate, put_IsIndeterminate)
    Maximum = property(get_Maximum, put_Maximum)
    Minimum = property(get_Minimum, put_Minimum)
    TemplateSettings = property(get_TemplateSettings, None)
    Value = property(get_Value, put_Value)
class IProgressRingFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IProgressRingFactory'
    _iid_ = Guid('{092fa98c-62a7-5dbc-9a85-3e556ba81f79}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.ProgressRing: ...
class IProgressRingStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IProgressRingStatics'
    _iid_ = Guid('{4ba1166a-cec2-50e2-b26b-66b69dc2e371}')
    @winrt_commethod(6)
    def get_IsActiveProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_IsIndeterminateProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_ValueProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_MinimumProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_MaximumProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    IsActiveProperty = property(get_IsActiveProperty, None)
    IsIndeterminateProperty = property(get_IsIndeterminateProperty, None)
    MaximumProperty = property(get_MaximumProperty, None)
    MinimumProperty = property(get_MinimumProperty, None)
    ValueProperty = property(get_ValueProperty, None)
class IProgressRingTemplateSettings(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IProgressRingTemplateSettings'
    _iid_ = Guid('{34020d86-e1c1-5d7c-b223-acd7f862ffd5}')
    @winrt_commethod(6)
    def get_EllipseDiameter(self) -> Double: ...
    @winrt_commethod(7)
    def get_EllipseOffset(self) -> win32more.Microsoft.UI.Xaml.Thickness: ...
    @winrt_commethod(8)
    def get_MaxSideLength(self) -> Double: ...
    EllipseDiameter = property(get_EllipseDiameter, None)
    EllipseOffset = property(get_EllipseOffset, None)
    MaxSideLength = property(get_MaxSideLength, None)
class IRadioButton(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IRadioButton'
    _iid_ = Guid('{38f30cee-e75a-5ba1-ae64-4474a3abeac7}')
    @winrt_commethod(6)
    def get_GroupName(self) -> hstr: ...
    @winrt_commethod(7)
    def put_GroupName(self, value: hstr) -> Void: ...
    GroupName = property(get_GroupName, put_GroupName)
class IRadioButtonFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IRadioButtonFactory'
    _iid_ = Guid('{5772c79a-b3eb-5719-8005-2a513429495a}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.RadioButton: ...
class IRadioButtonStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IRadioButtonStatics'
    _iid_ = Guid('{a8bce4d4-68fe-53d9-a317-74ab409cd4ee}')
    @winrt_commethod(6)
    def get_GroupNameProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    GroupNameProperty = property(get_GroupNameProperty, None)
class IRadioButtons(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IRadioButtons'
    _iid_ = Guid('{966daf80-ee85-5d90-b6b3-80bec9134673}')
    @winrt_commethod(6)
    def get_ItemsSource(self) -> IInspectable: ...
    @winrt_commethod(7)
    def put_ItemsSource(self, value: IInspectable) -> Void: ...
    @winrt_commethod(8)
    def get_Items(self) -> win32more.Windows.Foundation.Collections.IVector[IInspectable]: ...
    @winrt_commethod(9)
    def get_ItemTemplate(self) -> IInspectable: ...
    @winrt_commethod(10)
    def put_ItemTemplate(self, value: IInspectable) -> Void: ...
    @winrt_commethod(11)
    def ContainerFromIndex(self, index: Int32) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_commethod(12)
    def get_SelectedIndex(self) -> Int32: ...
    @winrt_commethod(13)
    def put_SelectedIndex(self, value: Int32) -> Void: ...
    @winrt_commethod(14)
    def get_SelectedItem(self) -> IInspectable: ...
    @winrt_commethod(15)
    def put_SelectedItem(self, value: IInspectable) -> Void: ...
    @winrt_commethod(16)
    def add_SelectionChanged(self, handler: win32more.Microsoft.UI.Xaml.Controls.SelectionChangedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(17)
    def remove_SelectionChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(18)
    def get_MaxColumns(self) -> Int32: ...
    @winrt_commethod(19)
    def put_MaxColumns(self, value: Int32) -> Void: ...
    @winrt_commethod(20)
    def get_Header(self) -> IInspectable: ...
    @winrt_commethod(21)
    def put_Header(self, value: IInspectable) -> Void: ...
    @winrt_commethod(22)
    def get_HeaderTemplate(self) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_commethod(23)
    def put_HeaderTemplate(self, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    Header = property(get_Header, put_Header)
    HeaderTemplate = property(get_HeaderTemplate, put_HeaderTemplate)
    ItemTemplate = property(get_ItemTemplate, put_ItemTemplate)
    Items = property(get_Items, None)
    ItemsSource = property(get_ItemsSource, put_ItemsSource)
    MaxColumns = property(get_MaxColumns, put_MaxColumns)
    SelectedIndex = property(get_SelectedIndex, put_SelectedIndex)
    SelectedItem = property(get_SelectedItem, put_SelectedItem)
    SelectionChanged = event(add_SelectionChanged, remove_SelectionChanged)
class IRadioButtonsFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IRadioButtonsFactory'
    _iid_ = Guid('{2cf95efb-a7a2-5d85-8ead-ea222baa3c55}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.RadioButtons: ...
class IRadioButtonsStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IRadioButtonsStatics'
    _iid_ = Guid('{de0bf0ca-9ae8-5b8a-9738-7d98b344c039}')
    @winrt_commethod(6)
    def get_ItemsSourceProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_ItemsProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_ItemTemplateProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_SelectedIndexProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_SelectedItemProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_MaxColumnsProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_HeaderProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_HeaderTemplateProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    HeaderProperty = property(get_HeaderProperty, None)
    HeaderTemplateProperty = property(get_HeaderTemplateProperty, None)
    ItemTemplateProperty = property(get_ItemTemplateProperty, None)
    ItemsProperty = property(get_ItemsProperty, None)
    ItemsSourceProperty = property(get_ItemsSourceProperty, None)
    MaxColumnsProperty = property(get_MaxColumnsProperty, None)
    SelectedIndexProperty = property(get_SelectedIndexProperty, None)
    SelectedItemProperty = property(get_SelectedItemProperty, None)
class IRadioMenuFlyoutItem(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IRadioMenuFlyoutItem'
    _iid_ = Guid('{9d6f45f5-5532-5669-8f02-05735953026a}')
    @winrt_commethod(6)
    def get_IsChecked(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_IsChecked(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def get_GroupName(self) -> hstr: ...
    @winrt_commethod(9)
    def put_GroupName(self, value: hstr) -> Void: ...
    GroupName = property(get_GroupName, put_GroupName)
    IsChecked = property(get_IsChecked, put_IsChecked)
class IRadioMenuFlyoutItemFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IRadioMenuFlyoutItemFactory'
    _iid_ = Guid('{113822d2-35a3-5b0d-9d0d-c3830ec1973b}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.RadioMenuFlyoutItem: ...
class IRadioMenuFlyoutItemStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IRadioMenuFlyoutItemStatics'
    _iid_ = Guid('{47117e20-e03d-53f0-938e-eccbfffb5421}')
    @winrt_commethod(6)
    def get_IsCheckedProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_GroupNameProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    GroupNameProperty = property(get_GroupNameProperty, None)
    IsCheckedProperty = property(get_IsCheckedProperty, None)
class IRadioMenuFlyoutItemStatics2(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IRadioMenuFlyoutItemStatics2'
    _iid_ = Guid('{2040ffbf-947f-58ed-969f-5d8d8967b9a0}')
    @winrt_commethod(6)
    def get_AreCheckStatesEnabledProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def SetAreCheckStatesEnabled(self, object: win32more.Microsoft.UI.Xaml.Controls.MenuFlyoutSubItem, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def GetAreCheckStatesEnabled(self, object: win32more.Microsoft.UI.Xaml.Controls.MenuFlyoutSubItem) -> Boolean: ...
    AreCheckStatesEnabledProperty = property(get_AreCheckStatesEnabledProperty, None)
class IRatingControl(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IRatingControl'
    _iid_ = Guid('{5488193b-ea4b-52c6-8544-c063219bcd90}')
    @winrt_commethod(6)
    def get_Caption(self) -> hstr: ...
    @winrt_commethod(7)
    def put_Caption(self, value: hstr) -> Void: ...
    @winrt_commethod(8)
    def get_InitialSetValue(self) -> Int32: ...
    @winrt_commethod(9)
    def put_InitialSetValue(self, value: Int32) -> Void: ...
    @winrt_commethod(10)
    def get_IsClearEnabled(self) -> Boolean: ...
    @winrt_commethod(11)
    def put_IsClearEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(12)
    def get_IsReadOnly(self) -> Boolean: ...
    @winrt_commethod(13)
    def put_IsReadOnly(self, value: Boolean) -> Void: ...
    @winrt_commethod(14)
    def get_MaxRating(self) -> Int32: ...
    @winrt_commethod(15)
    def put_MaxRating(self, value: Int32) -> Void: ...
    @winrt_commethod(16)
    def get_PlaceholderValue(self) -> Double: ...
    @winrt_commethod(17)
    def put_PlaceholderValue(self, value: Double) -> Void: ...
    @winrt_commethod(18)
    def get_ItemInfo(self) -> win32more.Microsoft.UI.Xaml.Controls.RatingItemInfo: ...
    @winrt_commethod(19)
    def put_ItemInfo(self, value: win32more.Microsoft.UI.Xaml.Controls.RatingItemInfo) -> Void: ...
    @winrt_commethod(20)
    def get_Value(self) -> Double: ...
    @winrt_commethod(21)
    def put_Value(self, value: Double) -> Void: ...
    @winrt_commethod(22)
    def add_ValueChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.RatingControl, IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(23)
    def remove_ValueChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    Caption = property(get_Caption, put_Caption)
    InitialSetValue = property(get_InitialSetValue, put_InitialSetValue)
    IsClearEnabled = property(get_IsClearEnabled, put_IsClearEnabled)
    IsReadOnly = property(get_IsReadOnly, put_IsReadOnly)
    ItemInfo = property(get_ItemInfo, put_ItemInfo)
    MaxRating = property(get_MaxRating, put_MaxRating)
    PlaceholderValue = property(get_PlaceholderValue, put_PlaceholderValue)
    Value = property(get_Value, put_Value)
    ValueChanged = event(add_ValueChanged, remove_ValueChanged)
class IRatingControlFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IRatingControlFactory'
    _iid_ = Guid('{a53b9b73-bff9-548d-a294-ac63d819f78a}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.RatingControl: ...
class IRatingControlStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IRatingControlStatics'
    _iid_ = Guid('{dac61d65-e8f9-5e4d-813d-05c980b2f118}')
    @winrt_commethod(6)
    def get_CaptionProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_InitialSetValueProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_IsClearEnabledProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_IsReadOnlyProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_MaxRatingProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_PlaceholderValueProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_ItemInfoProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_ValueProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    CaptionProperty = property(get_CaptionProperty, None)
    InitialSetValueProperty = property(get_InitialSetValueProperty, None)
    IsClearEnabledProperty = property(get_IsClearEnabledProperty, None)
    IsReadOnlyProperty = property(get_IsReadOnlyProperty, None)
    ItemInfoProperty = property(get_ItemInfoProperty, None)
    MaxRatingProperty = property(get_MaxRatingProperty, None)
    PlaceholderValueProperty = property(get_PlaceholderValueProperty, None)
    ValueProperty = property(get_ValueProperty, None)
class IRatingItemFontInfo(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IRatingItemFontInfo'
    _iid_ = Guid('{995a16dc-3a0f-5727-9f38-52cfc8143654}')
    @winrt_commethod(6)
    def get_DisabledGlyph(self) -> hstr: ...
    @winrt_commethod(7)
    def put_DisabledGlyph(self, value: hstr) -> Void: ...
    @winrt_commethod(8)
    def get_Glyph(self) -> hstr: ...
    @winrt_commethod(9)
    def put_Glyph(self, value: hstr) -> Void: ...
    @winrt_commethod(10)
    def get_PointerOverGlyph(self) -> hstr: ...
    @winrt_commethod(11)
    def put_PointerOverGlyph(self, value: hstr) -> Void: ...
    @winrt_commethod(12)
    def get_PointerOverPlaceholderGlyph(self) -> hstr: ...
    @winrt_commethod(13)
    def put_PointerOverPlaceholderGlyph(self, value: hstr) -> Void: ...
    @winrt_commethod(14)
    def get_PlaceholderGlyph(self) -> hstr: ...
    @winrt_commethod(15)
    def put_PlaceholderGlyph(self, value: hstr) -> Void: ...
    @winrt_commethod(16)
    def get_UnsetGlyph(self) -> hstr: ...
    @winrt_commethod(17)
    def put_UnsetGlyph(self, value: hstr) -> Void: ...
    DisabledGlyph = property(get_DisabledGlyph, put_DisabledGlyph)
    Glyph = property(get_Glyph, put_Glyph)
    PlaceholderGlyph = property(get_PlaceholderGlyph, put_PlaceholderGlyph)
    PointerOverGlyph = property(get_PointerOverGlyph, put_PointerOverGlyph)
    PointerOverPlaceholderGlyph = property(get_PointerOverPlaceholderGlyph, put_PointerOverPlaceholderGlyph)
    UnsetGlyph = property(get_UnsetGlyph, put_UnsetGlyph)
class IRatingItemFontInfoFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IRatingItemFontInfoFactory'
    _iid_ = Guid('{109c6541-706e-5fd7-baae-020b24899f61}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.RatingItemFontInfo: ...
class IRatingItemFontInfoStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IRatingItemFontInfoStatics'
    _iid_ = Guid('{f600f780-a5ed-537f-90c2-eaee8a61f8a5}')
    @winrt_commethod(6)
    def get_DisabledGlyphProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_GlyphProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_PlaceholderGlyphProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_PointerOverGlyphProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_PointerOverPlaceholderGlyphProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_UnsetGlyphProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    DisabledGlyphProperty = property(get_DisabledGlyphProperty, None)
    GlyphProperty = property(get_GlyphProperty, None)
    PlaceholderGlyphProperty = property(get_PlaceholderGlyphProperty, None)
    PointerOverGlyphProperty = property(get_PointerOverGlyphProperty, None)
    PointerOverPlaceholderGlyphProperty = property(get_PointerOverPlaceholderGlyphProperty, None)
    UnsetGlyphProperty = property(get_UnsetGlyphProperty, None)
class IRatingItemImageInfo(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IRatingItemImageInfo'
    _iid_ = Guid('{fcdaebd2-6fb5-523f-959e-3516bc0b72b7}')
    @winrt_commethod(6)
    def get_DisabledImage(self) -> win32more.Microsoft.UI.Xaml.Media.ImageSource: ...
    @winrt_commethod(7)
    def put_DisabledImage(self, value: win32more.Microsoft.UI.Xaml.Media.ImageSource) -> Void: ...
    @winrt_commethod(8)
    def get_Image(self) -> win32more.Microsoft.UI.Xaml.Media.ImageSource: ...
    @winrt_commethod(9)
    def put_Image(self, value: win32more.Microsoft.UI.Xaml.Media.ImageSource) -> Void: ...
    @winrt_commethod(10)
    def get_PlaceholderImage(self) -> win32more.Microsoft.UI.Xaml.Media.ImageSource: ...
    @winrt_commethod(11)
    def put_PlaceholderImage(self, value: win32more.Microsoft.UI.Xaml.Media.ImageSource) -> Void: ...
    @winrt_commethod(12)
    def get_PointerOverImage(self) -> win32more.Microsoft.UI.Xaml.Media.ImageSource: ...
    @winrt_commethod(13)
    def put_PointerOverImage(self, value: win32more.Microsoft.UI.Xaml.Media.ImageSource) -> Void: ...
    @winrt_commethod(14)
    def get_PointerOverPlaceholderImage(self) -> win32more.Microsoft.UI.Xaml.Media.ImageSource: ...
    @winrt_commethod(15)
    def put_PointerOverPlaceholderImage(self, value: win32more.Microsoft.UI.Xaml.Media.ImageSource) -> Void: ...
    @winrt_commethod(16)
    def get_UnsetImage(self) -> win32more.Microsoft.UI.Xaml.Media.ImageSource: ...
    @winrt_commethod(17)
    def put_UnsetImage(self, value: win32more.Microsoft.UI.Xaml.Media.ImageSource) -> Void: ...
    DisabledImage = property(get_DisabledImage, put_DisabledImage)
    Image = property(get_Image, put_Image)
    PlaceholderImage = property(get_PlaceholderImage, put_PlaceholderImage)
    PointerOverImage = property(get_PointerOverImage, put_PointerOverImage)
    PointerOverPlaceholderImage = property(get_PointerOverPlaceholderImage, put_PointerOverPlaceholderImage)
    UnsetImage = property(get_UnsetImage, put_UnsetImage)
class IRatingItemImageInfoFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IRatingItemImageInfoFactory'
    _iid_ = Guid('{4acc8cac-bca8-5380-95e4-345c1be256b2}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.RatingItemImageInfo: ...
class IRatingItemImageInfoStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IRatingItemImageInfoStatics'
    _iid_ = Guid('{f582921d-0431-5e52-96d9-284d82dc7cba}')
    @winrt_commethod(6)
    def get_DisabledImageProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_ImageProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_PlaceholderImageProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_PointerOverImageProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_PointerOverPlaceholderImageProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_UnsetImageProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    DisabledImageProperty = property(get_DisabledImageProperty, None)
    ImageProperty = property(get_ImageProperty, None)
    PlaceholderImageProperty = property(get_PlaceholderImageProperty, None)
    PointerOverImageProperty = property(get_PointerOverImageProperty, None)
    PointerOverPlaceholderImageProperty = property(get_PointerOverPlaceholderImageProperty, None)
    UnsetImageProperty = property(get_UnsetImageProperty, None)
class IRatingItemInfo(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IRatingItemInfo'
    _iid_ = Guid('{801e924e-3613-55dd-8321-9ebabbed0b8a}')
class IRatingItemInfoFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IRatingItemInfoFactory'
    _iid_ = Guid('{61f13480-cd0c-556a-b532-a0cf53e3cda0}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.RatingItemInfo: ...
class IRefreshContainer(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IRefreshContainer'
    _iid_ = Guid('{1c9778e8-a427-5f86-9d5e-02db9b2c4093}')
    @winrt_commethod(6)
    def get_Visualizer(self) -> win32more.Microsoft.UI.Xaml.Controls.RefreshVisualizer: ...
    @winrt_commethod(7)
    def put_Visualizer(self, value: win32more.Microsoft.UI.Xaml.Controls.RefreshVisualizer) -> Void: ...
    @winrt_commethod(8)
    def get_PullDirection(self) -> win32more.Microsoft.UI.Xaml.Controls.RefreshPullDirection: ...
    @winrt_commethod(9)
    def put_PullDirection(self, value: win32more.Microsoft.UI.Xaml.Controls.RefreshPullDirection) -> Void: ...
    @winrt_commethod(10)
    def add_RefreshRequested(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.RefreshContainer, win32more.Microsoft.UI.Xaml.Controls.RefreshRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(11)
    def remove_RefreshRequested(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(12)
    def RequestRefresh(self) -> Void: ...
    PullDirection = property(get_PullDirection, put_PullDirection)
    Visualizer = property(get_Visualizer, put_Visualizer)
    RefreshRequested = event(add_RefreshRequested, remove_RefreshRequested)
class IRefreshContainerFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IRefreshContainerFactory'
    _iid_ = Guid('{5f228fa1-2ea2-52b5-b78a-0c133f86f020}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.RefreshContainer: ...
class IRefreshContainerStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IRefreshContainerStatics'
    _iid_ = Guid('{875ef8a0-74c2-5201-b708-50a48e7e7601}')
    @winrt_commethod(6)
    def get_VisualizerProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_PullDirectionProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    PullDirectionProperty = property(get_PullDirectionProperty, None)
    VisualizerProperty = property(get_VisualizerProperty, None)
class IRefreshInteractionRatioChangedEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IRefreshInteractionRatioChangedEventArgs'
    _iid_ = Guid('{790b70e0-f199-552b-b126-6cb45c2de8f9}')
    @winrt_commethod(6)
    def get_InteractionRatio(self) -> Double: ...
    InteractionRatio = property(get_InteractionRatio, None)
class IRefreshRequestedEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IRefreshRequestedEventArgs'
    _iid_ = Guid('{ed97a956-6019-5329-9312-f885b5c774cd}')
    @winrt_commethod(6)
    def GetDeferral(self) -> win32more.Windows.Foundation.Deferral: ...
class IRefreshStateChangedEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IRefreshStateChangedEventArgs'
    _iid_ = Guid('{7be897ce-17c4-5fdf-b441-c6ef3301e0f6}')
    @winrt_commethod(6)
    def get_OldState(self) -> win32more.Microsoft.UI.Xaml.Controls.RefreshVisualizerState: ...
    @winrt_commethod(7)
    def get_NewState(self) -> win32more.Microsoft.UI.Xaml.Controls.RefreshVisualizerState: ...
    NewState = property(get_NewState, None)
    OldState = property(get_OldState, None)
class IRefreshVisualizer(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IRefreshVisualizer'
    _iid_ = Guid('{d6c55db6-d82d-5b68-ba1d-28593fb0ab12}')
    @winrt_commethod(6)
    def RequestRefresh(self) -> Void: ...
    @winrt_commethod(7)
    def get_Orientation(self) -> win32more.Microsoft.UI.Xaml.Controls.RefreshVisualizerOrientation: ...
    @winrt_commethod(8)
    def put_Orientation(self, value: win32more.Microsoft.UI.Xaml.Controls.RefreshVisualizerOrientation) -> Void: ...
    @winrt_commethod(9)
    def get_Content(self) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_commethod(10)
    def put_Content(self, value: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    @winrt_commethod(11)
    def get_State(self) -> win32more.Microsoft.UI.Xaml.Controls.RefreshVisualizerState: ...
    @winrt_commethod(12)
    def add_RefreshRequested(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.RefreshVisualizer, win32more.Microsoft.UI.Xaml.Controls.RefreshRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(13)
    def remove_RefreshRequested(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(14)
    def add_RefreshStateChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.RefreshVisualizer, win32more.Microsoft.UI.Xaml.Controls.RefreshStateChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(15)
    def remove_RefreshStateChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    Content = property(get_Content, put_Content)
    Orientation = property(get_Orientation, put_Orientation)
    State = property(get_State, None)
    RefreshRequested = event(add_RefreshRequested, remove_RefreshRequested)
    RefreshStateChanged = event(add_RefreshStateChanged, remove_RefreshStateChanged)
class IRefreshVisualizerFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IRefreshVisualizerFactory'
    _iid_ = Guid('{9d6f2bf2-6628-582a-892b-68c2770c173c}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.RefreshVisualizer: ...
class IRefreshVisualizerStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IRefreshVisualizerStatics'
    _iid_ = Guid('{3540fe79-590d-546f-bf2a-a30d46e8cdfa}')
    @winrt_commethod(6)
    def get_InfoProviderProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_OrientationProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_ContentProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_StateProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    ContentProperty = property(get_ContentProperty, None)
    InfoProviderProperty = property(get_InfoProviderProperty, None)
    OrientationProperty = property(get_OrientationProperty, None)
    StateProperty = property(get_StateProperty, None)
class IRelativePanel(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IRelativePanel'
    _iid_ = Guid('{c432fcc4-88f2-59d8-9d0e-a237beaeb07f}')
    @winrt_commethod(6)
    def get_BackgroundSizing(self) -> win32more.Microsoft.UI.Xaml.Controls.BackgroundSizing: ...
    @winrt_commethod(7)
    def put_BackgroundSizing(self, value: win32more.Microsoft.UI.Xaml.Controls.BackgroundSizing) -> Void: ...
    @winrt_commethod(8)
    def get_BorderBrush(self) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_commethod(9)
    def put_BorderBrush(self, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(10)
    def get_BorderThickness(self) -> win32more.Microsoft.UI.Xaml.Thickness: ...
    @winrt_commethod(11)
    def put_BorderThickness(self, value: win32more.Microsoft.UI.Xaml.Thickness) -> Void: ...
    @winrt_commethod(12)
    def get_CornerRadius(self) -> win32more.Microsoft.UI.Xaml.CornerRadius: ...
    @winrt_commethod(13)
    def put_CornerRadius(self, value: win32more.Microsoft.UI.Xaml.CornerRadius) -> Void: ...
    @winrt_commethod(14)
    def get_Padding(self) -> win32more.Microsoft.UI.Xaml.Thickness: ...
    @winrt_commethod(15)
    def put_Padding(self, value: win32more.Microsoft.UI.Xaml.Thickness) -> Void: ...
    BackgroundSizing = property(get_BackgroundSizing, put_BackgroundSizing)
    BorderBrush = property(get_BorderBrush, put_BorderBrush)
    BorderThickness = property(get_BorderThickness, put_BorderThickness)
    CornerRadius = property(get_CornerRadius, put_CornerRadius)
    Padding = property(get_Padding, put_Padding)
class IRelativePanelFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IRelativePanelFactory'
    _iid_ = Guid('{c85f1443-d973-50fd-9497-b867f492468f}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.RelativePanel: ...
class IRelativePanelStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IRelativePanelStatics'
    _iid_ = Guid('{bdd929a2-76cc-59c4-82c1-f14b5da4221a}')
    @winrt_commethod(6)
    def get_BackgroundSizingProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_LeftOfProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def GetLeftOf(self, element: win32more.Microsoft.UI.Xaml.UIElement) -> IInspectable: ...
    @winrt_commethod(9)
    def SetLeftOf(self, element: win32more.Microsoft.UI.Xaml.UIElement, value: IInspectable) -> Void: ...
    @winrt_commethod(10)
    def get_AboveProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def GetAbove(self, element: win32more.Microsoft.UI.Xaml.UIElement) -> IInspectable: ...
    @winrt_commethod(12)
    def SetAbove(self, element: win32more.Microsoft.UI.Xaml.UIElement, value: IInspectable) -> Void: ...
    @winrt_commethod(13)
    def get_RightOfProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(14)
    def GetRightOf(self, element: win32more.Microsoft.UI.Xaml.UIElement) -> IInspectable: ...
    @winrt_commethod(15)
    def SetRightOf(self, element: win32more.Microsoft.UI.Xaml.UIElement, value: IInspectable) -> Void: ...
    @winrt_commethod(16)
    def get_BelowProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(17)
    def GetBelow(self, element: win32more.Microsoft.UI.Xaml.UIElement) -> IInspectable: ...
    @winrt_commethod(18)
    def SetBelow(self, element: win32more.Microsoft.UI.Xaml.UIElement, value: IInspectable) -> Void: ...
    @winrt_commethod(19)
    def get_AlignHorizontalCenterWithProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(20)
    def GetAlignHorizontalCenterWith(self, element: win32more.Microsoft.UI.Xaml.UIElement) -> IInspectable: ...
    @winrt_commethod(21)
    def SetAlignHorizontalCenterWith(self, element: win32more.Microsoft.UI.Xaml.UIElement, value: IInspectable) -> Void: ...
    @winrt_commethod(22)
    def get_AlignVerticalCenterWithProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(23)
    def GetAlignVerticalCenterWith(self, element: win32more.Microsoft.UI.Xaml.UIElement) -> IInspectable: ...
    @winrt_commethod(24)
    def SetAlignVerticalCenterWith(self, element: win32more.Microsoft.UI.Xaml.UIElement, value: IInspectable) -> Void: ...
    @winrt_commethod(25)
    def get_AlignLeftWithProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(26)
    def GetAlignLeftWith(self, element: win32more.Microsoft.UI.Xaml.UIElement) -> IInspectable: ...
    @winrt_commethod(27)
    def SetAlignLeftWith(self, element: win32more.Microsoft.UI.Xaml.UIElement, value: IInspectable) -> Void: ...
    @winrt_commethod(28)
    def get_AlignTopWithProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(29)
    def GetAlignTopWith(self, element: win32more.Microsoft.UI.Xaml.UIElement) -> IInspectable: ...
    @winrt_commethod(30)
    def SetAlignTopWith(self, element: win32more.Microsoft.UI.Xaml.UIElement, value: IInspectable) -> Void: ...
    @winrt_commethod(31)
    def get_AlignRightWithProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(32)
    def GetAlignRightWith(self, element: win32more.Microsoft.UI.Xaml.UIElement) -> IInspectable: ...
    @winrt_commethod(33)
    def SetAlignRightWith(self, element: win32more.Microsoft.UI.Xaml.UIElement, value: IInspectable) -> Void: ...
    @winrt_commethod(34)
    def get_AlignBottomWithProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(35)
    def GetAlignBottomWith(self, element: win32more.Microsoft.UI.Xaml.UIElement) -> IInspectable: ...
    @winrt_commethod(36)
    def SetAlignBottomWith(self, element: win32more.Microsoft.UI.Xaml.UIElement, value: IInspectable) -> Void: ...
    @winrt_commethod(37)
    def get_AlignLeftWithPanelProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(38)
    def GetAlignLeftWithPanel(self, element: win32more.Microsoft.UI.Xaml.UIElement) -> Boolean: ...
    @winrt_commethod(39)
    def SetAlignLeftWithPanel(self, element: win32more.Microsoft.UI.Xaml.UIElement, value: Boolean) -> Void: ...
    @winrt_commethod(40)
    def get_AlignTopWithPanelProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(41)
    def GetAlignTopWithPanel(self, element: win32more.Microsoft.UI.Xaml.UIElement) -> Boolean: ...
    @winrt_commethod(42)
    def SetAlignTopWithPanel(self, element: win32more.Microsoft.UI.Xaml.UIElement, value: Boolean) -> Void: ...
    @winrt_commethod(43)
    def get_AlignRightWithPanelProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(44)
    def GetAlignRightWithPanel(self, element: win32more.Microsoft.UI.Xaml.UIElement) -> Boolean: ...
    @winrt_commethod(45)
    def SetAlignRightWithPanel(self, element: win32more.Microsoft.UI.Xaml.UIElement, value: Boolean) -> Void: ...
    @winrt_commethod(46)
    def get_AlignBottomWithPanelProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(47)
    def GetAlignBottomWithPanel(self, element: win32more.Microsoft.UI.Xaml.UIElement) -> Boolean: ...
    @winrt_commethod(48)
    def SetAlignBottomWithPanel(self, element: win32more.Microsoft.UI.Xaml.UIElement, value: Boolean) -> Void: ...
    @winrt_commethod(49)
    def get_AlignHorizontalCenterWithPanelProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(50)
    def GetAlignHorizontalCenterWithPanel(self, element: win32more.Microsoft.UI.Xaml.UIElement) -> Boolean: ...
    @winrt_commethod(51)
    def SetAlignHorizontalCenterWithPanel(self, element: win32more.Microsoft.UI.Xaml.UIElement, value: Boolean) -> Void: ...
    @winrt_commethod(52)
    def get_AlignVerticalCenterWithPanelProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(53)
    def GetAlignVerticalCenterWithPanel(self, element: win32more.Microsoft.UI.Xaml.UIElement) -> Boolean: ...
    @winrt_commethod(54)
    def SetAlignVerticalCenterWithPanel(self, element: win32more.Microsoft.UI.Xaml.UIElement, value: Boolean) -> Void: ...
    @winrt_commethod(55)
    def get_BorderBrushProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(56)
    def get_BorderThicknessProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(57)
    def get_CornerRadiusProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(58)
    def get_PaddingProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    AboveProperty = property(get_AboveProperty, None)
    AlignBottomWithPanelProperty = property(get_AlignBottomWithPanelProperty, None)
    AlignBottomWithProperty = property(get_AlignBottomWithProperty, None)
    AlignHorizontalCenterWithPanelProperty = property(get_AlignHorizontalCenterWithPanelProperty, None)
    AlignHorizontalCenterWithProperty = property(get_AlignHorizontalCenterWithProperty, None)
    AlignLeftWithPanelProperty = property(get_AlignLeftWithPanelProperty, None)
    AlignLeftWithProperty = property(get_AlignLeftWithProperty, None)
    AlignRightWithPanelProperty = property(get_AlignRightWithPanelProperty, None)
    AlignRightWithProperty = property(get_AlignRightWithProperty, None)
    AlignTopWithPanelProperty = property(get_AlignTopWithPanelProperty, None)
    AlignTopWithProperty = property(get_AlignTopWithProperty, None)
    AlignVerticalCenterWithPanelProperty = property(get_AlignVerticalCenterWithPanelProperty, None)
    AlignVerticalCenterWithProperty = property(get_AlignVerticalCenterWithProperty, None)
    BackgroundSizingProperty = property(get_BackgroundSizingProperty, None)
    BelowProperty = property(get_BelowProperty, None)
    BorderBrushProperty = property(get_BorderBrushProperty, None)
    BorderThicknessProperty = property(get_BorderThicknessProperty, None)
    CornerRadiusProperty = property(get_CornerRadiusProperty, None)
    LeftOfProperty = property(get_LeftOfProperty, None)
    PaddingProperty = property(get_PaddingProperty, None)
    RightOfProperty = property(get_RightOfProperty, None)
class IRevealListViewItemPresenter(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IRevealListViewItemPresenter'
    _iid_ = Guid('{365fdbac-3989-559c-bea9-764561881c96}')
class IRevealListViewItemPresenterFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IRevealListViewItemPresenterFactory'
    _iid_ = Guid('{e730c53b-8f94-55b3-8bc1-98f77c5766bd}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.RevealListViewItemPresenter: ...
class IRichEditBox(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IRichEditBox'
    _iid_ = Guid('{699163db-723d-5514-a8c9-2c64d99e1ea6}')
    @winrt_commethod(6)
    def get_IsReadOnly(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_IsReadOnly(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def get_AcceptsReturn(self) -> Boolean: ...
    @winrt_commethod(9)
    def put_AcceptsReturn(self, value: Boolean) -> Void: ...
    @winrt_commethod(10)
    def get_TextAlignment(self) -> win32more.Microsoft.UI.Xaml.TextAlignment: ...
    @winrt_commethod(11)
    def put_TextAlignment(self, value: win32more.Microsoft.UI.Xaml.TextAlignment) -> Void: ...
    @winrt_commethod(12)
    def get_TextWrapping(self) -> win32more.Microsoft.UI.Xaml.TextWrapping: ...
    @winrt_commethod(13)
    def put_TextWrapping(self, value: win32more.Microsoft.UI.Xaml.TextWrapping) -> Void: ...
    @winrt_commethod(14)
    def get_IsSpellCheckEnabled(self) -> Boolean: ...
    @winrt_commethod(15)
    def put_IsSpellCheckEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(16)
    def get_IsTextPredictionEnabled(self) -> Boolean: ...
    @winrt_commethod(17)
    def put_IsTextPredictionEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(18)
    def get_Document(self) -> win32more.Microsoft.UI.Text.RichEditTextDocument: ...
    @winrt_commethod(19)
    def get_InputScope(self) -> win32more.Microsoft.UI.Xaml.Input.InputScope: ...
    @winrt_commethod(20)
    def put_InputScope(self, value: win32more.Microsoft.UI.Xaml.Input.InputScope) -> Void: ...
    @winrt_commethod(21)
    def get_Header(self) -> IInspectable: ...
    @winrt_commethod(22)
    def put_Header(self, value: IInspectable) -> Void: ...
    @winrt_commethod(23)
    def get_HeaderTemplate(self) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_commethod(24)
    def put_HeaderTemplate(self, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_commethod(25)
    def get_PlaceholderText(self) -> hstr: ...
    @winrt_commethod(26)
    def put_PlaceholderText(self, value: hstr) -> Void: ...
    @winrt_commethod(27)
    def get_SelectionHighlightColor(self) -> win32more.Microsoft.UI.Xaml.Media.SolidColorBrush: ...
    @winrt_commethod(28)
    def put_SelectionHighlightColor(self, value: win32more.Microsoft.UI.Xaml.Media.SolidColorBrush) -> Void: ...
    @winrt_commethod(29)
    def get_PreventKeyboardDisplayOnProgrammaticFocus(self) -> Boolean: ...
    @winrt_commethod(30)
    def put_PreventKeyboardDisplayOnProgrammaticFocus(self, value: Boolean) -> Void: ...
    @winrt_commethod(31)
    def get_IsColorFontEnabled(self) -> Boolean: ...
    @winrt_commethod(32)
    def put_IsColorFontEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(33)
    def get_SelectionHighlightColorWhenNotFocused(self) -> win32more.Microsoft.UI.Xaml.Media.SolidColorBrush: ...
    @winrt_commethod(34)
    def put_SelectionHighlightColorWhenNotFocused(self, value: win32more.Microsoft.UI.Xaml.Media.SolidColorBrush) -> Void: ...
    @winrt_commethod(35)
    def get_MaxLength(self) -> Int32: ...
    @winrt_commethod(36)
    def put_MaxLength(self, value: Int32) -> Void: ...
    @winrt_commethod(37)
    def get_HorizontalTextAlignment(self) -> win32more.Microsoft.UI.Xaml.TextAlignment: ...
    @winrt_commethod(38)
    def put_HorizontalTextAlignment(self, value: win32more.Microsoft.UI.Xaml.TextAlignment) -> Void: ...
    @winrt_commethod(39)
    def get_CharacterCasing(self) -> win32more.Microsoft.UI.Xaml.Controls.CharacterCasing: ...
    @winrt_commethod(40)
    def put_CharacterCasing(self, value: win32more.Microsoft.UI.Xaml.Controls.CharacterCasing) -> Void: ...
    @winrt_commethod(41)
    def get_DisabledFormattingAccelerators(self) -> win32more.Microsoft.UI.Xaml.Controls.DisabledFormattingAccelerators: ...
    @winrt_commethod(42)
    def put_DisabledFormattingAccelerators(self, value: win32more.Microsoft.UI.Xaml.Controls.DisabledFormattingAccelerators) -> Void: ...
    @winrt_commethod(43)
    def get_TextDocument(self) -> win32more.Microsoft.UI.Text.RichEditTextDocument: ...
    @winrt_commethod(44)
    def get_SelectionFlyout(self) -> win32more.Microsoft.UI.Xaml.Controls.Primitives.FlyoutBase: ...
    @winrt_commethod(45)
    def put_SelectionFlyout(self, value: win32more.Microsoft.UI.Xaml.Controls.Primitives.FlyoutBase) -> Void: ...
    @winrt_commethod(46)
    def get_ProofingMenuFlyout(self) -> win32more.Microsoft.UI.Xaml.Controls.Primitives.FlyoutBase: ...
    @winrt_commethod(47)
    def get_Description(self) -> IInspectable: ...
    @winrt_commethod(48)
    def put_Description(self, value: IInspectable) -> Void: ...
    @winrt_commethod(49)
    def add_TextChanged(self, handler: win32more.Microsoft.UI.Xaml.RoutedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(50)
    def remove_TextChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(51)
    def add_SelectionChanged(self, handler: win32more.Microsoft.UI.Xaml.RoutedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(52)
    def remove_SelectionChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(53)
    def add_ContextMenuOpening(self, handler: win32more.Microsoft.UI.Xaml.Controls.ContextMenuOpeningEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(54)
    def remove_ContextMenuOpening(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(55)
    def add_Paste(self, handler: win32more.Microsoft.UI.Xaml.Controls.TextControlPasteEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(56)
    def remove_Paste(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(57)
    def add_TextCompositionStarted(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.RichEditBox, win32more.Microsoft.UI.Xaml.Controls.TextCompositionStartedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(58)
    def remove_TextCompositionStarted(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(59)
    def add_TextCompositionChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.RichEditBox, win32more.Microsoft.UI.Xaml.Controls.TextCompositionChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(60)
    def remove_TextCompositionChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(61)
    def add_TextCompositionEnded(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.RichEditBox, win32more.Microsoft.UI.Xaml.Controls.TextCompositionEndedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(62)
    def remove_TextCompositionEnded(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(63)
    def add_CopyingToClipboard(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.RichEditBox, win32more.Microsoft.UI.Xaml.Controls.TextControlCopyingToClipboardEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(64)
    def remove_CopyingToClipboard(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(65)
    def add_CuttingToClipboard(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.RichEditBox, win32more.Microsoft.UI.Xaml.Controls.TextControlCuttingToClipboardEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(66)
    def remove_CuttingToClipboard(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(67)
    def add_SelectionChanging(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.RichEditBox, win32more.Microsoft.UI.Xaml.Controls.RichEditBoxSelectionChangingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(68)
    def remove_SelectionChanging(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(69)
    def GetLinguisticAlternativesAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[hstr]]: ...
    @winrt_commethod(70)
    def get_TextReadingOrder(self) -> win32more.Microsoft.UI.Xaml.TextReadingOrder: ...
    @winrt_commethod(71)
    def put_TextReadingOrder(self, value: win32more.Microsoft.UI.Xaml.TextReadingOrder) -> Void: ...
    @winrt_commethod(72)
    def get_ClipboardCopyFormat(self) -> win32more.Microsoft.UI.Xaml.Controls.RichEditClipboardFormat: ...
    @winrt_commethod(73)
    def put_ClipboardCopyFormat(self, value: win32more.Microsoft.UI.Xaml.Controls.RichEditClipboardFormat) -> Void: ...
    @winrt_commethod(74)
    def get_DesiredCandidateWindowAlignment(self) -> win32more.Microsoft.UI.Xaml.Controls.CandidateWindowAlignment: ...
    @winrt_commethod(75)
    def put_DesiredCandidateWindowAlignment(self, value: win32more.Microsoft.UI.Xaml.Controls.CandidateWindowAlignment) -> Void: ...
    @winrt_commethod(76)
    def add_CandidateWindowBoundsChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.RichEditBox, win32more.Microsoft.UI.Xaml.Controls.CandidateWindowBoundsChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(77)
    def remove_CandidateWindowBoundsChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(78)
    def add_TextChanging(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.RichEditBox, win32more.Microsoft.UI.Xaml.Controls.RichEditBoxTextChangingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(79)
    def remove_TextChanging(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    AcceptsReturn = property(get_AcceptsReturn, put_AcceptsReturn)
    CharacterCasing = property(get_CharacterCasing, put_CharacterCasing)
    ClipboardCopyFormat = property(get_ClipboardCopyFormat, put_ClipboardCopyFormat)
    Description = property(get_Description, put_Description)
    DesiredCandidateWindowAlignment = property(get_DesiredCandidateWindowAlignment, put_DesiredCandidateWindowAlignment)
    DisabledFormattingAccelerators = property(get_DisabledFormattingAccelerators, put_DisabledFormattingAccelerators)
    Document = property(get_Document, None)
    Header = property(get_Header, put_Header)
    HeaderTemplate = property(get_HeaderTemplate, put_HeaderTemplate)
    HorizontalTextAlignment = property(get_HorizontalTextAlignment, put_HorizontalTextAlignment)
    InputScope = property(get_InputScope, put_InputScope)
    IsColorFontEnabled = property(get_IsColorFontEnabled, put_IsColorFontEnabled)
    IsReadOnly = property(get_IsReadOnly, put_IsReadOnly)
    IsSpellCheckEnabled = property(get_IsSpellCheckEnabled, put_IsSpellCheckEnabled)
    IsTextPredictionEnabled = property(get_IsTextPredictionEnabled, put_IsTextPredictionEnabled)
    MaxLength = property(get_MaxLength, put_MaxLength)
    PlaceholderText = property(get_PlaceholderText, put_PlaceholderText)
    PreventKeyboardDisplayOnProgrammaticFocus = property(get_PreventKeyboardDisplayOnProgrammaticFocus, put_PreventKeyboardDisplayOnProgrammaticFocus)
    ProofingMenuFlyout = property(get_ProofingMenuFlyout, None)
    SelectionFlyout = property(get_SelectionFlyout, put_SelectionFlyout)
    SelectionHighlightColor = property(get_SelectionHighlightColor, put_SelectionHighlightColor)
    SelectionHighlightColorWhenNotFocused = property(get_SelectionHighlightColorWhenNotFocused, put_SelectionHighlightColorWhenNotFocused)
    TextAlignment = property(get_TextAlignment, put_TextAlignment)
    TextDocument = property(get_TextDocument, None)
    TextReadingOrder = property(get_TextReadingOrder, put_TextReadingOrder)
    TextWrapping = property(get_TextWrapping, put_TextWrapping)
    CandidateWindowBoundsChanged = event(add_CandidateWindowBoundsChanged, remove_CandidateWindowBoundsChanged)
    ContextMenuOpening = event(add_ContextMenuOpening, remove_ContextMenuOpening)
    CopyingToClipboard = event(add_CopyingToClipboard, remove_CopyingToClipboard)
    CuttingToClipboard = event(add_CuttingToClipboard, remove_CuttingToClipboard)
    Paste = event(add_Paste, remove_Paste)
    SelectionChanged = event(add_SelectionChanged, remove_SelectionChanged)
    SelectionChanging = event(add_SelectionChanging, remove_SelectionChanging)
    TextChanged = event(add_TextChanged, remove_TextChanged)
    TextChanging = event(add_TextChanging, remove_TextChanging)
    TextCompositionChanged = event(add_TextCompositionChanged, remove_TextCompositionChanged)
    TextCompositionEnded = event(add_TextCompositionEnded, remove_TextCompositionEnded)
    TextCompositionStarted = event(add_TextCompositionStarted, remove_TextCompositionStarted)
class IRichEditBoxFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IRichEditBoxFactory'
    _iid_ = Guid('{7c993c60-f5b6-589f-bba8-b68b9713e4ae}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.RichEditBox: ...
class IRichEditBoxSelectionChangingEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IRichEditBoxSelectionChangingEventArgs'
    _iid_ = Guid('{5dbadbe1-0515-5045-9a6f-6859237301ac}')
    @winrt_commethod(6)
    def get_SelectionStart(self) -> Int32: ...
    @winrt_commethod(7)
    def get_SelectionLength(self) -> Int32: ...
    @winrt_commethod(8)
    def get_Cancel(self) -> Boolean: ...
    @winrt_commethod(9)
    def put_Cancel(self, value: Boolean) -> Void: ...
    Cancel = property(get_Cancel, put_Cancel)
    SelectionLength = property(get_SelectionLength, None)
    SelectionStart = property(get_SelectionStart, None)
class IRichEditBoxStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IRichEditBoxStatics'
    _iid_ = Guid('{b3f59239-efd1-5129-bf80-2841a331b24a}')
    @winrt_commethod(6)
    def get_IsReadOnlyProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_AcceptsReturnProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_TextAlignmentProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_TextWrappingProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_IsSpellCheckEnabledProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_IsTextPredictionEnabledProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_InputScopeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_HeaderProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(14)
    def get_HeaderTemplateProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(15)
    def get_PlaceholderTextProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(16)
    def get_SelectionHighlightColorProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(17)
    def get_PreventKeyboardDisplayOnProgrammaticFocusProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(18)
    def get_IsColorFontEnabledProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(19)
    def get_SelectionHighlightColorWhenNotFocusedProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(20)
    def get_MaxLengthProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(21)
    def get_HorizontalTextAlignmentProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(22)
    def get_CharacterCasingProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(23)
    def get_DisabledFormattingAcceleratorsProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(24)
    def get_SelectionFlyoutProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(25)
    def get_ProofingMenuFlyoutProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(26)
    def get_DescriptionProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(27)
    def get_DesiredCandidateWindowAlignmentProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(28)
    def get_TextReadingOrderProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(29)
    def get_ClipboardCopyFormatProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    AcceptsReturnProperty = property(get_AcceptsReturnProperty, None)
    CharacterCasingProperty = property(get_CharacterCasingProperty, None)
    ClipboardCopyFormatProperty = property(get_ClipboardCopyFormatProperty, None)
    DescriptionProperty = property(get_DescriptionProperty, None)
    DesiredCandidateWindowAlignmentProperty = property(get_DesiredCandidateWindowAlignmentProperty, None)
    DisabledFormattingAcceleratorsProperty = property(get_DisabledFormattingAcceleratorsProperty, None)
    HeaderProperty = property(get_HeaderProperty, None)
    HeaderTemplateProperty = property(get_HeaderTemplateProperty, None)
    HorizontalTextAlignmentProperty = property(get_HorizontalTextAlignmentProperty, None)
    InputScopeProperty = property(get_InputScopeProperty, None)
    IsColorFontEnabledProperty = property(get_IsColorFontEnabledProperty, None)
    IsReadOnlyProperty = property(get_IsReadOnlyProperty, None)
    IsSpellCheckEnabledProperty = property(get_IsSpellCheckEnabledProperty, None)
    IsTextPredictionEnabledProperty = property(get_IsTextPredictionEnabledProperty, None)
    MaxLengthProperty = property(get_MaxLengthProperty, None)
    PlaceholderTextProperty = property(get_PlaceholderTextProperty, None)
    PreventKeyboardDisplayOnProgrammaticFocusProperty = property(get_PreventKeyboardDisplayOnProgrammaticFocusProperty, None)
    ProofingMenuFlyoutProperty = property(get_ProofingMenuFlyoutProperty, None)
    SelectionFlyoutProperty = property(get_SelectionFlyoutProperty, None)
    SelectionHighlightColorProperty = property(get_SelectionHighlightColorProperty, None)
    SelectionHighlightColorWhenNotFocusedProperty = property(get_SelectionHighlightColorWhenNotFocusedProperty, None)
    TextAlignmentProperty = property(get_TextAlignmentProperty, None)
    TextReadingOrderProperty = property(get_TextReadingOrderProperty, None)
    TextWrappingProperty = property(get_TextWrappingProperty, None)
class IRichEditBoxTextChangingEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IRichEditBoxTextChangingEventArgs'
    _iid_ = Guid('{e887b29a-1551-5868-a5dc-3fcfe7452e6b}')
    @winrt_commethod(6)
    def get_IsContentChanging(self) -> Boolean: ...
    IsContentChanging = property(get_IsContentChanging, None)
class IRichTextBlock(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IRichTextBlock'
    _iid_ = Guid('{d766e4db-a684-50b7-a202-c8e91fa26ff3}')
    @winrt_commethod(6)
    def get_FontSize(self) -> Double: ...
    @winrt_commethod(7)
    def put_FontSize(self, value: Double) -> Void: ...
    @winrt_commethod(8)
    def get_FontFamily(self) -> win32more.Microsoft.UI.Xaml.Media.FontFamily: ...
    @winrt_commethod(9)
    def put_FontFamily(self, value: win32more.Microsoft.UI.Xaml.Media.FontFamily) -> Void: ...
    @winrt_commethod(10)
    def get_FontWeight(self) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_commethod(11)
    def put_FontWeight(self, value: win32more.Windows.UI.Text.FontWeight) -> Void: ...
    @winrt_commethod(12)
    def get_FontStyle(self) -> win32more.Windows.UI.Text.FontStyle: ...
    @winrt_commethod(13)
    def put_FontStyle(self, value: win32more.Windows.UI.Text.FontStyle) -> Void: ...
    @winrt_commethod(14)
    def get_FontStretch(self) -> win32more.Windows.UI.Text.FontStretch: ...
    @winrt_commethod(15)
    def put_FontStretch(self, value: win32more.Windows.UI.Text.FontStretch) -> Void: ...
    @winrt_commethod(16)
    def get_Foreground(self) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_commethod(17)
    def put_Foreground(self, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(18)
    def get_TextWrapping(self) -> win32more.Microsoft.UI.Xaml.TextWrapping: ...
    @winrt_commethod(19)
    def put_TextWrapping(self, value: win32more.Microsoft.UI.Xaml.TextWrapping) -> Void: ...
    @winrt_commethod(20)
    def get_TextTrimming(self) -> win32more.Microsoft.UI.Xaml.TextTrimming: ...
    @winrt_commethod(21)
    def put_TextTrimming(self, value: win32more.Microsoft.UI.Xaml.TextTrimming) -> Void: ...
    @winrt_commethod(22)
    def get_TextAlignment(self) -> win32more.Microsoft.UI.Xaml.TextAlignment: ...
    @winrt_commethod(23)
    def put_TextAlignment(self, value: win32more.Microsoft.UI.Xaml.TextAlignment) -> Void: ...
    @winrt_commethod(24)
    def get_Blocks(self) -> win32more.Microsoft.UI.Xaml.Documents.BlockCollection: ...
    @winrt_commethod(25)
    def get_Padding(self) -> win32more.Microsoft.UI.Xaml.Thickness: ...
    @winrt_commethod(26)
    def put_Padding(self, value: win32more.Microsoft.UI.Xaml.Thickness) -> Void: ...
    @winrt_commethod(27)
    def get_LineHeight(self) -> Double: ...
    @winrt_commethod(28)
    def put_LineHeight(self, value: Double) -> Void: ...
    @winrt_commethod(29)
    def get_LineStackingStrategy(self) -> win32more.Microsoft.UI.Xaml.LineStackingStrategy: ...
    @winrt_commethod(30)
    def put_LineStackingStrategy(self, value: win32more.Microsoft.UI.Xaml.LineStackingStrategy) -> Void: ...
    @winrt_commethod(31)
    def get_CharacterSpacing(self) -> Int32: ...
    @winrt_commethod(32)
    def put_CharacterSpacing(self, value: Int32) -> Void: ...
    @winrt_commethod(33)
    def get_OverflowContentTarget(self) -> win32more.Microsoft.UI.Xaml.Controls.RichTextBlockOverflow: ...
    @winrt_commethod(34)
    def put_OverflowContentTarget(self, value: win32more.Microsoft.UI.Xaml.Controls.RichTextBlockOverflow) -> Void: ...
    @winrt_commethod(35)
    def get_IsTextSelectionEnabled(self) -> Boolean: ...
    @winrt_commethod(36)
    def put_IsTextSelectionEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(37)
    def get_HasOverflowContent(self) -> Boolean: ...
    @winrt_commethod(38)
    def get_SelectedText(self) -> hstr: ...
    @winrt_commethod(39)
    def get_ContentStart(self) -> win32more.Microsoft.UI.Xaml.Documents.TextPointer: ...
    @winrt_commethod(40)
    def get_ContentEnd(self) -> win32more.Microsoft.UI.Xaml.Documents.TextPointer: ...
    @winrt_commethod(41)
    def get_SelectionStart(self) -> win32more.Microsoft.UI.Xaml.Documents.TextPointer: ...
    @winrt_commethod(42)
    def get_SelectionEnd(self) -> win32more.Microsoft.UI.Xaml.Documents.TextPointer: ...
    @winrt_commethod(43)
    def get_BaselineOffset(self) -> Double: ...
    @winrt_commethod(44)
    def get_MaxLines(self) -> Int32: ...
    @winrt_commethod(45)
    def put_MaxLines(self, value: Int32) -> Void: ...
    @winrt_commethod(46)
    def get_TextLineBounds(self) -> win32more.Microsoft.UI.Xaml.TextLineBounds: ...
    @winrt_commethod(47)
    def put_TextLineBounds(self, value: win32more.Microsoft.UI.Xaml.TextLineBounds) -> Void: ...
    @winrt_commethod(48)
    def get_SelectionHighlightColor(self) -> win32more.Microsoft.UI.Xaml.Media.SolidColorBrush: ...
    @winrt_commethod(49)
    def put_SelectionHighlightColor(self, value: win32more.Microsoft.UI.Xaml.Media.SolidColorBrush) -> Void: ...
    @winrt_commethod(50)
    def get_OpticalMarginAlignment(self) -> win32more.Microsoft.UI.Xaml.OpticalMarginAlignment: ...
    @winrt_commethod(51)
    def put_OpticalMarginAlignment(self, value: win32more.Microsoft.UI.Xaml.OpticalMarginAlignment) -> Void: ...
    @winrt_commethod(52)
    def get_IsColorFontEnabled(self) -> Boolean: ...
    @winrt_commethod(53)
    def put_IsColorFontEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(54)
    def get_TextReadingOrder(self) -> win32more.Microsoft.UI.Xaml.TextReadingOrder: ...
    @winrt_commethod(55)
    def put_TextReadingOrder(self, value: win32more.Microsoft.UI.Xaml.TextReadingOrder) -> Void: ...
    @winrt_commethod(56)
    def get_IsTextScaleFactorEnabled(self) -> Boolean: ...
    @winrt_commethod(57)
    def put_IsTextScaleFactorEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(58)
    def get_TextDecorations(self) -> win32more.Windows.UI.Text.TextDecorations: ...
    @winrt_commethod(59)
    def put_TextDecorations(self, value: win32more.Windows.UI.Text.TextDecorations) -> Void: ...
    @winrt_commethod(60)
    def get_IsTextTrimmed(self) -> Boolean: ...
    @winrt_commethod(61)
    def get_HorizontalTextAlignment(self) -> win32more.Microsoft.UI.Xaml.TextAlignment: ...
    @winrt_commethod(62)
    def put_HorizontalTextAlignment(self, value: win32more.Microsoft.UI.Xaml.TextAlignment) -> Void: ...
    @winrt_commethod(63)
    def get_TextHighlighters(self) -> win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Documents.TextHighlighter]: ...
    @winrt_commethod(64)
    def get_SelectionFlyout(self) -> win32more.Microsoft.UI.Xaml.Controls.Primitives.FlyoutBase: ...
    @winrt_commethod(65)
    def put_SelectionFlyout(self, value: win32more.Microsoft.UI.Xaml.Controls.Primitives.FlyoutBase) -> Void: ...
    @winrt_commethod(66)
    def add_SelectionChanged(self, handler: win32more.Microsoft.UI.Xaml.RoutedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(67)
    def remove_SelectionChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(68)
    def add_ContextMenuOpening(self, handler: win32more.Microsoft.UI.Xaml.Controls.ContextMenuOpeningEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(69)
    def remove_ContextMenuOpening(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(70)
    def add_IsTextTrimmedChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.RichTextBlock, win32more.Microsoft.UI.Xaml.Controls.IsTextTrimmedChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(71)
    def remove_IsTextTrimmedChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(72)
    def SelectAll(self) -> Void: ...
    @winrt_commethod(73)
    def Select(self, start: win32more.Microsoft.UI.Xaml.Documents.TextPointer, end: win32more.Microsoft.UI.Xaml.Documents.TextPointer) -> Void: ...
    @winrt_commethod(74)
    def GetPositionFromPoint(self, point: win32more.Windows.Foundation.Point) -> win32more.Microsoft.UI.Xaml.Documents.TextPointer: ...
    @winrt_commethod(75)
    def CopySelectionToClipboard(self) -> Void: ...
    @winrt_commethod(76)
    def get_TextIndent(self) -> Double: ...
    @winrt_commethod(77)
    def put_TextIndent(self, value: Double) -> Void: ...
    BaselineOffset = property(get_BaselineOffset, None)
    Blocks = property(get_Blocks, None)
    CharacterSpacing = property(get_CharacterSpacing, put_CharacterSpacing)
    ContentEnd = property(get_ContentEnd, None)
    ContentStart = property(get_ContentStart, None)
    FontFamily = property(get_FontFamily, put_FontFamily)
    FontSize = property(get_FontSize, put_FontSize)
    FontStretch = property(get_FontStretch, put_FontStretch)
    FontStyle = property(get_FontStyle, put_FontStyle)
    FontWeight = property(get_FontWeight, put_FontWeight)
    Foreground = property(get_Foreground, put_Foreground)
    HasOverflowContent = property(get_HasOverflowContent, None)
    HorizontalTextAlignment = property(get_HorizontalTextAlignment, put_HorizontalTextAlignment)
    IsColorFontEnabled = property(get_IsColorFontEnabled, put_IsColorFontEnabled)
    IsTextScaleFactorEnabled = property(get_IsTextScaleFactorEnabled, put_IsTextScaleFactorEnabled)
    IsTextSelectionEnabled = property(get_IsTextSelectionEnabled, put_IsTextSelectionEnabled)
    IsTextTrimmed = property(get_IsTextTrimmed, None)
    LineHeight = property(get_LineHeight, put_LineHeight)
    LineStackingStrategy = property(get_LineStackingStrategy, put_LineStackingStrategy)
    MaxLines = property(get_MaxLines, put_MaxLines)
    OpticalMarginAlignment = property(get_OpticalMarginAlignment, put_OpticalMarginAlignment)
    OverflowContentTarget = property(get_OverflowContentTarget, put_OverflowContentTarget)
    Padding = property(get_Padding, put_Padding)
    SelectedText = property(get_SelectedText, None)
    SelectionEnd = property(get_SelectionEnd, None)
    SelectionFlyout = property(get_SelectionFlyout, put_SelectionFlyout)
    SelectionHighlightColor = property(get_SelectionHighlightColor, put_SelectionHighlightColor)
    SelectionStart = property(get_SelectionStart, None)
    TextAlignment = property(get_TextAlignment, put_TextAlignment)
    TextDecorations = property(get_TextDecorations, put_TextDecorations)
    TextHighlighters = property(get_TextHighlighters, None)
    TextIndent = property(get_TextIndent, put_TextIndent)
    TextLineBounds = property(get_TextLineBounds, put_TextLineBounds)
    TextReadingOrder = property(get_TextReadingOrder, put_TextReadingOrder)
    TextTrimming = property(get_TextTrimming, put_TextTrimming)
    TextWrapping = property(get_TextWrapping, put_TextWrapping)
    ContextMenuOpening = event(add_ContextMenuOpening, remove_ContextMenuOpening)
    IsTextTrimmedChanged = event(add_IsTextTrimmedChanged, remove_IsTextTrimmedChanged)
    SelectionChanged = event(add_SelectionChanged, remove_SelectionChanged)
class IRichTextBlockOverflow(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IRichTextBlockOverflow'
    _iid_ = Guid('{015c2522-0646-5c71-9f54-3c38c7235a62}')
    @winrt_commethod(6)
    def get_OverflowContentTarget(self) -> win32more.Microsoft.UI.Xaml.Controls.RichTextBlockOverflow: ...
    @winrt_commethod(7)
    def put_OverflowContentTarget(self, value: win32more.Microsoft.UI.Xaml.Controls.RichTextBlockOverflow) -> Void: ...
    @winrt_commethod(8)
    def get_Padding(self) -> win32more.Microsoft.UI.Xaml.Thickness: ...
    @winrt_commethod(9)
    def put_Padding(self, value: win32more.Microsoft.UI.Xaml.Thickness) -> Void: ...
    @winrt_commethod(10)
    def get_ContentSource(self) -> win32more.Microsoft.UI.Xaml.Controls.RichTextBlock: ...
    @winrt_commethod(11)
    def get_HasOverflowContent(self) -> Boolean: ...
    @winrt_commethod(12)
    def get_ContentStart(self) -> win32more.Microsoft.UI.Xaml.Documents.TextPointer: ...
    @winrt_commethod(13)
    def get_ContentEnd(self) -> win32more.Microsoft.UI.Xaml.Documents.TextPointer: ...
    @winrt_commethod(14)
    def get_BaselineOffset(self) -> Double: ...
    @winrt_commethod(15)
    def get_MaxLines(self) -> Int32: ...
    @winrt_commethod(16)
    def put_MaxLines(self, value: Int32) -> Void: ...
    @winrt_commethod(17)
    def get_IsTextTrimmed(self) -> Boolean: ...
    @winrt_commethod(18)
    def add_IsTextTrimmedChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.RichTextBlockOverflow, win32more.Microsoft.UI.Xaml.Controls.IsTextTrimmedChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(19)
    def remove_IsTextTrimmedChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(20)
    def GetPositionFromPoint(self, point: win32more.Windows.Foundation.Point) -> win32more.Microsoft.UI.Xaml.Documents.TextPointer: ...
    BaselineOffset = property(get_BaselineOffset, None)
    ContentEnd = property(get_ContentEnd, None)
    ContentSource = property(get_ContentSource, None)
    ContentStart = property(get_ContentStart, None)
    HasOverflowContent = property(get_HasOverflowContent, None)
    IsTextTrimmed = property(get_IsTextTrimmed, None)
    MaxLines = property(get_MaxLines, put_MaxLines)
    OverflowContentTarget = property(get_OverflowContentTarget, put_OverflowContentTarget)
    Padding = property(get_Padding, put_Padding)
    IsTextTrimmedChanged = event(add_IsTextTrimmedChanged, remove_IsTextTrimmedChanged)
class IRichTextBlockOverflowStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IRichTextBlockOverflowStatics'
    _iid_ = Guid('{6db6ee42-a333-5e5b-9ce8-f5e2f46f4d66}')
    @winrt_commethod(6)
    def get_OverflowContentTargetProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_PaddingProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_HasOverflowContentProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_MaxLinesProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_IsTextTrimmedProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    HasOverflowContentProperty = property(get_HasOverflowContentProperty, None)
    IsTextTrimmedProperty = property(get_IsTextTrimmedProperty, None)
    MaxLinesProperty = property(get_MaxLinesProperty, None)
    OverflowContentTargetProperty = property(get_OverflowContentTargetProperty, None)
    PaddingProperty = property(get_PaddingProperty, None)
class IRichTextBlockStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IRichTextBlockStatics'
    _iid_ = Guid('{65dca245-b4fc-5718-b628-a4953f61d6a3}')
    @winrt_commethod(6)
    def get_FontSizeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_FontFamilyProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_FontWeightProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_FontStyleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_FontStretchProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_ForegroundProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_TextWrappingProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_TextTrimmingProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(14)
    def get_TextAlignmentProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(15)
    def get_PaddingProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(16)
    def get_LineHeightProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(17)
    def get_LineStackingStrategyProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(18)
    def get_CharacterSpacingProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(19)
    def get_OverflowContentTargetProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(20)
    def get_IsTextSelectionEnabledProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(21)
    def get_HasOverflowContentProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(22)
    def get_SelectedTextProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(23)
    def get_MaxLinesProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(24)
    def get_TextLineBoundsProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(25)
    def get_SelectionHighlightColorProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(26)
    def get_OpticalMarginAlignmentProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(27)
    def get_IsColorFontEnabledProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(28)
    def get_TextReadingOrderProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(29)
    def get_IsTextScaleFactorEnabledProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(30)
    def get_TextDecorationsProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(31)
    def get_IsTextTrimmedProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(32)
    def get_HorizontalTextAlignmentProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(33)
    def get_SelectionFlyoutProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(34)
    def get_TextIndentProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    CharacterSpacingProperty = property(get_CharacterSpacingProperty, None)
    FontFamilyProperty = property(get_FontFamilyProperty, None)
    FontSizeProperty = property(get_FontSizeProperty, None)
    FontStretchProperty = property(get_FontStretchProperty, None)
    FontStyleProperty = property(get_FontStyleProperty, None)
    FontWeightProperty = property(get_FontWeightProperty, None)
    ForegroundProperty = property(get_ForegroundProperty, None)
    HasOverflowContentProperty = property(get_HasOverflowContentProperty, None)
    HorizontalTextAlignmentProperty = property(get_HorizontalTextAlignmentProperty, None)
    IsColorFontEnabledProperty = property(get_IsColorFontEnabledProperty, None)
    IsTextScaleFactorEnabledProperty = property(get_IsTextScaleFactorEnabledProperty, None)
    IsTextSelectionEnabledProperty = property(get_IsTextSelectionEnabledProperty, None)
    IsTextTrimmedProperty = property(get_IsTextTrimmedProperty, None)
    LineHeightProperty = property(get_LineHeightProperty, None)
    LineStackingStrategyProperty = property(get_LineStackingStrategyProperty, None)
    MaxLinesProperty = property(get_MaxLinesProperty, None)
    OpticalMarginAlignmentProperty = property(get_OpticalMarginAlignmentProperty, None)
    OverflowContentTargetProperty = property(get_OverflowContentTargetProperty, None)
    PaddingProperty = property(get_PaddingProperty, None)
    SelectedTextProperty = property(get_SelectedTextProperty, None)
    SelectionFlyoutProperty = property(get_SelectionFlyoutProperty, None)
    SelectionHighlightColorProperty = property(get_SelectionHighlightColorProperty, None)
    TextAlignmentProperty = property(get_TextAlignmentProperty, None)
    TextDecorationsProperty = property(get_TextDecorationsProperty, None)
    TextIndentProperty = property(get_TextIndentProperty, None)
    TextLineBoundsProperty = property(get_TextLineBoundsProperty, None)
    TextReadingOrderProperty = property(get_TextReadingOrderProperty, None)
    TextTrimmingProperty = property(get_TextTrimmingProperty, None)
    TextWrappingProperty = property(get_TextWrappingProperty, None)
class IRowDefinition(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IRowDefinition'
    _iid_ = Guid('{fe870f2f-89ef-5dac-9f33-968d0dc577c3}')
    @winrt_commethod(6)
    def get_Height(self) -> win32more.Microsoft.UI.Xaml.GridLength: ...
    @winrt_commethod(7)
    def put_Height(self, value: win32more.Microsoft.UI.Xaml.GridLength) -> Void: ...
    @winrt_commethod(8)
    def get_MaxHeight(self) -> Double: ...
    @winrt_commethod(9)
    def put_MaxHeight(self, value: Double) -> Void: ...
    @winrt_commethod(10)
    def get_MinHeight(self) -> Double: ...
    @winrt_commethod(11)
    def put_MinHeight(self, value: Double) -> Void: ...
    @winrt_commethod(12)
    def get_ActualHeight(self) -> Double: ...
    ActualHeight = property(get_ActualHeight, None)
    Height = property(get_Height, put_Height)
    MaxHeight = property(get_MaxHeight, put_MaxHeight)
    MinHeight = property(get_MinHeight, put_MinHeight)
class IRowDefinitionStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IRowDefinitionStatics'
    _iid_ = Guid('{7317c7c5-fd6f-58d9-9b53-4978dbacde23}')
    @winrt_commethod(6)
    def get_HeightProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_MaxHeightProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_MinHeightProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    HeightProperty = property(get_HeightProperty, None)
    MaxHeightProperty = property(get_MaxHeightProperty, None)
    MinHeightProperty = property(get_MinHeightProperty, None)
class IScrollAnchorProvider(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IScrollAnchorProvider'
    _iid_ = Guid('{885df41f-f240-5b7b-a703-bfaf39c6a2cd}')
    @winrt_commethod(6)
    def get_CurrentAnchor(self) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_commethod(7)
    def RegisterAnchorCandidate(self, element: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    @winrt_commethod(8)
    def UnregisterAnchorCandidate(self, element: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    CurrentAnchor = property(get_CurrentAnchor, None)
class IScrollContentPresenter(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IScrollContentPresenter'
    _iid_ = Guid('{9a896eb9-3189-5c53-912f-c470896331b8}')
    @winrt_commethod(6)
    def get_CanVerticallyScroll(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_CanVerticallyScroll(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def get_CanHorizontallyScroll(self) -> Boolean: ...
    @winrt_commethod(9)
    def put_CanHorizontallyScroll(self, value: Boolean) -> Void: ...
    @winrt_commethod(10)
    def get_ExtentWidth(self) -> Double: ...
    @winrt_commethod(11)
    def get_ExtentHeight(self) -> Double: ...
    @winrt_commethod(12)
    def get_ViewportWidth(self) -> Double: ...
    @winrt_commethod(13)
    def get_ViewportHeight(self) -> Double: ...
    @winrt_commethod(14)
    def get_HorizontalOffset(self) -> Double: ...
    @winrt_commethod(15)
    def get_VerticalOffset(self) -> Double: ...
    @winrt_commethod(16)
    def get_ScrollOwner(self) -> IInspectable: ...
    @winrt_commethod(17)
    def put_ScrollOwner(self, value: IInspectable) -> Void: ...
    @winrt_commethod(18)
    def get_CanContentRenderOutsideBounds(self) -> Boolean: ...
    @winrt_commethod(19)
    def put_CanContentRenderOutsideBounds(self, value: Boolean) -> Void: ...
    @winrt_commethod(20)
    def get_SizesContentToTemplatedParent(self) -> Boolean: ...
    @winrt_commethod(21)
    def put_SizesContentToTemplatedParent(self, value: Boolean) -> Void: ...
    @winrt_commethod(22)
    def LineUp(self) -> Void: ...
    @winrt_commethod(23)
    def LineDown(self) -> Void: ...
    @winrt_commethod(24)
    def LineLeft(self) -> Void: ...
    @winrt_commethod(25)
    def LineRight(self) -> Void: ...
    @winrt_commethod(26)
    def PageUp(self) -> Void: ...
    @winrt_commethod(27)
    def PageDown(self) -> Void: ...
    @winrt_commethod(28)
    def PageLeft(self) -> Void: ...
    @winrt_commethod(29)
    def PageRight(self) -> Void: ...
    @winrt_commethod(30)
    def MouseWheelUp(self) -> Void: ...
    @winrt_commethod(31)
    def MouseWheelDown(self) -> Void: ...
    @winrt_commethod(32)
    def MouseWheelLeft(self) -> Void: ...
    @winrt_commethod(33)
    def MouseWheelRight(self) -> Void: ...
    @winrt_commethod(34)
    def SetHorizontalOffset(self, offset: Double) -> Void: ...
    @winrt_commethod(35)
    def SetVerticalOffset(self, offset: Double) -> Void: ...
    @winrt_commethod(36)
    def MakeVisible(self, visual: win32more.Microsoft.UI.Xaml.UIElement, rectangle: win32more.Windows.Foundation.Rect) -> win32more.Windows.Foundation.Rect: ...
    CanContentRenderOutsideBounds = property(get_CanContentRenderOutsideBounds, put_CanContentRenderOutsideBounds)
    CanHorizontallyScroll = property(get_CanHorizontallyScroll, put_CanHorizontallyScroll)
    CanVerticallyScroll = property(get_CanVerticallyScroll, put_CanVerticallyScroll)
    ExtentHeight = property(get_ExtentHeight, None)
    ExtentWidth = property(get_ExtentWidth, None)
    HorizontalOffset = property(get_HorizontalOffset, None)
    ScrollOwner = property(get_ScrollOwner, put_ScrollOwner)
    SizesContentToTemplatedParent = property(get_SizesContentToTemplatedParent, put_SizesContentToTemplatedParent)
    VerticalOffset = property(get_VerticalOffset, None)
    ViewportHeight = property(get_ViewportHeight, None)
    ViewportWidth = property(get_ViewportWidth, None)
class IScrollContentPresenterStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IScrollContentPresenterStatics'
    _iid_ = Guid('{4e93f295-ef2e-517b-bbf9-dedb854849c8}')
    @winrt_commethod(6)
    def get_CanContentRenderOutsideBoundsProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_SizesContentToTemplatedParentProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    CanContentRenderOutsideBoundsProperty = property(get_CanContentRenderOutsideBoundsProperty, None)
    SizesContentToTemplatedParentProperty = property(get_SizesContentToTemplatedParentProperty, None)
class IScrollView(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IScrollView'
    _iid_ = Guid('{8c98c86d-378a-5102-a1e3-3352280fa010}')
    @winrt_commethod(6)
    def get_Content(self) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_commethod(7)
    def put_Content(self, value: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    @winrt_commethod(8)
    def get_CurrentAnchor(self) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_commethod(9)
    def get_ScrollPresenter(self) -> win32more.Microsoft.UI.Xaml.Controls.Primitives.ScrollPresenter: ...
    @winrt_commethod(10)
    def get_ExpressionAnimationSources(self) -> win32more.Microsoft.UI.Composition.CompositionPropertySet: ...
    @winrt_commethod(11)
    def get_HorizontalOffset(self) -> Double: ...
    @winrt_commethod(12)
    def get_VerticalOffset(self) -> Double: ...
    @winrt_commethod(13)
    def get_ZoomFactor(self) -> Single: ...
    @winrt_commethod(14)
    def get_ExtentWidth(self) -> Double: ...
    @winrt_commethod(15)
    def get_ExtentHeight(self) -> Double: ...
    @winrt_commethod(16)
    def get_ViewportWidth(self) -> Double: ...
    @winrt_commethod(17)
    def get_ViewportHeight(self) -> Double: ...
    @winrt_commethod(18)
    def get_ScrollableWidth(self) -> Double: ...
    @winrt_commethod(19)
    def get_ScrollableHeight(self) -> Double: ...
    @winrt_commethod(20)
    def get_State(self) -> win32more.Microsoft.UI.Xaml.Controls.ScrollingInteractionState: ...
    @winrt_commethod(21)
    def get_HorizontalScrollBarVisibility(self) -> win32more.Microsoft.UI.Xaml.Controls.ScrollingScrollBarVisibility: ...
    @winrt_commethod(22)
    def put_HorizontalScrollBarVisibility(self, value: win32more.Microsoft.UI.Xaml.Controls.ScrollingScrollBarVisibility) -> Void: ...
    @winrt_commethod(23)
    def get_VerticalScrollBarVisibility(self) -> win32more.Microsoft.UI.Xaml.Controls.ScrollingScrollBarVisibility: ...
    @winrt_commethod(24)
    def put_VerticalScrollBarVisibility(self, value: win32more.Microsoft.UI.Xaml.Controls.ScrollingScrollBarVisibility) -> Void: ...
    @winrt_commethod(25)
    def get_ContentOrientation(self) -> win32more.Microsoft.UI.Xaml.Controls.ScrollingContentOrientation: ...
    @winrt_commethod(26)
    def put_ContentOrientation(self, value: win32more.Microsoft.UI.Xaml.Controls.ScrollingContentOrientation) -> Void: ...
    @winrt_commethod(27)
    def get_HorizontalScrollChainMode(self) -> win32more.Microsoft.UI.Xaml.Controls.ScrollingChainMode: ...
    @winrt_commethod(28)
    def put_HorizontalScrollChainMode(self, value: win32more.Microsoft.UI.Xaml.Controls.ScrollingChainMode) -> Void: ...
    @winrt_commethod(29)
    def get_VerticalScrollChainMode(self) -> win32more.Microsoft.UI.Xaml.Controls.ScrollingChainMode: ...
    @winrt_commethod(30)
    def put_VerticalScrollChainMode(self, value: win32more.Microsoft.UI.Xaml.Controls.ScrollingChainMode) -> Void: ...
    @winrt_commethod(31)
    def get_HorizontalScrollRailMode(self) -> win32more.Microsoft.UI.Xaml.Controls.ScrollingRailMode: ...
    @winrt_commethod(32)
    def put_HorizontalScrollRailMode(self, value: win32more.Microsoft.UI.Xaml.Controls.ScrollingRailMode) -> Void: ...
    @winrt_commethod(33)
    def get_VerticalScrollRailMode(self) -> win32more.Microsoft.UI.Xaml.Controls.ScrollingRailMode: ...
    @winrt_commethod(34)
    def put_VerticalScrollRailMode(self, value: win32more.Microsoft.UI.Xaml.Controls.ScrollingRailMode) -> Void: ...
    @winrt_commethod(35)
    def get_HorizontalScrollMode(self) -> win32more.Microsoft.UI.Xaml.Controls.ScrollingScrollMode: ...
    @winrt_commethod(36)
    def put_HorizontalScrollMode(self, value: win32more.Microsoft.UI.Xaml.Controls.ScrollingScrollMode) -> Void: ...
    @winrt_commethod(37)
    def get_VerticalScrollMode(self) -> win32more.Microsoft.UI.Xaml.Controls.ScrollingScrollMode: ...
    @winrt_commethod(38)
    def put_VerticalScrollMode(self, value: win32more.Microsoft.UI.Xaml.Controls.ScrollingScrollMode) -> Void: ...
    @winrt_commethod(39)
    def get_ComputedHorizontalScrollBarVisibility(self) -> win32more.Microsoft.UI.Xaml.Visibility: ...
    @winrt_commethod(40)
    def get_ComputedVerticalScrollBarVisibility(self) -> win32more.Microsoft.UI.Xaml.Visibility: ...
    @winrt_commethod(41)
    def get_ComputedHorizontalScrollMode(self) -> win32more.Microsoft.UI.Xaml.Controls.ScrollingScrollMode: ...
    @winrt_commethod(42)
    def get_ComputedVerticalScrollMode(self) -> win32more.Microsoft.UI.Xaml.Controls.ScrollingScrollMode: ...
    @winrt_commethod(43)
    def get_ZoomChainMode(self) -> win32more.Microsoft.UI.Xaml.Controls.ScrollingChainMode: ...
    @winrt_commethod(44)
    def put_ZoomChainMode(self, value: win32more.Microsoft.UI.Xaml.Controls.ScrollingChainMode) -> Void: ...
    @winrt_commethod(45)
    def get_ZoomMode(self) -> win32more.Microsoft.UI.Xaml.Controls.ScrollingZoomMode: ...
    @winrt_commethod(46)
    def put_ZoomMode(self, value: win32more.Microsoft.UI.Xaml.Controls.ScrollingZoomMode) -> Void: ...
    @winrt_commethod(47)
    def get_IgnoredInputKinds(self) -> win32more.Microsoft.UI.Xaml.Controls.ScrollingInputKinds: ...
    @winrt_commethod(48)
    def put_IgnoredInputKinds(self, value: win32more.Microsoft.UI.Xaml.Controls.ScrollingInputKinds) -> Void: ...
    @winrt_commethod(49)
    def get_MinZoomFactor(self) -> Double: ...
    @winrt_commethod(50)
    def put_MinZoomFactor(self, value: Double) -> Void: ...
    @winrt_commethod(51)
    def get_MaxZoomFactor(self) -> Double: ...
    @winrt_commethod(52)
    def put_MaxZoomFactor(self, value: Double) -> Void: ...
    @winrt_commethod(53)
    def get_HorizontalAnchorRatio(self) -> Double: ...
    @winrt_commethod(54)
    def put_HorizontalAnchorRatio(self, value: Double) -> Void: ...
    @winrt_commethod(55)
    def get_VerticalAnchorRatio(self) -> Double: ...
    @winrt_commethod(56)
    def put_VerticalAnchorRatio(self, value: Double) -> Void: ...
    @winrt_commethod(57)
    def RegisterAnchorCandidate(self, element: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    @winrt_commethod(58)
    def UnregisterAnchorCandidate(self, element: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    @winrt_commethod(59)
    def ScrollTo(self, horizontalOffset: Double, verticalOffset: Double) -> Int32: ...
    @winrt_commethod(60)
    def ScrollToWithOptions(self, horizontalOffset: Double, verticalOffset: Double, options: win32more.Microsoft.UI.Xaml.Controls.ScrollingScrollOptions) -> Int32: ...
    @winrt_commethod(61)
    def ScrollBy(self, horizontalOffsetDelta: Double, verticalOffsetDelta: Double) -> Int32: ...
    @winrt_commethod(62)
    def ScrollByWithOptions(self, horizontalOffsetDelta: Double, verticalOffsetDelta: Double, options: win32more.Microsoft.UI.Xaml.Controls.ScrollingScrollOptions) -> Int32: ...
    @winrt_commethod(63)
    def AddScrollVelocity(self, offsetsVelocity: win32more.Windows.Foundation.Numerics.Vector2, inertiaDecayRate: win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.Numerics.Vector2]) -> Int32: ...
    @winrt_commethod(64)
    def ZoomTo(self, zoomFactor: Single, centerPoint: win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.Numerics.Vector2]) -> Int32: ...
    @winrt_commethod(65)
    def ZoomToWithOptions(self, zoomFactor: Single, centerPoint: win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.Numerics.Vector2], options: win32more.Microsoft.UI.Xaml.Controls.ScrollingZoomOptions) -> Int32: ...
    @winrt_commethod(66)
    def ZoomBy(self, zoomFactorDelta: Single, centerPoint: win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.Numerics.Vector2]) -> Int32: ...
    @winrt_commethod(67)
    def ZoomByWithOptions(self, zoomFactorDelta: Single, centerPoint: win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.Numerics.Vector2], options: win32more.Microsoft.UI.Xaml.Controls.ScrollingZoomOptions) -> Int32: ...
    @winrt_commethod(68)
    def AddZoomVelocity(self, zoomFactorVelocity: Single, centerPoint: win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.Numerics.Vector2], inertiaDecayRate: win32more.Windows.Foundation.IReference[Single]) -> Int32: ...
    @winrt_commethod(69)
    def add_ExtentChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.ScrollView, IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(70)
    def remove_ExtentChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(71)
    def add_StateChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.ScrollView, IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(72)
    def remove_StateChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(73)
    def add_ViewChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.ScrollView, IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(74)
    def remove_ViewChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(75)
    def add_ScrollAnimationStarting(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.ScrollView, win32more.Microsoft.UI.Xaml.Controls.ScrollingScrollAnimationStartingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(76)
    def remove_ScrollAnimationStarting(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(77)
    def add_ZoomAnimationStarting(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.ScrollView, win32more.Microsoft.UI.Xaml.Controls.ScrollingZoomAnimationStartingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(78)
    def remove_ZoomAnimationStarting(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(79)
    def add_ScrollCompleted(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.ScrollView, win32more.Microsoft.UI.Xaml.Controls.ScrollingScrollCompletedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(80)
    def remove_ScrollCompleted(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(81)
    def add_ZoomCompleted(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.ScrollView, win32more.Microsoft.UI.Xaml.Controls.ScrollingZoomCompletedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(82)
    def remove_ZoomCompleted(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(83)
    def add_BringingIntoView(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.ScrollView, win32more.Microsoft.UI.Xaml.Controls.ScrollingBringingIntoViewEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(84)
    def remove_BringingIntoView(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(85)
    def add_AnchorRequested(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.ScrollView, win32more.Microsoft.UI.Xaml.Controls.ScrollingAnchorRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(86)
    def remove_AnchorRequested(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    ComputedHorizontalScrollBarVisibility = property(get_ComputedHorizontalScrollBarVisibility, None)
    ComputedHorizontalScrollMode = property(get_ComputedHorizontalScrollMode, None)
    ComputedVerticalScrollBarVisibility = property(get_ComputedVerticalScrollBarVisibility, None)
    ComputedVerticalScrollMode = property(get_ComputedVerticalScrollMode, None)
    Content = property(get_Content, put_Content)
    ContentOrientation = property(get_ContentOrientation, put_ContentOrientation)
    CurrentAnchor = property(get_CurrentAnchor, None)
    ExpressionAnimationSources = property(get_ExpressionAnimationSources, None)
    ExtentHeight = property(get_ExtentHeight, None)
    ExtentWidth = property(get_ExtentWidth, None)
    HorizontalAnchorRatio = property(get_HorizontalAnchorRatio, put_HorizontalAnchorRatio)
    HorizontalOffset = property(get_HorizontalOffset, None)
    HorizontalScrollBarVisibility = property(get_HorizontalScrollBarVisibility, put_HorizontalScrollBarVisibility)
    HorizontalScrollChainMode = property(get_HorizontalScrollChainMode, put_HorizontalScrollChainMode)
    HorizontalScrollMode = property(get_HorizontalScrollMode, put_HorizontalScrollMode)
    HorizontalScrollRailMode = property(get_HorizontalScrollRailMode, put_HorizontalScrollRailMode)
    IgnoredInputKinds = property(get_IgnoredInputKinds, put_IgnoredInputKinds)
    MaxZoomFactor = property(get_MaxZoomFactor, put_MaxZoomFactor)
    MinZoomFactor = property(get_MinZoomFactor, put_MinZoomFactor)
    ScrollPresenter = property(get_ScrollPresenter, None)
    ScrollableHeight = property(get_ScrollableHeight, None)
    ScrollableWidth = property(get_ScrollableWidth, None)
    State = property(get_State, None)
    VerticalAnchorRatio = property(get_VerticalAnchorRatio, put_VerticalAnchorRatio)
    VerticalOffset = property(get_VerticalOffset, None)
    VerticalScrollBarVisibility = property(get_VerticalScrollBarVisibility, put_VerticalScrollBarVisibility)
    VerticalScrollChainMode = property(get_VerticalScrollChainMode, put_VerticalScrollChainMode)
    VerticalScrollMode = property(get_VerticalScrollMode, put_VerticalScrollMode)
    VerticalScrollRailMode = property(get_VerticalScrollRailMode, put_VerticalScrollRailMode)
    ViewportHeight = property(get_ViewportHeight, None)
    ViewportWidth = property(get_ViewportWidth, None)
    ZoomChainMode = property(get_ZoomChainMode, put_ZoomChainMode)
    ZoomFactor = property(get_ZoomFactor, None)
    ZoomMode = property(get_ZoomMode, put_ZoomMode)
    AnchorRequested = event(add_AnchorRequested, remove_AnchorRequested)
    BringingIntoView = event(add_BringingIntoView, remove_BringingIntoView)
    ExtentChanged = event(add_ExtentChanged, remove_ExtentChanged)
    ScrollAnimationStarting = event(add_ScrollAnimationStarting, remove_ScrollAnimationStarting)
    ScrollCompleted = event(add_ScrollCompleted, remove_ScrollCompleted)
    StateChanged = event(add_StateChanged, remove_StateChanged)
    ViewChanged = event(add_ViewChanged, remove_ViewChanged)
    ZoomAnimationStarting = event(add_ZoomAnimationStarting, remove_ZoomAnimationStarting)
    ZoomCompleted = event(add_ZoomCompleted, remove_ZoomCompleted)
class IScrollViewFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IScrollViewFactory'
    _iid_ = Guid('{f3547344-22e4-5e6c-9ece-66504ef733ed}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.ScrollView: ...
class IScrollViewStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IScrollViewStatics'
    _iid_ = Guid('{ac966c50-31f1-5485-8e08-ee7a7e9a6fd0}')
    @winrt_commethod(6)
    def get_ContentProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_ScrollPresenterProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_HorizontalScrollBarVisibilityProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_VerticalScrollBarVisibilityProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_ContentOrientationProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_HorizontalScrollChainModeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_VerticalScrollChainModeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_HorizontalScrollRailModeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(14)
    def get_VerticalScrollRailModeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(15)
    def get_HorizontalScrollModeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(16)
    def get_VerticalScrollModeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(17)
    def get_ComputedHorizontalScrollBarVisibilityProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(18)
    def get_ComputedVerticalScrollBarVisibilityProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(19)
    def get_ComputedHorizontalScrollModeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(20)
    def get_ComputedVerticalScrollModeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(21)
    def get_ZoomChainModeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(22)
    def get_ZoomModeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(23)
    def get_IgnoredInputKindsProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(24)
    def get_MinZoomFactorProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(25)
    def get_MaxZoomFactorProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(26)
    def get_HorizontalAnchorRatioProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(27)
    def get_VerticalAnchorRatioProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    ComputedHorizontalScrollBarVisibilityProperty = property(get_ComputedHorizontalScrollBarVisibilityProperty, None)
    ComputedHorizontalScrollModeProperty = property(get_ComputedHorizontalScrollModeProperty, None)
    ComputedVerticalScrollBarVisibilityProperty = property(get_ComputedVerticalScrollBarVisibilityProperty, None)
    ComputedVerticalScrollModeProperty = property(get_ComputedVerticalScrollModeProperty, None)
    ContentOrientationProperty = property(get_ContentOrientationProperty, None)
    ContentProperty = property(get_ContentProperty, None)
    HorizontalAnchorRatioProperty = property(get_HorizontalAnchorRatioProperty, None)
    HorizontalScrollBarVisibilityProperty = property(get_HorizontalScrollBarVisibilityProperty, None)
    HorizontalScrollChainModeProperty = property(get_HorizontalScrollChainModeProperty, None)
    HorizontalScrollModeProperty = property(get_HorizontalScrollModeProperty, None)
    HorizontalScrollRailModeProperty = property(get_HorizontalScrollRailModeProperty, None)
    IgnoredInputKindsProperty = property(get_IgnoredInputKindsProperty, None)
    MaxZoomFactorProperty = property(get_MaxZoomFactorProperty, None)
    MinZoomFactorProperty = property(get_MinZoomFactorProperty, None)
    ScrollPresenterProperty = property(get_ScrollPresenterProperty, None)
    VerticalAnchorRatioProperty = property(get_VerticalAnchorRatioProperty, None)
    VerticalScrollBarVisibilityProperty = property(get_VerticalScrollBarVisibilityProperty, None)
    VerticalScrollChainModeProperty = property(get_VerticalScrollChainModeProperty, None)
    VerticalScrollModeProperty = property(get_VerticalScrollModeProperty, None)
    VerticalScrollRailModeProperty = property(get_VerticalScrollRailModeProperty, None)
    ZoomChainModeProperty = property(get_ZoomChainModeProperty, None)
    ZoomModeProperty = property(get_ZoomModeProperty, None)
class IScrollViewer(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IScrollViewer'
    _iid_ = Guid('{1dc28c2e-996c-5394-89c3-4dc656b4ad46}')
    @winrt_commethod(6)
    def get_HorizontalScrollBarVisibility(self) -> win32more.Microsoft.UI.Xaml.Controls.ScrollBarVisibility: ...
    @winrt_commethod(7)
    def put_HorizontalScrollBarVisibility(self, value: win32more.Microsoft.UI.Xaml.Controls.ScrollBarVisibility) -> Void: ...
    @winrt_commethod(8)
    def get_VerticalScrollBarVisibility(self) -> win32more.Microsoft.UI.Xaml.Controls.ScrollBarVisibility: ...
    @winrt_commethod(9)
    def put_VerticalScrollBarVisibility(self, value: win32more.Microsoft.UI.Xaml.Controls.ScrollBarVisibility) -> Void: ...
    @winrt_commethod(10)
    def get_IsHorizontalRailEnabled(self) -> Boolean: ...
    @winrt_commethod(11)
    def put_IsHorizontalRailEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(12)
    def get_IsVerticalRailEnabled(self) -> Boolean: ...
    @winrt_commethod(13)
    def put_IsVerticalRailEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(14)
    def get_IsHorizontalScrollChainingEnabled(self) -> Boolean: ...
    @winrt_commethod(15)
    def put_IsHorizontalScrollChainingEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(16)
    def get_IsVerticalScrollChainingEnabled(self) -> Boolean: ...
    @winrt_commethod(17)
    def put_IsVerticalScrollChainingEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(18)
    def get_IsZoomChainingEnabled(self) -> Boolean: ...
    @winrt_commethod(19)
    def put_IsZoomChainingEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(20)
    def get_IsScrollInertiaEnabled(self) -> Boolean: ...
    @winrt_commethod(21)
    def put_IsScrollInertiaEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(22)
    def get_IsZoomInertiaEnabled(self) -> Boolean: ...
    @winrt_commethod(23)
    def put_IsZoomInertiaEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(24)
    def get_HorizontalScrollMode(self) -> win32more.Microsoft.UI.Xaml.Controls.ScrollMode: ...
    @winrt_commethod(25)
    def put_HorizontalScrollMode(self, value: win32more.Microsoft.UI.Xaml.Controls.ScrollMode) -> Void: ...
    @winrt_commethod(26)
    def get_VerticalScrollMode(self) -> win32more.Microsoft.UI.Xaml.Controls.ScrollMode: ...
    @winrt_commethod(27)
    def put_VerticalScrollMode(self, value: win32more.Microsoft.UI.Xaml.Controls.ScrollMode) -> Void: ...
    @winrt_commethod(28)
    def get_ZoomMode(self) -> win32more.Microsoft.UI.Xaml.Controls.ZoomMode: ...
    @winrt_commethod(29)
    def put_ZoomMode(self, value: win32more.Microsoft.UI.Xaml.Controls.ZoomMode) -> Void: ...
    @winrt_commethod(30)
    def get_HorizontalSnapPointsAlignment(self) -> win32more.Microsoft.UI.Xaml.Controls.Primitives.SnapPointsAlignment: ...
    @winrt_commethod(31)
    def put_HorizontalSnapPointsAlignment(self, value: win32more.Microsoft.UI.Xaml.Controls.Primitives.SnapPointsAlignment) -> Void: ...
    @winrt_commethod(32)
    def get_VerticalSnapPointsAlignment(self) -> win32more.Microsoft.UI.Xaml.Controls.Primitives.SnapPointsAlignment: ...
    @winrt_commethod(33)
    def put_VerticalSnapPointsAlignment(self, value: win32more.Microsoft.UI.Xaml.Controls.Primitives.SnapPointsAlignment) -> Void: ...
    @winrt_commethod(34)
    def get_HorizontalSnapPointsType(self) -> win32more.Microsoft.UI.Xaml.Controls.SnapPointsType: ...
    @winrt_commethod(35)
    def put_HorizontalSnapPointsType(self, value: win32more.Microsoft.UI.Xaml.Controls.SnapPointsType) -> Void: ...
    @winrt_commethod(36)
    def get_VerticalSnapPointsType(self) -> win32more.Microsoft.UI.Xaml.Controls.SnapPointsType: ...
    @winrt_commethod(37)
    def put_VerticalSnapPointsType(self, value: win32more.Microsoft.UI.Xaml.Controls.SnapPointsType) -> Void: ...
    @winrt_commethod(38)
    def get_ZoomSnapPointsType(self) -> win32more.Microsoft.UI.Xaml.Controls.SnapPointsType: ...
    @winrt_commethod(39)
    def put_ZoomSnapPointsType(self, value: win32more.Microsoft.UI.Xaml.Controls.SnapPointsType) -> Void: ...
    @winrt_commethod(40)
    def get_HorizontalOffset(self) -> Double: ...
    @winrt_commethod(41)
    def get_ViewportWidth(self) -> Double: ...
    @winrt_commethod(42)
    def get_ScrollableWidth(self) -> Double: ...
    @winrt_commethod(43)
    def get_ComputedHorizontalScrollBarVisibility(self) -> win32more.Microsoft.UI.Xaml.Visibility: ...
    @winrt_commethod(44)
    def get_ExtentWidth(self) -> Double: ...
    @winrt_commethod(45)
    def get_VerticalOffset(self) -> Double: ...
    @winrt_commethod(46)
    def get_ViewportHeight(self) -> Double: ...
    @winrt_commethod(47)
    def get_ScrollableHeight(self) -> Double: ...
    @winrt_commethod(48)
    def get_ComputedVerticalScrollBarVisibility(self) -> win32more.Microsoft.UI.Xaml.Visibility: ...
    @winrt_commethod(49)
    def get_ExtentHeight(self) -> Double: ...
    @winrt_commethod(50)
    def get_MinZoomFactor(self) -> Single: ...
    @winrt_commethod(51)
    def put_MinZoomFactor(self, value: Single) -> Void: ...
    @winrt_commethod(52)
    def get_MaxZoomFactor(self) -> Single: ...
    @winrt_commethod(53)
    def put_MaxZoomFactor(self, value: Single) -> Void: ...
    @winrt_commethod(54)
    def get_ZoomFactor(self) -> Single: ...
    @winrt_commethod(55)
    def get_ZoomSnapPoints(self) -> win32more.Windows.Foundation.Collections.IVector[Single]: ...
    @winrt_commethod(56)
    def get_TopLeftHeader(self) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_commethod(57)
    def put_TopLeftHeader(self, value: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    @winrt_commethod(58)
    def get_LeftHeader(self) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_commethod(59)
    def put_LeftHeader(self, value: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    @winrt_commethod(60)
    def get_TopHeader(self) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_commethod(61)
    def put_TopHeader(self, value: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    @winrt_commethod(62)
    def get_ReduceViewportForCoreInputViewOcclusions(self) -> Boolean: ...
    @winrt_commethod(63)
    def put_ReduceViewportForCoreInputViewOcclusions(self, value: Boolean) -> Void: ...
    @winrt_commethod(64)
    def get_HorizontalAnchorRatio(self) -> Double: ...
    @winrt_commethod(65)
    def put_HorizontalAnchorRatio(self, value: Double) -> Void: ...
    @winrt_commethod(66)
    def get_VerticalAnchorRatio(self) -> Double: ...
    @winrt_commethod(67)
    def put_VerticalAnchorRatio(self, value: Double) -> Void: ...
    @winrt_commethod(68)
    def get_CanContentRenderOutsideBounds(self) -> Boolean: ...
    @winrt_commethod(69)
    def put_CanContentRenderOutsideBounds(self, value: Boolean) -> Void: ...
    @winrt_commethod(70)
    def add_AnchorRequested(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.ScrollViewer, win32more.Microsoft.UI.Xaml.Controls.AnchorRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(71)
    def remove_AnchorRequested(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(72)
    def add_ViewChanging(self, handler: win32more.Windows.Foundation.EventHandler[win32more.Microsoft.UI.Xaml.Controls.ScrollViewerViewChangingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(73)
    def remove_ViewChanging(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(74)
    def add_ViewChanged(self, handler: win32more.Windows.Foundation.EventHandler[win32more.Microsoft.UI.Xaml.Controls.ScrollViewerViewChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(75)
    def remove_ViewChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(76)
    def add_DirectManipulationStarted(self, handler: win32more.Windows.Foundation.EventHandler[IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(77)
    def remove_DirectManipulationStarted(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(78)
    def add_DirectManipulationCompleted(self, handler: win32more.Windows.Foundation.EventHandler[IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(79)
    def remove_DirectManipulationCompleted(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(80)
    def ScrollToHorizontalOffset(self, offset: Double) -> Void: ...
    @winrt_commethod(81)
    def ScrollToVerticalOffset(self, offset: Double) -> Void: ...
    @winrt_commethod(82)
    def ZoomToFactor(self, factor: Single) -> Void: ...
    @winrt_commethod(83)
    def ChangeView(self, horizontalOffset: win32more.Windows.Foundation.IReference[Double], verticalOffset: win32more.Windows.Foundation.IReference[Double], zoomFactor: win32more.Windows.Foundation.IReference[Single]) -> Boolean: ...
    @winrt_commethod(84)
    def ChangeViewWithOptionalAnimation(self, horizontalOffset: win32more.Windows.Foundation.IReference[Double], verticalOffset: win32more.Windows.Foundation.IReference[Double], zoomFactor: win32more.Windows.Foundation.IReference[Single], disableAnimation: Boolean) -> Boolean: ...
    @winrt_commethod(85)
    def InvalidateScrollInfo(self) -> Void: ...
    @winrt_commethod(86)
    def get_IsDeferredScrollingEnabled(self) -> Boolean: ...
    @winrt_commethod(87)
    def put_IsDeferredScrollingEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(88)
    def get_BringIntoViewOnFocusChange(self) -> Boolean: ...
    @winrt_commethod(89)
    def put_BringIntoViewOnFocusChange(self, value: Boolean) -> Void: ...
    BringIntoViewOnFocusChange = property(get_BringIntoViewOnFocusChange, put_BringIntoViewOnFocusChange)
    CanContentRenderOutsideBounds = property(get_CanContentRenderOutsideBounds, put_CanContentRenderOutsideBounds)
    ComputedHorizontalScrollBarVisibility = property(get_ComputedHorizontalScrollBarVisibility, None)
    ComputedVerticalScrollBarVisibility = property(get_ComputedVerticalScrollBarVisibility, None)
    ExtentHeight = property(get_ExtentHeight, None)
    ExtentWidth = property(get_ExtentWidth, None)
    HorizontalAnchorRatio = property(get_HorizontalAnchorRatio, put_HorizontalAnchorRatio)
    HorizontalOffset = property(get_HorizontalOffset, None)
    HorizontalScrollBarVisibility = property(get_HorizontalScrollBarVisibility, put_HorizontalScrollBarVisibility)
    HorizontalScrollMode = property(get_HorizontalScrollMode, put_HorizontalScrollMode)
    HorizontalSnapPointsAlignment = property(get_HorizontalSnapPointsAlignment, put_HorizontalSnapPointsAlignment)
    HorizontalSnapPointsType = property(get_HorizontalSnapPointsType, put_HorizontalSnapPointsType)
    IsDeferredScrollingEnabled = property(get_IsDeferredScrollingEnabled, put_IsDeferredScrollingEnabled)
    IsHorizontalRailEnabled = property(get_IsHorizontalRailEnabled, put_IsHorizontalRailEnabled)
    IsHorizontalScrollChainingEnabled = property(get_IsHorizontalScrollChainingEnabled, put_IsHorizontalScrollChainingEnabled)
    IsScrollInertiaEnabled = property(get_IsScrollInertiaEnabled, put_IsScrollInertiaEnabled)
    IsVerticalRailEnabled = property(get_IsVerticalRailEnabled, put_IsVerticalRailEnabled)
    IsVerticalScrollChainingEnabled = property(get_IsVerticalScrollChainingEnabled, put_IsVerticalScrollChainingEnabled)
    IsZoomChainingEnabled = property(get_IsZoomChainingEnabled, put_IsZoomChainingEnabled)
    IsZoomInertiaEnabled = property(get_IsZoomInertiaEnabled, put_IsZoomInertiaEnabled)
    LeftHeader = property(get_LeftHeader, put_LeftHeader)
    MaxZoomFactor = property(get_MaxZoomFactor, put_MaxZoomFactor)
    MinZoomFactor = property(get_MinZoomFactor, put_MinZoomFactor)
    ReduceViewportForCoreInputViewOcclusions = property(get_ReduceViewportForCoreInputViewOcclusions, put_ReduceViewportForCoreInputViewOcclusions)
    ScrollableHeight = property(get_ScrollableHeight, None)
    ScrollableWidth = property(get_ScrollableWidth, None)
    TopHeader = property(get_TopHeader, put_TopHeader)
    TopLeftHeader = property(get_TopLeftHeader, put_TopLeftHeader)
    VerticalAnchorRatio = property(get_VerticalAnchorRatio, put_VerticalAnchorRatio)
    VerticalOffset = property(get_VerticalOffset, None)
    VerticalScrollBarVisibility = property(get_VerticalScrollBarVisibility, put_VerticalScrollBarVisibility)
    VerticalScrollMode = property(get_VerticalScrollMode, put_VerticalScrollMode)
    VerticalSnapPointsAlignment = property(get_VerticalSnapPointsAlignment, put_VerticalSnapPointsAlignment)
    VerticalSnapPointsType = property(get_VerticalSnapPointsType, put_VerticalSnapPointsType)
    ViewportHeight = property(get_ViewportHeight, None)
    ViewportWidth = property(get_ViewportWidth, None)
    ZoomFactor = property(get_ZoomFactor, None)
    ZoomMode = property(get_ZoomMode, put_ZoomMode)
    ZoomSnapPoints = property(get_ZoomSnapPoints, None)
    ZoomSnapPointsType = property(get_ZoomSnapPointsType, put_ZoomSnapPointsType)
    AnchorRequested = event(add_AnchorRequested, remove_AnchorRequested)
    DirectManipulationCompleted = event(add_DirectManipulationCompleted, remove_DirectManipulationCompleted)
    DirectManipulationStarted = event(add_DirectManipulationStarted, remove_DirectManipulationStarted)
    ViewChanged = event(add_ViewChanged, remove_ViewChanged)
    ViewChanging = event(add_ViewChanging, remove_ViewChanging)
class IScrollViewerStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IScrollViewerStatics'
    _iid_ = Guid('{d971fd86-0a96-50c4-a6e1-9975faa2a142}')
    @winrt_commethod(6)
    def get_HorizontalSnapPointsAlignmentProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_VerticalSnapPointsAlignmentProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_HorizontalSnapPointsTypeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_VerticalSnapPointsTypeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_ZoomSnapPointsTypeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_HorizontalOffsetProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_ViewportWidthProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_ScrollableWidthProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(14)
    def get_ComputedHorizontalScrollBarVisibilityProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(15)
    def get_ExtentWidthProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(16)
    def get_VerticalOffsetProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(17)
    def get_ViewportHeightProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(18)
    def get_ScrollableHeightProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(19)
    def get_ComputedVerticalScrollBarVisibilityProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(20)
    def get_ExtentHeightProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(21)
    def get_MinZoomFactorProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(22)
    def get_MaxZoomFactorProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(23)
    def get_ZoomFactorProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(24)
    def get_ZoomSnapPointsProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(25)
    def get_TopLeftHeaderProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(26)
    def get_LeftHeaderProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(27)
    def get_TopHeaderProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(28)
    def get_ReduceViewportForCoreInputViewOcclusionsProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(29)
    def get_HorizontalAnchorRatioProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(30)
    def get_VerticalAnchorRatioProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(31)
    def get_HorizontalScrollBarVisibilityProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(32)
    def GetHorizontalScrollBarVisibility(self, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> win32more.Microsoft.UI.Xaml.Controls.ScrollBarVisibility: ...
    @winrt_commethod(33)
    def SetHorizontalScrollBarVisibility(self, element: win32more.Microsoft.UI.Xaml.DependencyObject, horizontalScrollBarVisibility: win32more.Microsoft.UI.Xaml.Controls.ScrollBarVisibility) -> Void: ...
    @winrt_commethod(34)
    def get_VerticalScrollBarVisibilityProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(35)
    def GetVerticalScrollBarVisibility(self, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> win32more.Microsoft.UI.Xaml.Controls.ScrollBarVisibility: ...
    @winrt_commethod(36)
    def SetVerticalScrollBarVisibility(self, element: win32more.Microsoft.UI.Xaml.DependencyObject, verticalScrollBarVisibility: win32more.Microsoft.UI.Xaml.Controls.ScrollBarVisibility) -> Void: ...
    @winrt_commethod(37)
    def get_IsHorizontalRailEnabledProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(38)
    def GetIsHorizontalRailEnabled(self, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_commethod(39)
    def SetIsHorizontalRailEnabled(self, element: win32more.Microsoft.UI.Xaml.DependencyObject, isHorizontalRailEnabled: Boolean) -> Void: ...
    @winrt_commethod(40)
    def get_IsVerticalRailEnabledProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(41)
    def GetIsVerticalRailEnabled(self, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_commethod(42)
    def SetIsVerticalRailEnabled(self, element: win32more.Microsoft.UI.Xaml.DependencyObject, isVerticalRailEnabled: Boolean) -> Void: ...
    @winrt_commethod(43)
    def get_IsHorizontalScrollChainingEnabledProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(44)
    def GetIsHorizontalScrollChainingEnabled(self, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_commethod(45)
    def SetIsHorizontalScrollChainingEnabled(self, element: win32more.Microsoft.UI.Xaml.DependencyObject, isHorizontalScrollChainingEnabled: Boolean) -> Void: ...
    @winrt_commethod(46)
    def get_IsVerticalScrollChainingEnabledProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(47)
    def GetIsVerticalScrollChainingEnabled(self, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_commethod(48)
    def SetIsVerticalScrollChainingEnabled(self, element: win32more.Microsoft.UI.Xaml.DependencyObject, isVerticalScrollChainingEnabled: Boolean) -> Void: ...
    @winrt_commethod(49)
    def get_IsZoomChainingEnabledProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(50)
    def GetIsZoomChainingEnabled(self, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_commethod(51)
    def SetIsZoomChainingEnabled(self, element: win32more.Microsoft.UI.Xaml.DependencyObject, isZoomChainingEnabled: Boolean) -> Void: ...
    @winrt_commethod(52)
    def get_IsScrollInertiaEnabledProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(53)
    def GetIsScrollInertiaEnabled(self, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_commethod(54)
    def SetIsScrollInertiaEnabled(self, element: win32more.Microsoft.UI.Xaml.DependencyObject, isScrollInertiaEnabled: Boolean) -> Void: ...
    @winrt_commethod(55)
    def get_IsZoomInertiaEnabledProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(56)
    def GetIsZoomInertiaEnabled(self, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_commethod(57)
    def SetIsZoomInertiaEnabled(self, element: win32more.Microsoft.UI.Xaml.DependencyObject, isZoomInertiaEnabled: Boolean) -> Void: ...
    @winrt_commethod(58)
    def get_HorizontalScrollModeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(59)
    def GetHorizontalScrollMode(self, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> win32more.Microsoft.UI.Xaml.Controls.ScrollMode: ...
    @winrt_commethod(60)
    def SetHorizontalScrollMode(self, element: win32more.Microsoft.UI.Xaml.DependencyObject, horizontalScrollMode: win32more.Microsoft.UI.Xaml.Controls.ScrollMode) -> Void: ...
    @winrt_commethod(61)
    def get_VerticalScrollModeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(62)
    def GetVerticalScrollMode(self, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> win32more.Microsoft.UI.Xaml.Controls.ScrollMode: ...
    @winrt_commethod(63)
    def SetVerticalScrollMode(self, element: win32more.Microsoft.UI.Xaml.DependencyObject, verticalScrollMode: win32more.Microsoft.UI.Xaml.Controls.ScrollMode) -> Void: ...
    @winrt_commethod(64)
    def get_ZoomModeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(65)
    def GetZoomMode(self, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> win32more.Microsoft.UI.Xaml.Controls.ZoomMode: ...
    @winrt_commethod(66)
    def SetZoomMode(self, element: win32more.Microsoft.UI.Xaml.DependencyObject, zoomMode: win32more.Microsoft.UI.Xaml.Controls.ZoomMode) -> Void: ...
    @winrt_commethod(67)
    def get_CanContentRenderOutsideBoundsProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(68)
    def GetCanContentRenderOutsideBounds(self, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_commethod(69)
    def SetCanContentRenderOutsideBounds(self, element: win32more.Microsoft.UI.Xaml.DependencyObject, canContentRenderOutsideBounds: Boolean) -> Void: ...
    @winrt_commethod(70)
    def get_IsDeferredScrollingEnabledProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(71)
    def GetIsDeferredScrollingEnabled(self, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_commethod(72)
    def SetIsDeferredScrollingEnabled(self, element: win32more.Microsoft.UI.Xaml.DependencyObject, isDeferredScrollingEnabled: Boolean) -> Void: ...
    @winrt_commethod(73)
    def get_BringIntoViewOnFocusChangeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(74)
    def GetBringIntoViewOnFocusChange(self, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_commethod(75)
    def SetBringIntoViewOnFocusChange(self, element: win32more.Microsoft.UI.Xaml.DependencyObject, bringIntoViewOnFocusChange: Boolean) -> Void: ...
    BringIntoViewOnFocusChangeProperty = property(get_BringIntoViewOnFocusChangeProperty, None)
    CanContentRenderOutsideBoundsProperty = property(get_CanContentRenderOutsideBoundsProperty, None)
    ComputedHorizontalScrollBarVisibilityProperty = property(get_ComputedHorizontalScrollBarVisibilityProperty, None)
    ComputedVerticalScrollBarVisibilityProperty = property(get_ComputedVerticalScrollBarVisibilityProperty, None)
    ExtentHeightProperty = property(get_ExtentHeightProperty, None)
    ExtentWidthProperty = property(get_ExtentWidthProperty, None)
    HorizontalAnchorRatioProperty = property(get_HorizontalAnchorRatioProperty, None)
    HorizontalOffsetProperty = property(get_HorizontalOffsetProperty, None)
    HorizontalScrollBarVisibilityProperty = property(get_HorizontalScrollBarVisibilityProperty, None)
    HorizontalScrollModeProperty = property(get_HorizontalScrollModeProperty, None)
    HorizontalSnapPointsAlignmentProperty = property(get_HorizontalSnapPointsAlignmentProperty, None)
    HorizontalSnapPointsTypeProperty = property(get_HorizontalSnapPointsTypeProperty, None)
    IsDeferredScrollingEnabledProperty = property(get_IsDeferredScrollingEnabledProperty, None)
    IsHorizontalRailEnabledProperty = property(get_IsHorizontalRailEnabledProperty, None)
    IsHorizontalScrollChainingEnabledProperty = property(get_IsHorizontalScrollChainingEnabledProperty, None)
    IsScrollInertiaEnabledProperty = property(get_IsScrollInertiaEnabledProperty, None)
    IsVerticalRailEnabledProperty = property(get_IsVerticalRailEnabledProperty, None)
    IsVerticalScrollChainingEnabledProperty = property(get_IsVerticalScrollChainingEnabledProperty, None)
    IsZoomChainingEnabledProperty = property(get_IsZoomChainingEnabledProperty, None)
    IsZoomInertiaEnabledProperty = property(get_IsZoomInertiaEnabledProperty, None)
    LeftHeaderProperty = property(get_LeftHeaderProperty, None)
    MaxZoomFactorProperty = property(get_MaxZoomFactorProperty, None)
    MinZoomFactorProperty = property(get_MinZoomFactorProperty, None)
    ReduceViewportForCoreInputViewOcclusionsProperty = property(get_ReduceViewportForCoreInputViewOcclusionsProperty, None)
    ScrollableHeightProperty = property(get_ScrollableHeightProperty, None)
    ScrollableWidthProperty = property(get_ScrollableWidthProperty, None)
    TopHeaderProperty = property(get_TopHeaderProperty, None)
    TopLeftHeaderProperty = property(get_TopLeftHeaderProperty, None)
    VerticalAnchorRatioProperty = property(get_VerticalAnchorRatioProperty, None)
    VerticalOffsetProperty = property(get_VerticalOffsetProperty, None)
    VerticalScrollBarVisibilityProperty = property(get_VerticalScrollBarVisibilityProperty, None)
    VerticalScrollModeProperty = property(get_VerticalScrollModeProperty, None)
    VerticalSnapPointsAlignmentProperty = property(get_VerticalSnapPointsAlignmentProperty, None)
    VerticalSnapPointsTypeProperty = property(get_VerticalSnapPointsTypeProperty, None)
    ViewportHeightProperty = property(get_ViewportHeightProperty, None)
    ViewportWidthProperty = property(get_ViewportWidthProperty, None)
    ZoomFactorProperty = property(get_ZoomFactorProperty, None)
    ZoomModeProperty = property(get_ZoomModeProperty, None)
    ZoomSnapPointsProperty = property(get_ZoomSnapPointsProperty, None)
    ZoomSnapPointsTypeProperty = property(get_ZoomSnapPointsTypeProperty, None)
class IScrollViewerView(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IScrollViewerView'
    _iid_ = Guid('{1e9f68ee-6ce5-5cbf-bbfe-b8cd284b9c23}')
    @winrt_commethod(6)
    def get_HorizontalOffset(self) -> Double: ...
    @winrt_commethod(7)
    def get_VerticalOffset(self) -> Double: ...
    @winrt_commethod(8)
    def get_ZoomFactor(self) -> Single: ...
    HorizontalOffset = property(get_HorizontalOffset, None)
    VerticalOffset = property(get_VerticalOffset, None)
    ZoomFactor = property(get_ZoomFactor, None)
class IScrollViewerViewChangedEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IScrollViewerViewChangedEventArgs'
    _iid_ = Guid('{bf7bb85b-1d46-5004-a370-ecb626630588}')
    @winrt_commethod(6)
    def get_IsIntermediate(self) -> Boolean: ...
    IsIntermediate = property(get_IsIntermediate, None)
class IScrollViewerViewChangingEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IScrollViewerViewChangingEventArgs'
    _iid_ = Guid('{aee37d7c-4696-55f1-96ca-656832fc0fd2}')
    @winrt_commethod(6)
    def get_NextView(self) -> win32more.Microsoft.UI.Xaml.Controls.ScrollViewerView: ...
    @winrt_commethod(7)
    def get_FinalView(self) -> win32more.Microsoft.UI.Xaml.Controls.ScrollViewerView: ...
    @winrt_commethod(8)
    def get_IsInertial(self) -> Boolean: ...
    FinalView = property(get_FinalView, None)
    IsInertial = property(get_IsInertial, None)
    NextView = property(get_NextView, None)
class IScrollingAnchorRequestedEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IScrollingAnchorRequestedEventArgs'
    _iid_ = Guid('{6a46cb4b-ab26-55b2-aa76-9b337a4f8e8e}')
    @winrt_commethod(6)
    def get_AnchorCandidates(self) -> win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.UIElement]: ...
    @winrt_commethod(7)
    def get_AnchorElement(self) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_commethod(8)
    def put_AnchorElement(self, value: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    AnchorCandidates = property(get_AnchorCandidates, None)
    AnchorElement = property(get_AnchorElement, put_AnchorElement)
class IScrollingBringingIntoViewEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IScrollingBringingIntoViewEventArgs'
    _iid_ = Guid('{09760d99-d60c-5c76-8033-127b2085358c}')
    @winrt_commethod(6)
    def get_SnapPointsMode(self) -> win32more.Microsoft.UI.Xaml.Controls.ScrollingSnapPointsMode: ...
    @winrt_commethod(7)
    def put_SnapPointsMode(self, value: win32more.Microsoft.UI.Xaml.Controls.ScrollingSnapPointsMode) -> Void: ...
    @winrt_commethod(8)
    def get_RequestEventArgs(self) -> win32more.Microsoft.UI.Xaml.BringIntoViewRequestedEventArgs: ...
    @winrt_commethod(9)
    def get_TargetHorizontalOffset(self) -> Double: ...
    @winrt_commethod(10)
    def get_TargetVerticalOffset(self) -> Double: ...
    @winrt_commethod(11)
    def get_CorrelationId(self) -> Int32: ...
    @winrt_commethod(12)
    def get_Cancel(self) -> Boolean: ...
    @winrt_commethod(13)
    def put_Cancel(self, value: Boolean) -> Void: ...
    Cancel = property(get_Cancel, put_Cancel)
    CorrelationId = property(get_CorrelationId, None)
    RequestEventArgs = property(get_RequestEventArgs, None)
    SnapPointsMode = property(get_SnapPointsMode, put_SnapPointsMode)
    TargetHorizontalOffset = property(get_TargetHorizontalOffset, None)
    TargetVerticalOffset = property(get_TargetVerticalOffset, None)
class IScrollingScrollAnimationStartingEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IScrollingScrollAnimationStartingEventArgs'
    _iid_ = Guid('{7acb0423-6fc7-516b-ab67-03a4a4285a90}')
    @winrt_commethod(6)
    def get_Animation(self) -> win32more.Microsoft.UI.Composition.CompositionAnimation: ...
    @winrt_commethod(7)
    def put_Animation(self, value: win32more.Microsoft.UI.Composition.CompositionAnimation) -> Void: ...
    @winrt_commethod(8)
    def get_StartPosition(self) -> win32more.Windows.Foundation.Numerics.Vector2: ...
    @winrt_commethod(9)
    def get_EndPosition(self) -> win32more.Windows.Foundation.Numerics.Vector2: ...
    @winrt_commethod(10)
    def get_CorrelationId(self) -> Int32: ...
    Animation = property(get_Animation, put_Animation)
    CorrelationId = property(get_CorrelationId, None)
    EndPosition = property(get_EndPosition, None)
    StartPosition = property(get_StartPosition, None)
class IScrollingScrollCompletedEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IScrollingScrollCompletedEventArgs'
    _iid_ = Guid('{9bdeae9c-972c-54ae-9c62-fc1a03ff3fa8}')
    @winrt_commethod(6)
    def get_CorrelationId(self) -> Int32: ...
    CorrelationId = property(get_CorrelationId, None)
class IScrollingScrollOptions(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IScrollingScrollOptions'
    _iid_ = Guid('{30b2e77b-2553-5b09-b308-b4b06fc8f9af}')
    @winrt_commethod(6)
    def get_AnimationMode(self) -> win32more.Microsoft.UI.Xaml.Controls.ScrollingAnimationMode: ...
    @winrt_commethod(7)
    def put_AnimationMode(self, value: win32more.Microsoft.UI.Xaml.Controls.ScrollingAnimationMode) -> Void: ...
    @winrt_commethod(8)
    def get_SnapPointsMode(self) -> win32more.Microsoft.UI.Xaml.Controls.ScrollingSnapPointsMode: ...
    @winrt_commethod(9)
    def put_SnapPointsMode(self, value: win32more.Microsoft.UI.Xaml.Controls.ScrollingSnapPointsMode) -> Void: ...
    AnimationMode = property(get_AnimationMode, put_AnimationMode)
    SnapPointsMode = property(get_SnapPointsMode, put_SnapPointsMode)
class IScrollingScrollOptionsFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IScrollingScrollOptionsFactory'
    _iid_ = Guid('{31eb58fe-0f6a-51ec-90db-5ccaa0a288a6}')
    @winrt_commethod(6)
    def CreateInstance(self, animationMode: win32more.Microsoft.UI.Xaml.Controls.ScrollingAnimationMode, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.ScrollingScrollOptions: ...
    @winrt_commethod(7)
    def CreateInstance2(self, animationMode: win32more.Microsoft.UI.Xaml.Controls.ScrollingAnimationMode, snapPointsMode: win32more.Microsoft.UI.Xaml.Controls.ScrollingSnapPointsMode, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.ScrollingScrollOptions: ...
class IScrollingZoomAnimationStartingEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IScrollingZoomAnimationStartingEventArgs'
    _iid_ = Guid('{59bfb77b-47c9-5691-bdcd-536fbe8eb8c1}')
    @winrt_commethod(6)
    def get_CenterPoint(self) -> win32more.Windows.Foundation.Numerics.Vector2: ...
    @winrt_commethod(7)
    def get_StartZoomFactor(self) -> Single: ...
    @winrt_commethod(8)
    def get_EndZoomFactor(self) -> Single: ...
    @winrt_commethod(9)
    def get_Animation(self) -> win32more.Microsoft.UI.Composition.CompositionAnimation: ...
    @winrt_commethod(10)
    def put_Animation(self, value: win32more.Microsoft.UI.Composition.CompositionAnimation) -> Void: ...
    @winrt_commethod(11)
    def get_CorrelationId(self) -> Int32: ...
    Animation = property(get_Animation, put_Animation)
    CenterPoint = property(get_CenterPoint, None)
    CorrelationId = property(get_CorrelationId, None)
    EndZoomFactor = property(get_EndZoomFactor, None)
    StartZoomFactor = property(get_StartZoomFactor, None)
class IScrollingZoomCompletedEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IScrollingZoomCompletedEventArgs'
    _iid_ = Guid('{c821207e-ab2a-5f6c-9074-411840a68d55}')
    @winrt_commethod(6)
    def get_CorrelationId(self) -> Int32: ...
    CorrelationId = property(get_CorrelationId, None)
class IScrollingZoomOptions(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IScrollingZoomOptions'
    _iid_ = Guid('{e4ace0b2-9b0c-5eda-88a2-c31b1b84f829}')
    @winrt_commethod(6)
    def get_AnimationMode(self) -> win32more.Microsoft.UI.Xaml.Controls.ScrollingAnimationMode: ...
    @winrt_commethod(7)
    def put_AnimationMode(self, value: win32more.Microsoft.UI.Xaml.Controls.ScrollingAnimationMode) -> Void: ...
    @winrt_commethod(8)
    def get_SnapPointsMode(self) -> win32more.Microsoft.UI.Xaml.Controls.ScrollingSnapPointsMode: ...
    @winrt_commethod(9)
    def put_SnapPointsMode(self, value: win32more.Microsoft.UI.Xaml.Controls.ScrollingSnapPointsMode) -> Void: ...
    AnimationMode = property(get_AnimationMode, put_AnimationMode)
    SnapPointsMode = property(get_SnapPointsMode, put_SnapPointsMode)
class IScrollingZoomOptionsFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IScrollingZoomOptionsFactory'
    _iid_ = Guid('{d1c82e57-d5e8-58f5-a2c0-ee70c64143be}')
    @winrt_commethod(6)
    def CreateInstance(self, animationMode: win32more.Microsoft.UI.Xaml.Controls.ScrollingAnimationMode, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.ScrollingZoomOptions: ...
    @winrt_commethod(7)
    def CreateInstance2(self, animationMode: win32more.Microsoft.UI.Xaml.Controls.ScrollingAnimationMode, snapPointsMode: win32more.Microsoft.UI.Xaml.Controls.ScrollingSnapPointsMode, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.ScrollingZoomOptions: ...
class ISectionsInViewChangedEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ISectionsInViewChangedEventArgs'
    _iid_ = Guid('{5e727da0-b909-536c-8656-28017b48f5a5}')
    @winrt_commethod(6)
    def get_AddedSections(self) -> win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.HubSection]: ...
    @winrt_commethod(7)
    def get_RemovedSections(self) -> win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.HubSection]: ...
    AddedSections = property(get_AddedSections, None)
    RemovedSections = property(get_RemovedSections, None)
class ISectionsInViewChangedEventArgsFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ISectionsInViewChangedEventArgsFactory'
    _iid_ = Guid('{df5ab91f-e316-53cf-9636-a85bdc24e85e}')
class ISelectionChangedEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ISelectionChangedEventArgs'
    _iid_ = Guid('{b6c18076-4b76-5416-ad29-e2dc20c46246}')
    @winrt_commethod(6)
    def get_AddedItems(self) -> win32more.Windows.Foundation.Collections.IVector[IInspectable]: ...
    @winrt_commethod(7)
    def get_RemovedItems(self) -> win32more.Windows.Foundation.Collections.IVector[IInspectable]: ...
    AddedItems = property(get_AddedItems, None)
    RemovedItems = property(get_RemovedItems, None)
class ISelectionChangedEventArgsFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ISelectionChangedEventArgsFactory'
    _iid_ = Guid('{0fcd041d-465f-5745-9882-0c8348e4135d}')
    @winrt_commethod(6)
    def CreateInstanceWithRemovedItemsAndAddedItems(self, removedItems: win32more.Windows.Foundation.Collections.IVector[IInspectable], addedItems: win32more.Windows.Foundation.Collections.IVector[IInspectable], baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.SelectionChangedEventArgs: ...
class ISelectorBar(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ISelectorBar'
    _iid_ = Guid('{7f4ad191-55ea-508e-bf47-7047d8677370}')
    @winrt_commethod(6)
    def get_Items(self) -> win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.SelectorBarItem]: ...
    @winrt_commethod(7)
    def get_SelectedItem(self) -> win32more.Microsoft.UI.Xaml.Controls.SelectorBarItem: ...
    @winrt_commethod(8)
    def put_SelectedItem(self, value: win32more.Microsoft.UI.Xaml.Controls.SelectorBarItem) -> Void: ...
    @winrt_commethod(9)
    def add_SelectionChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.SelectorBar, win32more.Microsoft.UI.Xaml.Controls.SelectorBarSelectionChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(10)
    def remove_SelectionChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    Items = property(get_Items, None)
    SelectedItem = property(get_SelectedItem, put_SelectedItem)
    SelectionChanged = event(add_SelectionChanged, remove_SelectionChanged)
class ISelectorBarFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ISelectorBarFactory'
    _iid_ = Guid('{71243dc7-b46c-5a04-9894-e420e462703f}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.SelectorBar: ...
class ISelectorBarItem(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ISelectorBarItem'
    _iid_ = Guid('{3cdba1f9-a13a-56a2-b9a9-f954998d3658}')
    @winrt_commethod(6)
    def get_Text(self) -> hstr: ...
    @winrt_commethod(7)
    def put_Text(self, value: hstr) -> Void: ...
    @winrt_commethod(8)
    def get_Icon(self) -> win32more.Microsoft.UI.Xaml.Controls.IconElement: ...
    @winrt_commethod(9)
    def put_Icon(self, value: win32more.Microsoft.UI.Xaml.Controls.IconElement) -> Void: ...
    Icon = property(get_Icon, put_Icon)
    Text = property(get_Text, put_Text)
class ISelectorBarItemFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ISelectorBarItemFactory'
    _iid_ = Guid('{e46b62ea-e60d-5989-bea7-5470da326816}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.SelectorBarItem: ...
class ISelectorBarItemStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ISelectorBarItemStatics'
    _iid_ = Guid('{08b5bdfc-54de-5d4c-aae3-3763a6b4e75b}')
    @winrt_commethod(6)
    def get_TextProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_IconProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    IconProperty = property(get_IconProperty, None)
    TextProperty = property(get_TextProperty, None)
class ISelectorBarSelectionChangedEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ISelectorBarSelectionChangedEventArgs'
    _iid_ = Guid('{73b3f6c5-5050-5c5a-899c-4e6e0474cb63}')
class ISelectorBarStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ISelectorBarStatics'
    _iid_ = Guid('{672b4e72-728a-53ea-b66a-968bc802dc24}')
    @winrt_commethod(6)
    def get_ItemsProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_SelectedItemProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    ItemsProperty = property(get_ItemsProperty, None)
    SelectedItemProperty = property(get_SelectedItemProperty, None)
class ISemanticZoom(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ISemanticZoom'
    _iid_ = Guid('{7e14616d-55ef-548c-a997-c923e302718f}')
    @winrt_commethod(6)
    def get_ZoomedInView(self) -> win32more.Microsoft.UI.Xaml.Controls.ISemanticZoomInformation: ...
    @winrt_commethod(7)
    def put_ZoomedInView(self, value: win32more.Microsoft.UI.Xaml.Controls.ISemanticZoomInformation) -> Void: ...
    @winrt_commethod(8)
    def get_ZoomedOutView(self) -> win32more.Microsoft.UI.Xaml.Controls.ISemanticZoomInformation: ...
    @winrt_commethod(9)
    def put_ZoomedOutView(self, value: win32more.Microsoft.UI.Xaml.Controls.ISemanticZoomInformation) -> Void: ...
    @winrt_commethod(10)
    def get_IsZoomedInViewActive(self) -> Boolean: ...
    @winrt_commethod(11)
    def put_IsZoomedInViewActive(self, value: Boolean) -> Void: ...
    @winrt_commethod(12)
    def get_CanChangeViews(self) -> Boolean: ...
    @winrt_commethod(13)
    def put_CanChangeViews(self, value: Boolean) -> Void: ...
    @winrt_commethod(14)
    def add_ViewChangeStarted(self, handler: win32more.Microsoft.UI.Xaml.Controls.SemanticZoomViewChangedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(15)
    def remove_ViewChangeStarted(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(16)
    def add_ViewChangeCompleted(self, handler: win32more.Microsoft.UI.Xaml.Controls.SemanticZoomViewChangedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(17)
    def remove_ViewChangeCompleted(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(18)
    def ToggleActiveView(self) -> Void: ...
    @winrt_commethod(19)
    def get_IsZoomOutButtonEnabled(self) -> Boolean: ...
    @winrt_commethod(20)
    def put_IsZoomOutButtonEnabled(self, value: Boolean) -> Void: ...
    CanChangeViews = property(get_CanChangeViews, put_CanChangeViews)
    IsZoomOutButtonEnabled = property(get_IsZoomOutButtonEnabled, put_IsZoomOutButtonEnabled)
    IsZoomedInViewActive = property(get_IsZoomedInViewActive, put_IsZoomedInViewActive)
    ZoomedInView = property(get_ZoomedInView, put_ZoomedInView)
    ZoomedOutView = property(get_ZoomedOutView, put_ZoomedOutView)
    ViewChangeCompleted = event(add_ViewChangeCompleted, remove_ViewChangeCompleted)
    ViewChangeStarted = event(add_ViewChangeStarted, remove_ViewChangeStarted)
class ISemanticZoomInformation(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ISemanticZoomInformation'
    _iid_ = Guid('{12d62b04-bb13-50f2-9d8b-e57c02b4bde4}')
    @winrt_commethod(6)
    def get_SemanticZoomOwner(self) -> win32more.Microsoft.UI.Xaml.Controls.SemanticZoom: ...
    @winrt_commethod(7)
    def put_SemanticZoomOwner(self, value: win32more.Microsoft.UI.Xaml.Controls.SemanticZoom) -> Void: ...
    @winrt_commethod(8)
    def get_IsActiveView(self) -> Boolean: ...
    @winrt_commethod(9)
    def put_IsActiveView(self, value: Boolean) -> Void: ...
    @winrt_commethod(10)
    def get_IsZoomedInView(self) -> Boolean: ...
    @winrt_commethod(11)
    def put_IsZoomedInView(self, value: Boolean) -> Void: ...
    @winrt_commethod(12)
    def InitializeViewChange(self) -> Void: ...
    @winrt_commethod(13)
    def CompleteViewChange(self) -> Void: ...
    @winrt_commethod(14)
    def MakeVisible(self, item: win32more.Microsoft.UI.Xaml.Controls.SemanticZoomLocation) -> Void: ...
    @winrt_commethod(15)
    def StartViewChangeFrom(self, source: win32more.Microsoft.UI.Xaml.Controls.SemanticZoomLocation, destination: win32more.Microsoft.UI.Xaml.Controls.SemanticZoomLocation) -> Void: ...
    @winrt_commethod(16)
    def StartViewChangeTo(self, source: win32more.Microsoft.UI.Xaml.Controls.SemanticZoomLocation, destination: win32more.Microsoft.UI.Xaml.Controls.SemanticZoomLocation) -> Void: ...
    @winrt_commethod(17)
    def CompleteViewChangeFrom(self, source: win32more.Microsoft.UI.Xaml.Controls.SemanticZoomLocation, destination: win32more.Microsoft.UI.Xaml.Controls.SemanticZoomLocation) -> Void: ...
    @winrt_commethod(18)
    def CompleteViewChangeTo(self, source: win32more.Microsoft.UI.Xaml.Controls.SemanticZoomLocation, destination: win32more.Microsoft.UI.Xaml.Controls.SemanticZoomLocation) -> Void: ...
    IsActiveView = property(get_IsActiveView, put_IsActiveView)
    IsZoomedInView = property(get_IsZoomedInView, put_IsZoomedInView)
    SemanticZoomOwner = property(get_SemanticZoomOwner, put_SemanticZoomOwner)
class ISemanticZoomLocation(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ISemanticZoomLocation'
    _iid_ = Guid('{41c1dec7-f34f-51db-9525-5c149b05a527}')
    @winrt_commethod(6)
    def get_Item(self) -> IInspectable: ...
    @winrt_commethod(7)
    def put_Item(self, value: IInspectable) -> Void: ...
    @winrt_commethod(8)
    def get_Bounds(self) -> win32more.Windows.Foundation.Rect: ...
    @winrt_commethod(9)
    def put_Bounds(self, value: win32more.Windows.Foundation.Rect) -> Void: ...
    Bounds = property(get_Bounds, put_Bounds)
    Item = property(get_Item, put_Item)
class ISemanticZoomStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ISemanticZoomStatics'
    _iid_ = Guid('{e4fbd358-9342-56d3-b5c2-bf80de6f47ed}')
    @winrt_commethod(6)
    def get_ZoomedInViewProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_ZoomedOutViewProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_IsZoomedInViewActiveProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_CanChangeViewsProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_IsZoomOutButtonEnabledProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    CanChangeViewsProperty = property(get_CanChangeViewsProperty, None)
    IsZoomOutButtonEnabledProperty = property(get_IsZoomOutButtonEnabledProperty, None)
    IsZoomedInViewActiveProperty = property(get_IsZoomedInViewActiveProperty, None)
    ZoomedInViewProperty = property(get_ZoomedInViewProperty, None)
    ZoomedOutViewProperty = property(get_ZoomedOutViewProperty, None)
class ISemanticZoomViewChangedEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ISemanticZoomViewChangedEventArgs'
    _iid_ = Guid('{cf62d53d-97d3-5cef-96f3-1c413f524eca}')
    @winrt_commethod(6)
    def get_IsSourceZoomedInView(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_IsSourceZoomedInView(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def get_SourceItem(self) -> win32more.Microsoft.UI.Xaml.Controls.SemanticZoomLocation: ...
    @winrt_commethod(9)
    def put_SourceItem(self, value: win32more.Microsoft.UI.Xaml.Controls.SemanticZoomLocation) -> Void: ...
    @winrt_commethod(10)
    def get_DestinationItem(self) -> win32more.Microsoft.UI.Xaml.Controls.SemanticZoomLocation: ...
    @winrt_commethod(11)
    def put_DestinationItem(self, value: win32more.Microsoft.UI.Xaml.Controls.SemanticZoomLocation) -> Void: ...
    DestinationItem = property(get_DestinationItem, put_DestinationItem)
    IsSourceZoomedInView = property(get_IsSourceZoomedInView, put_IsSourceZoomedInView)
    SourceItem = property(get_SourceItem, put_SourceItem)
class ISlider(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ISlider'
    _iid_ = Guid('{f7418ecf-7c35-5216-8bf1-d82d47cce5df}')
    @winrt_commethod(6)
    def get_IntermediateValue(self) -> Double: ...
    @winrt_commethod(7)
    def put_IntermediateValue(self, value: Double) -> Void: ...
    @winrt_commethod(8)
    def get_StepFrequency(self) -> Double: ...
    @winrt_commethod(9)
    def put_StepFrequency(self, value: Double) -> Void: ...
    @winrt_commethod(10)
    def get_SnapsTo(self) -> win32more.Microsoft.UI.Xaml.Controls.Primitives.SliderSnapsTo: ...
    @winrt_commethod(11)
    def put_SnapsTo(self, value: win32more.Microsoft.UI.Xaml.Controls.Primitives.SliderSnapsTo) -> Void: ...
    @winrt_commethod(12)
    def get_TickFrequency(self) -> Double: ...
    @winrt_commethod(13)
    def put_TickFrequency(self, value: Double) -> Void: ...
    @winrt_commethod(14)
    def get_TickPlacement(self) -> win32more.Microsoft.UI.Xaml.Controls.Primitives.TickPlacement: ...
    @winrt_commethod(15)
    def put_TickPlacement(self, value: win32more.Microsoft.UI.Xaml.Controls.Primitives.TickPlacement) -> Void: ...
    @winrt_commethod(16)
    def get_Orientation(self) -> win32more.Microsoft.UI.Xaml.Controls.Orientation: ...
    @winrt_commethod(17)
    def put_Orientation(self, value: win32more.Microsoft.UI.Xaml.Controls.Orientation) -> Void: ...
    @winrt_commethod(18)
    def get_IsDirectionReversed(self) -> Boolean: ...
    @winrt_commethod(19)
    def put_IsDirectionReversed(self, value: Boolean) -> Void: ...
    @winrt_commethod(20)
    def get_IsThumbToolTipEnabled(self) -> Boolean: ...
    @winrt_commethod(21)
    def put_IsThumbToolTipEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(22)
    def get_ThumbToolTipValueConverter(self) -> win32more.Microsoft.UI.Xaml.Data.IValueConverter: ...
    @winrt_commethod(23)
    def put_ThumbToolTipValueConverter(self, value: win32more.Microsoft.UI.Xaml.Data.IValueConverter) -> Void: ...
    @winrt_commethod(24)
    def get_Header(self) -> IInspectable: ...
    @winrt_commethod(25)
    def put_Header(self, value: IInspectable) -> Void: ...
    @winrt_commethod(26)
    def get_HeaderTemplate(self) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_commethod(27)
    def put_HeaderTemplate(self, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    Header = property(get_Header, put_Header)
    HeaderTemplate = property(get_HeaderTemplate, put_HeaderTemplate)
    IntermediateValue = property(get_IntermediateValue, put_IntermediateValue)
    IsDirectionReversed = property(get_IsDirectionReversed, put_IsDirectionReversed)
    IsThumbToolTipEnabled = property(get_IsThumbToolTipEnabled, put_IsThumbToolTipEnabled)
    Orientation = property(get_Orientation, put_Orientation)
    SnapsTo = property(get_SnapsTo, put_SnapsTo)
    StepFrequency = property(get_StepFrequency, put_StepFrequency)
    ThumbToolTipValueConverter = property(get_ThumbToolTipValueConverter, put_ThumbToolTipValueConverter)
    TickFrequency = property(get_TickFrequency, put_TickFrequency)
    TickPlacement = property(get_TickPlacement, put_TickPlacement)
class ISliderFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ISliderFactory'
    _iid_ = Guid('{06604d71-34ca-5f39-9656-29d81d3c110c}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.Slider: ...
class ISliderStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ISliderStatics'
    _iid_ = Guid('{f0541f7b-6d81-59e2-997a-2e65fbcccd21}')
    @winrt_commethod(6)
    def get_IntermediateValueProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_StepFrequencyProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_SnapsToProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_TickFrequencyProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_TickPlacementProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_OrientationProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_IsDirectionReversedProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_IsThumbToolTipEnabledProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(14)
    def get_ThumbToolTipValueConverterProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(15)
    def get_HeaderProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(16)
    def get_HeaderTemplateProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    HeaderProperty = property(get_HeaderProperty, None)
    HeaderTemplateProperty = property(get_HeaderTemplateProperty, None)
    IntermediateValueProperty = property(get_IntermediateValueProperty, None)
    IsDirectionReversedProperty = property(get_IsDirectionReversedProperty, None)
    IsThumbToolTipEnabledProperty = property(get_IsThumbToolTipEnabledProperty, None)
    OrientationProperty = property(get_OrientationProperty, None)
    SnapsToProperty = property(get_SnapsToProperty, None)
    StepFrequencyProperty = property(get_StepFrequencyProperty, None)
    ThumbToolTipValueConverterProperty = property(get_ThumbToolTipValueConverterProperty, None)
    TickFrequencyProperty = property(get_TickFrequencyProperty, None)
    TickPlacementProperty = property(get_TickPlacementProperty, None)
class ISplitButton(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ISplitButton'
    _iid_ = Guid('{f627202d-d2d7-5ff6-bb05-8c48eb6b1fc6}')
    @winrt_commethod(6)
    def get_Flyout(self) -> win32more.Microsoft.UI.Xaml.Controls.Primitives.FlyoutBase: ...
    @winrt_commethod(7)
    def put_Flyout(self, value: win32more.Microsoft.UI.Xaml.Controls.Primitives.FlyoutBase) -> Void: ...
    @winrt_commethod(8)
    def get_Command(self) -> win32more.Microsoft.UI.Xaml.Input.ICommand: ...
    @winrt_commethod(9)
    def put_Command(self, value: win32more.Microsoft.UI.Xaml.Input.ICommand) -> Void: ...
    @winrt_commethod(10)
    def get_CommandParameter(self) -> IInspectable: ...
    @winrt_commethod(11)
    def put_CommandParameter(self, value: IInspectable) -> Void: ...
    @winrt_commethod(12)
    def add_Click(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.SplitButton, win32more.Microsoft.UI.Xaml.Controls.SplitButtonClickEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(13)
    def remove_Click(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    Command = property(get_Command, put_Command)
    CommandParameter = property(get_CommandParameter, put_CommandParameter)
    Flyout = property(get_Flyout, put_Flyout)
    Click = event(add_Click, remove_Click)
class ISplitButtonClickEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ISplitButtonClickEventArgs'
    _iid_ = Guid('{6af896c2-e65a-5998-9c82-2af8f3e0741f}')
class ISplitButtonFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ISplitButtonFactory'
    _iid_ = Guid('{07510092-2612-55e7-981c-a536ddd4570e}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.SplitButton: ...
class ISplitButtonStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ISplitButtonStatics'
    _iid_ = Guid('{d54ddd05-73e7-55a1-a119-aa342e5f9feb}')
    @winrt_commethod(6)
    def get_FlyoutProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_CommandProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_CommandParameterProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    CommandParameterProperty = property(get_CommandParameterProperty, None)
    CommandProperty = property(get_CommandProperty, None)
    FlyoutProperty = property(get_FlyoutProperty, None)
class ISplitView(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ISplitView'
    _iid_ = Guid('{10ae18f7-1666-5897-bbce-1e687e7784a8}')
    @winrt_commethod(6)
    def get_Content(self) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_commethod(7)
    def put_Content(self, value: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    @winrt_commethod(8)
    def get_Pane(self) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_commethod(9)
    def put_Pane(self, value: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    @winrt_commethod(10)
    def get_IsPaneOpen(self) -> Boolean: ...
    @winrt_commethod(11)
    def put_IsPaneOpen(self, value: Boolean) -> Void: ...
    @winrt_commethod(12)
    def get_OpenPaneLength(self) -> Double: ...
    @winrt_commethod(13)
    def put_OpenPaneLength(self, value: Double) -> Void: ...
    @winrt_commethod(14)
    def get_CompactPaneLength(self) -> Double: ...
    @winrt_commethod(15)
    def put_CompactPaneLength(self, value: Double) -> Void: ...
    @winrt_commethod(16)
    def get_PanePlacement(self) -> win32more.Microsoft.UI.Xaml.Controls.SplitViewPanePlacement: ...
    @winrt_commethod(17)
    def put_PanePlacement(self, value: win32more.Microsoft.UI.Xaml.Controls.SplitViewPanePlacement) -> Void: ...
    @winrt_commethod(18)
    def get_DisplayMode(self) -> win32more.Microsoft.UI.Xaml.Controls.SplitViewDisplayMode: ...
    @winrt_commethod(19)
    def put_DisplayMode(self, value: win32more.Microsoft.UI.Xaml.Controls.SplitViewDisplayMode) -> Void: ...
    @winrt_commethod(20)
    def get_TemplateSettings(self) -> win32more.Microsoft.UI.Xaml.Controls.Primitives.SplitViewTemplateSettings: ...
    @winrt_commethod(21)
    def get_PaneBackground(self) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_commethod(22)
    def put_PaneBackground(self, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(23)
    def get_LightDismissOverlayMode(self) -> win32more.Microsoft.UI.Xaml.Controls.LightDismissOverlayMode: ...
    @winrt_commethod(24)
    def put_LightDismissOverlayMode(self, value: win32more.Microsoft.UI.Xaml.Controls.LightDismissOverlayMode) -> Void: ...
    @winrt_commethod(25)
    def add_PaneClosing(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.SplitView, win32more.Microsoft.UI.Xaml.Controls.SplitViewPaneClosingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(26)
    def remove_PaneClosing(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(27)
    def add_PaneClosed(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.SplitView, IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(28)
    def remove_PaneClosed(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(29)
    def add_PaneOpening(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.SplitView, IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(30)
    def remove_PaneOpening(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(31)
    def add_PaneOpened(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.SplitView, IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(32)
    def remove_PaneOpened(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    CompactPaneLength = property(get_CompactPaneLength, put_CompactPaneLength)
    Content = property(get_Content, put_Content)
    DisplayMode = property(get_DisplayMode, put_DisplayMode)
    IsPaneOpen = property(get_IsPaneOpen, put_IsPaneOpen)
    LightDismissOverlayMode = property(get_LightDismissOverlayMode, put_LightDismissOverlayMode)
    OpenPaneLength = property(get_OpenPaneLength, put_OpenPaneLength)
    Pane = property(get_Pane, put_Pane)
    PaneBackground = property(get_PaneBackground, put_PaneBackground)
    PanePlacement = property(get_PanePlacement, put_PanePlacement)
    TemplateSettings = property(get_TemplateSettings, None)
    PaneClosed = event(add_PaneClosed, remove_PaneClosed)
    PaneClosing = event(add_PaneClosing, remove_PaneClosing)
    PaneOpened = event(add_PaneOpened, remove_PaneOpened)
    PaneOpening = event(add_PaneOpening, remove_PaneOpening)
class ISplitViewFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ISplitViewFactory'
    _iid_ = Guid('{389ece72-75ce-561b-aad3-c52125ca6a50}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.SplitView: ...
class ISplitViewPaneClosingEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ISplitViewPaneClosingEventArgs'
    _iid_ = Guid('{9138965b-8499-5f9c-93e0-34beda441e6d}')
    @winrt_commethod(6)
    def get_Cancel(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_Cancel(self, value: Boolean) -> Void: ...
    Cancel = property(get_Cancel, put_Cancel)
class ISplitViewStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ISplitViewStatics'
    _iid_ = Guid('{1c69a263-552c-5505-ac81-49e247fee9db}')
    @winrt_commethod(6)
    def get_ContentProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_PaneProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_IsPaneOpenProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_OpenPaneLengthProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_CompactPaneLengthProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_PanePlacementProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_DisplayModeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_TemplateSettingsProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(14)
    def get_PaneBackgroundProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(15)
    def get_LightDismissOverlayModeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    CompactPaneLengthProperty = property(get_CompactPaneLengthProperty, None)
    ContentProperty = property(get_ContentProperty, None)
    DisplayModeProperty = property(get_DisplayModeProperty, None)
    IsPaneOpenProperty = property(get_IsPaneOpenProperty, None)
    LightDismissOverlayModeProperty = property(get_LightDismissOverlayModeProperty, None)
    OpenPaneLengthProperty = property(get_OpenPaneLengthProperty, None)
    PaneBackgroundProperty = property(get_PaneBackgroundProperty, None)
    PanePlacementProperty = property(get_PanePlacementProperty, None)
    PaneProperty = property(get_PaneProperty, None)
    TemplateSettingsProperty = property(get_TemplateSettingsProperty, None)
class IStackLayout(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IStackLayout'
    _iid_ = Guid('{3ea9c3dd-8103-571f-9e07-44ea76c91a10}')
    @winrt_commethod(6)
    def get_Orientation(self) -> win32more.Microsoft.UI.Xaml.Controls.Orientation: ...
    @winrt_commethod(7)
    def put_Orientation(self, value: win32more.Microsoft.UI.Xaml.Controls.Orientation) -> Void: ...
    @winrt_commethod(8)
    def get_Spacing(self) -> Double: ...
    @winrt_commethod(9)
    def put_Spacing(self, value: Double) -> Void: ...
    Orientation = property(get_Orientation, put_Orientation)
    Spacing = property(get_Spacing, put_Spacing)
class IStackLayoutFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IStackLayoutFactory'
    _iid_ = Guid('{ea606f86-21a1-5c35-911e-4a1de8bc69d9}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.StackLayout: ...
class IStackLayoutStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IStackLayoutStatics'
    _iid_ = Guid('{5610aecf-fb2a-5726-ac3a-16479ba2ecad}')
    @winrt_commethod(6)
    def get_OrientationProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_SpacingProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    OrientationProperty = property(get_OrientationProperty, None)
    SpacingProperty = property(get_SpacingProperty, None)
class IStackPanel(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IStackPanel'
    _iid_ = Guid('{493ab00b-3a6a-5e4a-9452-407cd5197406}')
    @winrt_commethod(6)
    def get_AreScrollSnapPointsRegular(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_AreScrollSnapPointsRegular(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def get_Orientation(self) -> win32more.Microsoft.UI.Xaml.Controls.Orientation: ...
    @winrt_commethod(9)
    def put_Orientation(self, value: win32more.Microsoft.UI.Xaml.Controls.Orientation) -> Void: ...
    @winrt_commethod(10)
    def get_BackgroundSizing(self) -> win32more.Microsoft.UI.Xaml.Controls.BackgroundSizing: ...
    @winrt_commethod(11)
    def put_BackgroundSizing(self, value: win32more.Microsoft.UI.Xaml.Controls.BackgroundSizing) -> Void: ...
    @winrt_commethod(12)
    def get_BorderBrush(self) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_commethod(13)
    def put_BorderBrush(self, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(14)
    def get_BorderThickness(self) -> win32more.Microsoft.UI.Xaml.Thickness: ...
    @winrt_commethod(15)
    def put_BorderThickness(self, value: win32more.Microsoft.UI.Xaml.Thickness) -> Void: ...
    @winrt_commethod(16)
    def get_CornerRadius(self) -> win32more.Microsoft.UI.Xaml.CornerRadius: ...
    @winrt_commethod(17)
    def put_CornerRadius(self, value: win32more.Microsoft.UI.Xaml.CornerRadius) -> Void: ...
    @winrt_commethod(18)
    def get_Padding(self) -> win32more.Microsoft.UI.Xaml.Thickness: ...
    @winrt_commethod(19)
    def put_Padding(self, value: win32more.Microsoft.UI.Xaml.Thickness) -> Void: ...
    @winrt_commethod(20)
    def get_Spacing(self) -> Double: ...
    @winrt_commethod(21)
    def put_Spacing(self, value: Double) -> Void: ...
    AreScrollSnapPointsRegular = property(get_AreScrollSnapPointsRegular, put_AreScrollSnapPointsRegular)
    BackgroundSizing = property(get_BackgroundSizing, put_BackgroundSizing)
    BorderBrush = property(get_BorderBrush, put_BorderBrush)
    BorderThickness = property(get_BorderThickness, put_BorderThickness)
    CornerRadius = property(get_CornerRadius, put_CornerRadius)
    Orientation = property(get_Orientation, put_Orientation)
    Padding = property(get_Padding, put_Padding)
    Spacing = property(get_Spacing, put_Spacing)
class IStackPanelFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IStackPanelFactory'
    _iid_ = Guid('{64c1d388-47a2-5a74-a75b-559d151ee5ac}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.StackPanel: ...
class IStackPanelStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IStackPanelStatics'
    _iid_ = Guid('{10bb04e3-eb01-5ea8-9f96-69508479def9}')
    @winrt_commethod(6)
    def get_AreScrollSnapPointsRegularProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_OrientationProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_BackgroundSizingProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_BorderBrushProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_BorderThicknessProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_CornerRadiusProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_PaddingProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_SpacingProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    AreScrollSnapPointsRegularProperty = property(get_AreScrollSnapPointsRegularProperty, None)
    BackgroundSizingProperty = property(get_BackgroundSizingProperty, None)
    BorderBrushProperty = property(get_BorderBrushProperty, None)
    BorderThicknessProperty = property(get_BorderThicknessProperty, None)
    CornerRadiusProperty = property(get_CornerRadiusProperty, None)
    OrientationProperty = property(get_OrientationProperty, None)
    PaddingProperty = property(get_PaddingProperty, None)
    SpacingProperty = property(get_SpacingProperty, None)
class IStyleSelector(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IStyleSelector'
    _iid_ = Guid('{7f9cf759-785b-5ef9-9ea7-1555673a475a}')
    @winrt_commethod(6)
    def SelectStyle(self, item: IInspectable, container: win32more.Microsoft.UI.Xaml.DependencyObject) -> win32more.Microsoft.UI.Xaml.Style: ...
class IStyleSelectorFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IStyleSelectorFactory'
    _iid_ = Guid('{2a033206-a4fb-5f11-8c2d-61e1df78fbc3}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.StyleSelector: ...
class IStyleSelectorOverrides(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IStyleSelectorOverrides'
    _iid_ = Guid('{26015d75-ef00-5c78-8e58-163da10f694f}')
    @winrt_commethod(6)
    def SelectStyleCore(self, item: IInspectable, container: win32more.Microsoft.UI.Xaml.DependencyObject) -> win32more.Microsoft.UI.Xaml.Style: ...
class ISwapChainBackgroundPanel(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ISwapChainBackgroundPanel'
    _iid_ = Guid('{095a213f-ffea-55ff-b875-e698254ba6df}')
class ISwapChainBackgroundPanelFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ISwapChainBackgroundPanelFactory'
    _iid_ = Guid('{83abaa33-6d13-5b13-8e92-ea95579b6ff3}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.SwapChainBackgroundPanel: ...
class ISwapChainPanel(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ISwapChainPanel'
    _iid_ = Guid('{08844f85-aa1b-540d-bef2-b2bb7b257f8c}')
    @winrt_commethod(6)
    def get_CompositionScaleX(self) -> Single: ...
    @winrt_commethod(7)
    def get_CompositionScaleY(self) -> Single: ...
    @winrt_commethod(8)
    def add_CompositionScaleChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.SwapChainPanel, IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(9)
    def remove_CompositionScaleChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(10)
    def CreateCoreIndependentInputSource(self, deviceKinds: win32more.Microsoft.UI.Input.InputPointerSourceDeviceKinds) -> win32more.Microsoft.UI.Input.InputPointerSource: ...
    CompositionScaleX = property(get_CompositionScaleX, None)
    CompositionScaleY = property(get_CompositionScaleY, None)
    CompositionScaleChanged = event(add_CompositionScaleChanged, remove_CompositionScaleChanged)
class ISwapChainPanelFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ISwapChainPanelFactory'
    _iid_ = Guid('{38d00b69-5759-5f37-9e1c-3ae0d4288b26}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.SwapChainPanel: ...
class ISwapChainPanelStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ISwapChainPanelStatics'
    _iid_ = Guid('{d83b0621-aaca-534b-afde-5370167176b5}')
    @winrt_commethod(6)
    def get_CompositionScaleXProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_CompositionScaleYProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    CompositionScaleXProperty = property(get_CompositionScaleXProperty, None)
    CompositionScaleYProperty = property(get_CompositionScaleYProperty, None)
class ISwipeControl(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ISwipeControl'
    _iid_ = Guid('{337800fe-f51d-5f6b-9d35-e7f5de10a97c}')
    @winrt_commethod(6)
    def get_LeftItems(self) -> win32more.Microsoft.UI.Xaml.Controls.SwipeItems: ...
    @winrt_commethod(7)
    def put_LeftItems(self, value: win32more.Microsoft.UI.Xaml.Controls.SwipeItems) -> Void: ...
    @winrt_commethod(8)
    def get_RightItems(self) -> win32more.Microsoft.UI.Xaml.Controls.SwipeItems: ...
    @winrt_commethod(9)
    def put_RightItems(self, value: win32more.Microsoft.UI.Xaml.Controls.SwipeItems) -> Void: ...
    @winrt_commethod(10)
    def get_TopItems(self) -> win32more.Microsoft.UI.Xaml.Controls.SwipeItems: ...
    @winrt_commethod(11)
    def put_TopItems(self, value: win32more.Microsoft.UI.Xaml.Controls.SwipeItems) -> Void: ...
    @winrt_commethod(12)
    def get_BottomItems(self) -> win32more.Microsoft.UI.Xaml.Controls.SwipeItems: ...
    @winrt_commethod(13)
    def put_BottomItems(self, value: win32more.Microsoft.UI.Xaml.Controls.SwipeItems) -> Void: ...
    @winrt_commethod(14)
    def Close(self) -> Void: ...
    BottomItems = property(get_BottomItems, put_BottomItems)
    LeftItems = property(get_LeftItems, put_LeftItems)
    RightItems = property(get_RightItems, put_RightItems)
    TopItems = property(get_TopItems, put_TopItems)
class ISwipeControlFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ISwipeControlFactory'
    _iid_ = Guid('{6e9213f4-30c1-56ca-9905-46aa1a83dfc1}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.SwipeControl: ...
class ISwipeControlStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ISwipeControlStatics'
    _iid_ = Guid('{fb216c88-c1b1-56ac-a5dd-67064d1e47bc}')
    @winrt_commethod(6)
    def get_LeftItemsProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_RightItemsProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_TopItemsProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_BottomItemsProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    BottomItemsProperty = property(get_BottomItemsProperty, None)
    LeftItemsProperty = property(get_LeftItemsProperty, None)
    RightItemsProperty = property(get_RightItemsProperty, None)
    TopItemsProperty = property(get_TopItemsProperty, None)
class ISwipeItem(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ISwipeItem'
    _iid_ = Guid('{5e8d4950-b826-510a-b309-77afcdc65b1f}')
    @winrt_commethod(6)
    def get_Text(self) -> hstr: ...
    @winrt_commethod(7)
    def put_Text(self, value: hstr) -> Void: ...
    @winrt_commethod(8)
    def get_IconSource(self) -> win32more.Microsoft.UI.Xaml.Controls.IconSource: ...
    @winrt_commethod(9)
    def put_IconSource(self, value: win32more.Microsoft.UI.Xaml.Controls.IconSource) -> Void: ...
    @winrt_commethod(10)
    def get_Background(self) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_commethod(11)
    def put_Background(self, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(12)
    def get_Foreground(self) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_commethod(13)
    def put_Foreground(self, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(14)
    def get_Command(self) -> win32more.Microsoft.UI.Xaml.Input.ICommand: ...
    @winrt_commethod(15)
    def put_Command(self, value: win32more.Microsoft.UI.Xaml.Input.ICommand) -> Void: ...
    @winrt_commethod(16)
    def get_CommandParameter(self) -> IInspectable: ...
    @winrt_commethod(17)
    def put_CommandParameter(self, value: IInspectable) -> Void: ...
    @winrt_commethod(18)
    def get_BehaviorOnInvoked(self) -> win32more.Microsoft.UI.Xaml.Controls.SwipeBehaviorOnInvoked: ...
    @winrt_commethod(19)
    def put_BehaviorOnInvoked(self, value: win32more.Microsoft.UI.Xaml.Controls.SwipeBehaviorOnInvoked) -> Void: ...
    @winrt_commethod(20)
    def add_Invoked(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.SwipeItem, win32more.Microsoft.UI.Xaml.Controls.SwipeItemInvokedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(21)
    def remove_Invoked(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    Background = property(get_Background, put_Background)
    BehaviorOnInvoked = property(get_BehaviorOnInvoked, put_BehaviorOnInvoked)
    Command = property(get_Command, put_Command)
    CommandParameter = property(get_CommandParameter, put_CommandParameter)
    Foreground = property(get_Foreground, put_Foreground)
    IconSource = property(get_IconSource, put_IconSource)
    Text = property(get_Text, put_Text)
    Invoked = event(add_Invoked, remove_Invoked)
class ISwipeItemFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ISwipeItemFactory'
    _iid_ = Guid('{011513e1-1adc-5a69-a74f-623fcc18a51c}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.SwipeItem: ...
class ISwipeItemInvokedEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ISwipeItemInvokedEventArgs'
    _iid_ = Guid('{7bf51c95-53a2-5a0d-bb32-2b4b1f7d2f20}')
    @winrt_commethod(6)
    def get_SwipeControl(self) -> win32more.Microsoft.UI.Xaml.Controls.SwipeControl: ...
    SwipeControl = property(get_SwipeControl, None)
class ISwipeItemStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ISwipeItemStatics'
    _iid_ = Guid('{7898cf24-7a54-586a-82d5-bbd54e596510}')
    @winrt_commethod(6)
    def get_IconSourceProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_TextProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_BackgroundProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_ForegroundProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_CommandProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_CommandParameterProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_BehaviorOnInvokedProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    BackgroundProperty = property(get_BackgroundProperty, None)
    BehaviorOnInvokedProperty = property(get_BehaviorOnInvokedProperty, None)
    CommandParameterProperty = property(get_CommandParameterProperty, None)
    CommandProperty = property(get_CommandProperty, None)
    ForegroundProperty = property(get_ForegroundProperty, None)
    IconSourceProperty = property(get_IconSourceProperty, None)
    TextProperty = property(get_TextProperty, None)
class ISwipeItems(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ISwipeItems'
    _iid_ = Guid('{40d3022b-c82b-5565-a4e4-ad9d7a66b1a9}')
    @winrt_commethod(6)
    def get_Mode(self) -> win32more.Microsoft.UI.Xaml.Controls.SwipeMode: ...
    @winrt_commethod(7)
    def put_Mode(self, value: win32more.Microsoft.UI.Xaml.Controls.SwipeMode) -> Void: ...
    Mode = property(get_Mode, put_Mode)
class ISwipeItemsFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ISwipeItemsFactory'
    _iid_ = Guid('{9a5d7d77-39bd-5b81-ab4e-f44aca6ede3f}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.SwipeItems: ...
class ISwipeItemsStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ISwipeItemsStatics'
    _iid_ = Guid('{db32c3b0-a93f-5797-a18d-d946b0615906}')
    @winrt_commethod(6)
    def get_ModeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    ModeProperty = property(get_ModeProperty, None)
class ISymbolIcon(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ISymbolIcon'
    _iid_ = Guid('{a4322906-0dbe-5eb7-8b64-3e832246eb7f}')
    @winrt_commethod(6)
    def get_Symbol(self) -> win32more.Microsoft.UI.Xaml.Controls.Symbol: ...
    @winrt_commethod(7)
    def put_Symbol(self, value: win32more.Microsoft.UI.Xaml.Controls.Symbol) -> Void: ...
    Symbol = property(get_Symbol, put_Symbol)
class ISymbolIconFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ISymbolIconFactory'
    _iid_ = Guid('{d4430447-567c-5aad-996a-a547774e2c3c}')
    @winrt_commethod(6)
    def CreateInstanceWithSymbol(self, symbol: win32more.Microsoft.UI.Xaml.Controls.Symbol) -> win32more.Microsoft.UI.Xaml.Controls.SymbolIcon: ...
class ISymbolIconSource(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ISymbolIconSource'
    _iid_ = Guid('{45120d6b-e868-59f2-a30a-b1915ce374bd}')
    @winrt_commethod(6)
    def get_Symbol(self) -> win32more.Microsoft.UI.Xaml.Controls.Symbol: ...
    @winrt_commethod(7)
    def put_Symbol(self, value: win32more.Microsoft.UI.Xaml.Controls.Symbol) -> Void: ...
    Symbol = property(get_Symbol, put_Symbol)
class ISymbolIconSourceFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ISymbolIconSourceFactory'
    _iid_ = Guid('{afbf55fa-ff79-552a-a3a1-48e2ef17152a}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.SymbolIconSource: ...
class ISymbolIconSourceStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ISymbolIconSourceStatics'
    _iid_ = Guid('{fdb6b1c7-33d9-56d0-98e5-8776aa1bb79a}')
    @winrt_commethod(6)
    def get_SymbolProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    SymbolProperty = property(get_SymbolProperty, None)
class ISymbolIconStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ISymbolIconStatics'
    _iid_ = Guid('{ccaa0c34-31f2-50f1-b328-be6edc291aaa}')
    @winrt_commethod(6)
    def get_SymbolProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    SymbolProperty = property(get_SymbolProperty, None)
class ITabView(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITabView'
    _iid_ = Guid('{07b509e1-1d38-551b-95f4-4732b049f6a6}')
    @winrt_commethod(6)
    def get_TabWidthMode(self) -> win32more.Microsoft.UI.Xaml.Controls.TabViewWidthMode: ...
    @winrt_commethod(7)
    def put_TabWidthMode(self, value: win32more.Microsoft.UI.Xaml.Controls.TabViewWidthMode) -> Void: ...
    @winrt_commethod(8)
    def get_CloseButtonOverlayMode(self) -> win32more.Microsoft.UI.Xaml.Controls.TabViewCloseButtonOverlayMode: ...
    @winrt_commethod(9)
    def put_CloseButtonOverlayMode(self, value: win32more.Microsoft.UI.Xaml.Controls.TabViewCloseButtonOverlayMode) -> Void: ...
    @winrt_commethod(10)
    def get_TabStripHeader(self) -> IInspectable: ...
    @winrt_commethod(11)
    def put_TabStripHeader(self, value: IInspectable) -> Void: ...
    @winrt_commethod(12)
    def get_TabStripHeaderTemplate(self) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_commethod(13)
    def put_TabStripHeaderTemplate(self, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_commethod(14)
    def get_TabStripFooter(self) -> IInspectable: ...
    @winrt_commethod(15)
    def put_TabStripFooter(self, value: IInspectable) -> Void: ...
    @winrt_commethod(16)
    def get_TabStripFooterTemplate(self) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_commethod(17)
    def put_TabStripFooterTemplate(self, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_commethod(18)
    def get_IsAddTabButtonVisible(self) -> Boolean: ...
    @winrt_commethod(19)
    def put_IsAddTabButtonVisible(self, value: Boolean) -> Void: ...
    @winrt_commethod(20)
    def get_AddTabButtonCommand(self) -> win32more.Microsoft.UI.Xaml.Input.ICommand: ...
    @winrt_commethod(21)
    def put_AddTabButtonCommand(self, value: win32more.Microsoft.UI.Xaml.Input.ICommand) -> Void: ...
    @winrt_commethod(22)
    def get_AddTabButtonCommandParameter(self) -> IInspectable: ...
    @winrt_commethod(23)
    def put_AddTabButtonCommandParameter(self, value: IInspectable) -> Void: ...
    @winrt_commethod(24)
    def add_TabCloseRequested(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.TabView, win32more.Microsoft.UI.Xaml.Controls.TabViewTabCloseRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(25)
    def remove_TabCloseRequested(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(26)
    def add_TabDroppedOutside(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.TabView, win32more.Microsoft.UI.Xaml.Controls.TabViewTabDroppedOutsideEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(27)
    def remove_TabDroppedOutside(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(28)
    def add_AddTabButtonClick(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.TabView, IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(29)
    def remove_AddTabButtonClick(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(30)
    def add_TabItemsChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.TabView, win32more.Windows.Foundation.Collections.IVectorChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(31)
    def remove_TabItemsChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(32)
    def get_TabItemsSource(self) -> IInspectable: ...
    @winrt_commethod(33)
    def put_TabItemsSource(self, value: IInspectable) -> Void: ...
    @winrt_commethod(34)
    def get_TabItems(self) -> win32more.Windows.Foundation.Collections.IVector[IInspectable]: ...
    @winrt_commethod(35)
    def get_TabItemTemplate(self) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_commethod(36)
    def put_TabItemTemplate(self, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_commethod(37)
    def get_TabItemTemplateSelector(self) -> win32more.Microsoft.UI.Xaml.Controls.DataTemplateSelector: ...
    @winrt_commethod(38)
    def put_TabItemTemplateSelector(self, value: win32more.Microsoft.UI.Xaml.Controls.DataTemplateSelector) -> Void: ...
    @winrt_commethod(39)
    def get_CanDragTabs(self) -> Boolean: ...
    @winrt_commethod(40)
    def put_CanDragTabs(self, value: Boolean) -> Void: ...
    @winrt_commethod(41)
    def get_CanReorderTabs(self) -> Boolean: ...
    @winrt_commethod(42)
    def put_CanReorderTabs(self, value: Boolean) -> Void: ...
    @winrt_commethod(43)
    def get_AllowDropTabs(self) -> Boolean: ...
    @winrt_commethod(44)
    def put_AllowDropTabs(self, value: Boolean) -> Void: ...
    @winrt_commethod(45)
    def get_SelectedIndex(self) -> Int32: ...
    @winrt_commethod(46)
    def put_SelectedIndex(self, value: Int32) -> Void: ...
    @winrt_commethod(47)
    def get_SelectedItem(self) -> IInspectable: ...
    @winrt_commethod(48)
    def put_SelectedItem(self, value: IInspectable) -> Void: ...
    @winrt_commethod(49)
    def ContainerFromItem(self, item: IInspectable) -> win32more.Microsoft.UI.Xaml.DependencyObject: ...
    @winrt_commethod(50)
    def ContainerFromIndex(self, index: Int32) -> win32more.Microsoft.UI.Xaml.DependencyObject: ...
    @winrt_commethod(51)
    def add_SelectionChanged(self, handler: win32more.Microsoft.UI.Xaml.Controls.SelectionChangedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(52)
    def remove_SelectionChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(53)
    def add_TabDragStarting(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.TabView, win32more.Microsoft.UI.Xaml.Controls.TabViewTabDragStartingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(54)
    def remove_TabDragStarting(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(55)
    def add_TabDragCompleted(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.TabView, win32more.Microsoft.UI.Xaml.Controls.TabViewTabDragCompletedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(56)
    def remove_TabDragCompleted(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(57)
    def add_TabStripDragOver(self, handler: win32more.Microsoft.UI.Xaml.DragEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(58)
    def remove_TabStripDragOver(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(59)
    def add_TabStripDrop(self, handler: win32more.Microsoft.UI.Xaml.DragEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(60)
    def remove_TabStripDrop(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    AddTabButtonCommand = property(get_AddTabButtonCommand, put_AddTabButtonCommand)
    AddTabButtonCommandParameter = property(get_AddTabButtonCommandParameter, put_AddTabButtonCommandParameter)
    AllowDropTabs = property(get_AllowDropTabs, put_AllowDropTabs)
    CanDragTabs = property(get_CanDragTabs, put_CanDragTabs)
    CanReorderTabs = property(get_CanReorderTabs, put_CanReorderTabs)
    CloseButtonOverlayMode = property(get_CloseButtonOverlayMode, put_CloseButtonOverlayMode)
    IsAddTabButtonVisible = property(get_IsAddTabButtonVisible, put_IsAddTabButtonVisible)
    SelectedIndex = property(get_SelectedIndex, put_SelectedIndex)
    SelectedItem = property(get_SelectedItem, put_SelectedItem)
    TabItemTemplate = property(get_TabItemTemplate, put_TabItemTemplate)
    TabItemTemplateSelector = property(get_TabItemTemplateSelector, put_TabItemTemplateSelector)
    TabItems = property(get_TabItems, None)
    TabItemsSource = property(get_TabItemsSource, put_TabItemsSource)
    TabStripFooter = property(get_TabStripFooter, put_TabStripFooter)
    TabStripFooterTemplate = property(get_TabStripFooterTemplate, put_TabStripFooterTemplate)
    TabStripHeader = property(get_TabStripHeader, put_TabStripHeader)
    TabStripHeaderTemplate = property(get_TabStripHeaderTemplate, put_TabStripHeaderTemplate)
    TabWidthMode = property(get_TabWidthMode, put_TabWidthMode)
    AddTabButtonClick = event(add_AddTabButtonClick, remove_AddTabButtonClick)
    SelectionChanged = event(add_SelectionChanged, remove_SelectionChanged)
    TabCloseRequested = event(add_TabCloseRequested, remove_TabCloseRequested)
    TabDragCompleted = event(add_TabDragCompleted, remove_TabDragCompleted)
    TabDragStarting = event(add_TabDragStarting, remove_TabDragStarting)
    TabDroppedOutside = event(add_TabDroppedOutside, remove_TabDroppedOutside)
    TabItemsChanged = event(add_TabItemsChanged, remove_TabItemsChanged)
    TabStripDragOver = event(add_TabStripDragOver, remove_TabStripDragOver)
    TabStripDrop = event(add_TabStripDrop, remove_TabStripDrop)
class ITabViewFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITabViewFactory'
    _iid_ = Guid('{e7e83685-eedf-5106-9429-884435ab166b}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.TabView: ...
class ITabViewItem(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITabViewItem'
    _iid_ = Guid('{64980afa-97af-5190-90b3-4ba277b1113d}')
    @winrt_commethod(6)
    def get_Header(self) -> IInspectable: ...
    @winrt_commethod(7)
    def put_Header(self, value: IInspectable) -> Void: ...
    @winrt_commethod(8)
    def get_HeaderTemplate(self) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_commethod(9)
    def put_HeaderTemplate(self, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_commethod(10)
    def get_IconSource(self) -> win32more.Microsoft.UI.Xaml.Controls.IconSource: ...
    @winrt_commethod(11)
    def put_IconSource(self, value: win32more.Microsoft.UI.Xaml.Controls.IconSource) -> Void: ...
    @winrt_commethod(12)
    def get_IsClosable(self) -> Boolean: ...
    @winrt_commethod(13)
    def put_IsClosable(self, value: Boolean) -> Void: ...
    @winrt_commethod(14)
    def get_TabViewTemplateSettings(self) -> win32more.Microsoft.UI.Xaml.Controls.TabViewItemTemplateSettings: ...
    @winrt_commethod(15)
    def add_CloseRequested(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.TabViewItem, win32more.Microsoft.UI.Xaml.Controls.TabViewTabCloseRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(16)
    def remove_CloseRequested(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    Header = property(get_Header, put_Header)
    HeaderTemplate = property(get_HeaderTemplate, put_HeaderTemplate)
    IconSource = property(get_IconSource, put_IconSource)
    IsClosable = property(get_IsClosable, put_IsClosable)
    TabViewTemplateSettings = property(get_TabViewTemplateSettings, None)
    CloseRequested = event(add_CloseRequested, remove_CloseRequested)
class ITabViewItemFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITabViewItemFactory'
    _iid_ = Guid('{b64c2423-7e56-5d41-8a84-1ee28f9826a4}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.TabViewItem: ...
class ITabViewItemStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITabViewItemStatics'
    _iid_ = Guid('{4cfc7eab-2eff-5457-8251-c19d374ab34d}')
    @winrt_commethod(6)
    def get_HeaderProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_HeaderTemplateProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_IconSourceProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_IsClosableProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_TabViewTemplateSettingsProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    HeaderProperty = property(get_HeaderProperty, None)
    HeaderTemplateProperty = property(get_HeaderTemplateProperty, None)
    IconSourceProperty = property(get_IconSourceProperty, None)
    IsClosableProperty = property(get_IsClosableProperty, None)
    TabViewTemplateSettingsProperty = property(get_TabViewTemplateSettingsProperty, None)
class ITabViewItemTemplateSettings(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITabViewItemTemplateSettings'
    _iid_ = Guid('{cc5c99ec-c9d1-55f5-bc81-7612ff4e2b77}')
    @winrt_commethod(6)
    def get_IconElement(self) -> win32more.Microsoft.UI.Xaml.Controls.IconElement: ...
    @winrt_commethod(7)
    def put_IconElement(self, value: win32more.Microsoft.UI.Xaml.Controls.IconElement) -> Void: ...
    IconElement = property(get_IconElement, put_IconElement)
class ITabViewItemTemplateSettings2(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITabViewItemTemplateSettings2'
    _iid_ = Guid('{9e2780d3-7056-5aaf-9a7a-404a2c094ced}')
    @winrt_commethod(6)
    def get_TabGeometry(self) -> win32more.Microsoft.UI.Xaml.Media.Geometry: ...
    @winrt_commethod(7)
    def put_TabGeometry(self, value: win32more.Microsoft.UI.Xaml.Media.Geometry) -> Void: ...
    TabGeometry = property(get_TabGeometry, put_TabGeometry)
class ITabViewItemTemplateSettingsFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITabViewItemTemplateSettingsFactory'
    _iid_ = Guid('{cba3e467-4c98-5885-ba24-6fa699cc8edd}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.TabViewItemTemplateSettings: ...
class ITabViewItemTemplateSettingsStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITabViewItemTemplateSettingsStatics'
    _iid_ = Guid('{eb62dd88-fc12-5338-8e88-788be72d07d6}')
    @winrt_commethod(6)
    def get_IconElementProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    IconElementProperty = property(get_IconElementProperty, None)
class ITabViewItemTemplateSettingsStatics2(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITabViewItemTemplateSettingsStatics2'
    _iid_ = Guid('{d31ab42b-3842-5e4d-8845-6232eea8ee1d}')
    @winrt_commethod(6)
    def get_TabGeometryProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    TabGeometryProperty = property(get_TabGeometryProperty, None)
class ITabViewStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITabViewStatics'
    _iid_ = Guid('{f4326c08-1b94-53d7-934f-e6ae0d3d18ab}')
    @winrt_commethod(6)
    def get_TabWidthModeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_TabStripHeaderProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_TabStripHeaderTemplateProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_TabStripFooterProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_TabStripFooterTemplateProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_IsAddTabButtonVisibleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_AddTabButtonCommandProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_AddTabButtonCommandParameterProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(14)
    def get_TabItemsSourceProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(15)
    def get_TabItemsProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(16)
    def get_TabItemTemplateProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(17)
    def get_TabItemTemplateSelectorProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(18)
    def get_CloseButtonOverlayModeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(19)
    def get_CanDragTabsProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(20)
    def get_CanReorderTabsProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(21)
    def get_AllowDropTabsProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(22)
    def get_SelectedIndexProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(23)
    def get_SelectedItemProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    AddTabButtonCommandParameterProperty = property(get_AddTabButtonCommandParameterProperty, None)
    AddTabButtonCommandProperty = property(get_AddTabButtonCommandProperty, None)
    AllowDropTabsProperty = property(get_AllowDropTabsProperty, None)
    CanDragTabsProperty = property(get_CanDragTabsProperty, None)
    CanReorderTabsProperty = property(get_CanReorderTabsProperty, None)
    CloseButtonOverlayModeProperty = property(get_CloseButtonOverlayModeProperty, None)
    IsAddTabButtonVisibleProperty = property(get_IsAddTabButtonVisibleProperty, None)
    SelectedIndexProperty = property(get_SelectedIndexProperty, None)
    SelectedItemProperty = property(get_SelectedItemProperty, None)
    TabItemTemplateProperty = property(get_TabItemTemplateProperty, None)
    TabItemTemplateSelectorProperty = property(get_TabItemTemplateSelectorProperty, None)
    TabItemsProperty = property(get_TabItemsProperty, None)
    TabItemsSourceProperty = property(get_TabItemsSourceProperty, None)
    TabStripFooterProperty = property(get_TabStripFooterProperty, None)
    TabStripFooterTemplateProperty = property(get_TabStripFooterTemplateProperty, None)
    TabStripHeaderProperty = property(get_TabStripHeaderProperty, None)
    TabStripHeaderTemplateProperty = property(get_TabStripHeaderTemplateProperty, None)
    TabWidthModeProperty = property(get_TabWidthModeProperty, None)
class ITabViewTabCloseRequestedEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITabViewTabCloseRequestedEventArgs'
    _iid_ = Guid('{d56ab9b2-e264-5c7e-a1cb-e41a16a6c6c6}')
    @winrt_commethod(6)
    def get_Item(self) -> IInspectable: ...
    @winrt_commethod(7)
    def get_Tab(self) -> win32more.Microsoft.UI.Xaml.Controls.TabViewItem: ...
    Item = property(get_Item, None)
    Tab = property(get_Tab, None)
class ITabViewTabDragCompletedEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITabViewTabDragCompletedEventArgs'
    _iid_ = Guid('{791fc623-c8f6-5102-81bd-1869cde82284}')
    @winrt_commethod(6)
    def get_DropResult(self) -> win32more.Windows.ApplicationModel.DataTransfer.DataPackageOperation: ...
    @winrt_commethod(7)
    def get_Item(self) -> IInspectable: ...
    @winrt_commethod(8)
    def get_Tab(self) -> win32more.Microsoft.UI.Xaml.Controls.TabViewItem: ...
    DropResult = property(get_DropResult, None)
    Item = property(get_Item, None)
    Tab = property(get_Tab, None)
class ITabViewTabDragStartingEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITabViewTabDragStartingEventArgs'
    _iid_ = Guid('{97682812-1a7b-53fd-8b4e-c2f70d2ad250}')
    @winrt_commethod(6)
    def get_Cancel(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_Cancel(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def get_Data(self) -> win32more.Windows.ApplicationModel.DataTransfer.DataPackage: ...
    @winrt_commethod(9)
    def get_Item(self) -> IInspectable: ...
    @winrt_commethod(10)
    def get_Tab(self) -> win32more.Microsoft.UI.Xaml.Controls.TabViewItem: ...
    Cancel = property(get_Cancel, put_Cancel)
    Data = property(get_Data, None)
    Item = property(get_Item, None)
    Tab = property(get_Tab, None)
class ITabViewTabDroppedOutsideEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITabViewTabDroppedOutsideEventArgs'
    _iid_ = Guid('{1f1f4d5d-0fb1-51ab-b66f-f7a322bf2d13}')
    @winrt_commethod(6)
    def get_Item(self) -> IInspectable: ...
    @winrt_commethod(7)
    def get_Tab(self) -> win32more.Microsoft.UI.Xaml.Controls.TabViewItem: ...
    Item = property(get_Item, None)
    Tab = property(get_Tab, None)
class ITeachingTip(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITeachingTip'
    _iid_ = Guid('{daebd5f7-3b47-5b12-b804-f4e1442b2113}')
    @winrt_commethod(6)
    def get_Title(self) -> hstr: ...
    @winrt_commethod(7)
    def put_Title(self, value: hstr) -> Void: ...
    @winrt_commethod(8)
    def get_Subtitle(self) -> hstr: ...
    @winrt_commethod(9)
    def put_Subtitle(self, value: hstr) -> Void: ...
    @winrt_commethod(10)
    def get_IsOpen(self) -> Boolean: ...
    @winrt_commethod(11)
    def put_IsOpen(self, value: Boolean) -> Void: ...
    @winrt_commethod(12)
    def get_Target(self) -> win32more.Microsoft.UI.Xaml.FrameworkElement: ...
    @winrt_commethod(13)
    def put_Target(self, value: win32more.Microsoft.UI.Xaml.FrameworkElement) -> Void: ...
    @winrt_commethod(14)
    def get_TailVisibility(self) -> win32more.Microsoft.UI.Xaml.Controls.TeachingTipTailVisibility: ...
    @winrt_commethod(15)
    def put_TailVisibility(self, value: win32more.Microsoft.UI.Xaml.Controls.TeachingTipTailVisibility) -> Void: ...
    @winrt_commethod(16)
    def get_ActionButtonContent(self) -> IInspectable: ...
    @winrt_commethod(17)
    def put_ActionButtonContent(self, value: IInspectable) -> Void: ...
    @winrt_commethod(18)
    def get_ActionButtonStyle(self) -> win32more.Microsoft.UI.Xaml.Style: ...
    @winrt_commethod(19)
    def put_ActionButtonStyle(self, value: win32more.Microsoft.UI.Xaml.Style) -> Void: ...
    @winrt_commethod(20)
    def get_ActionButtonCommand(self) -> win32more.Microsoft.UI.Xaml.Input.ICommand: ...
    @winrt_commethod(21)
    def put_ActionButtonCommand(self, value: win32more.Microsoft.UI.Xaml.Input.ICommand) -> Void: ...
    @winrt_commethod(22)
    def get_ActionButtonCommandParameter(self) -> IInspectable: ...
    @winrt_commethod(23)
    def put_ActionButtonCommandParameter(self, value: IInspectable) -> Void: ...
    @winrt_commethod(24)
    def get_CloseButtonContent(self) -> IInspectable: ...
    @winrt_commethod(25)
    def put_CloseButtonContent(self, value: IInspectable) -> Void: ...
    @winrt_commethod(26)
    def get_CloseButtonStyle(self) -> win32more.Microsoft.UI.Xaml.Style: ...
    @winrt_commethod(27)
    def put_CloseButtonStyle(self, value: win32more.Microsoft.UI.Xaml.Style) -> Void: ...
    @winrt_commethod(28)
    def get_CloseButtonCommand(self) -> win32more.Microsoft.UI.Xaml.Input.ICommand: ...
    @winrt_commethod(29)
    def put_CloseButtonCommand(self, value: win32more.Microsoft.UI.Xaml.Input.ICommand) -> Void: ...
    @winrt_commethod(30)
    def get_CloseButtonCommandParameter(self) -> IInspectable: ...
    @winrt_commethod(31)
    def put_CloseButtonCommandParameter(self, value: IInspectable) -> Void: ...
    @winrt_commethod(32)
    def get_PlacementMargin(self) -> win32more.Microsoft.UI.Xaml.Thickness: ...
    @winrt_commethod(33)
    def put_PlacementMargin(self, value: win32more.Microsoft.UI.Xaml.Thickness) -> Void: ...
    @winrt_commethod(34)
    def get_ShouldConstrainToRootBounds(self) -> Boolean: ...
    @winrt_commethod(35)
    def put_ShouldConstrainToRootBounds(self, value: Boolean) -> Void: ...
    @winrt_commethod(36)
    def get_IsLightDismissEnabled(self) -> Boolean: ...
    @winrt_commethod(37)
    def put_IsLightDismissEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(38)
    def get_PreferredPlacement(self) -> win32more.Microsoft.UI.Xaml.Controls.TeachingTipPlacementMode: ...
    @winrt_commethod(39)
    def put_PreferredPlacement(self, value: win32more.Microsoft.UI.Xaml.Controls.TeachingTipPlacementMode) -> Void: ...
    @winrt_commethod(40)
    def get_HeroContentPlacement(self) -> win32more.Microsoft.UI.Xaml.Controls.TeachingTipHeroContentPlacementMode: ...
    @winrt_commethod(41)
    def put_HeroContentPlacement(self, value: win32more.Microsoft.UI.Xaml.Controls.TeachingTipHeroContentPlacementMode) -> Void: ...
    @winrt_commethod(42)
    def get_HeroContent(self) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_commethod(43)
    def put_HeroContent(self, value: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    @winrt_commethod(44)
    def get_IconSource(self) -> win32more.Microsoft.UI.Xaml.Controls.IconSource: ...
    @winrt_commethod(45)
    def put_IconSource(self, value: win32more.Microsoft.UI.Xaml.Controls.IconSource) -> Void: ...
    @winrt_commethod(46)
    def get_TemplateSettings(self) -> win32more.Microsoft.UI.Xaml.Controls.TeachingTipTemplateSettings: ...
    @winrt_commethod(47)
    def add_ActionButtonClick(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.TeachingTip, IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(48)
    def remove_ActionButtonClick(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(49)
    def add_CloseButtonClick(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.TeachingTip, IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(50)
    def remove_CloseButtonClick(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(51)
    def add_Closing(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.TeachingTip, win32more.Microsoft.UI.Xaml.Controls.TeachingTipClosingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(52)
    def remove_Closing(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(53)
    def add_Closed(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.TeachingTip, win32more.Microsoft.UI.Xaml.Controls.TeachingTipClosedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(54)
    def remove_Closed(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    ActionButtonCommand = property(get_ActionButtonCommand, put_ActionButtonCommand)
    ActionButtonCommandParameter = property(get_ActionButtonCommandParameter, put_ActionButtonCommandParameter)
    ActionButtonContent = property(get_ActionButtonContent, put_ActionButtonContent)
    ActionButtonStyle = property(get_ActionButtonStyle, put_ActionButtonStyle)
    CloseButtonCommand = property(get_CloseButtonCommand, put_CloseButtonCommand)
    CloseButtonCommandParameter = property(get_CloseButtonCommandParameter, put_CloseButtonCommandParameter)
    CloseButtonContent = property(get_CloseButtonContent, put_CloseButtonContent)
    CloseButtonStyle = property(get_CloseButtonStyle, put_CloseButtonStyle)
    HeroContent = property(get_HeroContent, put_HeroContent)
    HeroContentPlacement = property(get_HeroContentPlacement, put_HeroContentPlacement)
    IconSource = property(get_IconSource, put_IconSource)
    IsLightDismissEnabled = property(get_IsLightDismissEnabled, put_IsLightDismissEnabled)
    IsOpen = property(get_IsOpen, put_IsOpen)
    PlacementMargin = property(get_PlacementMargin, put_PlacementMargin)
    PreferredPlacement = property(get_PreferredPlacement, put_PreferredPlacement)
    ShouldConstrainToRootBounds = property(get_ShouldConstrainToRootBounds, put_ShouldConstrainToRootBounds)
    Subtitle = property(get_Subtitle, put_Subtitle)
    TailVisibility = property(get_TailVisibility, put_TailVisibility)
    Target = property(get_Target, put_Target)
    TemplateSettings = property(get_TemplateSettings, None)
    Title = property(get_Title, put_Title)
    ActionButtonClick = event(add_ActionButtonClick, remove_ActionButtonClick)
    CloseButtonClick = event(add_CloseButtonClick, remove_CloseButtonClick)
    Closed = event(add_Closed, remove_Closed)
    Closing = event(add_Closing, remove_Closing)
class ITeachingTipClosedEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITeachingTipClosedEventArgs'
    _iid_ = Guid('{2536f506-4038-59db-9e35-a9252fb5adb2}')
    @winrt_commethod(6)
    def get_Reason(self) -> win32more.Microsoft.UI.Xaml.Controls.TeachingTipCloseReason: ...
    Reason = property(get_Reason, None)
class ITeachingTipClosingEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITeachingTipClosingEventArgs'
    _iid_ = Guid('{16f53512-3c55-5636-a856-229d9768d64e}')
    @winrt_commethod(6)
    def get_Reason(self) -> win32more.Microsoft.UI.Xaml.Controls.TeachingTipCloseReason: ...
    @winrt_commethod(7)
    def get_Cancel(self) -> Boolean: ...
    @winrt_commethod(8)
    def put_Cancel(self, value: Boolean) -> Void: ...
    @winrt_commethod(9)
    def GetDeferral(self) -> win32more.Windows.Foundation.Deferral: ...
    Cancel = property(get_Cancel, put_Cancel)
    Reason = property(get_Reason, None)
class ITeachingTipFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITeachingTipFactory'
    _iid_ = Guid('{a3ecd47d-2972-5d19-a62e-ddfbc5e1ad57}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.TeachingTip: ...
class ITeachingTipStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITeachingTipStatics'
    _iid_ = Guid('{7c3ecddb-0b4d-51c2-a27f-89180afd45a8}')
    @winrt_commethod(6)
    def get_IsOpenProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_TargetProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_TailVisibilityProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_TitleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_SubtitleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_ActionButtonContentProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_ActionButtonStyleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_ActionButtonCommandProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(14)
    def get_ActionButtonCommandParameterProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(15)
    def get_CloseButtonContentProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(16)
    def get_CloseButtonStyleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(17)
    def get_CloseButtonCommandProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(18)
    def get_CloseButtonCommandParameterProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(19)
    def get_PlacementMarginProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(20)
    def get_ShouldConstrainToRootBoundsProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(21)
    def get_IsLightDismissEnabledProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(22)
    def get_PreferredPlacementProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(23)
    def get_HeroContentPlacementProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(24)
    def get_HeroContentProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(25)
    def get_IconSourceProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(26)
    def get_TemplateSettingsProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    ActionButtonCommandParameterProperty = property(get_ActionButtonCommandParameterProperty, None)
    ActionButtonCommandProperty = property(get_ActionButtonCommandProperty, None)
    ActionButtonContentProperty = property(get_ActionButtonContentProperty, None)
    ActionButtonStyleProperty = property(get_ActionButtonStyleProperty, None)
    CloseButtonCommandParameterProperty = property(get_CloseButtonCommandParameterProperty, None)
    CloseButtonCommandProperty = property(get_CloseButtonCommandProperty, None)
    CloseButtonContentProperty = property(get_CloseButtonContentProperty, None)
    CloseButtonStyleProperty = property(get_CloseButtonStyleProperty, None)
    HeroContentPlacementProperty = property(get_HeroContentPlacementProperty, None)
    HeroContentProperty = property(get_HeroContentProperty, None)
    IconSourceProperty = property(get_IconSourceProperty, None)
    IsLightDismissEnabledProperty = property(get_IsLightDismissEnabledProperty, None)
    IsOpenProperty = property(get_IsOpenProperty, None)
    PlacementMarginProperty = property(get_PlacementMarginProperty, None)
    PreferredPlacementProperty = property(get_PreferredPlacementProperty, None)
    ShouldConstrainToRootBoundsProperty = property(get_ShouldConstrainToRootBoundsProperty, None)
    SubtitleProperty = property(get_SubtitleProperty, None)
    TailVisibilityProperty = property(get_TailVisibilityProperty, None)
    TargetProperty = property(get_TargetProperty, None)
    TemplateSettingsProperty = property(get_TemplateSettingsProperty, None)
    TitleProperty = property(get_TitleProperty, None)
class ITeachingTipTemplateSettings(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITeachingTipTemplateSettings'
    _iid_ = Guid('{b081e1e9-c1a5-590a-8049-69ea003b6cf7}')
    @winrt_commethod(6)
    def get_TopRightHighlightMargin(self) -> win32more.Microsoft.UI.Xaml.Thickness: ...
    @winrt_commethod(7)
    def put_TopRightHighlightMargin(self, value: win32more.Microsoft.UI.Xaml.Thickness) -> Void: ...
    @winrt_commethod(8)
    def get_TopLeftHighlightMargin(self) -> win32more.Microsoft.UI.Xaml.Thickness: ...
    @winrt_commethod(9)
    def put_TopLeftHighlightMargin(self, value: win32more.Microsoft.UI.Xaml.Thickness) -> Void: ...
    @winrt_commethod(10)
    def get_IconElement(self) -> win32more.Microsoft.UI.Xaml.Controls.IconElement: ...
    @winrt_commethod(11)
    def put_IconElement(self, value: win32more.Microsoft.UI.Xaml.Controls.IconElement) -> Void: ...
    IconElement = property(get_IconElement, put_IconElement)
    TopLeftHighlightMargin = property(get_TopLeftHighlightMargin, put_TopLeftHighlightMargin)
    TopRightHighlightMargin = property(get_TopRightHighlightMargin, put_TopRightHighlightMargin)
class ITeachingTipTemplateSettingsFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITeachingTipTemplateSettingsFactory'
    _iid_ = Guid('{63210545-e195-56cd-bccd-169255e134e3}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.TeachingTipTemplateSettings: ...
class ITeachingTipTemplateSettingsStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITeachingTipTemplateSettingsStatics'
    _iid_ = Guid('{fa9acf9a-9743-51ee-8db9-8abd063edfea}')
    @winrt_commethod(6)
    def get_TopRightHighlightMarginProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_TopLeftHighlightMarginProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_IconElementProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    IconElementProperty = property(get_IconElementProperty, None)
    TopLeftHighlightMarginProperty = property(get_TopLeftHighlightMarginProperty, None)
    TopRightHighlightMarginProperty = property(get_TopRightHighlightMarginProperty, None)
class ITextBlock(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITextBlock'
    _iid_ = Guid('{1ac8d84f-392c-5c7e-83f5-a53e3bf0abb0}')
    @winrt_commethod(6)
    def get_FontSize(self) -> Double: ...
    @winrt_commethod(7)
    def put_FontSize(self, value: Double) -> Void: ...
    @winrt_commethod(8)
    def get_FontFamily(self) -> win32more.Microsoft.UI.Xaml.Media.FontFamily: ...
    @winrt_commethod(9)
    def put_FontFamily(self, value: win32more.Microsoft.UI.Xaml.Media.FontFamily) -> Void: ...
    @winrt_commethod(10)
    def get_FontWeight(self) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_commethod(11)
    def put_FontWeight(self, value: win32more.Windows.UI.Text.FontWeight) -> Void: ...
    @winrt_commethod(12)
    def get_FontStyle(self) -> win32more.Windows.UI.Text.FontStyle: ...
    @winrt_commethod(13)
    def put_FontStyle(self, value: win32more.Windows.UI.Text.FontStyle) -> Void: ...
    @winrt_commethod(14)
    def get_FontStretch(self) -> win32more.Windows.UI.Text.FontStretch: ...
    @winrt_commethod(15)
    def put_FontStretch(self, value: win32more.Windows.UI.Text.FontStretch) -> Void: ...
    @winrt_commethod(16)
    def get_CharacterSpacing(self) -> Int32: ...
    @winrt_commethod(17)
    def put_CharacterSpacing(self, value: Int32) -> Void: ...
    @winrt_commethod(18)
    def get_Foreground(self) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_commethod(19)
    def put_Foreground(self, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(20)
    def get_TextWrapping(self) -> win32more.Microsoft.UI.Xaml.TextWrapping: ...
    @winrt_commethod(21)
    def put_TextWrapping(self, value: win32more.Microsoft.UI.Xaml.TextWrapping) -> Void: ...
    @winrt_commethod(22)
    def get_TextTrimming(self) -> win32more.Microsoft.UI.Xaml.TextTrimming: ...
    @winrt_commethod(23)
    def put_TextTrimming(self, value: win32more.Microsoft.UI.Xaml.TextTrimming) -> Void: ...
    @winrt_commethod(24)
    def get_TextAlignment(self) -> win32more.Microsoft.UI.Xaml.TextAlignment: ...
    @winrt_commethod(25)
    def put_TextAlignment(self, value: win32more.Microsoft.UI.Xaml.TextAlignment) -> Void: ...
    @winrt_commethod(26)
    def get_Text(self) -> hstr: ...
    @winrt_commethod(27)
    def put_Text(self, value: hstr) -> Void: ...
    @winrt_commethod(28)
    def get_Inlines(self) -> win32more.Microsoft.UI.Xaml.Documents.InlineCollection: ...
    @winrt_commethod(29)
    def get_Padding(self) -> win32more.Microsoft.UI.Xaml.Thickness: ...
    @winrt_commethod(30)
    def put_Padding(self, value: win32more.Microsoft.UI.Xaml.Thickness) -> Void: ...
    @winrt_commethod(31)
    def get_LineHeight(self) -> Double: ...
    @winrt_commethod(32)
    def put_LineHeight(self, value: Double) -> Void: ...
    @winrt_commethod(33)
    def get_LineStackingStrategy(self) -> win32more.Microsoft.UI.Xaml.LineStackingStrategy: ...
    @winrt_commethod(34)
    def put_LineStackingStrategy(self, value: win32more.Microsoft.UI.Xaml.LineStackingStrategy) -> Void: ...
    @winrt_commethod(35)
    def get_IsTextSelectionEnabled(self) -> Boolean: ...
    @winrt_commethod(36)
    def put_IsTextSelectionEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(37)
    def get_SelectedText(self) -> hstr: ...
    @winrt_commethod(38)
    def get_ContentStart(self) -> win32more.Microsoft.UI.Xaml.Documents.TextPointer: ...
    @winrt_commethod(39)
    def get_ContentEnd(self) -> win32more.Microsoft.UI.Xaml.Documents.TextPointer: ...
    @winrt_commethod(40)
    def get_SelectionStart(self) -> win32more.Microsoft.UI.Xaml.Documents.TextPointer: ...
    @winrt_commethod(41)
    def get_SelectionEnd(self) -> win32more.Microsoft.UI.Xaml.Documents.TextPointer: ...
    @winrt_commethod(42)
    def get_BaselineOffset(self) -> Double: ...
    @winrt_commethod(43)
    def get_SelectionHighlightColor(self) -> win32more.Microsoft.UI.Xaml.Media.SolidColorBrush: ...
    @winrt_commethod(44)
    def put_SelectionHighlightColor(self, value: win32more.Microsoft.UI.Xaml.Media.SolidColorBrush) -> Void: ...
    @winrt_commethod(45)
    def get_MaxLines(self) -> Int32: ...
    @winrt_commethod(46)
    def put_MaxLines(self, value: Int32) -> Void: ...
    @winrt_commethod(47)
    def get_TextLineBounds(self) -> win32more.Microsoft.UI.Xaml.TextLineBounds: ...
    @winrt_commethod(48)
    def put_TextLineBounds(self, value: win32more.Microsoft.UI.Xaml.TextLineBounds) -> Void: ...
    @winrt_commethod(49)
    def get_OpticalMarginAlignment(self) -> win32more.Microsoft.UI.Xaml.OpticalMarginAlignment: ...
    @winrt_commethod(50)
    def put_OpticalMarginAlignment(self, value: win32more.Microsoft.UI.Xaml.OpticalMarginAlignment) -> Void: ...
    @winrt_commethod(51)
    def get_IsColorFontEnabled(self) -> Boolean: ...
    @winrt_commethod(52)
    def put_IsColorFontEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(53)
    def get_TextReadingOrder(self) -> win32more.Microsoft.UI.Xaml.TextReadingOrder: ...
    @winrt_commethod(54)
    def put_TextReadingOrder(self, value: win32more.Microsoft.UI.Xaml.TextReadingOrder) -> Void: ...
    @winrt_commethod(55)
    def get_IsTextScaleFactorEnabled(self) -> Boolean: ...
    @winrt_commethod(56)
    def put_IsTextScaleFactorEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(57)
    def get_TextDecorations(self) -> win32more.Windows.UI.Text.TextDecorations: ...
    @winrt_commethod(58)
    def put_TextDecorations(self, value: win32more.Windows.UI.Text.TextDecorations) -> Void: ...
    @winrt_commethod(59)
    def get_IsTextTrimmed(self) -> Boolean: ...
    @winrt_commethod(60)
    def get_HorizontalTextAlignment(self) -> win32more.Microsoft.UI.Xaml.TextAlignment: ...
    @winrt_commethod(61)
    def put_HorizontalTextAlignment(self, value: win32more.Microsoft.UI.Xaml.TextAlignment) -> Void: ...
    @winrt_commethod(62)
    def get_TextHighlighters(self) -> win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Documents.TextHighlighter]: ...
    @winrt_commethod(63)
    def get_SelectionFlyout(self) -> win32more.Microsoft.UI.Xaml.Controls.Primitives.FlyoutBase: ...
    @winrt_commethod(64)
    def put_SelectionFlyout(self, value: win32more.Microsoft.UI.Xaml.Controls.Primitives.FlyoutBase) -> Void: ...
    @winrt_commethod(65)
    def add_SelectionChanged(self, handler: win32more.Microsoft.UI.Xaml.RoutedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(66)
    def remove_SelectionChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(67)
    def add_ContextMenuOpening(self, handler: win32more.Microsoft.UI.Xaml.Controls.ContextMenuOpeningEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(68)
    def remove_ContextMenuOpening(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(69)
    def add_IsTextTrimmedChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.TextBlock, win32more.Microsoft.UI.Xaml.Controls.IsTextTrimmedChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(70)
    def remove_IsTextTrimmedChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(71)
    def SelectAll(self) -> Void: ...
    @winrt_commethod(72)
    def Select(self, start: win32more.Microsoft.UI.Xaml.Documents.TextPointer, end: win32more.Microsoft.UI.Xaml.Documents.TextPointer) -> Void: ...
    @winrt_commethod(73)
    def GetAlphaMask(self) -> win32more.Microsoft.UI.Composition.CompositionBrush: ...
    @winrt_commethod(74)
    def CopySelectionToClipboard(self) -> Void: ...
    BaselineOffset = property(get_BaselineOffset, None)
    CharacterSpacing = property(get_CharacterSpacing, put_CharacterSpacing)
    ContentEnd = property(get_ContentEnd, None)
    ContentStart = property(get_ContentStart, None)
    FontFamily = property(get_FontFamily, put_FontFamily)
    FontSize = property(get_FontSize, put_FontSize)
    FontStretch = property(get_FontStretch, put_FontStretch)
    FontStyle = property(get_FontStyle, put_FontStyle)
    FontWeight = property(get_FontWeight, put_FontWeight)
    Foreground = property(get_Foreground, put_Foreground)
    HorizontalTextAlignment = property(get_HorizontalTextAlignment, put_HorizontalTextAlignment)
    Inlines = property(get_Inlines, None)
    IsColorFontEnabled = property(get_IsColorFontEnabled, put_IsColorFontEnabled)
    IsTextScaleFactorEnabled = property(get_IsTextScaleFactorEnabled, put_IsTextScaleFactorEnabled)
    IsTextSelectionEnabled = property(get_IsTextSelectionEnabled, put_IsTextSelectionEnabled)
    IsTextTrimmed = property(get_IsTextTrimmed, None)
    LineHeight = property(get_LineHeight, put_LineHeight)
    LineStackingStrategy = property(get_LineStackingStrategy, put_LineStackingStrategy)
    MaxLines = property(get_MaxLines, put_MaxLines)
    OpticalMarginAlignment = property(get_OpticalMarginAlignment, put_OpticalMarginAlignment)
    Padding = property(get_Padding, put_Padding)
    SelectedText = property(get_SelectedText, None)
    SelectionEnd = property(get_SelectionEnd, None)
    SelectionFlyout = property(get_SelectionFlyout, put_SelectionFlyout)
    SelectionHighlightColor = property(get_SelectionHighlightColor, put_SelectionHighlightColor)
    SelectionStart = property(get_SelectionStart, None)
    Text = property(get_Text, put_Text)
    TextAlignment = property(get_TextAlignment, put_TextAlignment)
    TextDecorations = property(get_TextDecorations, put_TextDecorations)
    TextHighlighters = property(get_TextHighlighters, None)
    TextLineBounds = property(get_TextLineBounds, put_TextLineBounds)
    TextReadingOrder = property(get_TextReadingOrder, put_TextReadingOrder)
    TextTrimming = property(get_TextTrimming, put_TextTrimming)
    TextWrapping = property(get_TextWrapping, put_TextWrapping)
    ContextMenuOpening = event(add_ContextMenuOpening, remove_ContextMenuOpening)
    IsTextTrimmedChanged = event(add_IsTextTrimmedChanged, remove_IsTextTrimmedChanged)
    SelectionChanged = event(add_SelectionChanged, remove_SelectionChanged)
class ITextBlockStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITextBlockStatics'
    _iid_ = Guid('{3187104b-65c2-5e53-b889-c8272b1314cd}')
    @winrt_commethod(6)
    def get_FontSizeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_FontFamilyProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_FontWeightProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_FontStyleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_FontStretchProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_CharacterSpacingProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_ForegroundProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_TextWrappingProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(14)
    def get_TextTrimmingProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(15)
    def get_TextAlignmentProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(16)
    def get_TextProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(17)
    def get_PaddingProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(18)
    def get_LineHeightProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(19)
    def get_LineStackingStrategyProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(20)
    def get_IsTextSelectionEnabledProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(21)
    def get_SelectedTextProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(22)
    def get_SelectionHighlightColorProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(23)
    def get_MaxLinesProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(24)
    def get_TextLineBoundsProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(25)
    def get_OpticalMarginAlignmentProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(26)
    def get_IsColorFontEnabledProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(27)
    def get_TextReadingOrderProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(28)
    def get_IsTextScaleFactorEnabledProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(29)
    def get_TextDecorationsProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(30)
    def get_IsTextTrimmedProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(31)
    def get_HorizontalTextAlignmentProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(32)
    def get_SelectionFlyoutProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    CharacterSpacingProperty = property(get_CharacterSpacingProperty, None)
    FontFamilyProperty = property(get_FontFamilyProperty, None)
    FontSizeProperty = property(get_FontSizeProperty, None)
    FontStretchProperty = property(get_FontStretchProperty, None)
    FontStyleProperty = property(get_FontStyleProperty, None)
    FontWeightProperty = property(get_FontWeightProperty, None)
    ForegroundProperty = property(get_ForegroundProperty, None)
    HorizontalTextAlignmentProperty = property(get_HorizontalTextAlignmentProperty, None)
    IsColorFontEnabledProperty = property(get_IsColorFontEnabledProperty, None)
    IsTextScaleFactorEnabledProperty = property(get_IsTextScaleFactorEnabledProperty, None)
    IsTextSelectionEnabledProperty = property(get_IsTextSelectionEnabledProperty, None)
    IsTextTrimmedProperty = property(get_IsTextTrimmedProperty, None)
    LineHeightProperty = property(get_LineHeightProperty, None)
    LineStackingStrategyProperty = property(get_LineStackingStrategyProperty, None)
    MaxLinesProperty = property(get_MaxLinesProperty, None)
    OpticalMarginAlignmentProperty = property(get_OpticalMarginAlignmentProperty, None)
    PaddingProperty = property(get_PaddingProperty, None)
    SelectedTextProperty = property(get_SelectedTextProperty, None)
    SelectionFlyoutProperty = property(get_SelectionFlyoutProperty, None)
    SelectionHighlightColorProperty = property(get_SelectionHighlightColorProperty, None)
    TextAlignmentProperty = property(get_TextAlignmentProperty, None)
    TextDecorationsProperty = property(get_TextDecorationsProperty, None)
    TextLineBoundsProperty = property(get_TextLineBoundsProperty, None)
    TextProperty = property(get_TextProperty, None)
    TextReadingOrderProperty = property(get_TextReadingOrderProperty, None)
    TextTrimmingProperty = property(get_TextTrimmingProperty, None)
    TextWrappingProperty = property(get_TextWrappingProperty, None)
class ITextBox(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITextBox'
    _iid_ = Guid('{873af7c2-ab89-5d76-8dbe-3d6325669df5}')
    @winrt_commethod(6)
    def get_Text(self) -> hstr: ...
    @winrt_commethod(7)
    def put_Text(self, value: hstr) -> Void: ...
    @winrt_commethod(8)
    def get_SelectedText(self) -> hstr: ...
    @winrt_commethod(9)
    def put_SelectedText(self, value: hstr) -> Void: ...
    @winrt_commethod(10)
    def get_SelectionLength(self) -> Int32: ...
    @winrt_commethod(11)
    def put_SelectionLength(self, value: Int32) -> Void: ...
    @winrt_commethod(12)
    def get_SelectionStart(self) -> Int32: ...
    @winrt_commethod(13)
    def put_SelectionStart(self, value: Int32) -> Void: ...
    @winrt_commethod(14)
    def get_MaxLength(self) -> Int32: ...
    @winrt_commethod(15)
    def put_MaxLength(self, value: Int32) -> Void: ...
    @winrt_commethod(16)
    def get_IsReadOnly(self) -> Boolean: ...
    @winrt_commethod(17)
    def put_IsReadOnly(self, value: Boolean) -> Void: ...
    @winrt_commethod(18)
    def get_AcceptsReturn(self) -> Boolean: ...
    @winrt_commethod(19)
    def put_AcceptsReturn(self, value: Boolean) -> Void: ...
    @winrt_commethod(20)
    def get_TextAlignment(self) -> win32more.Microsoft.UI.Xaml.TextAlignment: ...
    @winrt_commethod(21)
    def put_TextAlignment(self, value: win32more.Microsoft.UI.Xaml.TextAlignment) -> Void: ...
    @winrt_commethod(22)
    def get_TextWrapping(self) -> win32more.Microsoft.UI.Xaml.TextWrapping: ...
    @winrt_commethod(23)
    def put_TextWrapping(self, value: win32more.Microsoft.UI.Xaml.TextWrapping) -> Void: ...
    @winrt_commethod(24)
    def get_IsSpellCheckEnabled(self) -> Boolean: ...
    @winrt_commethod(25)
    def put_IsSpellCheckEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(26)
    def get_IsTextPredictionEnabled(self) -> Boolean: ...
    @winrt_commethod(27)
    def put_IsTextPredictionEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(28)
    def get_InputScope(self) -> win32more.Microsoft.UI.Xaml.Input.InputScope: ...
    @winrt_commethod(29)
    def put_InputScope(self, value: win32more.Microsoft.UI.Xaml.Input.InputScope) -> Void: ...
    @winrt_commethod(30)
    def get_Header(self) -> IInspectable: ...
    @winrt_commethod(31)
    def put_Header(self, value: IInspectable) -> Void: ...
    @winrt_commethod(32)
    def get_HeaderTemplate(self) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_commethod(33)
    def put_HeaderTemplate(self, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_commethod(34)
    def get_PlaceholderText(self) -> hstr: ...
    @winrt_commethod(35)
    def put_PlaceholderText(self, value: hstr) -> Void: ...
    @winrt_commethod(36)
    def get_SelectionHighlightColor(self) -> win32more.Microsoft.UI.Xaml.Media.SolidColorBrush: ...
    @winrt_commethod(37)
    def put_SelectionHighlightColor(self, value: win32more.Microsoft.UI.Xaml.Media.SolidColorBrush) -> Void: ...
    @winrt_commethod(38)
    def get_PreventKeyboardDisplayOnProgrammaticFocus(self) -> Boolean: ...
    @winrt_commethod(39)
    def put_PreventKeyboardDisplayOnProgrammaticFocus(self, value: Boolean) -> Void: ...
    @winrt_commethod(40)
    def get_IsColorFontEnabled(self) -> Boolean: ...
    @winrt_commethod(41)
    def put_IsColorFontEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(42)
    def get_SelectionHighlightColorWhenNotFocused(self) -> win32more.Microsoft.UI.Xaml.Media.SolidColorBrush: ...
    @winrt_commethod(43)
    def put_SelectionHighlightColorWhenNotFocused(self, value: win32more.Microsoft.UI.Xaml.Media.SolidColorBrush) -> Void: ...
    @winrt_commethod(44)
    def get_HorizontalTextAlignment(self) -> win32more.Microsoft.UI.Xaml.TextAlignment: ...
    @winrt_commethod(45)
    def put_HorizontalTextAlignment(self, value: win32more.Microsoft.UI.Xaml.TextAlignment) -> Void: ...
    @winrt_commethod(46)
    def get_CharacterCasing(self) -> win32more.Microsoft.UI.Xaml.Controls.CharacterCasing: ...
    @winrt_commethod(47)
    def put_CharacterCasing(self, value: win32more.Microsoft.UI.Xaml.Controls.CharacterCasing) -> Void: ...
    @winrt_commethod(48)
    def get_PlaceholderForeground(self) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_commethod(49)
    def put_PlaceholderForeground(self, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(50)
    def get_CanPasteClipboardContent(self) -> Boolean: ...
    @winrt_commethod(51)
    def get_CanUndo(self) -> Boolean: ...
    @winrt_commethod(52)
    def get_CanRedo(self) -> Boolean: ...
    @winrt_commethod(53)
    def get_SelectionFlyout(self) -> win32more.Microsoft.UI.Xaml.Controls.Primitives.FlyoutBase: ...
    @winrt_commethod(54)
    def put_SelectionFlyout(self, value: win32more.Microsoft.UI.Xaml.Controls.Primitives.FlyoutBase) -> Void: ...
    @winrt_commethod(55)
    def get_ProofingMenuFlyout(self) -> win32more.Microsoft.UI.Xaml.Controls.Primitives.FlyoutBase: ...
    @winrt_commethod(56)
    def get_Description(self) -> IInspectable: ...
    @winrt_commethod(57)
    def put_Description(self, value: IInspectable) -> Void: ...
    @winrt_commethod(58)
    def add_TextChanged(self, handler: win32more.Microsoft.UI.Xaml.Controls.TextChangedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(59)
    def remove_TextChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(60)
    def add_SelectionChanged(self, handler: win32more.Microsoft.UI.Xaml.RoutedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(61)
    def remove_SelectionChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(62)
    def add_ContextMenuOpening(self, handler: win32more.Microsoft.UI.Xaml.Controls.ContextMenuOpeningEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(63)
    def remove_ContextMenuOpening(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(64)
    def add_Paste(self, handler: win32more.Microsoft.UI.Xaml.Controls.TextControlPasteEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(65)
    def remove_Paste(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(66)
    def add_TextCompositionStarted(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.TextBox, win32more.Microsoft.UI.Xaml.Controls.TextCompositionStartedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(67)
    def remove_TextCompositionStarted(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(68)
    def add_TextCompositionChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.TextBox, win32more.Microsoft.UI.Xaml.Controls.TextCompositionChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(69)
    def remove_TextCompositionChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(70)
    def add_TextCompositionEnded(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.TextBox, win32more.Microsoft.UI.Xaml.Controls.TextCompositionEndedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(71)
    def remove_TextCompositionEnded(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(72)
    def add_CopyingToClipboard(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.TextBox, win32more.Microsoft.UI.Xaml.Controls.TextControlCopyingToClipboardEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(73)
    def remove_CopyingToClipboard(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(74)
    def add_CuttingToClipboard(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.TextBox, win32more.Microsoft.UI.Xaml.Controls.TextControlCuttingToClipboardEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(75)
    def remove_CuttingToClipboard(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(76)
    def add_BeforeTextChanging(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.TextBox, win32more.Microsoft.UI.Xaml.Controls.TextBoxBeforeTextChangingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(77)
    def remove_BeforeTextChanging(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(78)
    def add_SelectionChanging(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.TextBox, win32more.Microsoft.UI.Xaml.Controls.TextBoxSelectionChangingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(79)
    def remove_SelectionChanging(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(80)
    def Select(self, start: Int32, length: Int32) -> Void: ...
    @winrt_commethod(81)
    def SelectAll(self) -> Void: ...
    @winrt_commethod(82)
    def GetRectFromCharacterIndex(self, charIndex: Int32, trailingEdge: Boolean) -> win32more.Windows.Foundation.Rect: ...
    @winrt_commethod(83)
    def GetLinguisticAlternativesAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[hstr]]: ...
    @winrt_commethod(84)
    def Undo(self) -> Void: ...
    @winrt_commethod(85)
    def Redo(self) -> Void: ...
    @winrt_commethod(86)
    def PasteFromClipboard(self) -> Void: ...
    @winrt_commethod(87)
    def CopySelectionToClipboard(self) -> Void: ...
    @winrt_commethod(88)
    def CutSelectionToClipboard(self) -> Void: ...
    @winrt_commethod(89)
    def ClearUndoRedoHistory(self) -> Void: ...
    @winrt_commethod(90)
    def get_TextReadingOrder(self) -> win32more.Microsoft.UI.Xaml.TextReadingOrder: ...
    @winrt_commethod(91)
    def put_TextReadingOrder(self, value: win32more.Microsoft.UI.Xaml.TextReadingOrder) -> Void: ...
    @winrt_commethod(92)
    def get_DesiredCandidateWindowAlignment(self) -> win32more.Microsoft.UI.Xaml.Controls.CandidateWindowAlignment: ...
    @winrt_commethod(93)
    def put_DesiredCandidateWindowAlignment(self, value: win32more.Microsoft.UI.Xaml.Controls.CandidateWindowAlignment) -> Void: ...
    @winrt_commethod(94)
    def add_CandidateWindowBoundsChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.TextBox, win32more.Microsoft.UI.Xaml.Controls.CandidateWindowBoundsChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(95)
    def remove_CandidateWindowBoundsChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(96)
    def add_TextChanging(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.TextBox, win32more.Microsoft.UI.Xaml.Controls.TextBoxTextChangingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(97)
    def remove_TextChanging(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    AcceptsReturn = property(get_AcceptsReturn, put_AcceptsReturn)
    CanPasteClipboardContent = property(get_CanPasteClipboardContent, None)
    CanRedo = property(get_CanRedo, None)
    CanUndo = property(get_CanUndo, None)
    CharacterCasing = property(get_CharacterCasing, put_CharacterCasing)
    Description = property(get_Description, put_Description)
    DesiredCandidateWindowAlignment = property(get_DesiredCandidateWindowAlignment, put_DesiredCandidateWindowAlignment)
    Header = property(get_Header, put_Header)
    HeaderTemplate = property(get_HeaderTemplate, put_HeaderTemplate)
    HorizontalTextAlignment = property(get_HorizontalTextAlignment, put_HorizontalTextAlignment)
    InputScope = property(get_InputScope, put_InputScope)
    IsColorFontEnabled = property(get_IsColorFontEnabled, put_IsColorFontEnabled)
    IsReadOnly = property(get_IsReadOnly, put_IsReadOnly)
    IsSpellCheckEnabled = property(get_IsSpellCheckEnabled, put_IsSpellCheckEnabled)
    IsTextPredictionEnabled = property(get_IsTextPredictionEnabled, put_IsTextPredictionEnabled)
    MaxLength = property(get_MaxLength, put_MaxLength)
    PlaceholderForeground = property(get_PlaceholderForeground, put_PlaceholderForeground)
    PlaceholderText = property(get_PlaceholderText, put_PlaceholderText)
    PreventKeyboardDisplayOnProgrammaticFocus = property(get_PreventKeyboardDisplayOnProgrammaticFocus, put_PreventKeyboardDisplayOnProgrammaticFocus)
    ProofingMenuFlyout = property(get_ProofingMenuFlyout, None)
    SelectedText = property(get_SelectedText, put_SelectedText)
    SelectionFlyout = property(get_SelectionFlyout, put_SelectionFlyout)
    SelectionHighlightColor = property(get_SelectionHighlightColor, put_SelectionHighlightColor)
    SelectionHighlightColorWhenNotFocused = property(get_SelectionHighlightColorWhenNotFocused, put_SelectionHighlightColorWhenNotFocused)
    SelectionLength = property(get_SelectionLength, put_SelectionLength)
    SelectionStart = property(get_SelectionStart, put_SelectionStart)
    Text = property(get_Text, put_Text)
    TextAlignment = property(get_TextAlignment, put_TextAlignment)
    TextReadingOrder = property(get_TextReadingOrder, put_TextReadingOrder)
    TextWrapping = property(get_TextWrapping, put_TextWrapping)
    BeforeTextChanging = event(add_BeforeTextChanging, remove_BeforeTextChanging)
    CandidateWindowBoundsChanged = event(add_CandidateWindowBoundsChanged, remove_CandidateWindowBoundsChanged)
    ContextMenuOpening = event(add_ContextMenuOpening, remove_ContextMenuOpening)
    CopyingToClipboard = event(add_CopyingToClipboard, remove_CopyingToClipboard)
    CuttingToClipboard = event(add_CuttingToClipboard, remove_CuttingToClipboard)
    Paste = event(add_Paste, remove_Paste)
    SelectionChanged = event(add_SelectionChanged, remove_SelectionChanged)
    SelectionChanging = event(add_SelectionChanging, remove_SelectionChanging)
    TextChanged = event(add_TextChanged, remove_TextChanged)
    TextChanging = event(add_TextChanging, remove_TextChanging)
    TextCompositionChanged = event(add_TextCompositionChanged, remove_TextCompositionChanged)
    TextCompositionEnded = event(add_TextCompositionEnded, remove_TextCompositionEnded)
    TextCompositionStarted = event(add_TextCompositionStarted, remove_TextCompositionStarted)
class ITextBoxBeforeTextChangingEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITextBoxBeforeTextChangingEventArgs'
    _iid_ = Guid('{ba46105b-9a16-5237-a20f-5df750992a05}')
    @winrt_commethod(6)
    def get_NewText(self) -> hstr: ...
    @winrt_commethod(7)
    def get_Cancel(self) -> Boolean: ...
    @winrt_commethod(8)
    def put_Cancel(self, value: Boolean) -> Void: ...
    Cancel = property(get_Cancel, put_Cancel)
    NewText = property(get_NewText, None)
class ITextBoxFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITextBoxFactory'
    _iid_ = Guid('{e1d8b82e-bc60-5d27-b646-5ca4c4a69432}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.TextBox: ...
class ITextBoxSelectionChangingEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITextBoxSelectionChangingEventArgs'
    _iid_ = Guid('{6dce20db-894e-5ff6-825b-f9891af79516}')
    @winrt_commethod(6)
    def get_SelectionStart(self) -> Int32: ...
    @winrt_commethod(7)
    def get_SelectionLength(self) -> Int32: ...
    @winrt_commethod(8)
    def get_Cancel(self) -> Boolean: ...
    @winrt_commethod(9)
    def put_Cancel(self, value: Boolean) -> Void: ...
    Cancel = property(get_Cancel, put_Cancel)
    SelectionLength = property(get_SelectionLength, None)
    SelectionStart = property(get_SelectionStart, None)
class ITextBoxStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITextBoxStatics'
    _iid_ = Guid('{a41cf38f-712a-5599-bbed-5a3d9b6bd46e}')
    @winrt_commethod(6)
    def get_TextProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_MaxLengthProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_IsReadOnlyProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_AcceptsReturnProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_TextAlignmentProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_TextWrappingProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_IsSpellCheckEnabledProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_IsTextPredictionEnabledProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(14)
    def get_InputScopeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(15)
    def get_HeaderProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(16)
    def get_HeaderTemplateProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(17)
    def get_PlaceholderTextProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(18)
    def get_SelectionHighlightColorProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(19)
    def get_PreventKeyboardDisplayOnProgrammaticFocusProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(20)
    def get_IsColorFontEnabledProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(21)
    def get_SelectionHighlightColorWhenNotFocusedProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(22)
    def get_HorizontalTextAlignmentProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(23)
    def get_CharacterCasingProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(24)
    def get_PlaceholderForegroundProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(25)
    def get_CanPasteClipboardContentProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(26)
    def get_CanUndoProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(27)
    def get_CanRedoProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(28)
    def get_SelectionFlyoutProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(29)
    def get_ProofingMenuFlyoutProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(30)
    def get_DescriptionProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(31)
    def get_DesiredCandidateWindowAlignmentProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(32)
    def get_TextReadingOrderProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    AcceptsReturnProperty = property(get_AcceptsReturnProperty, None)
    CanPasteClipboardContentProperty = property(get_CanPasteClipboardContentProperty, None)
    CanRedoProperty = property(get_CanRedoProperty, None)
    CanUndoProperty = property(get_CanUndoProperty, None)
    CharacterCasingProperty = property(get_CharacterCasingProperty, None)
    DescriptionProperty = property(get_DescriptionProperty, None)
    DesiredCandidateWindowAlignmentProperty = property(get_DesiredCandidateWindowAlignmentProperty, None)
    HeaderProperty = property(get_HeaderProperty, None)
    HeaderTemplateProperty = property(get_HeaderTemplateProperty, None)
    HorizontalTextAlignmentProperty = property(get_HorizontalTextAlignmentProperty, None)
    InputScopeProperty = property(get_InputScopeProperty, None)
    IsColorFontEnabledProperty = property(get_IsColorFontEnabledProperty, None)
    IsReadOnlyProperty = property(get_IsReadOnlyProperty, None)
    IsSpellCheckEnabledProperty = property(get_IsSpellCheckEnabledProperty, None)
    IsTextPredictionEnabledProperty = property(get_IsTextPredictionEnabledProperty, None)
    MaxLengthProperty = property(get_MaxLengthProperty, None)
    PlaceholderForegroundProperty = property(get_PlaceholderForegroundProperty, None)
    PlaceholderTextProperty = property(get_PlaceholderTextProperty, None)
    PreventKeyboardDisplayOnProgrammaticFocusProperty = property(get_PreventKeyboardDisplayOnProgrammaticFocusProperty, None)
    ProofingMenuFlyoutProperty = property(get_ProofingMenuFlyoutProperty, None)
    SelectionFlyoutProperty = property(get_SelectionFlyoutProperty, None)
    SelectionHighlightColorProperty = property(get_SelectionHighlightColorProperty, None)
    SelectionHighlightColorWhenNotFocusedProperty = property(get_SelectionHighlightColorWhenNotFocusedProperty, None)
    TextAlignmentProperty = property(get_TextAlignmentProperty, None)
    TextProperty = property(get_TextProperty, None)
    TextReadingOrderProperty = property(get_TextReadingOrderProperty, None)
    TextWrappingProperty = property(get_TextWrappingProperty, None)
class ITextBoxTextChangingEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITextBoxTextChangingEventArgs'
    _iid_ = Guid('{a1a08d48-e8c0-5379-b138-7eb3f8d5f5e6}')
    @winrt_commethod(6)
    def get_IsContentChanging(self) -> Boolean: ...
    IsContentChanging = property(get_IsContentChanging, None)
class ITextChangedEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITextChangedEventArgs'
    _iid_ = Guid('{71c37e43-7be7-52fc-bf8c-9867f44be5f4}')
class ITextCommandBarFlyout(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITextCommandBarFlyout'
    _iid_ = Guid('{6d0f38a5-0eb3-5d73-8195-d2d89b76b0f7}')
class ITextCommandBarFlyoutFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITextCommandBarFlyoutFactory'
    _iid_ = Guid('{5c56a34f-621f-55f2-8d71-3e3a6e6906bd}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.TextCommandBarFlyout: ...
class ITextCompositionChangedEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITextCompositionChangedEventArgs'
    _iid_ = Guid('{04f420d2-ba9c-5f59-b8ac-0d8aa50a9240}')
    @winrt_commethod(6)
    def get_StartIndex(self) -> Int32: ...
    @winrt_commethod(7)
    def get_Length(self) -> Int32: ...
    Length = property(get_Length, None)
    StartIndex = property(get_StartIndex, None)
class ITextCompositionEndedEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITextCompositionEndedEventArgs'
    _iid_ = Guid('{19d0a5c5-8d0f-5118-8c30-e709326f1283}')
    @winrt_commethod(6)
    def get_StartIndex(self) -> Int32: ...
    @winrt_commethod(7)
    def get_Length(self) -> Int32: ...
    Length = property(get_Length, None)
    StartIndex = property(get_StartIndex, None)
class ITextCompositionStartedEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITextCompositionStartedEventArgs'
    _iid_ = Guid('{a604ff71-5d44-5859-8d71-72030ed78bc8}')
    @winrt_commethod(6)
    def get_StartIndex(self) -> Int32: ...
    @winrt_commethod(7)
    def get_Length(self) -> Int32: ...
    Length = property(get_Length, None)
    StartIndex = property(get_StartIndex, None)
class ITextControlCopyingToClipboardEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITextControlCopyingToClipboardEventArgs'
    _iid_ = Guid('{1daac6d5-8db5-5d9f-9382-1e644f9aa437}')
    @winrt_commethod(6)
    def get_Handled(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_Handled(self, value: Boolean) -> Void: ...
    Handled = property(get_Handled, put_Handled)
class ITextControlCuttingToClipboardEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITextControlCuttingToClipboardEventArgs'
    _iid_ = Guid('{9d73671f-ea30-555d-8129-5a96aec73a14}')
    @winrt_commethod(6)
    def get_Handled(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_Handled(self, value: Boolean) -> Void: ...
    Handled = property(get_Handled, put_Handled)
class ITextControlPasteEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITextControlPasteEventArgs'
    _iid_ = Guid('{fc5e567e-3aa9-5c57-88d4-834ad3b62e9e}')
    @winrt_commethod(6)
    def get_Handled(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_Handled(self, value: Boolean) -> Void: ...
    Handled = property(get_Handled, put_Handled)
class ITimePickedEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITimePickedEventArgs'
    _iid_ = Guid('{9f85d661-a9e0-5e08-a904-113b74ca3c59}')
    @winrt_commethod(6)
    def get_OldTime(self) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_commethod(7)
    def get_NewTime(self) -> win32more.Windows.Foundation.TimeSpan: ...
    NewTime = property(get_NewTime, None)
    OldTime = property(get_OldTime, None)
class ITimePicker(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITimePicker'
    _iid_ = Guid('{ed4baa33-c240-5934-9229-82d37b26f846}')
    @winrt_commethod(6)
    def get_Header(self) -> IInspectable: ...
    @winrt_commethod(7)
    def put_Header(self, value: IInspectable) -> Void: ...
    @winrt_commethod(8)
    def get_HeaderTemplate(self) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_commethod(9)
    def put_HeaderTemplate(self, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_commethod(10)
    def get_ClockIdentifier(self) -> hstr: ...
    @winrt_commethod(11)
    def put_ClockIdentifier(self, value: hstr) -> Void: ...
    @winrt_commethod(12)
    def get_MinuteIncrement(self) -> Int32: ...
    @winrt_commethod(13)
    def put_MinuteIncrement(self, value: Int32) -> Void: ...
    @winrt_commethod(14)
    def get_Time(self) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_commethod(15)
    def put_Time(self, value: win32more.Windows.Foundation.TimeSpan) -> Void: ...
    @winrt_commethod(16)
    def get_LightDismissOverlayMode(self) -> win32more.Microsoft.UI.Xaml.Controls.LightDismissOverlayMode: ...
    @winrt_commethod(17)
    def put_LightDismissOverlayMode(self, value: win32more.Microsoft.UI.Xaml.Controls.LightDismissOverlayMode) -> Void: ...
    @winrt_commethod(18)
    def get_SelectedTime(self) -> win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.TimeSpan]: ...
    @winrt_commethod(19)
    def put_SelectedTime(self, value: win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.TimeSpan]) -> Void: ...
    @winrt_commethod(20)
    def add_TimeChanged(self, handler: win32more.Windows.Foundation.EventHandler[win32more.Microsoft.UI.Xaml.Controls.TimePickerValueChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(21)
    def remove_TimeChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(22)
    def add_SelectedTimeChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.TimePicker, win32more.Microsoft.UI.Xaml.Controls.TimePickerSelectedValueChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(23)
    def remove_SelectedTimeChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    ClockIdentifier = property(get_ClockIdentifier, put_ClockIdentifier)
    Header = property(get_Header, put_Header)
    HeaderTemplate = property(get_HeaderTemplate, put_HeaderTemplate)
    LightDismissOverlayMode = property(get_LightDismissOverlayMode, put_LightDismissOverlayMode)
    MinuteIncrement = property(get_MinuteIncrement, put_MinuteIncrement)
    SelectedTime = property(get_SelectedTime, put_SelectedTime)
    Time = property(get_Time, put_Time)
    SelectedTimeChanged = event(add_SelectedTimeChanged, remove_SelectedTimeChanged)
    TimeChanged = event(add_TimeChanged, remove_TimeChanged)
class ITimePickerFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITimePickerFactory'
    _iid_ = Guid('{1584429e-aafe-5c65-89e9-8c066e5690e7}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.TimePicker: ...
class ITimePickerFlyout(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITimePickerFlyout'
    _iid_ = Guid('{479799dc-700a-5a9c-ba0b-9ab2587ed2e8}')
    @winrt_commethod(6)
    def get_ClockIdentifier(self) -> hstr: ...
    @winrt_commethod(7)
    def put_ClockIdentifier(self, value: hstr) -> Void: ...
    @winrt_commethod(8)
    def get_Time(self) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_commethod(9)
    def put_Time(self, value: win32more.Windows.Foundation.TimeSpan) -> Void: ...
    @winrt_commethod(10)
    def get_MinuteIncrement(self) -> Int32: ...
    @winrt_commethod(11)
    def put_MinuteIncrement(self, value: Int32) -> Void: ...
    @winrt_commethod(12)
    def add_TimePicked(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.TimePickerFlyout, win32more.Microsoft.UI.Xaml.Controls.TimePickedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(13)
    def remove_TimePicked(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(14)
    def ShowAtAsync(self, target: win32more.Microsoft.UI.Xaml.FrameworkElement) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.TimeSpan]]: ...
    ClockIdentifier = property(get_ClockIdentifier, put_ClockIdentifier)
    MinuteIncrement = property(get_MinuteIncrement, put_MinuteIncrement)
    Time = property(get_Time, put_Time)
    TimePicked = event(add_TimePicked, remove_TimePicked)
class ITimePickerFlyoutPresenter(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITimePickerFlyoutPresenter'
    _iid_ = Guid('{a7439b37-7a77-5aeb-806b-bc726005de20}')
    @winrt_commethod(6)
    def get_IsDefaultShadowEnabled(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_IsDefaultShadowEnabled(self, value: Boolean) -> Void: ...
    IsDefaultShadowEnabled = property(get_IsDefaultShadowEnabled, put_IsDefaultShadowEnabled)
class ITimePickerFlyoutPresenterStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITimePickerFlyoutPresenterStatics'
    _iid_ = Guid('{0cd9d57d-970f-5df3-b2af-49cff489675e}')
    @winrt_commethod(6)
    def get_IsDefaultShadowEnabledProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    IsDefaultShadowEnabledProperty = property(get_IsDefaultShadowEnabledProperty, None)
class ITimePickerFlyoutStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITimePickerFlyoutStatics'
    _iid_ = Guid('{085a6a2d-68f4-5d4e-b89c-47cc0dd520a8}')
    @winrt_commethod(6)
    def get_ClockIdentifierProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_TimeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_MinuteIncrementProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    ClockIdentifierProperty = property(get_ClockIdentifierProperty, None)
    MinuteIncrementProperty = property(get_MinuteIncrementProperty, None)
    TimeProperty = property(get_TimeProperty, None)
class ITimePickerSelectedValueChangedEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITimePickerSelectedValueChangedEventArgs'
    _iid_ = Guid('{6ed7edf1-9b0b-5e7b-9e10-f35660a29fd2}')
    @winrt_commethod(6)
    def get_OldTime(self) -> win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.TimeSpan]: ...
    @winrt_commethod(7)
    def get_NewTime(self) -> win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.TimeSpan]: ...
    NewTime = property(get_NewTime, None)
    OldTime = property(get_OldTime, None)
class ITimePickerStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITimePickerStatics'
    _iid_ = Guid('{12bef59e-4222-507b-901e-effd04620c4f}')
    @winrt_commethod(6)
    def get_HeaderProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_HeaderTemplateProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_ClockIdentifierProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_MinuteIncrementProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_TimeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_LightDismissOverlayModeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_SelectedTimeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    ClockIdentifierProperty = property(get_ClockIdentifierProperty, None)
    HeaderProperty = property(get_HeaderProperty, None)
    HeaderTemplateProperty = property(get_HeaderTemplateProperty, None)
    LightDismissOverlayModeProperty = property(get_LightDismissOverlayModeProperty, None)
    MinuteIncrementProperty = property(get_MinuteIncrementProperty, None)
    SelectedTimeProperty = property(get_SelectedTimeProperty, None)
    TimeProperty = property(get_TimeProperty, None)
class ITimePickerValueChangedEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITimePickerValueChangedEventArgs'
    _iid_ = Guid('{7b98953f-c24a-53c6-8a3a-520558508b08}')
    @winrt_commethod(6)
    def get_OldTime(self) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_commethod(7)
    def get_NewTime(self) -> win32more.Windows.Foundation.TimeSpan: ...
    NewTime = property(get_NewTime, None)
    OldTime = property(get_OldTime, None)
class IToggleMenuFlyoutItem(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IToggleMenuFlyoutItem'
    _iid_ = Guid('{1803f260-67e4-5bc1-a63a-123510167bb8}')
    @winrt_commethod(6)
    def get_IsChecked(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_IsChecked(self, value: Boolean) -> Void: ...
    IsChecked = property(get_IsChecked, put_IsChecked)
class IToggleMenuFlyoutItemFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IToggleMenuFlyoutItemFactory'
    _iid_ = Guid('{426dfd57-6cc9-570f-950d-37437235dc89}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.ToggleMenuFlyoutItem: ...
class IToggleMenuFlyoutItemStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IToggleMenuFlyoutItemStatics'
    _iid_ = Guid('{7411e854-c59a-5463-beab-64ddb052c6dc}')
    @winrt_commethod(6)
    def get_IsCheckedProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    IsCheckedProperty = property(get_IsCheckedProperty, None)
class IToggleSplitButton(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IToggleSplitButton'
    _iid_ = Guid('{5c0f247b-bd00-5509-88a8-b09007ae22b0}')
    @winrt_commethod(6)
    def get_IsChecked(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_IsChecked(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def add_IsCheckedChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.ToggleSplitButton, win32more.Microsoft.UI.Xaml.Controls.ToggleSplitButtonIsCheckedChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(9)
    def remove_IsCheckedChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    IsChecked = property(get_IsChecked, put_IsChecked)
    IsCheckedChanged = event(add_IsCheckedChanged, remove_IsCheckedChanged)
class IToggleSplitButtonFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IToggleSplitButtonFactory'
    _iid_ = Guid('{25459d02-0ffc-5c7c-af56-f55aad6db5e7}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.ToggleSplitButton: ...
class IToggleSplitButtonIsCheckedChangedEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IToggleSplitButtonIsCheckedChangedEventArgs'
    _iid_ = Guid('{6cab1e15-c017-5760-828b-dafc21d54eb2}')
class IToggleSplitButtonStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IToggleSplitButtonStatics'
    _iid_ = Guid('{801c9ca9-5b24-5b9e-a8d1-cff4b6e6857f}')
    @winrt_commethod(6)
    def get_IsCheckedProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    IsCheckedProperty = property(get_IsCheckedProperty, None)
class IToggleSwitch(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IToggleSwitch'
    _iid_ = Guid('{1b17eeb1-74bf-5a83-8161-a86f0fdcdf24}')
    @winrt_commethod(6)
    def get_IsOn(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_IsOn(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def get_Header(self) -> IInspectable: ...
    @winrt_commethod(9)
    def put_Header(self, value: IInspectable) -> Void: ...
    @winrt_commethod(10)
    def get_HeaderTemplate(self) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_commethod(11)
    def put_HeaderTemplate(self, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_commethod(12)
    def get_OnContent(self) -> IInspectable: ...
    @winrt_commethod(13)
    def put_OnContent(self, value: IInspectable) -> Void: ...
    @winrt_commethod(14)
    def get_OnContentTemplate(self) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_commethod(15)
    def put_OnContentTemplate(self, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_commethod(16)
    def get_OffContent(self) -> IInspectable: ...
    @winrt_commethod(17)
    def put_OffContent(self, value: IInspectable) -> Void: ...
    @winrt_commethod(18)
    def get_OffContentTemplate(self) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_commethod(19)
    def put_OffContentTemplate(self, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_commethod(20)
    def get_TemplateSettings(self) -> win32more.Microsoft.UI.Xaml.Controls.Primitives.ToggleSwitchTemplateSettings: ...
    @winrt_commethod(21)
    def add_Toggled(self, handler: win32more.Microsoft.UI.Xaml.RoutedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(22)
    def remove_Toggled(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    Header = property(get_Header, put_Header)
    HeaderTemplate = property(get_HeaderTemplate, put_HeaderTemplate)
    IsOn = property(get_IsOn, put_IsOn)
    OffContent = property(get_OffContent, put_OffContent)
    OffContentTemplate = property(get_OffContentTemplate, put_OffContentTemplate)
    OnContent = property(get_OnContent, put_OnContent)
    OnContentTemplate = property(get_OnContentTemplate, put_OnContentTemplate)
    TemplateSettings = property(get_TemplateSettings, None)
    Toggled = event(add_Toggled, remove_Toggled)
class IToggleSwitchOverrides(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IToggleSwitchOverrides'
    _iid_ = Guid('{772682db-e3d4-5242-b6de-36705725eeb8}')
    @winrt_commethod(6)
    def OnToggled(self) -> Void: ...
    @winrt_commethod(7)
    def OnOnContentChanged(self, oldContent: IInspectable, newContent: IInspectable) -> Void: ...
    @winrt_commethod(8)
    def OnOffContentChanged(self, oldContent: IInspectable, newContent: IInspectable) -> Void: ...
    @winrt_commethod(9)
    def OnHeaderChanged(self, oldContent: IInspectable, newContent: IInspectable) -> Void: ...
class IToggleSwitchStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IToggleSwitchStatics'
    _iid_ = Guid('{c9c203d6-0619-504d-9ed8-5054fe3ca51e}')
    @winrt_commethod(6)
    def get_IsOnProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_HeaderProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_HeaderTemplateProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_OnContentProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_OnContentTemplateProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_OffContentProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_OffContentTemplateProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    HeaderProperty = property(get_HeaderProperty, None)
    HeaderTemplateProperty = property(get_HeaderTemplateProperty, None)
    IsOnProperty = property(get_IsOnProperty, None)
    OffContentProperty = property(get_OffContentProperty, None)
    OffContentTemplateProperty = property(get_OffContentTemplateProperty, None)
    OnContentProperty = property(get_OnContentProperty, None)
    OnContentTemplateProperty = property(get_OnContentTemplateProperty, None)
class IToolTip(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IToolTip'
    _iid_ = Guid('{67e93d74-5e93-59a1-91bf-413efbeb904c}')
    @winrt_commethod(6)
    def get_HorizontalOffset(self) -> Double: ...
    @winrt_commethod(7)
    def put_HorizontalOffset(self, value: Double) -> Void: ...
    @winrt_commethod(8)
    def get_IsOpen(self) -> Boolean: ...
    @winrt_commethod(9)
    def put_IsOpen(self, value: Boolean) -> Void: ...
    @winrt_commethod(10)
    def get_Placement(self) -> win32more.Microsoft.UI.Xaml.Controls.Primitives.PlacementMode: ...
    @winrt_commethod(11)
    def put_Placement(self, value: win32more.Microsoft.UI.Xaml.Controls.Primitives.PlacementMode) -> Void: ...
    @winrt_commethod(12)
    def get_PlacementTarget(self) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_commethod(13)
    def put_PlacementTarget(self, value: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    @winrt_commethod(14)
    def get_PlacementRect(self) -> win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.Rect]: ...
    @winrt_commethod(15)
    def put_PlacementRect(self, value: win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.Rect]) -> Void: ...
    @winrt_commethod(16)
    def get_VerticalOffset(self) -> Double: ...
    @winrt_commethod(17)
    def put_VerticalOffset(self, value: Double) -> Void: ...
    @winrt_commethod(18)
    def get_TemplateSettings(self) -> win32more.Microsoft.UI.Xaml.Controls.Primitives.ToolTipTemplateSettings: ...
    @winrt_commethod(19)
    def add_Closed(self, handler: win32more.Microsoft.UI.Xaml.RoutedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(20)
    def remove_Closed(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(21)
    def add_Opened(self, handler: win32more.Microsoft.UI.Xaml.RoutedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(22)
    def remove_Opened(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    HorizontalOffset = property(get_HorizontalOffset, put_HorizontalOffset)
    IsOpen = property(get_IsOpen, put_IsOpen)
    Placement = property(get_Placement, put_Placement)
    PlacementRect = property(get_PlacementRect, put_PlacementRect)
    PlacementTarget = property(get_PlacementTarget, put_PlacementTarget)
    TemplateSettings = property(get_TemplateSettings, None)
    VerticalOffset = property(get_VerticalOffset, put_VerticalOffset)
    Closed = event(add_Closed, remove_Closed)
    Opened = event(add_Opened, remove_Opened)
class IToolTipFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IToolTipFactory'
    _iid_ = Guid('{bcbb3720-2db8-54e1-8806-fcbed38949a9}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.ToolTip: ...
class IToolTipService(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IToolTipService'
    _iid_ = Guid('{01140768-2727-5f89-80e0-5210326a3431}')
class IToolTipServiceStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IToolTipServiceStatics'
    _iid_ = Guid('{5aa38adc-9874-5e0a-8d8e-1574efc0b88f}')
    @winrt_commethod(6)
    def get_PlacementProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def GetPlacement(self, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> win32more.Microsoft.UI.Xaml.Controls.Primitives.PlacementMode: ...
    @winrt_commethod(8)
    def SetPlacement(self, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: win32more.Microsoft.UI.Xaml.Controls.Primitives.PlacementMode) -> Void: ...
    @winrt_commethod(9)
    def get_PlacementTargetProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def GetPlacementTarget(self, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_commethod(11)
    def SetPlacementTarget(self, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    @winrt_commethod(12)
    def get_ToolTipProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def GetToolTip(self, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> IInspectable: ...
    @winrt_commethod(14)
    def SetToolTip(self, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: IInspectable) -> Void: ...
    PlacementProperty = property(get_PlacementProperty, None)
    PlacementTargetProperty = property(get_PlacementTargetProperty, None)
    ToolTipProperty = property(get_ToolTipProperty, None)
class IToolTipStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IToolTipStatics'
    _iid_ = Guid('{88eb60d4-cd54-5e23-bd1a-223702442ba4}')
    @winrt_commethod(6)
    def get_HorizontalOffsetProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_IsOpenProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_PlacementProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_PlacementTargetProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_PlacementRectProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_VerticalOffsetProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    HorizontalOffsetProperty = property(get_HorizontalOffsetProperty, None)
    IsOpenProperty = property(get_IsOpenProperty, None)
    PlacementProperty = property(get_PlacementProperty, None)
    PlacementRectProperty = property(get_PlacementRectProperty, None)
    PlacementTargetProperty = property(get_PlacementTargetProperty, None)
    VerticalOffsetProperty = property(get_VerticalOffsetProperty, None)
class ITreeView(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITreeView'
    _iid_ = Guid('{1bef9af4-712c-50ef-9bb4-881b975232ab}')
    @winrt_commethod(6)
    def get_RootNodes(self) -> win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.TreeViewNode]: ...
    @winrt_commethod(7)
    def get_SelectionMode(self) -> win32more.Microsoft.UI.Xaml.Controls.TreeViewSelectionMode: ...
    @winrt_commethod(8)
    def put_SelectionMode(self, value: win32more.Microsoft.UI.Xaml.Controls.TreeViewSelectionMode) -> Void: ...
    @winrt_commethod(9)
    def get_SelectedNodes(self) -> win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.TreeViewNode]: ...
    @winrt_commethod(10)
    def Expand(self, value: win32more.Microsoft.UI.Xaml.Controls.TreeViewNode) -> Void: ...
    @winrt_commethod(11)
    def Collapse(self, value: win32more.Microsoft.UI.Xaml.Controls.TreeViewNode) -> Void: ...
    @winrt_commethod(12)
    def SelectAll(self) -> Void: ...
    @winrt_commethod(13)
    def add_ItemInvoked(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.TreeView, win32more.Microsoft.UI.Xaml.Controls.TreeViewItemInvokedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(14)
    def remove_ItemInvoked(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(15)
    def add_Expanding(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.TreeView, win32more.Microsoft.UI.Xaml.Controls.TreeViewExpandingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(16)
    def remove_Expanding(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(17)
    def add_Collapsed(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.TreeView, win32more.Microsoft.UI.Xaml.Controls.TreeViewCollapsedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(18)
    def remove_Collapsed(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    RootNodes = property(get_RootNodes, None)
    SelectedNodes = property(get_SelectedNodes, None)
    SelectionMode = property(get_SelectionMode, put_SelectionMode)
    Collapsed = event(add_Collapsed, remove_Collapsed)
    Expanding = event(add_Expanding, remove_Expanding)
    ItemInvoked = event(add_ItemInvoked, remove_ItemInvoked)
class ITreeView2(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITreeView2'
    _iid_ = Guid('{b947ca7d-0f6f-594c-83ec-14153d343225}')
    @winrt_commethod(6)
    def NodeFromContainer(self, container: win32more.Microsoft.UI.Xaml.DependencyObject) -> win32more.Microsoft.UI.Xaml.Controls.TreeViewNode: ...
    @winrt_commethod(7)
    def ContainerFromNode(self, node: win32more.Microsoft.UI.Xaml.Controls.TreeViewNode) -> win32more.Microsoft.UI.Xaml.DependencyObject: ...
    @winrt_commethod(8)
    def ItemFromContainer(self, container: win32more.Microsoft.UI.Xaml.DependencyObject) -> IInspectable: ...
    @winrt_commethod(9)
    def ContainerFromItem(self, item: IInspectable) -> win32more.Microsoft.UI.Xaml.DependencyObject: ...
    @winrt_commethod(10)
    def get_CanDragItems(self) -> Boolean: ...
    @winrt_commethod(11)
    def put_CanDragItems(self, value: Boolean) -> Void: ...
    @winrt_commethod(12)
    def get_CanReorderItems(self) -> Boolean: ...
    @winrt_commethod(13)
    def put_CanReorderItems(self, value: Boolean) -> Void: ...
    @winrt_commethod(14)
    def get_ItemTemplate(self) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_commethod(15)
    def put_ItemTemplate(self, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_commethod(16)
    def get_ItemTemplateSelector(self) -> win32more.Microsoft.UI.Xaml.Controls.DataTemplateSelector: ...
    @winrt_commethod(17)
    def put_ItemTemplateSelector(self, value: win32more.Microsoft.UI.Xaml.Controls.DataTemplateSelector) -> Void: ...
    @winrt_commethod(18)
    def get_ItemContainerStyle(self) -> win32more.Microsoft.UI.Xaml.Style: ...
    @winrt_commethod(19)
    def put_ItemContainerStyle(self, value: win32more.Microsoft.UI.Xaml.Style) -> Void: ...
    @winrt_commethod(20)
    def get_ItemContainerStyleSelector(self) -> win32more.Microsoft.UI.Xaml.Controls.StyleSelector: ...
    @winrt_commethod(21)
    def put_ItemContainerStyleSelector(self, value: win32more.Microsoft.UI.Xaml.Controls.StyleSelector) -> Void: ...
    @winrt_commethod(22)
    def get_ItemContainerTransitions(self) -> win32more.Microsoft.UI.Xaml.Media.Animation.TransitionCollection: ...
    @winrt_commethod(23)
    def put_ItemContainerTransitions(self, value: win32more.Microsoft.UI.Xaml.Media.Animation.TransitionCollection) -> Void: ...
    @winrt_commethod(24)
    def get_ItemsSource(self) -> IInspectable: ...
    @winrt_commethod(25)
    def put_ItemsSource(self, value: IInspectable) -> Void: ...
    @winrt_commethod(26)
    def add_DragItemsStarting(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.TreeView, win32more.Microsoft.UI.Xaml.Controls.TreeViewDragItemsStartingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(27)
    def remove_DragItemsStarting(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(28)
    def add_DragItemsCompleted(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.TreeView, win32more.Microsoft.UI.Xaml.Controls.TreeViewDragItemsCompletedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(29)
    def remove_DragItemsCompleted(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(30)
    def get_SelectedNode(self) -> win32more.Microsoft.UI.Xaml.Controls.TreeViewNode: ...
    @winrt_commethod(31)
    def put_SelectedNode(self, value: win32more.Microsoft.UI.Xaml.Controls.TreeViewNode) -> Void: ...
    @winrt_commethod(32)
    def get_SelectedItem(self) -> IInspectable: ...
    @winrt_commethod(33)
    def put_SelectedItem(self, value: IInspectable) -> Void: ...
    @winrt_commethod(34)
    def get_SelectedItems(self) -> win32more.Windows.Foundation.Collections.IVector[IInspectable]: ...
    CanDragItems = property(get_CanDragItems, put_CanDragItems)
    CanReorderItems = property(get_CanReorderItems, put_CanReorderItems)
    ItemContainerStyle = property(get_ItemContainerStyle, put_ItemContainerStyle)
    ItemContainerStyleSelector = property(get_ItemContainerStyleSelector, put_ItemContainerStyleSelector)
    ItemContainerTransitions = property(get_ItemContainerTransitions, put_ItemContainerTransitions)
    ItemTemplate = property(get_ItemTemplate, put_ItemTemplate)
    ItemTemplateSelector = property(get_ItemTemplateSelector, put_ItemTemplateSelector)
    ItemsSource = property(get_ItemsSource, put_ItemsSource)
    SelectedItem = property(get_SelectedItem, put_SelectedItem)
    SelectedItems = property(get_SelectedItems, None)
    SelectedNode = property(get_SelectedNode, put_SelectedNode)
    DragItemsCompleted = event(add_DragItemsCompleted, remove_DragItemsCompleted)
    DragItemsStarting = event(add_DragItemsStarting, remove_DragItemsStarting)
class ITreeView3(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITreeView3'
    _iid_ = Guid('{a1b5538e-7956-5671-afd0-4c0f38122b70}')
    @winrt_commethod(6)
    def add_SelectionChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.TreeView, win32more.Microsoft.UI.Xaml.Controls.TreeViewSelectionChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(7)
    def remove_SelectionChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    SelectionChanged = event(add_SelectionChanged, remove_SelectionChanged)
class ITreeViewCollapsedEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITreeViewCollapsedEventArgs'
    _iid_ = Guid('{8ee00b59-42c6-5d73-809f-68710088e5a5}')
    @winrt_commethod(6)
    def get_Node(self) -> win32more.Microsoft.UI.Xaml.Controls.TreeViewNode: ...
    Node = property(get_Node, None)
class ITreeViewCollapsedEventArgs2(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITreeViewCollapsedEventArgs2'
    _iid_ = Guid('{77804a23-9feb-5c57-9c95-4dd984267217}')
    @winrt_commethod(6)
    def get_Item(self) -> IInspectable: ...
    Item = property(get_Item, None)
class ITreeViewDragItemsCompletedEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITreeViewDragItemsCompletedEventArgs'
    _iid_ = Guid('{e5b8547e-f839-55db-9c26-2a95f57a60dc}')
    @winrt_commethod(6)
    def get_DropResult(self) -> win32more.Windows.ApplicationModel.DataTransfer.DataPackageOperation: ...
    @winrt_commethod(7)
    def get_Items(self) -> win32more.Windows.Foundation.Collections.IVectorView[IInspectable]: ...
    DropResult = property(get_DropResult, None)
    Items = property(get_Items, None)
class ITreeViewDragItemsCompletedEventArgs2(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITreeViewDragItemsCompletedEventArgs2'
    _iid_ = Guid('{060d3921-57a0-5bc5-be26-320bd9c1a6e8}')
    @winrt_commethod(6)
    def get_NewParentItem(self) -> IInspectable: ...
    NewParentItem = property(get_NewParentItem, None)
class ITreeViewDragItemsStartingEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITreeViewDragItemsStartingEventArgs'
    _iid_ = Guid('{1b6c4ffc-cd32-5e06-b782-df9f077546c7}')
    @winrt_commethod(6)
    def get_Cancel(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_Cancel(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def get_Data(self) -> win32more.Windows.ApplicationModel.DataTransfer.DataPackage: ...
    @winrt_commethod(9)
    def get_Items(self) -> win32more.Windows.Foundation.Collections.IVector[IInspectable]: ...
    Cancel = property(get_Cancel, put_Cancel)
    Data = property(get_Data, None)
    Items = property(get_Items, None)
class ITreeViewExpandingEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITreeViewExpandingEventArgs'
    _iid_ = Guid('{bd769ef7-cadc-5334-93ad-c9bbe820643d}')
    @winrt_commethod(6)
    def get_Node(self) -> win32more.Microsoft.UI.Xaml.Controls.TreeViewNode: ...
    Node = property(get_Node, None)
class ITreeViewExpandingEventArgs2(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITreeViewExpandingEventArgs2'
    _iid_ = Guid('{ed7840e5-dbf5-5937-89dd-997a6fde0d5c}')
    @winrt_commethod(6)
    def get_Item(self) -> IInspectable: ...
    Item = property(get_Item, None)
class ITreeViewFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITreeViewFactory'
    _iid_ = Guid('{9c6220be-f9eb-518a-b30e-7e41de5efda9}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.TreeView: ...
class ITreeViewItem(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITreeViewItem'
    _iid_ = Guid('{70437a49-2999-5a97-b19d-354ef59d4f5c}')
    @winrt_commethod(6)
    def get_GlyphOpacity(self) -> Double: ...
    @winrt_commethod(7)
    def put_GlyphOpacity(self, value: Double) -> Void: ...
    @winrt_commethod(8)
    def get_GlyphBrush(self) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_commethod(9)
    def put_GlyphBrush(self, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_commethod(10)
    def get_ExpandedGlyph(self) -> hstr: ...
    @winrt_commethod(11)
    def put_ExpandedGlyph(self, value: hstr) -> Void: ...
    @winrt_commethod(12)
    def get_CollapsedGlyph(self) -> hstr: ...
    @winrt_commethod(13)
    def put_CollapsedGlyph(self, value: hstr) -> Void: ...
    @winrt_commethod(14)
    def get_GlyphSize(self) -> Double: ...
    @winrt_commethod(15)
    def put_GlyphSize(self, value: Double) -> Void: ...
    @winrt_commethod(16)
    def get_IsExpanded(self) -> Boolean: ...
    @winrt_commethod(17)
    def put_IsExpanded(self, value: Boolean) -> Void: ...
    @winrt_commethod(18)
    def get_TreeViewItemTemplateSettings(self) -> win32more.Microsoft.UI.Xaml.Controls.TreeViewItemTemplateSettings: ...
    CollapsedGlyph = property(get_CollapsedGlyph, put_CollapsedGlyph)
    ExpandedGlyph = property(get_ExpandedGlyph, put_ExpandedGlyph)
    GlyphBrush = property(get_GlyphBrush, put_GlyphBrush)
    GlyphOpacity = property(get_GlyphOpacity, put_GlyphOpacity)
    GlyphSize = property(get_GlyphSize, put_GlyphSize)
    IsExpanded = property(get_IsExpanded, put_IsExpanded)
    TreeViewItemTemplateSettings = property(get_TreeViewItemTemplateSettings, None)
class ITreeViewItem2(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITreeViewItem2'
    _iid_ = Guid('{b1b70143-3f5b-54f4-8bd7-41dc15cf45a9}')
    @winrt_commethod(6)
    def get_HasUnrealizedChildren(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_HasUnrealizedChildren(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def get_ItemsSource(self) -> IInspectable: ...
    @winrt_commethod(9)
    def put_ItemsSource(self, value: IInspectable) -> Void: ...
    HasUnrealizedChildren = property(get_HasUnrealizedChildren, put_HasUnrealizedChildren)
    ItemsSource = property(get_ItemsSource, put_ItemsSource)
class ITreeViewItemFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITreeViewItemFactory'
    _iid_ = Guid('{878fd918-e77e-5be8-8c8a-b79b27b08d9b}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.TreeViewItem: ...
class ITreeViewItemInvokedEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITreeViewItemInvokedEventArgs'
    _iid_ = Guid('{1a05853c-b101-542c-9a1e-775a044c4652}')
    @winrt_commethod(6)
    def get_InvokedItem(self) -> IInspectable: ...
    @winrt_commethod(7)
    def put_Handled(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def get_Handled(self) -> Boolean: ...
    Handled = property(get_Handled, put_Handled)
    InvokedItem = property(get_InvokedItem, None)
class ITreeViewItemStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITreeViewItemStatics'
    _iid_ = Guid('{efdb238d-2cca-589c-aedf-8e297b5aa248}')
    @winrt_commethod(6)
    def get_GlyphOpacityProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_GlyphBrushProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_ExpandedGlyphProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_CollapsedGlyphProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_GlyphSizeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_IsExpandedProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_TreeViewItemTemplateSettingsProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    CollapsedGlyphProperty = property(get_CollapsedGlyphProperty, None)
    ExpandedGlyphProperty = property(get_ExpandedGlyphProperty, None)
    GlyphBrushProperty = property(get_GlyphBrushProperty, None)
    GlyphOpacityProperty = property(get_GlyphOpacityProperty, None)
    GlyphSizeProperty = property(get_GlyphSizeProperty, None)
    IsExpandedProperty = property(get_IsExpandedProperty, None)
    TreeViewItemTemplateSettingsProperty = property(get_TreeViewItemTemplateSettingsProperty, None)
class ITreeViewItemStatics2(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITreeViewItemStatics2'
    _iid_ = Guid('{431bef52-d60d-5ce3-b812-aee4a2fb7ed3}')
    @winrt_commethod(6)
    def get_HasUnrealizedChildrenProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_ItemsSourceProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    HasUnrealizedChildrenProperty = property(get_HasUnrealizedChildrenProperty, None)
    ItemsSourceProperty = property(get_ItemsSourceProperty, None)
class ITreeViewItemTemplateSettings(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITreeViewItemTemplateSettings'
    _iid_ = Guid('{29b5dd9c-2bfb-5e1c-97cb-cdc3c34a365d}')
    @winrt_commethod(6)
    def get_ExpandedGlyphVisibility(self) -> win32more.Microsoft.UI.Xaml.Visibility: ...
    @winrt_commethod(7)
    def get_CollapsedGlyphVisibility(self) -> win32more.Microsoft.UI.Xaml.Visibility: ...
    @winrt_commethod(8)
    def get_Indentation(self) -> win32more.Microsoft.UI.Xaml.Thickness: ...
    @winrt_commethod(9)
    def get_DragItemsCount(self) -> Int32: ...
    CollapsedGlyphVisibility = property(get_CollapsedGlyphVisibility, None)
    DragItemsCount = property(get_DragItemsCount, None)
    ExpandedGlyphVisibility = property(get_ExpandedGlyphVisibility, None)
    Indentation = property(get_Indentation, None)
class ITreeViewItemTemplateSettingsFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITreeViewItemTemplateSettingsFactory'
    _iid_ = Guid('{1d1a66e3-f56d-5d7f-942c-f3a87f5c552e}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.TreeViewItemTemplateSettings: ...
class ITreeViewItemTemplateSettingsStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITreeViewItemTemplateSettingsStatics'
    _iid_ = Guid('{67817566-6528-5f4a-b1e1-710ab094c74f}')
    @winrt_commethod(6)
    def get_ExpandedGlyphVisibilityProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_CollapsedGlyphVisibilityProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_IndentationProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_DragItemsCountProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    CollapsedGlyphVisibilityProperty = property(get_CollapsedGlyphVisibilityProperty, None)
    DragItemsCountProperty = property(get_DragItemsCountProperty, None)
    ExpandedGlyphVisibilityProperty = property(get_ExpandedGlyphVisibilityProperty, None)
    IndentationProperty = property(get_IndentationProperty, None)
class ITreeViewList(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITreeViewList'
    _iid_ = Guid('{94cee57b-7085-5a6a-aac3-184509b8ece0}')
class ITreeViewListFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITreeViewListFactory'
    _iid_ = Guid('{461499a0-68cf-5b81-b0e4-b1af929b0b12}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.TreeViewList: ...
class ITreeViewNode(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITreeViewNode'
    _iid_ = Guid('{00378a74-790b-5328-8afa-7d65e22da426}')
    @winrt_commethod(6)
    def get_Content(self) -> IInspectable: ...
    @winrt_commethod(7)
    def put_Content(self, value: IInspectable) -> Void: ...
    @winrt_commethod(8)
    def get_Parent(self) -> win32more.Microsoft.UI.Xaml.Controls.TreeViewNode: ...
    @winrt_commethod(9)
    def get_IsExpanded(self) -> Boolean: ...
    @winrt_commethod(10)
    def put_IsExpanded(self, value: Boolean) -> Void: ...
    @winrt_commethod(11)
    def get_HasChildren(self) -> Boolean: ...
    @winrt_commethod(12)
    def get_Depth(self) -> Int32: ...
    @winrt_commethod(13)
    def get_HasUnrealizedChildren(self) -> Boolean: ...
    @winrt_commethod(14)
    def put_HasUnrealizedChildren(self, value: Boolean) -> Void: ...
    @winrt_commethod(15)
    def get_Children(self) -> win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.TreeViewNode]: ...
    Children = property(get_Children, None)
    Content = property(get_Content, put_Content)
    Depth = property(get_Depth, None)
    HasChildren = property(get_HasChildren, None)
    HasUnrealizedChildren = property(get_HasUnrealizedChildren, put_HasUnrealizedChildren)
    IsExpanded = property(get_IsExpanded, put_IsExpanded)
    Parent = property(get_Parent, None)
class ITreeViewNodeFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITreeViewNodeFactory'
    _iid_ = Guid('{c105a5e5-cea8-5efd-8be8-3d89b54cbd5f}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.TreeViewNode: ...
class ITreeViewNodeStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITreeViewNodeStatics'
    _iid_ = Guid('{f5bb217c-66b9-5b62-b2d6-fb47843c8f6f}')
    @winrt_commethod(6)
    def get_ContentProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_DepthProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_IsExpandedProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_HasChildrenProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    ContentProperty = property(get_ContentProperty, None)
    DepthProperty = property(get_DepthProperty, None)
    HasChildrenProperty = property(get_HasChildrenProperty, None)
    IsExpandedProperty = property(get_IsExpandedProperty, None)
class ITreeViewSelectionChangedEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITreeViewSelectionChangedEventArgs'
    _iid_ = Guid('{664190f3-7133-5599-b41c-1d54cd2cb930}')
    @winrt_commethod(6)
    def get_AddedItems(self) -> win32more.Windows.Foundation.Collections.IVector[IInspectable]: ...
    @winrt_commethod(7)
    def get_RemovedItems(self) -> win32more.Windows.Foundation.Collections.IVector[IInspectable]: ...
    AddedItems = property(get_AddedItems, None)
    RemovedItems = property(get_RemovedItems, None)
class ITreeViewStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITreeViewStatics'
    _iid_ = Guid('{71efaf86-4d73-5f5f-8ea6-a42dfe044917}')
    @winrt_commethod(6)
    def get_SelectedItemProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_SelectionModeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    SelectedItemProperty = property(get_SelectedItemProperty, None)
    SelectionModeProperty = property(get_SelectionModeProperty, None)
class ITreeViewStatics2(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITreeViewStatics2'
    _iid_ = Guid('{ddd01c44-a883-583b-9181-dca583da0ad9}')
    @winrt_commethod(6)
    def get_CanDragItemsProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_CanReorderItemsProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_ItemTemplateProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_ItemTemplateSelectorProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_ItemContainerStyleProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_ItemContainerStyleSelectorProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_ItemContainerTransitionsProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_ItemsSourceProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    CanDragItemsProperty = property(get_CanDragItemsProperty, None)
    CanReorderItemsProperty = property(get_CanReorderItemsProperty, None)
    ItemContainerStyleProperty = property(get_ItemContainerStyleProperty, None)
    ItemContainerStyleSelectorProperty = property(get_ItemContainerStyleSelectorProperty, None)
    ItemContainerTransitionsProperty = property(get_ItemContainerTransitionsProperty, None)
    ItemTemplateProperty = property(get_ItemTemplateProperty, None)
    ItemTemplateSelectorProperty = property(get_ItemTemplateSelectorProperty, None)
    ItemsSourceProperty = property(get_ItemsSourceProperty, None)
class ITwoPaneView(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITwoPaneView'
    _iid_ = Guid('{8d2e56d9-c333-5f15-81d1-b8b27e076522}')
    @winrt_commethod(6)
    def get_Pane1(self) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_commethod(7)
    def put_Pane1(self, value: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    @winrt_commethod(8)
    def get_Pane2(self) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_commethod(9)
    def put_Pane2(self, value: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    @winrt_commethod(10)
    def get_Pane1Length(self) -> win32more.Microsoft.UI.Xaml.GridLength: ...
    @winrt_commethod(11)
    def put_Pane1Length(self, value: win32more.Microsoft.UI.Xaml.GridLength) -> Void: ...
    @winrt_commethod(12)
    def get_Pane2Length(self) -> win32more.Microsoft.UI.Xaml.GridLength: ...
    @winrt_commethod(13)
    def put_Pane2Length(self, value: win32more.Microsoft.UI.Xaml.GridLength) -> Void: ...
    @winrt_commethod(14)
    def get_PanePriority(self) -> win32more.Microsoft.UI.Xaml.Controls.TwoPaneViewPriority: ...
    @winrt_commethod(15)
    def put_PanePriority(self, value: win32more.Microsoft.UI.Xaml.Controls.TwoPaneViewPriority) -> Void: ...
    @winrt_commethod(16)
    def get_Mode(self) -> win32more.Microsoft.UI.Xaml.Controls.TwoPaneViewMode: ...
    @winrt_commethod(17)
    def get_WideModeConfiguration(self) -> win32more.Microsoft.UI.Xaml.Controls.TwoPaneViewWideModeConfiguration: ...
    @winrt_commethod(18)
    def put_WideModeConfiguration(self, value: win32more.Microsoft.UI.Xaml.Controls.TwoPaneViewWideModeConfiguration) -> Void: ...
    @winrt_commethod(19)
    def get_TallModeConfiguration(self) -> win32more.Microsoft.UI.Xaml.Controls.TwoPaneViewTallModeConfiguration: ...
    @winrt_commethod(20)
    def put_TallModeConfiguration(self, value: win32more.Microsoft.UI.Xaml.Controls.TwoPaneViewTallModeConfiguration) -> Void: ...
    @winrt_commethod(21)
    def get_MinWideModeWidth(self) -> Double: ...
    @winrt_commethod(22)
    def put_MinWideModeWidth(self, value: Double) -> Void: ...
    @winrt_commethod(23)
    def get_MinTallModeHeight(self) -> Double: ...
    @winrt_commethod(24)
    def put_MinTallModeHeight(self, value: Double) -> Void: ...
    @winrt_commethod(25)
    def add_ModeChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.TwoPaneView, IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(26)
    def remove_ModeChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    MinTallModeHeight = property(get_MinTallModeHeight, put_MinTallModeHeight)
    MinWideModeWidth = property(get_MinWideModeWidth, put_MinWideModeWidth)
    Mode = property(get_Mode, None)
    Pane1 = property(get_Pane1, put_Pane1)
    Pane1Length = property(get_Pane1Length, put_Pane1Length)
    Pane2 = property(get_Pane2, put_Pane2)
    Pane2Length = property(get_Pane2Length, put_Pane2Length)
    PanePriority = property(get_PanePriority, put_PanePriority)
    TallModeConfiguration = property(get_TallModeConfiguration, put_TallModeConfiguration)
    WideModeConfiguration = property(get_WideModeConfiguration, put_WideModeConfiguration)
    ModeChanged = event(add_ModeChanged, remove_ModeChanged)
class ITwoPaneViewFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITwoPaneViewFactory'
    _iid_ = Guid('{0f1af0cd-f3dc-52f6-b632-396742533231}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.TwoPaneView: ...
class ITwoPaneViewStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.ITwoPaneViewStatics'
    _iid_ = Guid('{4fbd51c3-cee6-58de-a5e4-99abad873016}')
    @winrt_commethod(6)
    def get_Pane1Property(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_Pane2Property(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_Pane1LengthProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_Pane2LengthProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_PanePriorityProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_ModeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_WideModeConfigurationProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_TallModeConfigurationProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(14)
    def get_MinWideModeWidthProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(15)
    def get_MinTallModeHeightProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    MinTallModeHeightProperty = property(get_MinTallModeHeightProperty, None)
    MinWideModeWidthProperty = property(get_MinWideModeWidthProperty, None)
    ModeProperty = property(get_ModeProperty, None)
    Pane1LengthProperty = property(get_Pane1LengthProperty, None)
    Pane1Property = property(get_Pane1Property, None)
    Pane2LengthProperty = property(get_Pane2LengthProperty, None)
    Pane2Property = property(get_Pane2Property, None)
    PanePriorityProperty = property(get_PanePriorityProperty, None)
    TallModeConfigurationProperty = property(get_TallModeConfigurationProperty, None)
    WideModeConfigurationProperty = property(get_WideModeConfigurationProperty, None)
class IUIElementCollection(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IUIElementCollection'
    _iid_ = Guid('{23050cb1-db88-54ed-9083-5ecfb12512fd}')
    @winrt_commethod(6)
    def Move(self, oldIndex: UInt32, newIndex: UInt32) -> Void: ...
class IUniformGridLayout(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IUniformGridLayout'
    _iid_ = Guid('{8a164cbc-2a5e-56e5-a011-fb76334aabdf}')
    @winrt_commethod(6)
    def get_Orientation(self) -> win32more.Microsoft.UI.Xaml.Controls.Orientation: ...
    @winrt_commethod(7)
    def put_Orientation(self, value: win32more.Microsoft.UI.Xaml.Controls.Orientation) -> Void: ...
    @winrt_commethod(8)
    def get_MinItemWidth(self) -> Double: ...
    @winrt_commethod(9)
    def put_MinItemWidth(self, value: Double) -> Void: ...
    @winrt_commethod(10)
    def get_MinItemHeight(self) -> Double: ...
    @winrt_commethod(11)
    def put_MinItemHeight(self, value: Double) -> Void: ...
    @winrt_commethod(12)
    def get_MinRowSpacing(self) -> Double: ...
    @winrt_commethod(13)
    def put_MinRowSpacing(self, value: Double) -> Void: ...
    @winrt_commethod(14)
    def get_MinColumnSpacing(self) -> Double: ...
    @winrt_commethod(15)
    def put_MinColumnSpacing(self, value: Double) -> Void: ...
    @winrt_commethod(16)
    def get_ItemsJustification(self) -> win32more.Microsoft.UI.Xaml.Controls.UniformGridLayoutItemsJustification: ...
    @winrt_commethod(17)
    def put_ItemsJustification(self, value: win32more.Microsoft.UI.Xaml.Controls.UniformGridLayoutItemsJustification) -> Void: ...
    @winrt_commethod(18)
    def get_ItemsStretch(self) -> win32more.Microsoft.UI.Xaml.Controls.UniformGridLayoutItemsStretch: ...
    @winrt_commethod(19)
    def put_ItemsStretch(self, value: win32more.Microsoft.UI.Xaml.Controls.UniformGridLayoutItemsStretch) -> Void: ...
    @winrt_commethod(20)
    def get_MaximumRowsOrColumns(self) -> Int32: ...
    @winrt_commethod(21)
    def put_MaximumRowsOrColumns(self, value: Int32) -> Void: ...
    ItemsJustification = property(get_ItemsJustification, put_ItemsJustification)
    ItemsStretch = property(get_ItemsStretch, put_ItemsStretch)
    MaximumRowsOrColumns = property(get_MaximumRowsOrColumns, put_MaximumRowsOrColumns)
    MinColumnSpacing = property(get_MinColumnSpacing, put_MinColumnSpacing)
    MinItemHeight = property(get_MinItemHeight, put_MinItemHeight)
    MinItemWidth = property(get_MinItemWidth, put_MinItemWidth)
    MinRowSpacing = property(get_MinRowSpacing, put_MinRowSpacing)
    Orientation = property(get_Orientation, put_Orientation)
class IUniformGridLayoutFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IUniformGridLayoutFactory'
    _iid_ = Guid('{0d9ed808-f3f9-5034-9627-152b91e91b4b}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.UniformGridLayout: ...
class IUniformGridLayoutStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IUniformGridLayoutStatics'
    _iid_ = Guid('{19be9a3e-37e1-5a6d-8b62-419325ea705a}')
    @winrt_commethod(6)
    def get_OrientationProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_MinItemWidthProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_MinItemHeightProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_MinRowSpacingProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_MinColumnSpacingProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_ItemsJustificationProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_ItemsStretchProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def get_MaximumRowsOrColumnsProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    ItemsJustificationProperty = property(get_ItemsJustificationProperty, None)
    ItemsStretchProperty = property(get_ItemsStretchProperty, None)
    MaximumRowsOrColumnsProperty = property(get_MaximumRowsOrColumnsProperty, None)
    MinColumnSpacingProperty = property(get_MinColumnSpacingProperty, None)
    MinItemHeightProperty = property(get_MinItemHeightProperty, None)
    MinItemWidthProperty = property(get_MinItemWidthProperty, None)
    MinRowSpacingProperty = property(get_MinRowSpacingProperty, None)
    OrientationProperty = property(get_OrientationProperty, None)
class IUserControl(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IUserControl'
    _iid_ = Guid('{ab8a0a51-44cf-5337-ad77-8eda1795e9f6}')
    @winrt_commethod(6)
    def get_Content(self) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_commethod(7)
    def put_Content(self, value: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    Content = property(get_Content, put_Content)
class IUserControlFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IUserControlFactory'
    _iid_ = Guid('{61ac9074-aab3-50b8-8b18-d4d2573a5235}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.UserControl: ...
class IUserControlStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IUserControlStatics'
    _iid_ = Guid('{575e8fa1-2e2d-5857-9a93-6b11e54316ba}')
    @winrt_commethod(6)
    def get_ContentProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    ContentProperty = property(get_ContentProperty, None)
class IVariableSizedWrapGrid(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IVariableSizedWrapGrid'
    _iid_ = Guid('{bfecd12b-e16a-58a0-af5f-4672627462d5}')
    @winrt_commethod(6)
    def get_ItemHeight(self) -> Double: ...
    @winrt_commethod(7)
    def put_ItemHeight(self, value: Double) -> Void: ...
    @winrt_commethod(8)
    def get_ItemWidth(self) -> Double: ...
    @winrt_commethod(9)
    def put_ItemWidth(self, value: Double) -> Void: ...
    @winrt_commethod(10)
    def get_Orientation(self) -> win32more.Microsoft.UI.Xaml.Controls.Orientation: ...
    @winrt_commethod(11)
    def put_Orientation(self, value: win32more.Microsoft.UI.Xaml.Controls.Orientation) -> Void: ...
    @winrt_commethod(12)
    def get_HorizontalChildrenAlignment(self) -> win32more.Microsoft.UI.Xaml.HorizontalAlignment: ...
    @winrt_commethod(13)
    def put_HorizontalChildrenAlignment(self, value: win32more.Microsoft.UI.Xaml.HorizontalAlignment) -> Void: ...
    @winrt_commethod(14)
    def get_VerticalChildrenAlignment(self) -> win32more.Microsoft.UI.Xaml.VerticalAlignment: ...
    @winrt_commethod(15)
    def put_VerticalChildrenAlignment(self, value: win32more.Microsoft.UI.Xaml.VerticalAlignment) -> Void: ...
    @winrt_commethod(16)
    def get_MaximumRowsOrColumns(self) -> Int32: ...
    @winrt_commethod(17)
    def put_MaximumRowsOrColumns(self, value: Int32) -> Void: ...
    HorizontalChildrenAlignment = property(get_HorizontalChildrenAlignment, put_HorizontalChildrenAlignment)
    ItemHeight = property(get_ItemHeight, put_ItemHeight)
    ItemWidth = property(get_ItemWidth, put_ItemWidth)
    MaximumRowsOrColumns = property(get_MaximumRowsOrColumns, put_MaximumRowsOrColumns)
    Orientation = property(get_Orientation, put_Orientation)
    VerticalChildrenAlignment = property(get_VerticalChildrenAlignment, put_VerticalChildrenAlignment)
class IVariableSizedWrapGridStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IVariableSizedWrapGridStatics'
    _iid_ = Guid('{0d979fe6-64af-5af5-914a-dd38f2ccf2d7}')
    @winrt_commethod(6)
    def get_ItemHeightProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_ItemWidthProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_OrientationProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_HorizontalChildrenAlignmentProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_VerticalChildrenAlignmentProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_MaximumRowsOrColumnsProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def get_RowSpanProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(13)
    def GetRowSpan(self, element: win32more.Microsoft.UI.Xaml.UIElement) -> Int32: ...
    @winrt_commethod(14)
    def SetRowSpan(self, element: win32more.Microsoft.UI.Xaml.UIElement, value: Int32) -> Void: ...
    @winrt_commethod(15)
    def get_ColumnSpanProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(16)
    def GetColumnSpan(self, element: win32more.Microsoft.UI.Xaml.UIElement) -> Int32: ...
    @winrt_commethod(17)
    def SetColumnSpan(self, element: win32more.Microsoft.UI.Xaml.UIElement, value: Int32) -> Void: ...
    ColumnSpanProperty = property(get_ColumnSpanProperty, None)
    HorizontalChildrenAlignmentProperty = property(get_HorizontalChildrenAlignmentProperty, None)
    ItemHeightProperty = property(get_ItemHeightProperty, None)
    ItemWidthProperty = property(get_ItemWidthProperty, None)
    MaximumRowsOrColumnsProperty = property(get_MaximumRowsOrColumnsProperty, None)
    OrientationProperty = property(get_OrientationProperty, None)
    RowSpanProperty = property(get_RowSpanProperty, None)
    VerticalChildrenAlignmentProperty = property(get_VerticalChildrenAlignmentProperty, None)
class IViewbox(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IViewbox'
    _iid_ = Guid('{510683e8-d0fe-5ef4-85bd-e1131076ac22}')
    @winrt_commethod(6)
    def get_Child(self) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_commethod(7)
    def put_Child(self, value: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    @winrt_commethod(8)
    def get_Stretch(self) -> win32more.Microsoft.UI.Xaml.Media.Stretch: ...
    @winrt_commethod(9)
    def put_Stretch(self, value: win32more.Microsoft.UI.Xaml.Media.Stretch) -> Void: ...
    @winrt_commethod(10)
    def get_StretchDirection(self) -> win32more.Microsoft.UI.Xaml.Controls.StretchDirection: ...
    @winrt_commethod(11)
    def put_StretchDirection(self, value: win32more.Microsoft.UI.Xaml.Controls.StretchDirection) -> Void: ...
    Child = property(get_Child, put_Child)
    Stretch = property(get_Stretch, put_Stretch)
    StretchDirection = property(get_StretchDirection, put_StretchDirection)
class IViewboxStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IViewboxStatics'
    _iid_ = Guid('{0466c103-1e17-5e83-a262-8855f216b59f}')
    @winrt_commethod(6)
    def get_StretchProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_StretchDirectionProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    StretchDirectionProperty = property(get_StretchDirectionProperty, None)
    StretchProperty = property(get_StretchProperty, None)
class IVirtualizingLayout(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IVirtualizingLayout'
    _iid_ = Guid('{54857ce0-b9e6-51a3-bfa8-dcd8ee306d5c}')
class IVirtualizingLayoutContext(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IVirtualizingLayoutContext'
    _iid_ = Guid('{5b5b186a-a7f9-5a2e-b1f0-8950ccd97350}')
    @winrt_commethod(6)
    def get_ItemCount(self) -> Int32: ...
    @winrt_commethod(7)
    def GetItemAt(self, index: Int32) -> IInspectable: ...
    @winrt_commethod(8)
    def get_RealizationRect(self) -> win32more.Windows.Foundation.Rect: ...
    @winrt_commethod(9)
    def GetOrCreateElementAt(self, index: Int32) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_commethod(10)
    def GetOrCreateElementAt2(self, index: Int32, options: win32more.Microsoft.UI.Xaml.Controls.ElementRealizationOptions) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_commethod(11)
    def RecycleElement(self, element: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    @winrt_commethod(12)
    def get_RecommendedAnchorIndex(self) -> Int32: ...
    @winrt_commethod(13)
    def get_LayoutOrigin(self) -> win32more.Windows.Foundation.Point: ...
    @winrt_commethod(14)
    def put_LayoutOrigin(self, value: win32more.Windows.Foundation.Point) -> Void: ...
    ItemCount = property(get_ItemCount, None)
    LayoutOrigin = property(get_LayoutOrigin, put_LayoutOrigin)
    RealizationRect = property(get_RealizationRect, None)
    RecommendedAnchorIndex = property(get_RecommendedAnchorIndex, None)
class IVirtualizingLayoutContext2(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IVirtualizingLayoutContext2'
    _iid_ = Guid('{c34e5864-a883-59be-8ce0-4a77e87b0343}')
    @winrt_commethod(6)
    def get_VisibleRect(self) -> win32more.Windows.Foundation.Rect: ...
    VisibleRect = property(get_VisibleRect, None)
class IVirtualizingLayoutContextFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IVirtualizingLayoutContextFactory'
    _iid_ = Guid('{3f790b67-fdfb-505a-8b85-6210506df311}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.VirtualizingLayoutContext: ...
class IVirtualizingLayoutContextOverrides(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IVirtualizingLayoutContextOverrides'
    _iid_ = Guid('{78633b2a-9633-5086-89a7-0e960a95a3b2}')
    @winrt_commethod(6)
    def ItemCountCore(self) -> Int32: ...
    @winrt_commethod(7)
    def GetItemAtCore(self, index: Int32) -> IInspectable: ...
    @winrt_commethod(8)
    def RealizationRectCore(self) -> win32more.Windows.Foundation.Rect: ...
    @winrt_commethod(9)
    def GetOrCreateElementAtCore(self, index: Int32, options: win32more.Microsoft.UI.Xaml.Controls.ElementRealizationOptions) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_commethod(10)
    def RecycleElementCore(self, element: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    @winrt_commethod(11)
    def get_RecommendedAnchorIndexCore(self) -> Int32: ...
    @winrt_commethod(12)
    def get_LayoutOriginCore(self) -> win32more.Windows.Foundation.Point: ...
    @winrt_commethod(13)
    def put_LayoutOriginCore(self, value: win32more.Windows.Foundation.Point) -> Void: ...
    LayoutOriginCore = property(get_LayoutOriginCore, put_LayoutOriginCore)
    RecommendedAnchorIndexCore = property(get_RecommendedAnchorIndexCore, None)
class IVirtualizingLayoutContextOverrides2(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IVirtualizingLayoutContextOverrides2'
    _iid_ = Guid('{da384c25-5d8f-5ede-ae54-c318813ae784}')
    @winrt_commethod(6)
    def VisibleRectCore(self) -> win32more.Windows.Foundation.Rect: ...
class IVirtualizingLayoutFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IVirtualizingLayoutFactory'
    _iid_ = Guid('{c7c128e1-5df7-5345-b5cd-43afdfa948b4}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.VirtualizingLayout: ...
class IVirtualizingLayoutOverrides(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IVirtualizingLayoutOverrides'
    _iid_ = Guid('{4357a35b-3703-5819-a776-d139848e9ed9}')
    @winrt_commethod(6)
    def InitializeForContextCore(self, context: win32more.Microsoft.UI.Xaml.Controls.VirtualizingLayoutContext) -> Void: ...
    @winrt_commethod(7)
    def UninitializeForContextCore(self, context: win32more.Microsoft.UI.Xaml.Controls.VirtualizingLayoutContext) -> Void: ...
    @winrt_commethod(8)
    def MeasureOverride(self, context: win32more.Microsoft.UI.Xaml.Controls.VirtualizingLayoutContext, availableSize: win32more.Windows.Foundation.Size) -> win32more.Windows.Foundation.Size: ...
    @winrt_commethod(9)
    def ArrangeOverride(self, context: win32more.Microsoft.UI.Xaml.Controls.VirtualizingLayoutContext, finalSize: win32more.Windows.Foundation.Size) -> win32more.Windows.Foundation.Size: ...
    @winrt_commethod(10)
    def OnItemsChangedCore(self, context: win32more.Microsoft.UI.Xaml.Controls.VirtualizingLayoutContext, source: IInspectable, args: win32more.Microsoft.UI.Xaml.Interop.NotifyCollectionChangedEventArgs) -> Void: ...
class IVirtualizingPanel(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IVirtualizingPanel'
    _iid_ = Guid('{2b216a2d-5079-51ba-838a-9086903636b4}')
    @winrt_commethod(6)
    def get_ItemContainerGenerator(self) -> win32more.Microsoft.UI.Xaml.Controls.ItemContainerGenerator: ...
    ItemContainerGenerator = property(get_ItemContainerGenerator, None)
class IVirtualizingPanelFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IVirtualizingPanelFactory'
    _iid_ = Guid('{32e8c71b-b58c-5f19-9bd5-eeca5860f387}')
class IVirtualizingPanelOverrides(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IVirtualizingPanelOverrides'
    _iid_ = Guid('{3ffe2108-0382-50c8-b295-21bd8bee04d7}')
    @winrt_commethod(6)
    def OnItemsChanged(self, sender: IInspectable, args: win32more.Microsoft.UI.Xaml.Controls.Primitives.ItemsChangedEventArgs) -> Void: ...
    @winrt_commethod(7)
    def OnClearChildren(self) -> Void: ...
    @winrt_commethod(8)
    def BringIndexIntoView(self, index: Int32) -> Void: ...
class IVirtualizingPanelProtected(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IVirtualizingPanelProtected'
    _iid_ = Guid('{bc4579f5-fdc8-5da2-a98a-f44c13c073d3}')
    @winrt_commethod(6)
    def AddInternalChild(self, child: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    @winrt_commethod(7)
    def InsertInternalChild(self, index: Int32, child: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    @winrt_commethod(8)
    def RemoveInternalChildRange(self, index: Int32, range: Int32) -> Void: ...
class IVirtualizingStackPanel(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IVirtualizingStackPanel'
    _iid_ = Guid('{7d6103dc-2427-5576-9a69-bf53e2d7180b}')
    @winrt_commethod(6)
    def get_AreScrollSnapPointsRegular(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_AreScrollSnapPointsRegular(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def get_Orientation(self) -> win32more.Microsoft.UI.Xaml.Controls.Orientation: ...
    @winrt_commethod(9)
    def put_Orientation(self, value: win32more.Microsoft.UI.Xaml.Controls.Orientation) -> Void: ...
    @winrt_commethod(10)
    def add_CleanUpVirtualizedItemEvent(self, handler: win32more.Microsoft.UI.Xaml.Controls.CleanUpVirtualizedItemEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(11)
    def remove_CleanUpVirtualizedItemEvent(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    AreScrollSnapPointsRegular = property(get_AreScrollSnapPointsRegular, put_AreScrollSnapPointsRegular)
    Orientation = property(get_Orientation, put_Orientation)
    CleanUpVirtualizedItemEvent = event(add_CleanUpVirtualizedItemEvent, remove_CleanUpVirtualizedItemEvent)
class IVirtualizingStackPanelOverrides(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IVirtualizingStackPanelOverrides'
    _iid_ = Guid('{8fee3e46-6e2f-5c0a-9a3b-c0b659818801}')
    @winrt_commethod(6)
    def OnCleanUpVirtualizedItem(self, e: win32more.Microsoft.UI.Xaml.Controls.CleanUpVirtualizedItemEventArgs) -> Void: ...
class IVirtualizingStackPanelStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IVirtualizingStackPanelStatics'
    _iid_ = Guid('{731cc881-a71a-5af9-985e-1ede3d88c274}')
    @winrt_commethod(6)
    def get_AreScrollSnapPointsRegularProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_OrientationProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_VirtualizationModeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def GetVirtualizationMode(self, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> win32more.Microsoft.UI.Xaml.Controls.VirtualizationMode: ...
    @winrt_commethod(10)
    def SetVirtualizationMode(self, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: win32more.Microsoft.UI.Xaml.Controls.VirtualizationMode) -> Void: ...
    @winrt_commethod(11)
    def get_IsVirtualizingProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(12)
    def GetIsVirtualizing(self, o: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    AreScrollSnapPointsRegularProperty = property(get_AreScrollSnapPointsRegularProperty, None)
    IsVirtualizingProperty = property(get_IsVirtualizingProperty, None)
    OrientationProperty = property(get_OrientationProperty, None)
    VirtualizationModeProperty = property(get_VirtualizationModeProperty, None)
class IWebView2(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IWebView2'
    _iid_ = Guid('{2b2c76c2-997c-5069-a8f0-9b84cd7e624b}')
    @winrt_commethod(6)
    def get_CoreWebView2(self) -> win32more.Microsoft.Web.WebView2.Core.CoreWebView2: ...
    @winrt_commethod(7)
    def EnsureCoreWebView2Async(self) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(8)
    def ExecuteScriptAsync(self, javascriptCode: hstr) -> win32more.Windows.Foundation.IAsyncOperation[hstr]: ...
    @winrt_commethod(9)
    def get_Source(self) -> win32more.Windows.Foundation.Uri: ...
    @winrt_commethod(10)
    def put_Source(self, value: win32more.Windows.Foundation.Uri) -> Void: ...
    @winrt_commethod(11)
    def get_CanGoForward(self) -> Boolean: ...
    @winrt_commethod(12)
    def put_CanGoForward(self, value: Boolean) -> Void: ...
    @winrt_commethod(13)
    def get_CanGoBack(self) -> Boolean: ...
    @winrt_commethod(14)
    def put_CanGoBack(self, value: Boolean) -> Void: ...
    @winrt_commethod(15)
    def get_DefaultBackgroundColor(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(16)
    def put_DefaultBackgroundColor(self, value: win32more.Windows.UI.Color) -> Void: ...
    @winrt_commethod(17)
    def Reload(self) -> Void: ...
    @winrt_commethod(18)
    def GoForward(self) -> Void: ...
    @winrt_commethod(19)
    def GoBack(self) -> Void: ...
    @winrt_commethod(20)
    def NavigateToString(self, htmlContent: hstr) -> Void: ...
    @winrt_commethod(21)
    def Close(self) -> Void: ...
    @winrt_commethod(22)
    def add_NavigationCompleted(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.WebView2, win32more.Microsoft.Web.WebView2.Core.CoreWebView2NavigationCompletedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(23)
    def remove_NavigationCompleted(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(24)
    def add_WebMessageReceived(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.WebView2, win32more.Microsoft.Web.WebView2.Core.CoreWebView2WebMessageReceivedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(25)
    def remove_WebMessageReceived(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(26)
    def add_NavigationStarting(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.WebView2, win32more.Microsoft.Web.WebView2.Core.CoreWebView2NavigationStartingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(27)
    def remove_NavigationStarting(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(28)
    def add_CoreProcessFailed(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.WebView2, win32more.Microsoft.Web.WebView2.Core.CoreWebView2ProcessFailedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(29)
    def remove_CoreProcessFailed(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(30)
    def add_CoreWebView2Initialized(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.WebView2, win32more.Microsoft.UI.Xaml.Controls.CoreWebView2InitializedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(31)
    def remove_CoreWebView2Initialized(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    CanGoBack = property(get_CanGoBack, put_CanGoBack)
    CanGoForward = property(get_CanGoForward, put_CanGoForward)
    CoreWebView2 = property(get_CoreWebView2, None)
    DefaultBackgroundColor = property(get_DefaultBackgroundColor, put_DefaultBackgroundColor)
    Source = property(get_Source, put_Source)
    CoreProcessFailed = event(add_CoreProcessFailed, remove_CoreProcessFailed)
    CoreWebView2Initialized = event(add_CoreWebView2Initialized, remove_CoreWebView2Initialized)
    NavigationCompleted = event(add_NavigationCompleted, remove_NavigationCompleted)
    NavigationStarting = event(add_NavigationStarting, remove_NavigationStarting)
    WebMessageReceived = event(add_WebMessageReceived, remove_WebMessageReceived)
class IWebView22(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IWebView22'
    _iid_ = Guid('{560c5eed-3e7a-51e4-b14f-107ba02b89be}')
    @winrt_commethod(6)
    def EnsureCoreWebView2WithEnvironmentAsync(self, environment: win32more.Microsoft.Web.WebView2.Core.CoreWebView2Environment) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(7)
    def EnsureCoreWebView2WithEnvironmentAndOptionsAsync(self, environment: win32more.Microsoft.Web.WebView2.Core.CoreWebView2Environment, controllerOptions: win32more.Microsoft.Web.WebView2.Core.CoreWebView2ControllerOptions) -> win32more.Windows.Foundation.IAsyncAction: ...
class IWebView2Factory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IWebView2Factory'
    _iid_ = Guid('{fb4ec2ce-3074-5c42-b655-64fb81fbd040}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.WebView2: ...
class IWebView2Statics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IWebView2Statics'
    _iid_ = Guid('{7f3226d0-f6d5-5aa7-b175-645451ca3c85}')
    @winrt_commethod(6)
    def get_SourceProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_CanGoForwardProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_CanGoBackProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_DefaultBackgroundColorProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    CanGoBackProperty = property(get_CanGoBackProperty, None)
    CanGoForwardProperty = property(get_CanGoForwardProperty, None)
    DefaultBackgroundColorProperty = property(get_DefaultBackgroundColorProperty, None)
    SourceProperty = property(get_SourceProperty, None)
class IWrapGrid(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IWrapGrid'
    _iid_ = Guid('{2e570b6a-ff97-53b8-a887-348f59ee0544}')
    @winrt_commethod(6)
    def get_ItemWidth(self) -> Double: ...
    @winrt_commethod(7)
    def put_ItemWidth(self, value: Double) -> Void: ...
    @winrt_commethod(8)
    def get_ItemHeight(self) -> Double: ...
    @winrt_commethod(9)
    def put_ItemHeight(self, value: Double) -> Void: ...
    @winrt_commethod(10)
    def get_Orientation(self) -> win32more.Microsoft.UI.Xaml.Controls.Orientation: ...
    @winrt_commethod(11)
    def put_Orientation(self, value: win32more.Microsoft.UI.Xaml.Controls.Orientation) -> Void: ...
    @winrt_commethod(12)
    def get_HorizontalChildrenAlignment(self) -> win32more.Microsoft.UI.Xaml.HorizontalAlignment: ...
    @winrt_commethod(13)
    def put_HorizontalChildrenAlignment(self, value: win32more.Microsoft.UI.Xaml.HorizontalAlignment) -> Void: ...
    @winrt_commethod(14)
    def get_VerticalChildrenAlignment(self) -> win32more.Microsoft.UI.Xaml.VerticalAlignment: ...
    @winrt_commethod(15)
    def put_VerticalChildrenAlignment(self, value: win32more.Microsoft.UI.Xaml.VerticalAlignment) -> Void: ...
    @winrt_commethod(16)
    def get_MaximumRowsOrColumns(self) -> Int32: ...
    @winrt_commethod(17)
    def put_MaximumRowsOrColumns(self, value: Int32) -> Void: ...
    HorizontalChildrenAlignment = property(get_HorizontalChildrenAlignment, put_HorizontalChildrenAlignment)
    ItemHeight = property(get_ItemHeight, put_ItemHeight)
    ItemWidth = property(get_ItemWidth, put_ItemWidth)
    MaximumRowsOrColumns = property(get_MaximumRowsOrColumns, put_MaximumRowsOrColumns)
    Orientation = property(get_Orientation, put_Orientation)
    VerticalChildrenAlignment = property(get_VerticalChildrenAlignment, put_VerticalChildrenAlignment)
class IWrapGridStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IWrapGridStatics'
    _iid_ = Guid('{2fe223a8-018a-5d2f-933b-a7569f824f19}')
    @winrt_commethod(6)
    def get_ItemWidthProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_ItemHeightProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_OrientationProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_HorizontalChildrenAlignmentProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(10)
    def get_VerticalChildrenAlignmentProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(11)
    def get_MaximumRowsOrColumnsProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    HorizontalChildrenAlignmentProperty = property(get_HorizontalChildrenAlignmentProperty, None)
    ItemHeightProperty = property(get_ItemHeightProperty, None)
    ItemWidthProperty = property(get_ItemWidthProperty, None)
    MaximumRowsOrColumnsProperty = property(get_MaximumRowsOrColumnsProperty, None)
    OrientationProperty = property(get_OrientationProperty, None)
    VerticalChildrenAlignmentProperty = property(get_VerticalChildrenAlignmentProperty, None)
class IXamlControlsResources(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IXamlControlsResources'
    _iid_ = Guid('{918ca043-f42c-5805-861b-62d6d1d0c162}')
    @winrt_commethod(6)
    def get_UseCompactResources(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_UseCompactResources(self, value: Boolean) -> Void: ...
    UseCompactResources = property(get_UseCompactResources, put_UseCompactResources)
class IXamlControlsResourcesStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Controls.IXamlControlsResourcesStatics'
    _iid_ = Guid('{cb49196c-1458-5e92-b701-d08d3e816bc5}')
    @winrt_commethod(6)
    def EnsureRevealLights(self, element: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    @winrt_commethod(7)
    def get_UseCompactResourcesProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    UseCompactResourcesProperty = property(get_UseCompactResourcesProperty, None)
class _IconElement_Meta_(ComPtr.__class__):
    pass
class IconElement(ComPtr, metaclass=_IconElement_Meta_):
    extends: win32more.Microsoft.UI.Xaml.FrameworkElement
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IIconElement
    _classid_ = 'Microsoft.UI.Xaml.Controls.IconElement'
    @winrt_mixinmethod
    def get_Foreground(self: win32more.Microsoft.UI.Xaml.Controls.IIconElement) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_Foreground(self: win32more.Microsoft.UI.Xaml.Controls.IIconElement, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_classmethod
    def get_ForegroundProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IIconElementStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    Foreground = property(get_Foreground, put_Foreground)
    _IconElement_Meta_.ForegroundProperty = property(get_ForegroundProperty, None)
class _IconSource_Meta_(ComPtr.__class__):
    pass
class IconSource(ComPtr, metaclass=_IconSource_Meta_):
    extends: win32more.Microsoft.UI.Xaml.DependencyObject
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IIconSource
    _classid_ = 'Microsoft.UI.Xaml.Controls.IconSource'
    @winrt_mixinmethod
    def get_Foreground(self: win32more.Microsoft.UI.Xaml.Controls.IIconSource) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_Foreground(self: win32more.Microsoft.UI.Xaml.Controls.IIconSource, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def CreateIconElement(self: win32more.Microsoft.UI.Xaml.Controls.IIconSource) -> win32more.Microsoft.UI.Xaml.Controls.IconElement: ...
    @winrt_mixinmethod
    def CreateIconElementCore(self: win32more.Microsoft.UI.Xaml.Controls.IIconSourceOverrides) -> win32more.Microsoft.UI.Xaml.Controls.IconElement: ...
    @winrt_mixinmethod
    def GetIconElementPropertyCore(self: win32more.Microsoft.UI.Xaml.Controls.IIconSourceOverrides, iconSourceProperty: win32more.Microsoft.UI.Xaml.DependencyProperty) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ForegroundProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IIconSourceStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    Foreground = property(get_Foreground, put_Foreground)
    _IconSource_Meta_.ForegroundProperty = property(get_ForegroundProperty, None)
class _IconSourceElement_Meta_(ComPtr.__class__):
    pass
class IconSourceElement(ComPtr, metaclass=_IconSourceElement_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.IconElement
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IIconSourceElement
    _classid_ = 'Microsoft.UI.Xaml.Controls.IconSourceElement'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.IconSourceElement.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IIconSourceElementFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.IconSourceElement: ...
    @winrt_mixinmethod
    def get_IconSource(self: win32more.Microsoft.UI.Xaml.Controls.IIconSourceElement) -> win32more.Microsoft.UI.Xaml.Controls.IconSource: ...
    @winrt_mixinmethod
    def put_IconSource(self: win32more.Microsoft.UI.Xaml.Controls.IIconSourceElement, value: win32more.Microsoft.UI.Xaml.Controls.IconSource) -> Void: ...
    @winrt_classmethod
    def get_IconSourceProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IIconSourceElementStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    IconSource = property(get_IconSource, put_IconSource)
    _IconSourceElement_Meta_.IconSourceProperty = property(get_IconSourceProperty, None)
class _Image_Meta_(ComPtr.__class__):
    pass
class Image(ComPtr, metaclass=_Image_Meta_):
    extends: win32more.Microsoft.UI.Xaml.FrameworkElement
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IImage
    _classid_ = 'Microsoft.UI.Xaml.Controls.Image'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.Image.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Controls.Image: ...
    @winrt_mixinmethod
    def get_Source(self: win32more.Microsoft.UI.Xaml.Controls.IImage) -> win32more.Microsoft.UI.Xaml.Media.ImageSource: ...
    @winrt_mixinmethod
    def put_Source(self: win32more.Microsoft.UI.Xaml.Controls.IImage, value: win32more.Microsoft.UI.Xaml.Media.ImageSource) -> Void: ...
    @winrt_mixinmethod
    def get_Stretch(self: win32more.Microsoft.UI.Xaml.Controls.IImage) -> win32more.Microsoft.UI.Xaml.Media.Stretch: ...
    @winrt_mixinmethod
    def put_Stretch(self: win32more.Microsoft.UI.Xaml.Controls.IImage, value: win32more.Microsoft.UI.Xaml.Media.Stretch) -> Void: ...
    @winrt_mixinmethod
    def get_NineGrid(self: win32more.Microsoft.UI.Xaml.Controls.IImage) -> win32more.Microsoft.UI.Xaml.Thickness: ...
    @winrt_mixinmethod
    def put_NineGrid(self: win32more.Microsoft.UI.Xaml.Controls.IImage, value: win32more.Microsoft.UI.Xaml.Thickness) -> Void: ...
    @winrt_mixinmethod
    def add_ImageFailed(self: win32more.Microsoft.UI.Xaml.Controls.IImage, handler: win32more.Microsoft.UI.Xaml.ExceptionRoutedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ImageFailed(self: win32more.Microsoft.UI.Xaml.Controls.IImage, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_ImageOpened(self: win32more.Microsoft.UI.Xaml.Controls.IImage, handler: win32more.Microsoft.UI.Xaml.RoutedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ImageOpened(self: win32more.Microsoft.UI.Xaml.Controls.IImage, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def GetAsCastingSource(self: win32more.Microsoft.UI.Xaml.Controls.IImage) -> win32more.Windows.Media.Casting.CastingSource: ...
    @winrt_mixinmethod
    def GetAlphaMask(self: win32more.Microsoft.UI.Xaml.Controls.IImage) -> win32more.Microsoft.UI.Composition.CompositionBrush: ...
    @winrt_classmethod
    def get_SourceProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IImageStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_StretchProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IImageStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_NineGridProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IImageStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    NineGrid = property(get_NineGrid, put_NineGrid)
    Source = property(get_Source, put_Source)
    Stretch = property(get_Stretch, put_Stretch)
    _Image_Meta_.NineGridProperty = property(get_NineGridProperty, None)
    _Image_Meta_.SourceProperty = property(get_SourceProperty, None)
    _Image_Meta_.StretchProperty = property(get_StretchProperty, None)
    ImageFailed = event(add_ImageFailed, remove_ImageFailed)
    ImageOpened = event(add_ImageOpened, remove_ImageOpened)
class _ImageIcon_Meta_(ComPtr.__class__):
    pass
class ImageIcon(ComPtr, metaclass=_ImageIcon_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.IconElement
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IImageIcon
    _classid_ = 'Microsoft.UI.Xaml.Controls.ImageIcon'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.ImageIcon.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IImageIconFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.ImageIcon: ...
    @winrt_mixinmethod
    def get_Source(self: win32more.Microsoft.UI.Xaml.Controls.IImageIcon) -> win32more.Microsoft.UI.Xaml.Media.ImageSource: ...
    @winrt_mixinmethod
    def put_Source(self: win32more.Microsoft.UI.Xaml.Controls.IImageIcon, value: win32more.Microsoft.UI.Xaml.Media.ImageSource) -> Void: ...
    @winrt_classmethod
    def get_SourceProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IImageIconStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    Source = property(get_Source, put_Source)
    _ImageIcon_Meta_.SourceProperty = property(get_SourceProperty, None)
class _ImageIconSource_Meta_(ComPtr.__class__):
    pass
class ImageIconSource(ComPtr, metaclass=_ImageIconSource_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.IconSource
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IImageIconSource
    _classid_ = 'Microsoft.UI.Xaml.Controls.ImageIconSource'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.ImageIconSource.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IImageIconSourceFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.ImageIconSource: ...
    @winrt_mixinmethod
    def get_ImageSource(self: win32more.Microsoft.UI.Xaml.Controls.IImageIconSource) -> win32more.Microsoft.UI.Xaml.Media.ImageSource: ...
    @winrt_mixinmethod
    def put_ImageSource(self: win32more.Microsoft.UI.Xaml.Controls.IImageIconSource, value: win32more.Microsoft.UI.Xaml.Media.ImageSource) -> Void: ...
    @winrt_classmethod
    def get_ImageSourceProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IImageIconSourceStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    ImageSource = property(get_ImageSource, put_ImageSource)
    _ImageIconSource_Meta_.ImageSourceProperty = property(get_ImageSourceProperty, None)
class IncrementalLoadingTrigger(Enum, Int32):
    None_ = 0
    Edge = 1
class IndexBasedLayoutOrientation(Enum, Int32):
    None_ = 0
    TopToBottom = 1
    LeftToRight = 2
class _InfoBadge_Meta_(ComPtr.__class__):
    pass
class InfoBadge(ComPtr, metaclass=_InfoBadge_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.Control
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IInfoBadge
    _classid_ = 'Microsoft.UI.Xaml.Controls.InfoBadge'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.InfoBadge.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IInfoBadgeFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.InfoBadge: ...
    @winrt_mixinmethod
    def get_Value(self: win32more.Microsoft.UI.Xaml.Controls.IInfoBadge) -> Int32: ...
    @winrt_mixinmethod
    def put_Value(self: win32more.Microsoft.UI.Xaml.Controls.IInfoBadge, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_IconSource(self: win32more.Microsoft.UI.Xaml.Controls.IInfoBadge) -> win32more.Microsoft.UI.Xaml.Controls.IconSource: ...
    @winrt_mixinmethod
    def put_IconSource(self: win32more.Microsoft.UI.Xaml.Controls.IInfoBadge, value: win32more.Microsoft.UI.Xaml.Controls.IconSource) -> Void: ...
    @winrt_mixinmethod
    def get_TemplateSettings(self: win32more.Microsoft.UI.Xaml.Controls.IInfoBadge) -> win32more.Microsoft.UI.Xaml.Controls.InfoBadgeTemplateSettings: ...
    @winrt_classmethod
    def get_ValueProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IInfoBadgeStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IconSourceProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IInfoBadgeStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TemplateSettingsProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IInfoBadgeStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    IconSource = property(get_IconSource, put_IconSource)
    TemplateSettings = property(get_TemplateSettings, None)
    Value = property(get_Value, put_Value)
    _InfoBadge_Meta_.IconSourceProperty = property(get_IconSourceProperty, None)
    _InfoBadge_Meta_.TemplateSettingsProperty = property(get_TemplateSettingsProperty, None)
    _InfoBadge_Meta_.ValueProperty = property(get_ValueProperty, None)
class _InfoBadgeTemplateSettings_Meta_(ComPtr.__class__):
    pass
class InfoBadgeTemplateSettings(ComPtr, metaclass=_InfoBadgeTemplateSettings_Meta_):
    extends: win32more.Microsoft.UI.Xaml.DependencyObject
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IInfoBadgeTemplateSettings
    _classid_ = 'Microsoft.UI.Xaml.Controls.InfoBadgeTemplateSettings'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.InfoBadgeTemplateSettings.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IInfoBadgeTemplateSettingsFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.InfoBadgeTemplateSettings: ...
    @winrt_mixinmethod
    def get_InfoBadgeCornerRadius(self: win32more.Microsoft.UI.Xaml.Controls.IInfoBadgeTemplateSettings) -> win32more.Microsoft.UI.Xaml.CornerRadius: ...
    @winrt_mixinmethod
    def put_InfoBadgeCornerRadius(self: win32more.Microsoft.UI.Xaml.Controls.IInfoBadgeTemplateSettings, value: win32more.Microsoft.UI.Xaml.CornerRadius) -> Void: ...
    @winrt_mixinmethod
    def get_IconElement(self: win32more.Microsoft.UI.Xaml.Controls.IInfoBadgeTemplateSettings) -> win32more.Microsoft.UI.Xaml.Controls.IconElement: ...
    @winrt_mixinmethod
    def put_IconElement(self: win32more.Microsoft.UI.Xaml.Controls.IInfoBadgeTemplateSettings, value: win32more.Microsoft.UI.Xaml.Controls.IconElement) -> Void: ...
    @winrt_classmethod
    def get_InfoBadgeCornerRadiusProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IInfoBadgeTemplateSettingsStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IconElementProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IInfoBadgeTemplateSettingsStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    IconElement = property(get_IconElement, put_IconElement)
    InfoBadgeCornerRadius = property(get_InfoBadgeCornerRadius, put_InfoBadgeCornerRadius)
    _InfoBadgeTemplateSettings_Meta_.IconElementProperty = property(get_IconElementProperty, None)
    _InfoBadgeTemplateSettings_Meta_.InfoBadgeCornerRadiusProperty = property(get_InfoBadgeCornerRadiusProperty, None)
class _InfoBar_Meta_(ComPtr.__class__):
    pass
class InfoBar(ComPtr, metaclass=_InfoBar_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.Control
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IInfoBar
    _classid_ = 'Microsoft.UI.Xaml.Controls.InfoBar'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.InfoBar.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IInfoBarFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.InfoBar: ...
    @winrt_mixinmethod
    def get_IsOpen(self: win32more.Microsoft.UI.Xaml.Controls.IInfoBar) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsOpen(self: win32more.Microsoft.UI.Xaml.Controls.IInfoBar, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_Title(self: win32more.Microsoft.UI.Xaml.Controls.IInfoBar) -> hstr: ...
    @winrt_mixinmethod
    def put_Title(self: win32more.Microsoft.UI.Xaml.Controls.IInfoBar, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def get_Message(self: win32more.Microsoft.UI.Xaml.Controls.IInfoBar) -> hstr: ...
    @winrt_mixinmethod
    def put_Message(self: win32more.Microsoft.UI.Xaml.Controls.IInfoBar, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def get_Severity(self: win32more.Microsoft.UI.Xaml.Controls.IInfoBar) -> win32more.Microsoft.UI.Xaml.Controls.InfoBarSeverity: ...
    @winrt_mixinmethod
    def put_Severity(self: win32more.Microsoft.UI.Xaml.Controls.IInfoBar, value: win32more.Microsoft.UI.Xaml.Controls.InfoBarSeverity) -> Void: ...
    @winrt_mixinmethod
    def get_IconSource(self: win32more.Microsoft.UI.Xaml.Controls.IInfoBar) -> win32more.Microsoft.UI.Xaml.Controls.IconSource: ...
    @winrt_mixinmethod
    def put_IconSource(self: win32more.Microsoft.UI.Xaml.Controls.IInfoBar, value: win32more.Microsoft.UI.Xaml.Controls.IconSource) -> Void: ...
    @winrt_mixinmethod
    def get_IsIconVisible(self: win32more.Microsoft.UI.Xaml.Controls.IInfoBar) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsIconVisible(self: win32more.Microsoft.UI.Xaml.Controls.IInfoBar, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsClosable(self: win32more.Microsoft.UI.Xaml.Controls.IInfoBar) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsClosable(self: win32more.Microsoft.UI.Xaml.Controls.IInfoBar, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_CloseButtonStyle(self: win32more.Microsoft.UI.Xaml.Controls.IInfoBar) -> win32more.Microsoft.UI.Xaml.Style: ...
    @winrt_mixinmethod
    def put_CloseButtonStyle(self: win32more.Microsoft.UI.Xaml.Controls.IInfoBar, value: win32more.Microsoft.UI.Xaml.Style) -> Void: ...
    @winrt_mixinmethod
    def get_CloseButtonCommand(self: win32more.Microsoft.UI.Xaml.Controls.IInfoBar) -> win32more.Microsoft.UI.Xaml.Input.ICommand: ...
    @winrt_mixinmethod
    def put_CloseButtonCommand(self: win32more.Microsoft.UI.Xaml.Controls.IInfoBar, value: win32more.Microsoft.UI.Xaml.Input.ICommand) -> Void: ...
    @winrt_mixinmethod
    def get_CloseButtonCommandParameter(self: win32more.Microsoft.UI.Xaml.Controls.IInfoBar) -> IInspectable: ...
    @winrt_mixinmethod
    def put_CloseButtonCommandParameter(self: win32more.Microsoft.UI.Xaml.Controls.IInfoBar, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_ActionButton(self: win32more.Microsoft.UI.Xaml.Controls.IInfoBar) -> win32more.Microsoft.UI.Xaml.Controls.Primitives.ButtonBase: ...
    @winrt_mixinmethod
    def put_ActionButton(self: win32more.Microsoft.UI.Xaml.Controls.IInfoBar, value: win32more.Microsoft.UI.Xaml.Controls.Primitives.ButtonBase) -> Void: ...
    @winrt_mixinmethod
    def get_Content(self: win32more.Microsoft.UI.Xaml.Controls.IInfoBar) -> IInspectable: ...
    @winrt_mixinmethod
    def put_Content(self: win32more.Microsoft.UI.Xaml.Controls.IInfoBar, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_ContentTemplate(self: win32more.Microsoft.UI.Xaml.Controls.IInfoBar) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def put_ContentTemplate(self: win32more.Microsoft.UI.Xaml.Controls.IInfoBar, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_mixinmethod
    def get_TemplateSettings(self: win32more.Microsoft.UI.Xaml.Controls.IInfoBar) -> win32more.Microsoft.UI.Xaml.Controls.InfoBarTemplateSettings: ...
    @winrt_mixinmethod
    def add_CloseButtonClick(self: win32more.Microsoft.UI.Xaml.Controls.IInfoBar, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.InfoBar, IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_CloseButtonClick(self: win32more.Microsoft.UI.Xaml.Controls.IInfoBar, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_Closing(self: win32more.Microsoft.UI.Xaml.Controls.IInfoBar, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.InfoBar, win32more.Microsoft.UI.Xaml.Controls.InfoBarClosingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Closing(self: win32more.Microsoft.UI.Xaml.Controls.IInfoBar, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_Closed(self: win32more.Microsoft.UI.Xaml.Controls.IInfoBar, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.InfoBar, win32more.Microsoft.UI.Xaml.Controls.InfoBarClosedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Closed(self: win32more.Microsoft.UI.Xaml.Controls.IInfoBar, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def get_IsOpenProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IInfoBarStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TitleProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IInfoBarStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MessageProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IInfoBarStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SeverityProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IInfoBarStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IconSourceProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IInfoBarStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsIconVisibleProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IInfoBarStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsClosableProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IInfoBarStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CloseButtonStyleProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IInfoBarStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CloseButtonCommandProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IInfoBarStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CloseButtonCommandParameterProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IInfoBarStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ActionButtonProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IInfoBarStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ContentProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IInfoBarStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ContentTemplateProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IInfoBarStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TemplateSettingsProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IInfoBarStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    ActionButton = property(get_ActionButton, put_ActionButton)
    CloseButtonCommand = property(get_CloseButtonCommand, put_CloseButtonCommand)
    CloseButtonCommandParameter = property(get_CloseButtonCommandParameter, put_CloseButtonCommandParameter)
    CloseButtonStyle = property(get_CloseButtonStyle, put_CloseButtonStyle)
    Content = property(get_Content, put_Content)
    ContentTemplate = property(get_ContentTemplate, put_ContentTemplate)
    IconSource = property(get_IconSource, put_IconSource)
    IsClosable = property(get_IsClosable, put_IsClosable)
    IsIconVisible = property(get_IsIconVisible, put_IsIconVisible)
    IsOpen = property(get_IsOpen, put_IsOpen)
    Message = property(get_Message, put_Message)
    Severity = property(get_Severity, put_Severity)
    TemplateSettings = property(get_TemplateSettings, None)
    Title = property(get_Title, put_Title)
    _InfoBar_Meta_.ActionButtonProperty = property(get_ActionButtonProperty, None)
    _InfoBar_Meta_.CloseButtonCommandParameterProperty = property(get_CloseButtonCommandParameterProperty, None)
    _InfoBar_Meta_.CloseButtonCommandProperty = property(get_CloseButtonCommandProperty, None)
    _InfoBar_Meta_.CloseButtonStyleProperty = property(get_CloseButtonStyleProperty, None)
    _InfoBar_Meta_.ContentProperty = property(get_ContentProperty, None)
    _InfoBar_Meta_.ContentTemplateProperty = property(get_ContentTemplateProperty, None)
    _InfoBar_Meta_.IconSourceProperty = property(get_IconSourceProperty, None)
    _InfoBar_Meta_.IsClosableProperty = property(get_IsClosableProperty, None)
    _InfoBar_Meta_.IsIconVisibleProperty = property(get_IsIconVisibleProperty, None)
    _InfoBar_Meta_.IsOpenProperty = property(get_IsOpenProperty, None)
    _InfoBar_Meta_.MessageProperty = property(get_MessageProperty, None)
    _InfoBar_Meta_.SeverityProperty = property(get_SeverityProperty, None)
    _InfoBar_Meta_.TemplateSettingsProperty = property(get_TemplateSettingsProperty, None)
    _InfoBar_Meta_.TitleProperty = property(get_TitleProperty, None)
    CloseButtonClick = event(add_CloseButtonClick, remove_CloseButtonClick)
    Closed = event(add_Closed, remove_Closed)
    Closing = event(add_Closing, remove_Closing)
class InfoBarCloseReason(Enum, Int32):
    CloseButton = 0
    Programmatic = 1
class InfoBarClosedEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IInfoBarClosedEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.InfoBarClosedEventArgs'
    @winrt_mixinmethod
    def get_Reason(self: win32more.Microsoft.UI.Xaml.Controls.IInfoBarClosedEventArgs) -> win32more.Microsoft.UI.Xaml.Controls.InfoBarCloseReason: ...
    Reason = property(get_Reason, None)
class InfoBarClosingEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IInfoBarClosingEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.InfoBarClosingEventArgs'
    @winrt_mixinmethod
    def get_Reason(self: win32more.Microsoft.UI.Xaml.Controls.IInfoBarClosingEventArgs) -> win32more.Microsoft.UI.Xaml.Controls.InfoBarCloseReason: ...
    @winrt_mixinmethod
    def get_Cancel(self: win32more.Microsoft.UI.Xaml.Controls.IInfoBarClosingEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def put_Cancel(self: win32more.Microsoft.UI.Xaml.Controls.IInfoBarClosingEventArgs, value: Boolean) -> Void: ...
    Cancel = property(get_Cancel, put_Cancel)
    Reason = property(get_Reason, None)
class InfoBarSeverity(Enum, Int32):
    Informational = 0
    Success = 1
    Warning = 2
    Error = 3
class _InfoBarTemplateSettings_Meta_(ComPtr.__class__):
    pass
class InfoBarTemplateSettings(ComPtr, metaclass=_InfoBarTemplateSettings_Meta_):
    extends: win32more.Microsoft.UI.Xaml.DependencyObject
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IInfoBarTemplateSettings
    _classid_ = 'Microsoft.UI.Xaml.Controls.InfoBarTemplateSettings'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.InfoBarTemplateSettings.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IInfoBarTemplateSettingsFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.InfoBarTemplateSettings: ...
    @winrt_mixinmethod
    def get_IconElement(self: win32more.Microsoft.UI.Xaml.Controls.IInfoBarTemplateSettings) -> win32more.Microsoft.UI.Xaml.Controls.IconElement: ...
    @winrt_mixinmethod
    def put_IconElement(self: win32more.Microsoft.UI.Xaml.Controls.IInfoBarTemplateSettings, value: win32more.Microsoft.UI.Xaml.Controls.IconElement) -> Void: ...
    @winrt_classmethod
    def get_IconElementProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IInfoBarTemplateSettingsStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    IconElement = property(get_IconElement, put_IconElement)
    _InfoBarTemplateSettings_Meta_.IconElementProperty = property(get_IconElementProperty, None)
class IsTextTrimmedChangedEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IIsTextTrimmedChangedEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.IsTextTrimmedChangedEventArgs'
class ItemClickEventArgs(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.RoutedEventArgs
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IItemClickEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.ItemClickEventArgs'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.ItemClickEventArgs.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Controls.ItemClickEventArgs: ...
    @winrt_mixinmethod
    def get_ClickedItem(self: win32more.Microsoft.UI.Xaml.Controls.IItemClickEventArgs) -> IInspectable: ...
    ClickedItem = property(get_ClickedItem, None)
class ItemClickEventHandler(MulticastDelegate):
    extends: IUnknown
    _iid_ = Guid('{a3903624-3393-566c-a6b9-a6b4b3e301c3}')
    @winrt_commethod(3)
    def Invoke(self, sender: IInspectable, e: win32more.Microsoft.UI.Xaml.Controls.ItemClickEventArgs) -> Void: ...
class ItemCollection(ComPtr):
    extends: IInspectable
    implements: Tuple[SequenceProtocol[IInspectable]]
    default_interface: win32more.Windows.Foundation.Collections.IObservableVector[IInspectable]
    _classid_ = 'Microsoft.UI.Xaml.Controls.ItemCollection'
    @winrt_mixinmethod
    def add_VectorChanged(self: win32more.Windows.Foundation.Collections.IObservableVector[IInspectable], vhnd: win32more.Windows.Foundation.Collections.VectorChangedEventHandler[IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_VectorChanged(self: win32more.Windows.Foundation.Collections.IObservableVector[IInspectable], token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def GetAt(self: win32more.Windows.Foundation.Collections.IVector[IInspectable], index: UInt32) -> IInspectable: ...
    @winrt_mixinmethod
    def get_Size(self: win32more.Windows.Foundation.Collections.IVector[IInspectable]) -> UInt32: ...
    @winrt_mixinmethod
    def GetView(self: win32more.Windows.Foundation.Collections.IVector[IInspectable]) -> win32more.Windows.Foundation.Collections.IVectorView[IInspectable]: ...
    @winrt_mixinmethod
    def IndexOf(self: win32more.Windows.Foundation.Collections.IVector[IInspectable], value: IInspectable, index: POINTER(UInt32)) -> Boolean: ...
    @winrt_mixinmethod
    def SetAt(self: win32more.Windows.Foundation.Collections.IVector[IInspectable], index: UInt32, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def InsertAt(self: win32more.Windows.Foundation.Collections.IVector[IInspectable], index: UInt32, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def RemoveAt(self: win32more.Windows.Foundation.Collections.IVector[IInspectable], index: UInt32) -> Void: ...
    @winrt_mixinmethod
    def Append(self: win32more.Windows.Foundation.Collections.IVector[IInspectable], value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def RemoveAtEnd(self: win32more.Windows.Foundation.Collections.IVector[IInspectable]) -> Void: ...
    @winrt_mixinmethod
    def Clear(self: win32more.Windows.Foundation.Collections.IVector[IInspectable]) -> Void: ...
    @winrt_mixinmethod
    def GetMany(self: win32more.Windows.Foundation.Collections.IVector[IInspectable], startIndex: UInt32, items: FillArray[IInspectable]) -> UInt32: ...
    @winrt_mixinmethod
    def ReplaceAll(self: win32more.Windows.Foundation.Collections.IVector[IInspectable], items: PassArray[IInspectable]) -> Void: ...
    @winrt_mixinmethod
    def First(self: win32more.Windows.Foundation.Collections.IIterable[IInspectable]) -> win32more.Windows.Foundation.Collections.IIterator[IInspectable]: ...
    Size = property(get_Size, None)
    VectorChanged = event(add_VectorChanged, remove_VectorChanged)
class ItemCollectionTransition(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IItemCollectionTransition
    _classid_ = 'Microsoft.UI.Xaml.Controls.ItemCollectionTransition'
    @winrt_mixinmethod
    def get_Operation(self: win32more.Microsoft.UI.Xaml.Controls.IItemCollectionTransition) -> win32more.Microsoft.UI.Xaml.Controls.ItemCollectionTransitionOperation: ...
    @winrt_mixinmethod
    def get_Triggers(self: win32more.Microsoft.UI.Xaml.Controls.IItemCollectionTransition) -> win32more.Microsoft.UI.Xaml.Controls.ItemCollectionTransitionTriggers: ...
    @winrt_mixinmethod
    def get_OldBounds(self: win32more.Microsoft.UI.Xaml.Controls.IItemCollectionTransition) -> win32more.Windows.Foundation.Rect: ...
    @winrt_mixinmethod
    def get_NewBounds(self: win32more.Microsoft.UI.Xaml.Controls.IItemCollectionTransition) -> win32more.Windows.Foundation.Rect: ...
    @winrt_mixinmethod
    def get_HasStarted(self: win32more.Microsoft.UI.Xaml.Controls.IItemCollectionTransition) -> Boolean: ...
    @winrt_mixinmethod
    def Start(self: win32more.Microsoft.UI.Xaml.Controls.IItemCollectionTransition) -> win32more.Microsoft.UI.Xaml.Controls.ItemCollectionTransitionProgress: ...
    HasStarted = property(get_HasStarted, None)
    NewBounds = property(get_NewBounds, None)
    OldBounds = property(get_OldBounds, None)
    Operation = property(get_Operation, None)
    Triggers = property(get_Triggers, None)
class ItemCollectionTransitionCompletedEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IItemCollectionTransitionCompletedEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.ItemCollectionTransitionCompletedEventArgs'
    @winrt_mixinmethod
    def get_Transition(self: win32more.Microsoft.UI.Xaml.Controls.IItemCollectionTransitionCompletedEventArgs) -> win32more.Microsoft.UI.Xaml.Controls.ItemCollectionTransition: ...
    @winrt_mixinmethod
    def get_Element(self: win32more.Microsoft.UI.Xaml.Controls.IItemCollectionTransitionCompletedEventArgs) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    Element = property(get_Element, None)
    Transition = property(get_Transition, None)
class ItemCollectionTransitionOperation(Enum, Int32):
    Add = 0
    Remove = 1
    Move = 2
class ItemCollectionTransitionProgress(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IItemCollectionTransitionProgress
    _classid_ = 'Microsoft.UI.Xaml.Controls.ItemCollectionTransitionProgress'
    @winrt_mixinmethod
    def get_Transition(self: win32more.Microsoft.UI.Xaml.Controls.IItemCollectionTransitionProgress) -> win32more.Microsoft.UI.Xaml.Controls.ItemCollectionTransition: ...
    @winrt_mixinmethod
    def get_Element(self: win32more.Microsoft.UI.Xaml.Controls.IItemCollectionTransitionProgress) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_mixinmethod
    def Complete(self: win32more.Microsoft.UI.Xaml.Controls.IItemCollectionTransitionProgress) -> Void: ...
    Element = property(get_Element, None)
    Transition = property(get_Transition, None)
class ItemCollectionTransitionProvider(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IItemCollectionTransitionProvider
    _classid_ = 'Microsoft.UI.Xaml.Controls.ItemCollectionTransitionProvider'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.ItemCollectionTransitionProvider.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IItemCollectionTransitionProviderFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.ItemCollectionTransitionProvider: ...
    @winrt_mixinmethod
    def ShouldAnimate(self: win32more.Microsoft.UI.Xaml.Controls.IItemCollectionTransitionProvider, transition: win32more.Microsoft.UI.Xaml.Controls.ItemCollectionTransition) -> Boolean: ...
    @winrt_mixinmethod
    def QueueTransition(self: win32more.Microsoft.UI.Xaml.Controls.IItemCollectionTransitionProvider, transition: win32more.Microsoft.UI.Xaml.Controls.ItemCollectionTransition) -> Void: ...
    @winrt_mixinmethod
    def add_TransitionCompleted(self: win32more.Microsoft.UI.Xaml.Controls.IItemCollectionTransitionProvider, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.ItemCollectionTransitionProvider, win32more.Microsoft.UI.Xaml.Controls.ItemCollectionTransitionCompletedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_TransitionCompleted(self: win32more.Microsoft.UI.Xaml.Controls.IItemCollectionTransitionProvider, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def ShouldAnimateCore(self: win32more.Microsoft.UI.Xaml.Controls.IItemCollectionTransitionProviderOverrides, transition: win32more.Microsoft.UI.Xaml.Controls.ItemCollectionTransition) -> Boolean: ...
    @winrt_mixinmethod
    def StartTransitions(self: win32more.Microsoft.UI.Xaml.Controls.IItemCollectionTransitionProviderOverrides, transitions: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.ItemCollectionTransition]) -> Void: ...
    TransitionCompleted = event(add_TransitionCompleted, remove_TransitionCompleted)
class ItemCollectionTransitionTriggers(Enum, UInt32):
    CollectionChangeAdd = 1
    CollectionChangeRemove = 2
    CollectionChangeReset = 4
    LayoutTransition = 8
class _ItemContainer_Meta_(ComPtr.__class__):
    pass
class ItemContainer(ComPtr, metaclass=_ItemContainer_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.Control
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IItemContainer
    _classid_ = 'Microsoft.UI.Xaml.Controls.ItemContainer'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.ItemContainer.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IItemContainerFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.ItemContainer: ...
    @winrt_mixinmethod
    def get_Child(self: win32more.Microsoft.UI.Xaml.Controls.IItemContainer) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_mixinmethod
    def put_Child(self: win32more.Microsoft.UI.Xaml.Controls.IItemContainer, value: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    @winrt_mixinmethod
    def get_IsSelected(self: win32more.Microsoft.UI.Xaml.Controls.IItemContainer) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsSelected(self: win32more.Microsoft.UI.Xaml.Controls.IItemContainer, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_ChildProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IItemContainerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsSelectedProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IItemContainerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    Child = property(get_Child, put_Child)
    IsSelected = property(get_IsSelected, put_IsSelected)
    _ItemContainer_Meta_.ChildProperty = property(get_ChildProperty, None)
    _ItemContainer_Meta_.IsSelectedProperty = property(get_IsSelectedProperty, None)
class ItemContainerGenerator(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IItemContainerGenerator
    _classid_ = 'Microsoft.UI.Xaml.Controls.ItemContainerGenerator'
    @winrt_mixinmethod
    def add_ItemsChanged(self: win32more.Microsoft.UI.Xaml.Controls.IItemContainerGenerator, handler: win32more.Microsoft.UI.Xaml.Controls.Primitives.ItemsChangedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ItemsChanged(self: win32more.Microsoft.UI.Xaml.Controls.IItemContainerGenerator, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def ItemFromContainer(self: win32more.Microsoft.UI.Xaml.Controls.IItemContainerGenerator, container: win32more.Microsoft.UI.Xaml.DependencyObject) -> IInspectable: ...
    @winrt_mixinmethod
    def ContainerFromItem(self: win32more.Microsoft.UI.Xaml.Controls.IItemContainerGenerator, item: IInspectable) -> win32more.Microsoft.UI.Xaml.DependencyObject: ...
    @winrt_mixinmethod
    def IndexFromContainer(self: win32more.Microsoft.UI.Xaml.Controls.IItemContainerGenerator, container: win32more.Microsoft.UI.Xaml.DependencyObject) -> Int32: ...
    @winrt_mixinmethod
    def ContainerFromIndex(self: win32more.Microsoft.UI.Xaml.Controls.IItemContainerGenerator, index: Int32) -> win32more.Microsoft.UI.Xaml.DependencyObject: ...
    @winrt_mixinmethod
    def GetItemContainerGeneratorForPanel(self: win32more.Microsoft.UI.Xaml.Controls.IItemContainerGenerator, panel: win32more.Microsoft.UI.Xaml.Controls.Panel) -> win32more.Microsoft.UI.Xaml.Controls.ItemContainerGenerator: ...
    @winrt_mixinmethod
    def StartAt(self: win32more.Microsoft.UI.Xaml.Controls.IItemContainerGenerator, position: win32more.Microsoft.UI.Xaml.Controls.Primitives.GeneratorPosition, direction: win32more.Microsoft.UI.Xaml.Controls.Primitives.GeneratorDirection, allowStartAtRealizedItem: Boolean) -> Void: ...
    @winrt_mixinmethod
    def Stop(self: win32more.Microsoft.UI.Xaml.Controls.IItemContainerGenerator) -> Void: ...
    @winrt_mixinmethod
    def GenerateNext(self: win32more.Microsoft.UI.Xaml.Controls.IItemContainerGenerator, isNewlyRealized: POINTER(Boolean)) -> win32more.Microsoft.UI.Xaml.DependencyObject: ...
    @winrt_mixinmethod
    def PrepareItemContainer(self: win32more.Microsoft.UI.Xaml.Controls.IItemContainerGenerator, container: win32more.Microsoft.UI.Xaml.DependencyObject) -> Void: ...
    @winrt_mixinmethod
    def RemoveAll(self: win32more.Microsoft.UI.Xaml.Controls.IItemContainerGenerator) -> Void: ...
    @winrt_mixinmethod
    def Remove(self: win32more.Microsoft.UI.Xaml.Controls.IItemContainerGenerator, position: win32more.Microsoft.UI.Xaml.Controls.Primitives.GeneratorPosition, count: Int32) -> Void: ...
    @winrt_mixinmethod
    def GeneratorPositionFromIndex(self: win32more.Microsoft.UI.Xaml.Controls.IItemContainerGenerator, itemIndex: Int32) -> win32more.Microsoft.UI.Xaml.Controls.Primitives.GeneratorPosition: ...
    @winrt_mixinmethod
    def IndexFromGeneratorPosition(self: win32more.Microsoft.UI.Xaml.Controls.IItemContainerGenerator, position: win32more.Microsoft.UI.Xaml.Controls.Primitives.GeneratorPosition) -> Int32: ...
    @winrt_mixinmethod
    def Recycle(self: win32more.Microsoft.UI.Xaml.Controls.IItemContainerGenerator, position: win32more.Microsoft.UI.Xaml.Controls.Primitives.GeneratorPosition, count: Int32) -> Void: ...
    ItemsChanged = event(add_ItemsChanged, remove_ItemsChanged)
class _ItemsControl_Meta_(ComPtr.__class__):
    pass
class ItemsControl(ComPtr, metaclass=_ItemsControl_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.Control
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IItemsControl
    _classid_ = 'Microsoft.UI.Xaml.Controls.ItemsControl'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.ItemsControl.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IItemsControlFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.ItemsControl: ...
    @winrt_mixinmethod
    def get_ItemsSource(self: win32more.Microsoft.UI.Xaml.Controls.IItemsControl) -> IInspectable: ...
    @winrt_mixinmethod
    def put_ItemsSource(self: win32more.Microsoft.UI.Xaml.Controls.IItemsControl, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_Items(self: win32more.Microsoft.UI.Xaml.Controls.IItemsControl) -> win32more.Microsoft.UI.Xaml.Controls.ItemCollection: ...
    @winrt_mixinmethod
    def get_ItemTemplate(self: win32more.Microsoft.UI.Xaml.Controls.IItemsControl) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def put_ItemTemplate(self: win32more.Microsoft.UI.Xaml.Controls.IItemsControl, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_mixinmethod
    def get_ItemTemplateSelector(self: win32more.Microsoft.UI.Xaml.Controls.IItemsControl) -> win32more.Microsoft.UI.Xaml.Controls.DataTemplateSelector: ...
    @winrt_mixinmethod
    def put_ItemTemplateSelector(self: win32more.Microsoft.UI.Xaml.Controls.IItemsControl, value: win32more.Microsoft.UI.Xaml.Controls.DataTemplateSelector) -> Void: ...
    @winrt_mixinmethod
    def get_ItemsPanel(self: win32more.Microsoft.UI.Xaml.Controls.IItemsControl) -> win32more.Microsoft.UI.Xaml.Controls.ItemsPanelTemplate: ...
    @winrt_mixinmethod
    def put_ItemsPanel(self: win32more.Microsoft.UI.Xaml.Controls.IItemsControl, value: win32more.Microsoft.UI.Xaml.Controls.ItemsPanelTemplate) -> Void: ...
    @winrt_mixinmethod
    def get_DisplayMemberPath(self: win32more.Microsoft.UI.Xaml.Controls.IItemsControl) -> hstr: ...
    @winrt_mixinmethod
    def put_DisplayMemberPath(self: win32more.Microsoft.UI.Xaml.Controls.IItemsControl, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def get_ItemsPanelRoot(self: win32more.Microsoft.UI.Xaml.Controls.IItemsControl) -> win32more.Microsoft.UI.Xaml.Controls.Panel: ...
    @winrt_mixinmethod
    def get_ItemContainerStyle(self: win32more.Microsoft.UI.Xaml.Controls.IItemsControl) -> win32more.Microsoft.UI.Xaml.Style: ...
    @winrt_mixinmethod
    def put_ItemContainerStyle(self: win32more.Microsoft.UI.Xaml.Controls.IItemsControl, value: win32more.Microsoft.UI.Xaml.Style) -> Void: ...
    @winrt_mixinmethod
    def get_ItemContainerStyleSelector(self: win32more.Microsoft.UI.Xaml.Controls.IItemsControl) -> win32more.Microsoft.UI.Xaml.Controls.StyleSelector: ...
    @winrt_mixinmethod
    def put_ItemContainerStyleSelector(self: win32more.Microsoft.UI.Xaml.Controls.IItemsControl, value: win32more.Microsoft.UI.Xaml.Controls.StyleSelector) -> Void: ...
    @winrt_mixinmethod
    def get_ItemContainerGenerator(self: win32more.Microsoft.UI.Xaml.Controls.IItemsControl) -> win32more.Microsoft.UI.Xaml.Controls.ItemContainerGenerator: ...
    @winrt_mixinmethod
    def get_ItemContainerTransitions(self: win32more.Microsoft.UI.Xaml.Controls.IItemsControl) -> win32more.Microsoft.UI.Xaml.Media.Animation.TransitionCollection: ...
    @winrt_mixinmethod
    def put_ItemContainerTransitions(self: win32more.Microsoft.UI.Xaml.Controls.IItemsControl, value: win32more.Microsoft.UI.Xaml.Media.Animation.TransitionCollection) -> Void: ...
    @winrt_mixinmethod
    def get_GroupStyle(self: win32more.Microsoft.UI.Xaml.Controls.IItemsControl) -> win32more.Windows.Foundation.Collections.IObservableVector[win32more.Microsoft.UI.Xaml.Controls.GroupStyle]: ...
    @winrt_mixinmethod
    def get_GroupStyleSelector(self: win32more.Microsoft.UI.Xaml.Controls.IItemsControl) -> win32more.Microsoft.UI.Xaml.Controls.GroupStyleSelector: ...
    @winrt_mixinmethod
    def put_GroupStyleSelector(self: win32more.Microsoft.UI.Xaml.Controls.IItemsControl, value: win32more.Microsoft.UI.Xaml.Controls.GroupStyleSelector) -> Void: ...
    @winrt_mixinmethod
    def get_IsGrouping(self: win32more.Microsoft.UI.Xaml.Controls.IItemsControl) -> Boolean: ...
    @winrt_mixinmethod
    def GroupHeaderContainerFromItemContainer(self: win32more.Microsoft.UI.Xaml.Controls.IItemsControl, itemContainer: win32more.Microsoft.UI.Xaml.DependencyObject) -> win32more.Microsoft.UI.Xaml.DependencyObject: ...
    @winrt_mixinmethod
    def IsItemItsOwnContainerOverride(self: win32more.Microsoft.UI.Xaml.Controls.IItemsControlOverrides, item: IInspectable) -> Boolean: ...
    @winrt_mixinmethod
    def GetContainerForItemOverride(self: win32more.Microsoft.UI.Xaml.Controls.IItemsControlOverrides) -> win32more.Microsoft.UI.Xaml.DependencyObject: ...
    @winrt_mixinmethod
    def ClearContainerForItemOverride(self: win32more.Microsoft.UI.Xaml.Controls.IItemsControlOverrides, element: win32more.Microsoft.UI.Xaml.DependencyObject, item: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def PrepareContainerForItemOverride(self: win32more.Microsoft.UI.Xaml.Controls.IItemsControlOverrides, element: win32more.Microsoft.UI.Xaml.DependencyObject, item: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def OnItemsChanged(self: win32more.Microsoft.UI.Xaml.Controls.IItemsControlOverrides, e: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def OnItemContainerStyleChanged(self: win32more.Microsoft.UI.Xaml.Controls.IItemsControlOverrides, oldItemContainerStyle: win32more.Microsoft.UI.Xaml.Style, newItemContainerStyle: win32more.Microsoft.UI.Xaml.Style) -> Void: ...
    @winrt_mixinmethod
    def OnItemContainerStyleSelectorChanged(self: win32more.Microsoft.UI.Xaml.Controls.IItemsControlOverrides, oldItemContainerStyleSelector: win32more.Microsoft.UI.Xaml.Controls.StyleSelector, newItemContainerStyleSelector: win32more.Microsoft.UI.Xaml.Controls.StyleSelector) -> Void: ...
    @winrt_mixinmethod
    def OnItemTemplateChanged(self: win32more.Microsoft.UI.Xaml.Controls.IItemsControlOverrides, oldItemTemplate: win32more.Microsoft.UI.Xaml.DataTemplate, newItemTemplate: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_mixinmethod
    def OnItemTemplateSelectorChanged(self: win32more.Microsoft.UI.Xaml.Controls.IItemsControlOverrides, oldItemTemplateSelector: win32more.Microsoft.UI.Xaml.Controls.DataTemplateSelector, newItemTemplateSelector: win32more.Microsoft.UI.Xaml.Controls.DataTemplateSelector) -> Void: ...
    @winrt_mixinmethod
    def OnGroupStyleSelectorChanged(self: win32more.Microsoft.UI.Xaml.Controls.IItemsControlOverrides, oldGroupStyleSelector: win32more.Microsoft.UI.Xaml.Controls.GroupStyleSelector, newGroupStyleSelector: win32more.Microsoft.UI.Xaml.Controls.GroupStyleSelector) -> Void: ...
    @winrt_mixinmethod
    def ItemFromContainer(self: win32more.Microsoft.UI.Xaml.Controls.IItemContainerMapping, container: win32more.Microsoft.UI.Xaml.DependencyObject) -> IInspectable: ...
    @winrt_mixinmethod
    def ContainerFromItem(self: win32more.Microsoft.UI.Xaml.Controls.IItemContainerMapping, item: IInspectable) -> win32more.Microsoft.UI.Xaml.DependencyObject: ...
    @winrt_mixinmethod
    def IndexFromContainer(self: win32more.Microsoft.UI.Xaml.Controls.IItemContainerMapping, container: win32more.Microsoft.UI.Xaml.DependencyObject) -> Int32: ...
    @winrt_mixinmethod
    def ContainerFromIndex(self: win32more.Microsoft.UI.Xaml.Controls.IItemContainerMapping, index: Int32) -> win32more.Microsoft.UI.Xaml.DependencyObject: ...
    @winrt_classmethod
    def get_ItemsSourceProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IItemsControlStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ItemTemplateProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IItemsControlStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ItemTemplateSelectorProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IItemsControlStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ItemsPanelProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IItemsControlStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DisplayMemberPathProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IItemsControlStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ItemContainerStyleProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IItemsControlStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ItemContainerStyleSelectorProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IItemsControlStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ItemContainerTransitionsProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IItemsControlStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_GroupStyleSelectorProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IItemsControlStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsGroupingProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IItemsControlStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetItemsOwner(cls: win32more.Microsoft.UI.Xaml.Controls.IItemsControlStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> win32more.Microsoft.UI.Xaml.Controls.ItemsControl: ...
    @winrt_classmethod
    def ItemsControlFromItemContainer(cls: win32more.Microsoft.UI.Xaml.Controls.IItemsControlStatics, container: win32more.Microsoft.UI.Xaml.DependencyObject) -> win32more.Microsoft.UI.Xaml.Controls.ItemsControl: ...
    DisplayMemberPath = property(get_DisplayMemberPath, put_DisplayMemberPath)
    GroupStyle = property(get_GroupStyle, None)
    GroupStyleSelector = property(get_GroupStyleSelector, put_GroupStyleSelector)
    IsGrouping = property(get_IsGrouping, None)
    ItemContainerGenerator = property(get_ItemContainerGenerator, None)
    ItemContainerStyle = property(get_ItemContainerStyle, put_ItemContainerStyle)
    ItemContainerStyleSelector = property(get_ItemContainerStyleSelector, put_ItemContainerStyleSelector)
    ItemContainerTransitions = property(get_ItemContainerTransitions, put_ItemContainerTransitions)
    ItemTemplate = property(get_ItemTemplate, put_ItemTemplate)
    ItemTemplateSelector = property(get_ItemTemplateSelector, put_ItemTemplateSelector)
    Items = property(get_Items, None)
    ItemsPanel = property(get_ItemsPanel, put_ItemsPanel)
    ItemsPanelRoot = property(get_ItemsPanelRoot, None)
    ItemsSource = property(get_ItemsSource, put_ItemsSource)
    _ItemsControl_Meta_.DisplayMemberPathProperty = property(get_DisplayMemberPathProperty, None)
    _ItemsControl_Meta_.GroupStyleSelectorProperty = property(get_GroupStyleSelectorProperty, None)
    _ItemsControl_Meta_.IsGroupingProperty = property(get_IsGroupingProperty, None)
    _ItemsControl_Meta_.ItemContainerStyleProperty = property(get_ItemContainerStyleProperty, None)
    _ItemsControl_Meta_.ItemContainerStyleSelectorProperty = property(get_ItemContainerStyleSelectorProperty, None)
    _ItemsControl_Meta_.ItemContainerTransitionsProperty = property(get_ItemContainerTransitionsProperty, None)
    _ItemsControl_Meta_.ItemTemplateProperty = property(get_ItemTemplateProperty, None)
    _ItemsControl_Meta_.ItemTemplateSelectorProperty = property(get_ItemTemplateSelectorProperty, None)
    _ItemsControl_Meta_.ItemsPanelProperty = property(get_ItemsPanelProperty, None)
    _ItemsControl_Meta_.ItemsSourceProperty = property(get_ItemsSourceProperty, None)
class ItemsPanelTemplate(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.FrameworkTemplate
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IItemsPanelTemplate
    _classid_ = 'Microsoft.UI.Xaml.Controls.ItemsPanelTemplate'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.ItemsPanelTemplate.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Controls.ItemsPanelTemplate: ...
class ItemsPickedEventArgs(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.DependencyObject
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IItemsPickedEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.ItemsPickedEventArgs'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.ItemsPickedEventArgs.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Controls.ItemsPickedEventArgs: ...
    @winrt_mixinmethod
    def get_AddedItems(self: win32more.Microsoft.UI.Xaml.Controls.IItemsPickedEventArgs) -> win32more.Windows.Foundation.Collections.IVector[IInspectable]: ...
    @winrt_mixinmethod
    def get_RemovedItems(self: win32more.Microsoft.UI.Xaml.Controls.IItemsPickedEventArgs) -> win32more.Windows.Foundation.Collections.IVector[IInspectable]: ...
    AddedItems = property(get_AddedItems, None)
    RemovedItems = property(get_RemovedItems, None)
class _ItemsPresenter_Meta_(ComPtr.__class__):
    pass
class ItemsPresenter(ComPtr, metaclass=_ItemsPresenter_Meta_):
    extends: win32more.Microsoft.UI.Xaml.FrameworkElement
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IItemsPresenter
    _classid_ = 'Microsoft.UI.Xaml.Controls.ItemsPresenter'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.ItemsPresenter.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Controls.ItemsPresenter: ...
    @winrt_mixinmethod
    def get_Header(self: win32more.Microsoft.UI.Xaml.Controls.IItemsPresenter) -> IInspectable: ...
    @winrt_mixinmethod
    def put_Header(self: win32more.Microsoft.UI.Xaml.Controls.IItemsPresenter, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_HeaderTemplate(self: win32more.Microsoft.UI.Xaml.Controls.IItemsPresenter) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def put_HeaderTemplate(self: win32more.Microsoft.UI.Xaml.Controls.IItemsPresenter, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_mixinmethod
    def get_HeaderTransitions(self: win32more.Microsoft.UI.Xaml.Controls.IItemsPresenter) -> win32more.Microsoft.UI.Xaml.Media.Animation.TransitionCollection: ...
    @winrt_mixinmethod
    def put_HeaderTransitions(self: win32more.Microsoft.UI.Xaml.Controls.IItemsPresenter, value: win32more.Microsoft.UI.Xaml.Media.Animation.TransitionCollection) -> Void: ...
    @winrt_mixinmethod
    def get_Footer(self: win32more.Microsoft.UI.Xaml.Controls.IItemsPresenter) -> IInspectable: ...
    @winrt_mixinmethod
    def put_Footer(self: win32more.Microsoft.UI.Xaml.Controls.IItemsPresenter, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_FooterTemplate(self: win32more.Microsoft.UI.Xaml.Controls.IItemsPresenter) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def put_FooterTemplate(self: win32more.Microsoft.UI.Xaml.Controls.IItemsPresenter, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_mixinmethod
    def get_FooterTransitions(self: win32more.Microsoft.UI.Xaml.Controls.IItemsPresenter) -> win32more.Microsoft.UI.Xaml.Media.Animation.TransitionCollection: ...
    @winrt_mixinmethod
    def put_FooterTransitions(self: win32more.Microsoft.UI.Xaml.Controls.IItemsPresenter, value: win32more.Microsoft.UI.Xaml.Media.Animation.TransitionCollection) -> Void: ...
    @winrt_mixinmethod
    def get_Padding(self: win32more.Microsoft.UI.Xaml.Controls.IItemsPresenter) -> win32more.Microsoft.UI.Xaml.Thickness: ...
    @winrt_mixinmethod
    def put_Padding(self: win32more.Microsoft.UI.Xaml.Controls.IItemsPresenter, value: win32more.Microsoft.UI.Xaml.Thickness) -> Void: ...
    @winrt_mixinmethod
    def get_AreHorizontalSnapPointsRegular(self: win32more.Microsoft.UI.Xaml.Controls.Primitives.IScrollSnapPointsInfo) -> Boolean: ...
    @winrt_mixinmethod
    def get_AreVerticalSnapPointsRegular(self: win32more.Microsoft.UI.Xaml.Controls.Primitives.IScrollSnapPointsInfo) -> Boolean: ...
    @winrt_mixinmethod
    def add_HorizontalSnapPointsChanged(self: win32more.Microsoft.UI.Xaml.Controls.Primitives.IScrollSnapPointsInfo, handler: win32more.Windows.Foundation.EventHandler[IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_HorizontalSnapPointsChanged(self: win32more.Microsoft.UI.Xaml.Controls.Primitives.IScrollSnapPointsInfo, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_VerticalSnapPointsChanged(self: win32more.Microsoft.UI.Xaml.Controls.Primitives.IScrollSnapPointsInfo, handler: win32more.Windows.Foundation.EventHandler[IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_VerticalSnapPointsChanged(self: win32more.Microsoft.UI.Xaml.Controls.Primitives.IScrollSnapPointsInfo, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def GetIrregularSnapPoints(self: win32more.Microsoft.UI.Xaml.Controls.Primitives.IScrollSnapPointsInfo, orientation: win32more.Microsoft.UI.Xaml.Controls.Orientation, alignment: win32more.Microsoft.UI.Xaml.Controls.Primitives.SnapPointsAlignment) -> win32more.Windows.Foundation.Collections.IVectorView[Single]: ...
    @winrt_mixinmethod
    def GetRegularSnapPoints(self: win32more.Microsoft.UI.Xaml.Controls.Primitives.IScrollSnapPointsInfo, orientation: win32more.Microsoft.UI.Xaml.Controls.Orientation, alignment: win32more.Microsoft.UI.Xaml.Controls.Primitives.SnapPointsAlignment, offset: POINTER(Single)) -> Single: ...
    @winrt_classmethod
    def get_HeaderProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IItemsPresenterStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HeaderTemplateProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IItemsPresenterStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HeaderTransitionsProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IItemsPresenterStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FooterProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IItemsPresenterStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FooterTemplateProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IItemsPresenterStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FooterTransitionsProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IItemsPresenterStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PaddingProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IItemsPresenterStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    AreHorizontalSnapPointsRegular = property(get_AreHorizontalSnapPointsRegular, None)
    AreVerticalSnapPointsRegular = property(get_AreVerticalSnapPointsRegular, None)
    Footer = property(get_Footer, put_Footer)
    FooterTemplate = property(get_FooterTemplate, put_FooterTemplate)
    FooterTransitions = property(get_FooterTransitions, put_FooterTransitions)
    Header = property(get_Header, put_Header)
    HeaderTemplate = property(get_HeaderTemplate, put_HeaderTemplate)
    HeaderTransitions = property(get_HeaderTransitions, put_HeaderTransitions)
    Padding = property(get_Padding, put_Padding)
    _ItemsPresenter_Meta_.FooterProperty = property(get_FooterProperty, None)
    _ItemsPresenter_Meta_.FooterTemplateProperty = property(get_FooterTemplateProperty, None)
    _ItemsPresenter_Meta_.FooterTransitionsProperty = property(get_FooterTransitionsProperty, None)
    _ItemsPresenter_Meta_.HeaderProperty = property(get_HeaderProperty, None)
    _ItemsPresenter_Meta_.HeaderTemplateProperty = property(get_HeaderTemplateProperty, None)
    _ItemsPresenter_Meta_.HeaderTransitionsProperty = property(get_HeaderTransitionsProperty, None)
    _ItemsPresenter_Meta_.PaddingProperty = property(get_PaddingProperty, None)
    HorizontalSnapPointsChanged = event(add_HorizontalSnapPointsChanged, remove_HorizontalSnapPointsChanged)
    VerticalSnapPointsChanged = event(add_VerticalSnapPointsChanged, remove_VerticalSnapPointsChanged)
class _ItemsRepeater_Meta_(ComPtr.__class__):
    pass
class ItemsRepeater(ComPtr, metaclass=_ItemsRepeater_Meta_):
    extends: win32more.Microsoft.UI.Xaml.FrameworkElement
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IItemsRepeater
    _classid_ = 'Microsoft.UI.Xaml.Controls.ItemsRepeater'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.ItemsRepeater.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IItemsRepeaterFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.ItemsRepeater: ...
    @winrt_mixinmethod
    def get_ItemsSource(self: win32more.Microsoft.UI.Xaml.Controls.IItemsRepeater) -> IInspectable: ...
    @winrt_mixinmethod
    def put_ItemsSource(self: win32more.Microsoft.UI.Xaml.Controls.IItemsRepeater, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_ItemsSourceView(self: win32more.Microsoft.UI.Xaml.Controls.IItemsRepeater) -> win32more.Microsoft.UI.Xaml.Controls.ItemsSourceView: ...
    @winrt_mixinmethod
    def get_ItemTemplate(self: win32more.Microsoft.UI.Xaml.Controls.IItemsRepeater) -> IInspectable: ...
    @winrt_mixinmethod
    def put_ItemTemplate(self: win32more.Microsoft.UI.Xaml.Controls.IItemsRepeater, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_Layout(self: win32more.Microsoft.UI.Xaml.Controls.IItemsRepeater) -> win32more.Microsoft.UI.Xaml.Controls.Layout: ...
    @winrt_mixinmethod
    def put_Layout(self: win32more.Microsoft.UI.Xaml.Controls.IItemsRepeater, value: win32more.Microsoft.UI.Xaml.Controls.Layout) -> Void: ...
    @winrt_mixinmethod
    def get_HorizontalCacheLength(self: win32more.Microsoft.UI.Xaml.Controls.IItemsRepeater) -> Double: ...
    @winrt_mixinmethod
    def put_HorizontalCacheLength(self: win32more.Microsoft.UI.Xaml.Controls.IItemsRepeater, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_VerticalCacheLength(self: win32more.Microsoft.UI.Xaml.Controls.IItemsRepeater) -> Double: ...
    @winrt_mixinmethod
    def put_VerticalCacheLength(self: win32more.Microsoft.UI.Xaml.Controls.IItemsRepeater, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_Background(self: win32more.Microsoft.UI.Xaml.Controls.IItemsRepeater) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_Background(self: win32more.Microsoft.UI.Xaml.Controls.IItemsRepeater, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def GetElementIndex(self: win32more.Microsoft.UI.Xaml.Controls.IItemsRepeater, element: win32more.Microsoft.UI.Xaml.UIElement) -> Int32: ...
    @winrt_mixinmethod
    def TryGetElement(self: win32more.Microsoft.UI.Xaml.Controls.IItemsRepeater, index: Int32) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_mixinmethod
    def GetOrCreateElement(self: win32more.Microsoft.UI.Xaml.Controls.IItemsRepeater, index: Int32) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_mixinmethod
    def add_ElementPrepared(self: win32more.Microsoft.UI.Xaml.Controls.IItemsRepeater, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.ItemsRepeater, win32more.Microsoft.UI.Xaml.Controls.ItemsRepeaterElementPreparedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ElementPrepared(self: win32more.Microsoft.UI.Xaml.Controls.IItemsRepeater, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_ElementClearing(self: win32more.Microsoft.UI.Xaml.Controls.IItemsRepeater, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.ItemsRepeater, win32more.Microsoft.UI.Xaml.Controls.ItemsRepeaterElementClearingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ElementClearing(self: win32more.Microsoft.UI.Xaml.Controls.IItemsRepeater, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_ElementIndexChanged(self: win32more.Microsoft.UI.Xaml.Controls.IItemsRepeater, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.ItemsRepeater, win32more.Microsoft.UI.Xaml.Controls.ItemsRepeaterElementIndexChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ElementIndexChanged(self: win32more.Microsoft.UI.Xaml.Controls.IItemsRepeater, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def get_ItemTransitionProvider(self: win32more.Microsoft.UI.Xaml.Controls.IItemsRepeater2) -> win32more.Microsoft.UI.Xaml.Controls.ItemCollectionTransitionProvider: ...
    @winrt_mixinmethod
    def put_ItemTransitionProvider(self: win32more.Microsoft.UI.Xaml.Controls.IItemsRepeater2, value: win32more.Microsoft.UI.Xaml.Controls.ItemCollectionTransitionProvider) -> Void: ...
    @winrt_classmethod
    def get_ItemTransitionProviderProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IItemsRepeaterStatics2) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ItemsSourceProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IItemsRepeaterStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ItemTemplateProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IItemsRepeaterStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_LayoutProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IItemsRepeaterStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HorizontalCacheLengthProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IItemsRepeaterStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_VerticalCacheLengthProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IItemsRepeaterStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_BackgroundProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IItemsRepeaterStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    Background = property(get_Background, put_Background)
    HorizontalCacheLength = property(get_HorizontalCacheLength, put_HorizontalCacheLength)
    ItemTemplate = property(get_ItemTemplate, put_ItemTemplate)
    ItemTransitionProvider = property(get_ItemTransitionProvider, put_ItemTransitionProvider)
    ItemsSource = property(get_ItemsSource, put_ItemsSource)
    ItemsSourceView = property(get_ItemsSourceView, None)
    Layout = property(get_Layout, put_Layout)
    VerticalCacheLength = property(get_VerticalCacheLength, put_VerticalCacheLength)
    _ItemsRepeater_Meta_.BackgroundProperty = property(get_BackgroundProperty, None)
    _ItemsRepeater_Meta_.HorizontalCacheLengthProperty = property(get_HorizontalCacheLengthProperty, None)
    _ItemsRepeater_Meta_.ItemTemplateProperty = property(get_ItemTemplateProperty, None)
    _ItemsRepeater_Meta_.ItemTransitionProviderProperty = property(get_ItemTransitionProviderProperty, None)
    _ItemsRepeater_Meta_.ItemsSourceProperty = property(get_ItemsSourceProperty, None)
    _ItemsRepeater_Meta_.LayoutProperty = property(get_LayoutProperty, None)
    _ItemsRepeater_Meta_.VerticalCacheLengthProperty = property(get_VerticalCacheLengthProperty, None)
    ElementClearing = event(add_ElementClearing, remove_ElementClearing)
    ElementIndexChanged = event(add_ElementIndexChanged, remove_ElementIndexChanged)
    ElementPrepared = event(add_ElementPrepared, remove_ElementPrepared)
class ItemsRepeaterElementClearingEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IItemsRepeaterElementClearingEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.ItemsRepeaterElementClearingEventArgs'
    @winrt_mixinmethod
    def get_Element(self: win32more.Microsoft.UI.Xaml.Controls.IItemsRepeaterElementClearingEventArgs) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    Element = property(get_Element, None)
class ItemsRepeaterElementIndexChangedEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IItemsRepeaterElementIndexChangedEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.ItemsRepeaterElementIndexChangedEventArgs'
    @winrt_mixinmethod
    def get_Element(self: win32more.Microsoft.UI.Xaml.Controls.IItemsRepeaterElementIndexChangedEventArgs) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_mixinmethod
    def get_OldIndex(self: win32more.Microsoft.UI.Xaml.Controls.IItemsRepeaterElementIndexChangedEventArgs) -> Int32: ...
    @winrt_mixinmethod
    def get_NewIndex(self: win32more.Microsoft.UI.Xaml.Controls.IItemsRepeaterElementIndexChangedEventArgs) -> Int32: ...
    Element = property(get_Element, None)
    NewIndex = property(get_NewIndex, None)
    OldIndex = property(get_OldIndex, None)
class ItemsRepeaterElementPreparedEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IItemsRepeaterElementPreparedEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.ItemsRepeaterElementPreparedEventArgs'
    @winrt_mixinmethod
    def get_Element(self: win32more.Microsoft.UI.Xaml.Controls.IItemsRepeaterElementPreparedEventArgs) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_mixinmethod
    def get_Index(self: win32more.Microsoft.UI.Xaml.Controls.IItemsRepeaterElementPreparedEventArgs) -> Int32: ...
    Element = property(get_Element, None)
    Index = property(get_Index, None)
class ItemsRepeaterScrollHost(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.FrameworkElement
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IItemsRepeaterScrollHost
    _classid_ = 'Microsoft.UI.Xaml.Controls.ItemsRepeaterScrollHost'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.ItemsRepeaterScrollHost.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Controls.ItemsRepeaterScrollHost: ...
    @winrt_mixinmethod
    def get_ScrollViewer(self: win32more.Microsoft.UI.Xaml.Controls.IItemsRepeaterScrollHost) -> win32more.Microsoft.UI.Xaml.Controls.ScrollViewer: ...
    @winrt_mixinmethod
    def put_ScrollViewer(self: win32more.Microsoft.UI.Xaml.Controls.IItemsRepeaterScrollHost, value: win32more.Microsoft.UI.Xaml.Controls.ScrollViewer) -> Void: ...
    @winrt_mixinmethod
    def get_CurrentAnchor(self: win32more.Microsoft.UI.Xaml.Controls.IItemsRepeaterScrollHost) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_mixinmethod
    def get_HorizontalAnchorRatio(self: win32more.Microsoft.UI.Xaml.Controls.IItemsRepeaterScrollHost) -> Double: ...
    @winrt_mixinmethod
    def put_HorizontalAnchorRatio(self: win32more.Microsoft.UI.Xaml.Controls.IItemsRepeaterScrollHost, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_VerticalAnchorRatio(self: win32more.Microsoft.UI.Xaml.Controls.IItemsRepeaterScrollHost) -> Double: ...
    @winrt_mixinmethod
    def put_VerticalAnchorRatio(self: win32more.Microsoft.UI.Xaml.Controls.IItemsRepeaterScrollHost, value: Double) -> Void: ...
    CurrentAnchor = property(get_CurrentAnchor, None)
    HorizontalAnchorRatio = property(get_HorizontalAnchorRatio, put_HorizontalAnchorRatio)
    ScrollViewer = property(get_ScrollViewer, put_ScrollViewer)
    VerticalAnchorRatio = property(get_VerticalAnchorRatio, put_VerticalAnchorRatio)
class ItemsSourceView(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IItemsSourceView
    _classid_ = 'Microsoft.UI.Xaml.Controls.ItemsSourceView'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 1:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.ItemsSourceView.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IItemsSourceViewFactory, source: IInspectable, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.ItemsSourceView: ...
    @winrt_mixinmethod
    def get_Count(self: win32more.Microsoft.UI.Xaml.Controls.IItemsSourceView) -> Int32: ...
    @winrt_mixinmethod
    def GetAt(self: win32more.Microsoft.UI.Xaml.Controls.IItemsSourceView, index: Int32) -> IInspectable: ...
    @winrt_mixinmethod
    def get_HasKeyIndexMapping(self: win32more.Microsoft.UI.Xaml.Controls.IItemsSourceView) -> Boolean: ...
    @winrt_mixinmethod
    def KeyFromIndex(self: win32more.Microsoft.UI.Xaml.Controls.IItemsSourceView, index: Int32) -> hstr: ...
    @winrt_mixinmethod
    def IndexFromKey(self: win32more.Microsoft.UI.Xaml.Controls.IItemsSourceView, key: hstr) -> Int32: ...
    @winrt_mixinmethod
    def IndexOf(self: win32more.Microsoft.UI.Xaml.Controls.IItemsSourceView, item: IInspectable) -> Int32: ...
    @winrt_mixinmethod
    def add_CollectionChanged(self: win32more.Microsoft.UI.Xaml.Interop.INotifyCollectionChanged, handler: win32more.Microsoft.UI.Xaml.Interop.NotifyCollectionChangedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_CollectionChanged(self: win32more.Microsoft.UI.Xaml.Interop.INotifyCollectionChanged, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    Count = property(get_Count, None)
    HasKeyIndexMapping = property(get_HasKeyIndexMapping, None)
    CollectionChanged = event(add_CollectionChanged, remove_CollectionChanged)
class _ItemsStackPanel_Meta_(ComPtr.__class__):
    pass
class ItemsStackPanel(ComPtr, metaclass=_ItemsStackPanel_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.Panel
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IItemsStackPanel
    _classid_ = 'Microsoft.UI.Xaml.Controls.ItemsStackPanel'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.ItemsStackPanel.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Controls.ItemsStackPanel: ...
    @winrt_mixinmethod
    def get_GroupPadding(self: win32more.Microsoft.UI.Xaml.Controls.IItemsStackPanel) -> win32more.Microsoft.UI.Xaml.Thickness: ...
    @winrt_mixinmethod
    def put_GroupPadding(self: win32more.Microsoft.UI.Xaml.Controls.IItemsStackPanel, value: win32more.Microsoft.UI.Xaml.Thickness) -> Void: ...
    @winrt_mixinmethod
    def get_Orientation(self: win32more.Microsoft.UI.Xaml.Controls.IItemsStackPanel) -> win32more.Microsoft.UI.Xaml.Controls.Orientation: ...
    @winrt_mixinmethod
    def put_Orientation(self: win32more.Microsoft.UI.Xaml.Controls.IItemsStackPanel, value: win32more.Microsoft.UI.Xaml.Controls.Orientation) -> Void: ...
    @winrt_mixinmethod
    def get_FirstCacheIndex(self: win32more.Microsoft.UI.Xaml.Controls.IItemsStackPanel) -> Int32: ...
    @winrt_mixinmethod
    def get_FirstVisibleIndex(self: win32more.Microsoft.UI.Xaml.Controls.IItemsStackPanel) -> Int32: ...
    @winrt_mixinmethod
    def get_LastVisibleIndex(self: win32more.Microsoft.UI.Xaml.Controls.IItemsStackPanel) -> Int32: ...
    @winrt_mixinmethod
    def get_LastCacheIndex(self: win32more.Microsoft.UI.Xaml.Controls.IItemsStackPanel) -> Int32: ...
    @winrt_mixinmethod
    def get_ScrollingDirection(self: win32more.Microsoft.UI.Xaml.Controls.IItemsStackPanel) -> win32more.Microsoft.UI.Xaml.Controls.PanelScrollingDirection: ...
    @winrt_mixinmethod
    def get_GroupHeaderPlacement(self: win32more.Microsoft.UI.Xaml.Controls.IItemsStackPanel) -> win32more.Microsoft.UI.Xaml.Controls.Primitives.GroupHeaderPlacement: ...
    @winrt_mixinmethod
    def put_GroupHeaderPlacement(self: win32more.Microsoft.UI.Xaml.Controls.IItemsStackPanel, value: win32more.Microsoft.UI.Xaml.Controls.Primitives.GroupHeaderPlacement) -> Void: ...
    @winrt_mixinmethod
    def get_ItemsUpdatingScrollMode(self: win32more.Microsoft.UI.Xaml.Controls.IItemsStackPanel) -> win32more.Microsoft.UI.Xaml.Controls.ItemsUpdatingScrollMode: ...
    @winrt_mixinmethod
    def put_ItemsUpdatingScrollMode(self: win32more.Microsoft.UI.Xaml.Controls.IItemsStackPanel, value: win32more.Microsoft.UI.Xaml.Controls.ItemsUpdatingScrollMode) -> Void: ...
    @winrt_mixinmethod
    def get_CacheLength(self: win32more.Microsoft.UI.Xaml.Controls.IItemsStackPanel) -> Double: ...
    @winrt_mixinmethod
    def put_CacheLength(self: win32more.Microsoft.UI.Xaml.Controls.IItemsStackPanel, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_AreStickyGroupHeadersEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IItemsStackPanel) -> Boolean: ...
    @winrt_mixinmethod
    def put_AreStickyGroupHeadersEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IItemsStackPanel, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_GroupPaddingProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IItemsStackPanelStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_OrientationProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IItemsStackPanelStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_GroupHeaderPlacementProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IItemsStackPanelStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CacheLengthProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IItemsStackPanelStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_AreStickyGroupHeadersEnabledProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IItemsStackPanelStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    AreStickyGroupHeadersEnabled = property(get_AreStickyGroupHeadersEnabled, put_AreStickyGroupHeadersEnabled)
    CacheLength = property(get_CacheLength, put_CacheLength)
    FirstCacheIndex = property(get_FirstCacheIndex, None)
    FirstVisibleIndex = property(get_FirstVisibleIndex, None)
    GroupHeaderPlacement = property(get_GroupHeaderPlacement, put_GroupHeaderPlacement)
    GroupPadding = property(get_GroupPadding, put_GroupPadding)
    ItemsUpdatingScrollMode = property(get_ItemsUpdatingScrollMode, put_ItemsUpdatingScrollMode)
    LastCacheIndex = property(get_LastCacheIndex, None)
    LastVisibleIndex = property(get_LastVisibleIndex, None)
    Orientation = property(get_Orientation, put_Orientation)
    ScrollingDirection = property(get_ScrollingDirection, None)
    _ItemsStackPanel_Meta_.AreStickyGroupHeadersEnabledProperty = property(get_AreStickyGroupHeadersEnabledProperty, None)
    _ItemsStackPanel_Meta_.CacheLengthProperty = property(get_CacheLengthProperty, None)
    _ItemsStackPanel_Meta_.GroupHeaderPlacementProperty = property(get_GroupHeaderPlacementProperty, None)
    _ItemsStackPanel_Meta_.GroupPaddingProperty = property(get_GroupPaddingProperty, None)
    _ItemsStackPanel_Meta_.OrientationProperty = property(get_OrientationProperty, None)
class ItemsUpdatingScrollMode(Enum, Int32):
    KeepItemsInView = 0
    KeepScrollOffset = 1
    KeepLastItemInView = 2
class _ItemsView_Meta_(ComPtr.__class__):
    pass
class ItemsView(ComPtr, metaclass=_ItemsView_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.Control
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IItemsView
    _classid_ = 'Microsoft.UI.Xaml.Controls.ItemsView'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.ItemsView.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IItemsViewFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.ItemsView: ...
    @winrt_mixinmethod
    def get_ItemsSource(self: win32more.Microsoft.UI.Xaml.Controls.IItemsView) -> IInspectable: ...
    @winrt_mixinmethod
    def put_ItemsSource(self: win32more.Microsoft.UI.Xaml.Controls.IItemsView, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_ScrollView(self: win32more.Microsoft.UI.Xaml.Controls.IItemsView) -> win32more.Microsoft.UI.Xaml.Controls.ScrollView: ...
    @winrt_mixinmethod
    def get_VerticalScrollController(self: win32more.Microsoft.UI.Xaml.Controls.IItemsView) -> win32more.Microsoft.UI.Xaml.Controls.Primitives.IScrollController: ...
    @winrt_mixinmethod
    def put_VerticalScrollController(self: win32more.Microsoft.UI.Xaml.Controls.IItemsView, value: win32more.Microsoft.UI.Xaml.Controls.Primitives.IScrollController) -> Void: ...
    @winrt_mixinmethod
    def get_ItemTemplate(self: win32more.Microsoft.UI.Xaml.Controls.IItemsView) -> win32more.Microsoft.UI.Xaml.IElementFactory: ...
    @winrt_mixinmethod
    def put_ItemTemplate(self: win32more.Microsoft.UI.Xaml.Controls.IItemsView, value: win32more.Microsoft.UI.Xaml.IElementFactory) -> Void: ...
    @winrt_mixinmethod
    def get_Layout(self: win32more.Microsoft.UI.Xaml.Controls.IItemsView) -> win32more.Microsoft.UI.Xaml.Controls.Layout: ...
    @winrt_mixinmethod
    def put_Layout(self: win32more.Microsoft.UI.Xaml.Controls.IItemsView, value: win32more.Microsoft.UI.Xaml.Controls.Layout) -> Void: ...
    @winrt_mixinmethod
    def get_IsItemInvokedEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IItemsView) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsItemInvokedEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IItemsView, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_SelectionMode(self: win32more.Microsoft.UI.Xaml.Controls.IItemsView) -> win32more.Microsoft.UI.Xaml.Controls.ItemsViewSelectionMode: ...
    @winrt_mixinmethod
    def put_SelectionMode(self: win32more.Microsoft.UI.Xaml.Controls.IItemsView, value: win32more.Microsoft.UI.Xaml.Controls.ItemsViewSelectionMode) -> Void: ...
    @winrt_mixinmethod
    def get_ItemTransitionProvider(self: win32more.Microsoft.UI.Xaml.Controls.IItemsView) -> win32more.Microsoft.UI.Xaml.Controls.ItemCollectionTransitionProvider: ...
    @winrt_mixinmethod
    def put_ItemTransitionProvider(self: win32more.Microsoft.UI.Xaml.Controls.IItemsView, value: win32more.Microsoft.UI.Xaml.Controls.ItemCollectionTransitionProvider) -> Void: ...
    @winrt_mixinmethod
    def get_CurrentItemIndex(self: win32more.Microsoft.UI.Xaml.Controls.IItemsView) -> Int32: ...
    @winrt_mixinmethod
    def get_SelectedItem(self: win32more.Microsoft.UI.Xaml.Controls.IItemsView) -> IInspectable: ...
    @winrt_mixinmethod
    def get_SelectedItems(self: win32more.Microsoft.UI.Xaml.Controls.IItemsView) -> win32more.Windows.Foundation.Collections.IVectorView[IInspectable]: ...
    @winrt_mixinmethod
    def TryGetItemIndex(self: win32more.Microsoft.UI.Xaml.Controls.IItemsView, horizontalViewportRatio: Double, verticalViewportRatio: Double, index: POINTER(Int32)) -> Boolean: ...
    @winrt_mixinmethod
    def StartBringItemIntoView(self: win32more.Microsoft.UI.Xaml.Controls.IItemsView, index: Int32, options: win32more.Microsoft.UI.Xaml.BringIntoViewOptions) -> Void: ...
    @winrt_mixinmethod
    def Select(self: win32more.Microsoft.UI.Xaml.Controls.IItemsView, itemIndex: Int32) -> Void: ...
    @winrt_mixinmethod
    def Deselect(self: win32more.Microsoft.UI.Xaml.Controls.IItemsView, itemIndex: Int32) -> Void: ...
    @winrt_mixinmethod
    def IsSelected(self: win32more.Microsoft.UI.Xaml.Controls.IItemsView, itemIndex: Int32) -> Boolean: ...
    @winrt_mixinmethod
    def SelectAll(self: win32more.Microsoft.UI.Xaml.Controls.IItemsView) -> Void: ...
    @winrt_mixinmethod
    def DeselectAll(self: win32more.Microsoft.UI.Xaml.Controls.IItemsView) -> Void: ...
    @winrt_mixinmethod
    def InvertSelection(self: win32more.Microsoft.UI.Xaml.Controls.IItemsView) -> Void: ...
    @winrt_mixinmethod
    def add_ItemInvoked(self: win32more.Microsoft.UI.Xaml.Controls.IItemsView, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.ItemsView, win32more.Microsoft.UI.Xaml.Controls.ItemsViewItemInvokedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ItemInvoked(self: win32more.Microsoft.UI.Xaml.Controls.IItemsView, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_SelectionChanged(self: win32more.Microsoft.UI.Xaml.Controls.IItemsView, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.ItemsView, win32more.Microsoft.UI.Xaml.Controls.ItemsViewSelectionChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_SelectionChanged(self: win32more.Microsoft.UI.Xaml.Controls.IItemsView, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def get_IsItemInvokedEnabledProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IItemsViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ItemsSourceProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IItemsViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ItemTemplateProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IItemsViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_LayoutProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IItemsViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectionModeProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IItemsViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ItemTransitionProviderProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IItemsViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CurrentItemIndexProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IItemsViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectedItemProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IItemsViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ScrollViewProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IItemsViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_VerticalScrollControllerProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IItemsViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    CurrentItemIndex = property(get_CurrentItemIndex, None)
    IsItemInvokedEnabled = property(get_IsItemInvokedEnabled, put_IsItemInvokedEnabled)
    ItemTemplate = property(get_ItemTemplate, put_ItemTemplate)
    ItemTransitionProvider = property(get_ItemTransitionProvider, put_ItemTransitionProvider)
    ItemsSource = property(get_ItemsSource, put_ItemsSource)
    Layout = property(get_Layout, put_Layout)
    ScrollView = property(get_ScrollView, None)
    SelectedItem = property(get_SelectedItem, None)
    SelectedItems = property(get_SelectedItems, None)
    SelectionMode = property(get_SelectionMode, put_SelectionMode)
    VerticalScrollController = property(get_VerticalScrollController, put_VerticalScrollController)
    _ItemsView_Meta_.CurrentItemIndexProperty = property(get_CurrentItemIndexProperty, None)
    _ItemsView_Meta_.IsItemInvokedEnabledProperty = property(get_IsItemInvokedEnabledProperty, None)
    _ItemsView_Meta_.ItemTemplateProperty = property(get_ItemTemplateProperty, None)
    _ItemsView_Meta_.ItemTransitionProviderProperty = property(get_ItemTransitionProviderProperty, None)
    _ItemsView_Meta_.ItemsSourceProperty = property(get_ItemsSourceProperty, None)
    _ItemsView_Meta_.LayoutProperty = property(get_LayoutProperty, None)
    _ItemsView_Meta_.ScrollViewProperty = property(get_ScrollViewProperty, None)
    _ItemsView_Meta_.SelectedItemProperty = property(get_SelectedItemProperty, None)
    _ItemsView_Meta_.SelectionModeProperty = property(get_SelectionModeProperty, None)
    _ItemsView_Meta_.VerticalScrollControllerProperty = property(get_VerticalScrollControllerProperty, None)
    ItemInvoked = event(add_ItemInvoked, remove_ItemInvoked)
    SelectionChanged = event(add_SelectionChanged, remove_SelectionChanged)
class ItemsViewItemInvokedEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IItemsViewItemInvokedEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.ItemsViewItemInvokedEventArgs'
    @winrt_mixinmethod
    def get_InvokedItem(self: win32more.Microsoft.UI.Xaml.Controls.IItemsViewItemInvokedEventArgs) -> IInspectable: ...
    InvokedItem = property(get_InvokedItem, None)
class ItemsViewSelectionChangedEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IItemsViewSelectionChangedEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.ItemsViewSelectionChangedEventArgs'
class ItemsViewSelectionMode(Enum, Int32):
    None_ = 0
    Single = 1
    Multiple = 2
    Extended = 3
class _ItemsWrapGrid_Meta_(ComPtr.__class__):
    pass
class ItemsWrapGrid(ComPtr, metaclass=_ItemsWrapGrid_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.Panel
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IItemsWrapGrid
    _classid_ = 'Microsoft.UI.Xaml.Controls.ItemsWrapGrid'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.ItemsWrapGrid.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Controls.ItemsWrapGrid: ...
    @winrt_mixinmethod
    def get_GroupPadding(self: win32more.Microsoft.UI.Xaml.Controls.IItemsWrapGrid) -> win32more.Microsoft.UI.Xaml.Thickness: ...
    @winrt_mixinmethod
    def put_GroupPadding(self: win32more.Microsoft.UI.Xaml.Controls.IItemsWrapGrid, value: win32more.Microsoft.UI.Xaml.Thickness) -> Void: ...
    @winrt_mixinmethod
    def get_Orientation(self: win32more.Microsoft.UI.Xaml.Controls.IItemsWrapGrid) -> win32more.Microsoft.UI.Xaml.Controls.Orientation: ...
    @winrt_mixinmethod
    def put_Orientation(self: win32more.Microsoft.UI.Xaml.Controls.IItemsWrapGrid, value: win32more.Microsoft.UI.Xaml.Controls.Orientation) -> Void: ...
    @winrt_mixinmethod
    def get_MaximumRowsOrColumns(self: win32more.Microsoft.UI.Xaml.Controls.IItemsWrapGrid) -> Int32: ...
    @winrt_mixinmethod
    def put_MaximumRowsOrColumns(self: win32more.Microsoft.UI.Xaml.Controls.IItemsWrapGrid, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_ItemWidth(self: win32more.Microsoft.UI.Xaml.Controls.IItemsWrapGrid) -> Double: ...
    @winrt_mixinmethod
    def put_ItemWidth(self: win32more.Microsoft.UI.Xaml.Controls.IItemsWrapGrid, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_ItemHeight(self: win32more.Microsoft.UI.Xaml.Controls.IItemsWrapGrid) -> Double: ...
    @winrt_mixinmethod
    def put_ItemHeight(self: win32more.Microsoft.UI.Xaml.Controls.IItemsWrapGrid, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_FirstCacheIndex(self: win32more.Microsoft.UI.Xaml.Controls.IItemsWrapGrid) -> Int32: ...
    @winrt_mixinmethod
    def get_FirstVisibleIndex(self: win32more.Microsoft.UI.Xaml.Controls.IItemsWrapGrid) -> Int32: ...
    @winrt_mixinmethod
    def get_LastVisibleIndex(self: win32more.Microsoft.UI.Xaml.Controls.IItemsWrapGrid) -> Int32: ...
    @winrt_mixinmethod
    def get_LastCacheIndex(self: win32more.Microsoft.UI.Xaml.Controls.IItemsWrapGrid) -> Int32: ...
    @winrt_mixinmethod
    def get_ScrollingDirection(self: win32more.Microsoft.UI.Xaml.Controls.IItemsWrapGrid) -> win32more.Microsoft.UI.Xaml.Controls.PanelScrollingDirection: ...
    @winrt_mixinmethod
    def get_GroupHeaderPlacement(self: win32more.Microsoft.UI.Xaml.Controls.IItemsWrapGrid) -> win32more.Microsoft.UI.Xaml.Controls.Primitives.GroupHeaderPlacement: ...
    @winrt_mixinmethod
    def put_GroupHeaderPlacement(self: win32more.Microsoft.UI.Xaml.Controls.IItemsWrapGrid, value: win32more.Microsoft.UI.Xaml.Controls.Primitives.GroupHeaderPlacement) -> Void: ...
    @winrt_mixinmethod
    def get_CacheLength(self: win32more.Microsoft.UI.Xaml.Controls.IItemsWrapGrid) -> Double: ...
    @winrt_mixinmethod
    def put_CacheLength(self: win32more.Microsoft.UI.Xaml.Controls.IItemsWrapGrid, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_AreStickyGroupHeadersEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IItemsWrapGrid) -> Boolean: ...
    @winrt_mixinmethod
    def put_AreStickyGroupHeadersEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IItemsWrapGrid, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_GroupPaddingProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IItemsWrapGridStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_OrientationProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IItemsWrapGridStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MaximumRowsOrColumnsProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IItemsWrapGridStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ItemWidthProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IItemsWrapGridStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ItemHeightProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IItemsWrapGridStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_GroupHeaderPlacementProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IItemsWrapGridStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CacheLengthProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IItemsWrapGridStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_AreStickyGroupHeadersEnabledProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IItemsWrapGridStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    AreStickyGroupHeadersEnabled = property(get_AreStickyGroupHeadersEnabled, put_AreStickyGroupHeadersEnabled)
    CacheLength = property(get_CacheLength, put_CacheLength)
    FirstCacheIndex = property(get_FirstCacheIndex, None)
    FirstVisibleIndex = property(get_FirstVisibleIndex, None)
    GroupHeaderPlacement = property(get_GroupHeaderPlacement, put_GroupHeaderPlacement)
    GroupPadding = property(get_GroupPadding, put_GroupPadding)
    ItemHeight = property(get_ItemHeight, put_ItemHeight)
    ItemWidth = property(get_ItemWidth, put_ItemWidth)
    LastCacheIndex = property(get_LastCacheIndex, None)
    LastVisibleIndex = property(get_LastVisibleIndex, None)
    MaximumRowsOrColumns = property(get_MaximumRowsOrColumns, put_MaximumRowsOrColumns)
    Orientation = property(get_Orientation, put_Orientation)
    ScrollingDirection = property(get_ScrollingDirection, None)
    _ItemsWrapGrid_Meta_.AreStickyGroupHeadersEnabledProperty = property(get_AreStickyGroupHeadersEnabledProperty, None)
    _ItemsWrapGrid_Meta_.CacheLengthProperty = property(get_CacheLengthProperty, None)
    _ItemsWrapGrid_Meta_.GroupHeaderPlacementProperty = property(get_GroupHeaderPlacementProperty, None)
    _ItemsWrapGrid_Meta_.GroupPaddingProperty = property(get_GroupPaddingProperty, None)
    _ItemsWrapGrid_Meta_.ItemHeightProperty = property(get_ItemHeightProperty, None)
    _ItemsWrapGrid_Meta_.ItemWidthProperty = property(get_ItemWidthProperty, None)
    _ItemsWrapGrid_Meta_.MaximumRowsOrColumnsProperty = property(get_MaximumRowsOrColumnsProperty, None)
    _ItemsWrapGrid_Meta_.OrientationProperty = property(get_OrientationProperty, None)
class Layout(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.DependencyObject
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ILayout
    _classid_ = 'Microsoft.UI.Xaml.Controls.Layout'
    @winrt_mixinmethod
    def InitializeForContext(self: win32more.Microsoft.UI.Xaml.Controls.ILayout, context: win32more.Microsoft.UI.Xaml.Controls.LayoutContext) -> Void: ...
    @winrt_mixinmethod
    def UninitializeForContext(self: win32more.Microsoft.UI.Xaml.Controls.ILayout, context: win32more.Microsoft.UI.Xaml.Controls.LayoutContext) -> Void: ...
    @winrt_mixinmethod
    def Measure(self: win32more.Microsoft.UI.Xaml.Controls.ILayout, context: win32more.Microsoft.UI.Xaml.Controls.LayoutContext, availableSize: win32more.Windows.Foundation.Size) -> win32more.Windows.Foundation.Size: ...
    @winrt_mixinmethod
    def Arrange(self: win32more.Microsoft.UI.Xaml.Controls.ILayout, context: win32more.Microsoft.UI.Xaml.Controls.LayoutContext, finalSize: win32more.Windows.Foundation.Size) -> win32more.Windows.Foundation.Size: ...
    @winrt_mixinmethod
    def add_MeasureInvalidated(self: win32more.Microsoft.UI.Xaml.Controls.ILayout, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.Layout, IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_MeasureInvalidated(self: win32more.Microsoft.UI.Xaml.Controls.ILayout, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_ArrangeInvalidated(self: win32more.Microsoft.UI.Xaml.Controls.ILayout, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.Layout, IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ArrangeInvalidated(self: win32more.Microsoft.UI.Xaml.Controls.ILayout, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def get_IndexBasedLayoutOrientation(self: win32more.Microsoft.UI.Xaml.Controls.ILayout2) -> win32more.Microsoft.UI.Xaml.Controls.IndexBasedLayoutOrientation: ...
    @winrt_mixinmethod
    def InvalidateMeasure(self: win32more.Microsoft.UI.Xaml.Controls.ILayoutProtected) -> Void: ...
    @winrt_mixinmethod
    def InvalidateArrange(self: win32more.Microsoft.UI.Xaml.Controls.ILayoutProtected) -> Void: ...
    @winrt_mixinmethod
    def SetIndexBasedLayoutOrientation(self: win32more.Microsoft.UI.Xaml.Controls.ILayoutProtected2, orientation: win32more.Microsoft.UI.Xaml.Controls.IndexBasedLayoutOrientation) -> Void: ...
    @winrt_mixinmethod
    def CreateDefaultItemTransitionProvider(self: win32more.Microsoft.UI.Xaml.Controls.ILayoutOverrides) -> win32more.Microsoft.UI.Xaml.Controls.ItemCollectionTransitionProvider: ...
    IndexBasedLayoutOrientation = property(get_IndexBasedLayoutOrientation, None)
    ArrangeInvalidated = event(add_ArrangeInvalidated, remove_ArrangeInvalidated)
    MeasureInvalidated = event(add_MeasureInvalidated, remove_MeasureInvalidated)
class LayoutContext(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.DependencyObject
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ILayoutContext
    _classid_ = 'Microsoft.UI.Xaml.Controls.LayoutContext'
    @winrt_mixinmethod
    def get_LayoutState(self: win32more.Microsoft.UI.Xaml.Controls.ILayoutContext) -> IInspectable: ...
    @winrt_mixinmethod
    def put_LayoutState(self: win32more.Microsoft.UI.Xaml.Controls.ILayoutContext, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_LayoutStateCore(self: win32more.Microsoft.UI.Xaml.Controls.ILayoutContextOverrides) -> IInspectable: ...
    @winrt_mixinmethod
    def put_LayoutStateCore(self: win32more.Microsoft.UI.Xaml.Controls.ILayoutContextOverrides, value: IInspectable) -> Void: ...
    LayoutState = property(get_LayoutState, put_LayoutState)
    LayoutStateCore = property(get_LayoutStateCore, put_LayoutStateCore)
class LightDismissOverlayMode(Enum, Int32):
    Auto = 0
    On = 1
    Off = 2
class _LinedFlowLayout_Meta_(ComPtr.__class__):
    pass
class LinedFlowLayout(ComPtr, metaclass=_LinedFlowLayout_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.VirtualizingLayout
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ILinedFlowLayout
    _classid_ = 'Microsoft.UI.Xaml.Controls.LinedFlowLayout'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.LinedFlowLayout.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.ILinedFlowLayoutFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.LinedFlowLayout: ...
    @winrt_mixinmethod
    def add_ItemsInfoRequested(self: win32more.Microsoft.UI.Xaml.Controls.ILinedFlowLayout, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.LinedFlowLayout, win32more.Microsoft.UI.Xaml.Controls.LinedFlowLayoutItemsInfoRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ItemsInfoRequested(self: win32more.Microsoft.UI.Xaml.Controls.ILinedFlowLayout, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_ItemsUnlocked(self: win32more.Microsoft.UI.Xaml.Controls.ILinedFlowLayout, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.LinedFlowLayout, IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ItemsUnlocked(self: win32more.Microsoft.UI.Xaml.Controls.ILinedFlowLayout, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def get_ItemsJustification(self: win32more.Microsoft.UI.Xaml.Controls.ILinedFlowLayout) -> win32more.Microsoft.UI.Xaml.Controls.LinedFlowLayoutItemsJustification: ...
    @winrt_mixinmethod
    def put_ItemsJustification(self: win32more.Microsoft.UI.Xaml.Controls.ILinedFlowLayout, value: win32more.Microsoft.UI.Xaml.Controls.LinedFlowLayoutItemsJustification) -> Void: ...
    @winrt_mixinmethod
    def get_ItemsStretch(self: win32more.Microsoft.UI.Xaml.Controls.ILinedFlowLayout) -> win32more.Microsoft.UI.Xaml.Controls.LinedFlowLayoutItemsStretch: ...
    @winrt_mixinmethod
    def put_ItemsStretch(self: win32more.Microsoft.UI.Xaml.Controls.ILinedFlowLayout, value: win32more.Microsoft.UI.Xaml.Controls.LinedFlowLayoutItemsStretch) -> Void: ...
    @winrt_mixinmethod
    def get_MinItemSpacing(self: win32more.Microsoft.UI.Xaml.Controls.ILinedFlowLayout) -> Double: ...
    @winrt_mixinmethod
    def put_MinItemSpacing(self: win32more.Microsoft.UI.Xaml.Controls.ILinedFlowLayout, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_LineSpacing(self: win32more.Microsoft.UI.Xaml.Controls.ILinedFlowLayout) -> Double: ...
    @winrt_mixinmethod
    def put_LineSpacing(self: win32more.Microsoft.UI.Xaml.Controls.ILinedFlowLayout, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_LineHeight(self: win32more.Microsoft.UI.Xaml.Controls.ILinedFlowLayout) -> Double: ...
    @winrt_mixinmethod
    def put_LineHeight(self: win32more.Microsoft.UI.Xaml.Controls.ILinedFlowLayout, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_ActualLineHeight(self: win32more.Microsoft.UI.Xaml.Controls.ILinedFlowLayout) -> Double: ...
    @winrt_mixinmethod
    def get_RequestedRangeStartIndex(self: win32more.Microsoft.UI.Xaml.Controls.ILinedFlowLayout) -> Int32: ...
    @winrt_mixinmethod
    def get_RequestedRangeLength(self: win32more.Microsoft.UI.Xaml.Controls.ILinedFlowLayout) -> Int32: ...
    @winrt_mixinmethod
    def InvalidateItemsInfo(self: win32more.Microsoft.UI.Xaml.Controls.ILinedFlowLayout) -> Void: ...
    @winrt_mixinmethod
    def LockItemToLine(self: win32more.Microsoft.UI.Xaml.Controls.ILinedFlowLayout, itemIndex: Int32) -> Int32: ...
    @winrt_classmethod
    def get_ItemsJustificationProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ILinedFlowLayoutStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ItemsStretchProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ILinedFlowLayoutStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MinItemSpacingProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ILinedFlowLayoutStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_LineSpacingProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ILinedFlowLayoutStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_LineHeightProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ILinedFlowLayoutStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ActualLineHeightProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ILinedFlowLayoutStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    ActualLineHeight = property(get_ActualLineHeight, None)
    ItemsJustification = property(get_ItemsJustification, put_ItemsJustification)
    ItemsStretch = property(get_ItemsStretch, put_ItemsStretch)
    LineHeight = property(get_LineHeight, put_LineHeight)
    LineSpacing = property(get_LineSpacing, put_LineSpacing)
    MinItemSpacing = property(get_MinItemSpacing, put_MinItemSpacing)
    RequestedRangeLength = property(get_RequestedRangeLength, None)
    RequestedRangeStartIndex = property(get_RequestedRangeStartIndex, None)
    _LinedFlowLayout_Meta_.ActualLineHeightProperty = property(get_ActualLineHeightProperty, None)
    _LinedFlowLayout_Meta_.ItemsJustificationProperty = property(get_ItemsJustificationProperty, None)
    _LinedFlowLayout_Meta_.ItemsStretchProperty = property(get_ItemsStretchProperty, None)
    _LinedFlowLayout_Meta_.LineHeightProperty = property(get_LineHeightProperty, None)
    _LinedFlowLayout_Meta_.LineSpacingProperty = property(get_LineSpacingProperty, None)
    _LinedFlowLayout_Meta_.MinItemSpacingProperty = property(get_MinItemSpacingProperty, None)
    ItemsInfoRequested = event(add_ItemsInfoRequested, remove_ItemsInfoRequested)
    ItemsUnlocked = event(add_ItemsUnlocked, remove_ItemsUnlocked)
class LinedFlowLayoutItemCollectionTransitionProvider(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.Controls.ItemCollectionTransitionProvider
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ILinedFlowLayoutItemCollectionTransitionProvider
    _classid_ = 'Microsoft.UI.Xaml.Controls.LinedFlowLayoutItemCollectionTransitionProvider'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.LinedFlowLayoutItemCollectionTransitionProvider.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.ILinedFlowLayoutItemCollectionTransitionProviderFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.LinedFlowLayoutItemCollectionTransitionProvider: ...
class LinedFlowLayoutItemsInfoRequestedEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ILinedFlowLayoutItemsInfoRequestedEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.LinedFlowLayoutItemsInfoRequestedEventArgs'
    @winrt_mixinmethod
    def get_ItemsRangeStartIndex(self: win32more.Microsoft.UI.Xaml.Controls.ILinedFlowLayoutItemsInfoRequestedEventArgs) -> Int32: ...
    @winrt_mixinmethod
    def put_ItemsRangeStartIndex(self: win32more.Microsoft.UI.Xaml.Controls.ILinedFlowLayoutItemsInfoRequestedEventArgs, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_ItemsRangeRequestedLength(self: win32more.Microsoft.UI.Xaml.Controls.ILinedFlowLayoutItemsInfoRequestedEventArgs) -> Int32: ...
    @winrt_mixinmethod
    def get_MinWidth(self: win32more.Microsoft.UI.Xaml.Controls.ILinedFlowLayoutItemsInfoRequestedEventArgs) -> Double: ...
    @winrt_mixinmethod
    def put_MinWidth(self: win32more.Microsoft.UI.Xaml.Controls.ILinedFlowLayoutItemsInfoRequestedEventArgs, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_MaxWidth(self: win32more.Microsoft.UI.Xaml.Controls.ILinedFlowLayoutItemsInfoRequestedEventArgs) -> Double: ...
    @winrt_mixinmethod
    def put_MaxWidth(self: win32more.Microsoft.UI.Xaml.Controls.ILinedFlowLayoutItemsInfoRequestedEventArgs, value: Double) -> Void: ...
    @winrt_mixinmethod
    def SetDesiredAspectRatios(self: win32more.Microsoft.UI.Xaml.Controls.ILinedFlowLayoutItemsInfoRequestedEventArgs, values: PassArray[Double]) -> Void: ...
    @winrt_mixinmethod
    def SetMinWidths(self: win32more.Microsoft.UI.Xaml.Controls.ILinedFlowLayoutItemsInfoRequestedEventArgs, values: PassArray[Double]) -> Void: ...
    @winrt_mixinmethod
    def SetMaxWidths(self: win32more.Microsoft.UI.Xaml.Controls.ILinedFlowLayoutItemsInfoRequestedEventArgs, values: PassArray[Double]) -> Void: ...
    ItemsRangeRequestedLength = property(get_ItemsRangeRequestedLength, None)
    ItemsRangeStartIndex = property(get_ItemsRangeStartIndex, put_ItemsRangeStartIndex)
    MaxWidth = property(get_MaxWidth, put_MaxWidth)
    MinWidth = property(get_MinWidth, put_MinWidth)
class LinedFlowLayoutItemsJustification(Enum, Int32):
    Start = 0
    Center = 1
    End = 2
    SpaceAround = 3
    SpaceBetween = 4
    SpaceEvenly = 5
class LinedFlowLayoutItemsStretch(Enum, Int32):
    None_ = 0
    Fill = 1
class _ListBox_Meta_(ComPtr.__class__):
    pass
class ListBox(ComPtr, metaclass=_ListBox_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.Primitives.Selector
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IListBox
    _classid_ = 'Microsoft.UI.Xaml.Controls.ListBox'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.ListBox.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IListBoxFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.ListBox: ...
    @winrt_mixinmethod
    def get_SelectedItems(self: win32more.Microsoft.UI.Xaml.Controls.IListBox) -> win32more.Windows.Foundation.Collections.IVector[IInspectable]: ...
    @winrt_mixinmethod
    def get_SelectionMode(self: win32more.Microsoft.UI.Xaml.Controls.IListBox) -> win32more.Microsoft.UI.Xaml.Controls.SelectionMode: ...
    @winrt_mixinmethod
    def put_SelectionMode(self: win32more.Microsoft.UI.Xaml.Controls.IListBox, value: win32more.Microsoft.UI.Xaml.Controls.SelectionMode) -> Void: ...
    @winrt_mixinmethod
    def get_SingleSelectionFollowsFocus(self: win32more.Microsoft.UI.Xaml.Controls.IListBox) -> Boolean: ...
    @winrt_mixinmethod
    def put_SingleSelectionFollowsFocus(self: win32more.Microsoft.UI.Xaml.Controls.IListBox, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def ScrollIntoView(self: win32more.Microsoft.UI.Xaml.Controls.IListBox, item: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def SelectAll(self: win32more.Microsoft.UI.Xaml.Controls.IListBox) -> Void: ...
    @winrt_classmethod
    def get_SelectionModeProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IListBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SingleSelectionFollowsFocusProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IListBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    SelectedItems = property(get_SelectedItems, None)
    SelectionMode = property(get_SelectionMode, put_SelectionMode)
    SingleSelectionFollowsFocus = property(get_SingleSelectionFollowsFocus, put_SingleSelectionFollowsFocus)
    _ListBox_Meta_.SelectionModeProperty = property(get_SelectionModeProperty, None)
    _ListBox_Meta_.SingleSelectionFollowsFocusProperty = property(get_SingleSelectionFollowsFocusProperty, None)
class ListBoxItem(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.Controls.Primitives.SelectorItem
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IListBoxItem
    _classid_ = 'Microsoft.UI.Xaml.Controls.ListBoxItem'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.ListBoxItem.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IListBoxItemFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.ListBoxItem: ...
class _ListPickerFlyout_Meta_(ComPtr.__class__):
    pass
class ListPickerFlyout(ComPtr, metaclass=_ListPickerFlyout_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.Primitives.PickerFlyoutBase
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IListPickerFlyout
    _classid_ = 'Microsoft.UI.Xaml.Controls.ListPickerFlyout'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.ListPickerFlyout.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Controls.ListPickerFlyout: ...
    @winrt_mixinmethod
    def get_ItemsSource(self: win32more.Microsoft.UI.Xaml.Controls.IListPickerFlyout) -> IInspectable: ...
    @winrt_mixinmethod
    def put_ItemsSource(self: win32more.Microsoft.UI.Xaml.Controls.IListPickerFlyout, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_ItemTemplate(self: win32more.Microsoft.UI.Xaml.Controls.IListPickerFlyout) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def put_ItemTemplate(self: win32more.Microsoft.UI.Xaml.Controls.IListPickerFlyout, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_mixinmethod
    def get_DisplayMemberPath(self: win32more.Microsoft.UI.Xaml.Controls.IListPickerFlyout) -> hstr: ...
    @winrt_mixinmethod
    def put_DisplayMemberPath(self: win32more.Microsoft.UI.Xaml.Controls.IListPickerFlyout, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def get_SelectionMode(self: win32more.Microsoft.UI.Xaml.Controls.IListPickerFlyout) -> win32more.Microsoft.UI.Xaml.Controls.ListPickerFlyoutSelectionMode: ...
    @winrt_mixinmethod
    def put_SelectionMode(self: win32more.Microsoft.UI.Xaml.Controls.IListPickerFlyout, value: win32more.Microsoft.UI.Xaml.Controls.ListPickerFlyoutSelectionMode) -> Void: ...
    @winrt_mixinmethod
    def get_SelectedIndex(self: win32more.Microsoft.UI.Xaml.Controls.IListPickerFlyout) -> Int32: ...
    @winrt_mixinmethod
    def put_SelectedIndex(self: win32more.Microsoft.UI.Xaml.Controls.IListPickerFlyout, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_SelectedItem(self: win32more.Microsoft.UI.Xaml.Controls.IListPickerFlyout) -> IInspectable: ...
    @winrt_mixinmethod
    def put_SelectedItem(self: win32more.Microsoft.UI.Xaml.Controls.IListPickerFlyout, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_SelectedValue(self: win32more.Microsoft.UI.Xaml.Controls.IListPickerFlyout) -> IInspectable: ...
    @winrt_mixinmethod
    def put_SelectedValue(self: win32more.Microsoft.UI.Xaml.Controls.IListPickerFlyout, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_SelectedValuePath(self: win32more.Microsoft.UI.Xaml.Controls.IListPickerFlyout) -> hstr: ...
    @winrt_mixinmethod
    def put_SelectedValuePath(self: win32more.Microsoft.UI.Xaml.Controls.IListPickerFlyout, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def get_SelectedItems(self: win32more.Microsoft.UI.Xaml.Controls.IListPickerFlyout) -> win32more.Windows.Foundation.Collections.IVector[IInspectable]: ...
    @winrt_mixinmethod
    def add_ItemsPicked(self: win32more.Microsoft.UI.Xaml.Controls.IListPickerFlyout, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.ListPickerFlyout, win32more.Microsoft.UI.Xaml.Controls.ItemsPickedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ItemsPicked(self: win32more.Microsoft.UI.Xaml.Controls.IListPickerFlyout, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def ShowAtAsync(self: win32more.Microsoft.UI.Xaml.Controls.IListPickerFlyout, target: win32more.Microsoft.UI.Xaml.FrameworkElement) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[IInspectable]]: ...
    @winrt_classmethod
    def get_ItemsSourceProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IListPickerFlyoutStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ItemTemplateProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IListPickerFlyoutStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DisplayMemberPathProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IListPickerFlyoutStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectionModeProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IListPickerFlyoutStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectedIndexProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IListPickerFlyoutStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectedItemProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IListPickerFlyoutStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectedValueProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IListPickerFlyoutStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectedValuePathProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IListPickerFlyoutStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    DisplayMemberPath = property(get_DisplayMemberPath, put_DisplayMemberPath)
    ItemTemplate = property(get_ItemTemplate, put_ItemTemplate)
    ItemsSource = property(get_ItemsSource, put_ItemsSource)
    SelectedIndex = property(get_SelectedIndex, put_SelectedIndex)
    SelectedItem = property(get_SelectedItem, put_SelectedItem)
    SelectedItems = property(get_SelectedItems, None)
    SelectedValue = property(get_SelectedValue, put_SelectedValue)
    SelectedValuePath = property(get_SelectedValuePath, put_SelectedValuePath)
    SelectionMode = property(get_SelectionMode, put_SelectionMode)
    _ListPickerFlyout_Meta_.DisplayMemberPathProperty = property(get_DisplayMemberPathProperty, None)
    _ListPickerFlyout_Meta_.ItemTemplateProperty = property(get_ItemTemplateProperty, None)
    _ListPickerFlyout_Meta_.ItemsSourceProperty = property(get_ItemsSourceProperty, None)
    _ListPickerFlyout_Meta_.SelectedIndexProperty = property(get_SelectedIndexProperty, None)
    _ListPickerFlyout_Meta_.SelectedItemProperty = property(get_SelectedItemProperty, None)
    _ListPickerFlyout_Meta_.SelectedValuePathProperty = property(get_SelectedValuePathProperty, None)
    _ListPickerFlyout_Meta_.SelectedValueProperty = property(get_SelectedValueProperty, None)
    _ListPickerFlyout_Meta_.SelectionModeProperty = property(get_SelectionModeProperty, None)
    ItemsPicked = event(add_ItemsPicked, remove_ItemsPicked)
class ListPickerFlyoutPresenter(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.Controls.Control
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IListPickerFlyoutPresenter
    _classid_ = 'Microsoft.UI.Xaml.Controls.ListPickerFlyoutPresenter'
class ListPickerFlyoutSelectionMode(Enum, Int32):
    Single = 0
    Multiple = 1
class ListView(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.Controls.ListViewBase
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IListView
    _classid_ = 'Microsoft.UI.Xaml.Controls.ListView'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.ListView.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IListViewFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.ListView: ...
class _ListViewBase_Meta_(ComPtr.__class__):
    pass
class ListViewBase(ComPtr, metaclass=_ListViewBase_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.Primitives.Selector
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IListViewBase
    _classid_ = 'Microsoft.UI.Xaml.Controls.ListViewBase'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.ListViewBase.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IListViewBaseFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.ListViewBase: ...
    @winrt_mixinmethod
    def get_SelectedItems(self: win32more.Microsoft.UI.Xaml.Controls.IListViewBase) -> win32more.Windows.Foundation.Collections.IVector[IInspectable]: ...
    @winrt_mixinmethod
    def get_SelectionMode(self: win32more.Microsoft.UI.Xaml.Controls.IListViewBase) -> win32more.Microsoft.UI.Xaml.Controls.ListViewSelectionMode: ...
    @winrt_mixinmethod
    def put_SelectionMode(self: win32more.Microsoft.UI.Xaml.Controls.IListViewBase, value: win32more.Microsoft.UI.Xaml.Controls.ListViewSelectionMode) -> Void: ...
    @winrt_mixinmethod
    def get_IsSwipeEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IListViewBase) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsSwipeEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IListViewBase, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_CanDragItems(self: win32more.Microsoft.UI.Xaml.Controls.IListViewBase) -> Boolean: ...
    @winrt_mixinmethod
    def put_CanDragItems(self: win32more.Microsoft.UI.Xaml.Controls.IListViewBase, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_CanReorderItems(self: win32more.Microsoft.UI.Xaml.Controls.IListViewBase) -> Boolean: ...
    @winrt_mixinmethod
    def put_CanReorderItems(self: win32more.Microsoft.UI.Xaml.Controls.IListViewBase, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsItemClickEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IListViewBase) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsItemClickEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IListViewBase, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_DataFetchSize(self: win32more.Microsoft.UI.Xaml.Controls.IListViewBase) -> Double: ...
    @winrt_mixinmethod
    def put_DataFetchSize(self: win32more.Microsoft.UI.Xaml.Controls.IListViewBase, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_IncrementalLoadingThreshold(self: win32more.Microsoft.UI.Xaml.Controls.IListViewBase) -> Double: ...
    @winrt_mixinmethod
    def put_IncrementalLoadingThreshold(self: win32more.Microsoft.UI.Xaml.Controls.IListViewBase, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_IncrementalLoadingTrigger(self: win32more.Microsoft.UI.Xaml.Controls.IListViewBase) -> win32more.Microsoft.UI.Xaml.Controls.IncrementalLoadingTrigger: ...
    @winrt_mixinmethod
    def put_IncrementalLoadingTrigger(self: win32more.Microsoft.UI.Xaml.Controls.IListViewBase, value: win32more.Microsoft.UI.Xaml.Controls.IncrementalLoadingTrigger) -> Void: ...
    @winrt_mixinmethod
    def get_ShowsScrollingPlaceholders(self: win32more.Microsoft.UI.Xaml.Controls.IListViewBase) -> Boolean: ...
    @winrt_mixinmethod
    def put_ShowsScrollingPlaceholders(self: win32more.Microsoft.UI.Xaml.Controls.IListViewBase, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_ReorderMode(self: win32more.Microsoft.UI.Xaml.Controls.IListViewBase) -> win32more.Microsoft.UI.Xaml.Controls.ListViewReorderMode: ...
    @winrt_mixinmethod
    def put_ReorderMode(self: win32more.Microsoft.UI.Xaml.Controls.IListViewBase, value: win32more.Microsoft.UI.Xaml.Controls.ListViewReorderMode) -> Void: ...
    @winrt_mixinmethod
    def get_SelectedRanges(self: win32more.Microsoft.UI.Xaml.Controls.IListViewBase) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Microsoft.UI.Xaml.Data.ItemIndexRange]: ...
    @winrt_mixinmethod
    def get_IsMultiSelectCheckBoxEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IListViewBase) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsMultiSelectCheckBoxEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IListViewBase, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_SingleSelectionFollowsFocus(self: win32more.Microsoft.UI.Xaml.Controls.IListViewBase) -> Boolean: ...
    @winrt_mixinmethod
    def put_SingleSelectionFollowsFocus(self: win32more.Microsoft.UI.Xaml.Controls.IListViewBase, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def add_ItemClick(self: win32more.Microsoft.UI.Xaml.Controls.IListViewBase, handler: win32more.Microsoft.UI.Xaml.Controls.ItemClickEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ItemClick(self: win32more.Microsoft.UI.Xaml.Controls.IListViewBase, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_DragItemsStarting(self: win32more.Microsoft.UI.Xaml.Controls.IListViewBase, handler: win32more.Microsoft.UI.Xaml.Controls.DragItemsStartingEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_DragItemsStarting(self: win32more.Microsoft.UI.Xaml.Controls.IListViewBase, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_DragItemsCompleted(self: win32more.Microsoft.UI.Xaml.Controls.IListViewBase, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.ListViewBase, win32more.Microsoft.UI.Xaml.Controls.DragItemsCompletedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_DragItemsCompleted(self: win32more.Microsoft.UI.Xaml.Controls.IListViewBase, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_ContainerContentChanging(self: win32more.Microsoft.UI.Xaml.Controls.IListViewBase, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.ListViewBase, win32more.Microsoft.UI.Xaml.Controls.ContainerContentChangingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ContainerContentChanging(self: win32more.Microsoft.UI.Xaml.Controls.IListViewBase, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_ChoosingItemContainer(self: win32more.Microsoft.UI.Xaml.Controls.IListViewBase, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.ListViewBase, win32more.Microsoft.UI.Xaml.Controls.ChoosingItemContainerEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ChoosingItemContainer(self: win32more.Microsoft.UI.Xaml.Controls.IListViewBase, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_ChoosingGroupHeaderContainer(self: win32more.Microsoft.UI.Xaml.Controls.IListViewBase, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.ListViewBase, win32more.Microsoft.UI.Xaml.Controls.ChoosingGroupHeaderContainerEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ChoosingGroupHeaderContainer(self: win32more.Microsoft.UI.Xaml.Controls.IListViewBase, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def ScrollIntoView(self: win32more.Microsoft.UI.Xaml.Controls.IListViewBase, item: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def SelectAll(self: win32more.Microsoft.UI.Xaml.Controls.IListViewBase) -> Void: ...
    @winrt_mixinmethod
    def LoadMoreItemsAsync(self: win32more.Microsoft.UI.Xaml.Controls.IListViewBase) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Microsoft.UI.Xaml.Data.LoadMoreItemsResult]: ...
    @winrt_mixinmethod
    def ScrollIntoViewWithAlignment(self: win32more.Microsoft.UI.Xaml.Controls.IListViewBase, item: IInspectable, alignment: win32more.Microsoft.UI.Xaml.Controls.ScrollIntoViewAlignment) -> Void: ...
    @winrt_mixinmethod
    def SetDesiredContainerUpdateDuration(self: win32more.Microsoft.UI.Xaml.Controls.IListViewBase, duration: win32more.Windows.Foundation.TimeSpan) -> Void: ...
    @winrt_mixinmethod
    def SelectRange(self: win32more.Microsoft.UI.Xaml.Controls.IListViewBase, itemIndexRange: win32more.Microsoft.UI.Xaml.Data.ItemIndexRange) -> Void: ...
    @winrt_mixinmethod
    def DeselectRange(self: win32more.Microsoft.UI.Xaml.Controls.IListViewBase, itemIndexRange: win32more.Microsoft.UI.Xaml.Data.ItemIndexRange) -> Void: ...
    @winrt_mixinmethod
    def IsDragSource(self: win32more.Microsoft.UI.Xaml.Controls.IListViewBase) -> Boolean: ...
    @winrt_mixinmethod
    def TryStartConnectedAnimationAsync(self: win32more.Microsoft.UI.Xaml.Controls.IListViewBase, animation: win32more.Microsoft.UI.Xaml.Media.Animation.ConnectedAnimation, item: IInspectable, elementName: hstr) -> win32more.Windows.Foundation.IAsyncOperation[Boolean]: ...
    @winrt_mixinmethod
    def PrepareConnectedAnimation(self: win32more.Microsoft.UI.Xaml.Controls.IListViewBase, key: hstr, item: IInspectable, elementName: hstr) -> win32more.Microsoft.UI.Xaml.Media.Animation.ConnectedAnimation: ...
    @winrt_mixinmethod
    def get_Header(self: win32more.Microsoft.UI.Xaml.Controls.IListViewBase) -> IInspectable: ...
    @winrt_mixinmethod
    def put_Header(self: win32more.Microsoft.UI.Xaml.Controls.IListViewBase, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_HeaderTemplate(self: win32more.Microsoft.UI.Xaml.Controls.IListViewBase) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def put_HeaderTemplate(self: win32more.Microsoft.UI.Xaml.Controls.IListViewBase, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_mixinmethod
    def get_HeaderTransitions(self: win32more.Microsoft.UI.Xaml.Controls.IListViewBase) -> win32more.Microsoft.UI.Xaml.Media.Animation.TransitionCollection: ...
    @winrt_mixinmethod
    def put_HeaderTransitions(self: win32more.Microsoft.UI.Xaml.Controls.IListViewBase, value: win32more.Microsoft.UI.Xaml.Media.Animation.TransitionCollection) -> Void: ...
    @winrt_mixinmethod
    def get_Footer(self: win32more.Microsoft.UI.Xaml.Controls.IListViewBase) -> IInspectable: ...
    @winrt_mixinmethod
    def put_Footer(self: win32more.Microsoft.UI.Xaml.Controls.IListViewBase, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_FooterTemplate(self: win32more.Microsoft.UI.Xaml.Controls.IListViewBase) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def put_FooterTemplate(self: win32more.Microsoft.UI.Xaml.Controls.IListViewBase, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_mixinmethod
    def get_FooterTransitions(self: win32more.Microsoft.UI.Xaml.Controls.IListViewBase) -> win32more.Microsoft.UI.Xaml.Media.Animation.TransitionCollection: ...
    @winrt_mixinmethod
    def put_FooterTransitions(self: win32more.Microsoft.UI.Xaml.Controls.IListViewBase, value: win32more.Microsoft.UI.Xaml.Media.Animation.TransitionCollection) -> Void: ...
    @winrt_mixinmethod
    def get_SemanticZoomOwner(self: win32more.Microsoft.UI.Xaml.Controls.ISemanticZoomInformation) -> win32more.Microsoft.UI.Xaml.Controls.SemanticZoom: ...
    @winrt_mixinmethod
    def put_SemanticZoomOwner(self: win32more.Microsoft.UI.Xaml.Controls.ISemanticZoomInformation, value: win32more.Microsoft.UI.Xaml.Controls.SemanticZoom) -> Void: ...
    @winrt_mixinmethod
    def get_IsActiveView(self: win32more.Microsoft.UI.Xaml.Controls.ISemanticZoomInformation) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsActiveView(self: win32more.Microsoft.UI.Xaml.Controls.ISemanticZoomInformation, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsZoomedInView(self: win32more.Microsoft.UI.Xaml.Controls.ISemanticZoomInformation) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsZoomedInView(self: win32more.Microsoft.UI.Xaml.Controls.ISemanticZoomInformation, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def InitializeViewChange(self: win32more.Microsoft.UI.Xaml.Controls.ISemanticZoomInformation) -> Void: ...
    @winrt_mixinmethod
    def CompleteViewChange(self: win32more.Microsoft.UI.Xaml.Controls.ISemanticZoomInformation) -> Void: ...
    @winrt_mixinmethod
    def MakeVisible(self: win32more.Microsoft.UI.Xaml.Controls.ISemanticZoomInformation, item: win32more.Microsoft.UI.Xaml.Controls.SemanticZoomLocation) -> Void: ...
    @winrt_mixinmethod
    def StartViewChangeFrom(self: win32more.Microsoft.UI.Xaml.Controls.ISemanticZoomInformation, source: win32more.Microsoft.UI.Xaml.Controls.SemanticZoomLocation, destination: win32more.Microsoft.UI.Xaml.Controls.SemanticZoomLocation) -> Void: ...
    @winrt_mixinmethod
    def StartViewChangeTo(self: win32more.Microsoft.UI.Xaml.Controls.ISemanticZoomInformation, source: win32more.Microsoft.UI.Xaml.Controls.SemanticZoomLocation, destination: win32more.Microsoft.UI.Xaml.Controls.SemanticZoomLocation) -> Void: ...
    @winrt_mixinmethod
    def CompleteViewChangeFrom(self: win32more.Microsoft.UI.Xaml.Controls.ISemanticZoomInformation, source: win32more.Microsoft.UI.Xaml.Controls.SemanticZoomLocation, destination: win32more.Microsoft.UI.Xaml.Controls.SemanticZoomLocation) -> Void: ...
    @winrt_mixinmethod
    def CompleteViewChangeTo(self: win32more.Microsoft.UI.Xaml.Controls.ISemanticZoomInformation, source: win32more.Microsoft.UI.Xaml.Controls.SemanticZoomLocation, destination: win32more.Microsoft.UI.Xaml.Controls.SemanticZoomLocation) -> Void: ...
    @winrt_classmethod
    def get_SelectionModeProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IListViewBaseStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsSwipeEnabledProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IListViewBaseStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CanDragItemsProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IListViewBaseStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CanReorderItemsProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IListViewBaseStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsItemClickEnabledProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IListViewBaseStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DataFetchSizeProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IListViewBaseStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IncrementalLoadingThresholdProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IListViewBaseStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IncrementalLoadingTriggerProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IListViewBaseStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ShowsScrollingPlaceholdersProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IListViewBaseStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ReorderModeProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IListViewBaseStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsMultiSelectCheckBoxEnabledProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IListViewBaseStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SingleSelectionFollowsFocusProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IListViewBaseStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SemanticZoomOwnerProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IListViewBaseStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsActiveViewProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IListViewBaseStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsZoomedInViewProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IListViewBaseStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HeaderProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IListViewBaseStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HeaderTemplateProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IListViewBaseStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HeaderTransitionsProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IListViewBaseStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FooterProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IListViewBaseStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FooterTemplateProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IListViewBaseStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FooterTransitionsProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IListViewBaseStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    CanDragItems = property(get_CanDragItems, put_CanDragItems)
    CanReorderItems = property(get_CanReorderItems, put_CanReorderItems)
    DataFetchSize = property(get_DataFetchSize, put_DataFetchSize)
    Footer = property(get_Footer, put_Footer)
    FooterTemplate = property(get_FooterTemplate, put_FooterTemplate)
    FooterTransitions = property(get_FooterTransitions, put_FooterTransitions)
    Header = property(get_Header, put_Header)
    HeaderTemplate = property(get_HeaderTemplate, put_HeaderTemplate)
    HeaderTransitions = property(get_HeaderTransitions, put_HeaderTransitions)
    IncrementalLoadingThreshold = property(get_IncrementalLoadingThreshold, put_IncrementalLoadingThreshold)
    IncrementalLoadingTrigger = property(get_IncrementalLoadingTrigger, put_IncrementalLoadingTrigger)
    IsActiveView = property(get_IsActiveView, put_IsActiveView)
    IsItemClickEnabled = property(get_IsItemClickEnabled, put_IsItemClickEnabled)
    IsMultiSelectCheckBoxEnabled = property(get_IsMultiSelectCheckBoxEnabled, put_IsMultiSelectCheckBoxEnabled)
    IsSwipeEnabled = property(get_IsSwipeEnabled, put_IsSwipeEnabled)
    IsZoomedInView = property(get_IsZoomedInView, put_IsZoomedInView)
    ReorderMode = property(get_ReorderMode, put_ReorderMode)
    SelectedItems = property(get_SelectedItems, None)
    SelectedRanges = property(get_SelectedRanges, None)
    SelectionMode = property(get_SelectionMode, put_SelectionMode)
    SemanticZoomOwner = property(get_SemanticZoomOwner, put_SemanticZoomOwner)
    ShowsScrollingPlaceholders = property(get_ShowsScrollingPlaceholders, put_ShowsScrollingPlaceholders)
    SingleSelectionFollowsFocus = property(get_SingleSelectionFollowsFocus, put_SingleSelectionFollowsFocus)
    _ListViewBase_Meta_.CanDragItemsProperty = property(get_CanDragItemsProperty, None)
    _ListViewBase_Meta_.CanReorderItemsProperty = property(get_CanReorderItemsProperty, None)
    _ListViewBase_Meta_.DataFetchSizeProperty = property(get_DataFetchSizeProperty, None)
    _ListViewBase_Meta_.FooterProperty = property(get_FooterProperty, None)
    _ListViewBase_Meta_.FooterTemplateProperty = property(get_FooterTemplateProperty, None)
    _ListViewBase_Meta_.FooterTransitionsProperty = property(get_FooterTransitionsProperty, None)
    _ListViewBase_Meta_.HeaderProperty = property(get_HeaderProperty, None)
    _ListViewBase_Meta_.HeaderTemplateProperty = property(get_HeaderTemplateProperty, None)
    _ListViewBase_Meta_.HeaderTransitionsProperty = property(get_HeaderTransitionsProperty, None)
    _ListViewBase_Meta_.IncrementalLoadingThresholdProperty = property(get_IncrementalLoadingThresholdProperty, None)
    _ListViewBase_Meta_.IncrementalLoadingTriggerProperty = property(get_IncrementalLoadingTriggerProperty, None)
    _ListViewBase_Meta_.IsActiveViewProperty = property(get_IsActiveViewProperty, None)
    _ListViewBase_Meta_.IsItemClickEnabledProperty = property(get_IsItemClickEnabledProperty, None)
    _ListViewBase_Meta_.IsMultiSelectCheckBoxEnabledProperty = property(get_IsMultiSelectCheckBoxEnabledProperty, None)
    _ListViewBase_Meta_.IsSwipeEnabledProperty = property(get_IsSwipeEnabledProperty, None)
    _ListViewBase_Meta_.IsZoomedInViewProperty = property(get_IsZoomedInViewProperty, None)
    _ListViewBase_Meta_.ReorderModeProperty = property(get_ReorderModeProperty, None)
    _ListViewBase_Meta_.SelectionModeProperty = property(get_SelectionModeProperty, None)
    _ListViewBase_Meta_.SemanticZoomOwnerProperty = property(get_SemanticZoomOwnerProperty, None)
    _ListViewBase_Meta_.ShowsScrollingPlaceholdersProperty = property(get_ShowsScrollingPlaceholdersProperty, None)
    _ListViewBase_Meta_.SingleSelectionFollowsFocusProperty = property(get_SingleSelectionFollowsFocusProperty, None)
    ChoosingGroupHeaderContainer = event(add_ChoosingGroupHeaderContainer, remove_ChoosingGroupHeaderContainer)
    ChoosingItemContainer = event(add_ChoosingItemContainer, remove_ChoosingItemContainer)
    ContainerContentChanging = event(add_ContainerContentChanging, remove_ContainerContentChanging)
    DragItemsCompleted = event(add_DragItemsCompleted, remove_DragItemsCompleted)
    DragItemsStarting = event(add_DragItemsStarting, remove_DragItemsStarting)
    ItemClick = event(add_ItemClick, remove_ItemClick)
class ListViewBaseHeaderItem(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.Controls.ContentControl
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IListViewBaseHeaderItem
    _classid_ = 'Microsoft.UI.Xaml.Controls.ListViewBaseHeaderItem'
class ListViewHeaderItem(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.Controls.ListViewBaseHeaderItem
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IListViewHeaderItem
    _classid_ = 'Microsoft.UI.Xaml.Controls.ListViewHeaderItem'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.ListViewHeaderItem.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IListViewHeaderItemFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.ListViewHeaderItem: ...
class ListViewItem(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.Controls.Primitives.SelectorItem
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IListViewItem
    _classid_ = 'Microsoft.UI.Xaml.Controls.ListViewItem'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.ListViewItem.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IListViewItemFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.ListViewItem: ...
    @winrt_mixinmethod
    def get_TemplateSettings(self: win32more.Microsoft.UI.Xaml.Controls.IListViewItem) -> win32more.Microsoft.UI.Xaml.Controls.Primitives.ListViewItemTemplateSettings: ...
    TemplateSettings = property(get_TemplateSettings, None)
class ListViewItemToKeyHandler(MulticastDelegate):
    extends: IUnknown
    _iid_ = Guid('{2a47f009-91fc-54ce-9861-344e80f7e9d7}')
    @winrt_commethod(3)
    def Invoke(self, item: IInspectable) -> hstr: ...
class ListViewKeyToItemHandler(MulticastDelegate):
    extends: IUnknown
    _iid_ = Guid('{46c8e78e-b948-5ef3-b845-b278b5918ba9}')
    @winrt_commethod(3)
    def Invoke(self, key: hstr) -> win32more.Windows.Foundation.IAsyncOperation[IInspectable]: ...
class ListViewPersistenceHelper(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IListViewPersistenceHelper
    _classid_ = 'Microsoft.UI.Xaml.Controls.ListViewPersistenceHelper'
    @winrt_classmethod
    def GetRelativeScrollPosition(cls: win32more.Microsoft.UI.Xaml.Controls.IListViewPersistenceHelperStatics, listViewBase: win32more.Microsoft.UI.Xaml.Controls.ListViewBase, itemToKeyHandler: win32more.Microsoft.UI.Xaml.Controls.ListViewItemToKeyHandler) -> hstr: ...
    @winrt_classmethod
    def SetRelativeScrollPositionAsync(cls: win32more.Microsoft.UI.Xaml.Controls.IListViewPersistenceHelperStatics, listViewBase: win32more.Microsoft.UI.Xaml.Controls.ListViewBase, relativeScrollPosition: hstr, keyToItemHandler: win32more.Microsoft.UI.Xaml.Controls.ListViewKeyToItemHandler) -> win32more.Windows.Foundation.IAsyncAction: ...
class ListViewReorderMode(Enum, Int32):
    Disabled = 0
    Enabled = 1
class ListViewSelectionMode(Enum, Int32):
    None_ = 0
    Single = 1
    Multiple = 2
    Extended = 3
class _MapControl_Meta_(ComPtr.__class__):
    pass
class MapControl(ComPtr, metaclass=_MapControl_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.Control
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IMapControl
    _classid_ = 'Microsoft.UI.Xaml.Controls.MapControl'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.MapControl.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IMapControlFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.MapControl: ...
    @winrt_mixinmethod
    def get_MapServiceToken(self: win32more.Microsoft.UI.Xaml.Controls.IMapControl) -> hstr: ...
    @winrt_mixinmethod
    def put_MapServiceToken(self: win32more.Microsoft.UI.Xaml.Controls.IMapControl, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def get_Center(self: win32more.Microsoft.UI.Xaml.Controls.IMapControl) -> win32more.Windows.Devices.Geolocation.Geopoint: ...
    @winrt_mixinmethod
    def put_Center(self: win32more.Microsoft.UI.Xaml.Controls.IMapControl, value: win32more.Windows.Devices.Geolocation.Geopoint) -> Void: ...
    @winrt_mixinmethod
    def get_Layers(self: win32more.Microsoft.UI.Xaml.Controls.IMapControl) -> win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.MapLayer]: ...
    @winrt_mixinmethod
    def put_Layers(self: win32more.Microsoft.UI.Xaml.Controls.IMapControl, value: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.MapLayer]) -> Void: ...
    @winrt_mixinmethod
    def get_ZoomLevel(self: win32more.Microsoft.UI.Xaml.Controls.IMapControl) -> Double: ...
    @winrt_mixinmethod
    def put_ZoomLevel(self: win32more.Microsoft.UI.Xaml.Controls.IMapControl, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_InteractiveControlsVisible(self: win32more.Microsoft.UI.Xaml.Controls.IMapControl) -> Boolean: ...
    @winrt_mixinmethod
    def put_InteractiveControlsVisible(self: win32more.Microsoft.UI.Xaml.Controls.IMapControl, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def add_MapElementClick(self: win32more.Microsoft.UI.Xaml.Controls.IMapControl, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.MapControl, win32more.Microsoft.UI.Xaml.Controls.MapElementClickEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_MapElementClick(self: win32more.Microsoft.UI.Xaml.Controls.IMapControl, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_MapServiceErrorOccurred(self: win32more.Microsoft.UI.Xaml.Controls.IMapControl, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.MapControl, win32more.Microsoft.UI.Xaml.Controls.MapControlMapServiceErrorOccurredEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_MapServiceErrorOccurred(self: win32more.Microsoft.UI.Xaml.Controls.IMapControl, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def get_LayersProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IMapControlStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MapServiceTokenProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IMapControlStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CenterProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IMapControlStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ZoomLevelProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IMapControlStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_InteractiveControlsVisibleProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IMapControlStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    Center = property(get_Center, put_Center)
    InteractiveControlsVisible = property(get_InteractiveControlsVisible, put_InteractiveControlsVisible)
    Layers = property(get_Layers, put_Layers)
    MapServiceToken = property(get_MapServiceToken, put_MapServiceToken)
    ZoomLevel = property(get_ZoomLevel, put_ZoomLevel)
    _MapControl_Meta_.CenterProperty = property(get_CenterProperty, None)
    _MapControl_Meta_.InteractiveControlsVisibleProperty = property(get_InteractiveControlsVisibleProperty, None)
    _MapControl_Meta_.LayersProperty = property(get_LayersProperty, None)
    _MapControl_Meta_.MapServiceTokenProperty = property(get_MapServiceTokenProperty, None)
    _MapControl_Meta_.ZoomLevelProperty = property(get_ZoomLevelProperty, None)
    MapElementClick = event(add_MapElementClick, remove_MapElementClick)
    MapServiceErrorOccurred = event(add_MapServiceErrorOccurred, remove_MapServiceErrorOccurred)
class MapControlMapServiceErrorOccurredEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IMapControlMapServiceErrorOccurredEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.MapControlMapServiceErrorOccurredEventArgs'
    @winrt_mixinmethod
    def get_DiagnosticMessage(self: win32more.Microsoft.UI.Xaml.Controls.IMapControlMapServiceErrorOccurredEventArgs) -> hstr: ...
    DiagnosticMessage = property(get_DiagnosticMessage, None)
class MapElement(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.DependencyObject
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IMapElement
    _classid_ = 'Microsoft.UI.Xaml.Controls.MapElement'
class MapElementClickEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IMapElementClickEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.MapElementClickEventArgs'
    @winrt_mixinmethod
    def get_Location(self: win32more.Microsoft.UI.Xaml.Controls.IMapElementClickEventArgs) -> win32more.Windows.Devices.Geolocation.Geopoint: ...
    @winrt_mixinmethod
    def get_Element(self: win32more.Microsoft.UI.Xaml.Controls.IMapElementClickEventArgs) -> win32more.Microsoft.UI.Xaml.Controls.MapElement: ...
    Element = property(get_Element, None)
    Location = property(get_Location, None)
class _MapElementsLayer_Meta_(ComPtr.__class__):
    pass
class MapElementsLayer(ComPtr, metaclass=_MapElementsLayer_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.MapLayer
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IMapElementsLayer
    _classid_ = 'Microsoft.UI.Xaml.Controls.MapElementsLayer'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.MapElementsLayer.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IMapElementsLayerFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.MapElementsLayer: ...
    @winrt_mixinmethod
    def get_MapElements(self: win32more.Microsoft.UI.Xaml.Controls.IMapElementsLayer) -> win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.MapElement]: ...
    @winrt_mixinmethod
    def put_MapElements(self: win32more.Microsoft.UI.Xaml.Controls.IMapElementsLayer, value: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.MapElement]) -> Void: ...
    @winrt_mixinmethod
    def add_MapElementClick(self: win32more.Microsoft.UI.Xaml.Controls.IMapElementsLayer, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.MapElementsLayer, win32more.Microsoft.UI.Xaml.Controls.MapElementClickEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_MapElementClick(self: win32more.Microsoft.UI.Xaml.Controls.IMapElementsLayer, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def get_MapElementsProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IMapElementsLayerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    MapElements = property(get_MapElements, put_MapElements)
    _MapElementsLayer_Meta_.MapElementsProperty = property(get_MapElementsProperty, None)
    MapElementClick = event(add_MapElementClick, remove_MapElementClick)
class _MapIcon_Meta_(ComPtr.__class__):
    pass
class MapIcon(ComPtr, metaclass=_MapIcon_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.MapElement
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IMapIcon
    _classid_ = 'Microsoft.UI.Xaml.Controls.MapIcon'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.MapIcon.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IMapIconFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.MapIcon: ...
    @winrt_mixinmethod
    def get_Location(self: win32more.Microsoft.UI.Xaml.Controls.IMapIcon) -> win32more.Windows.Devices.Geolocation.Geopoint: ...
    @winrt_mixinmethod
    def put_Location(self: win32more.Microsoft.UI.Xaml.Controls.IMapIcon, value: win32more.Windows.Devices.Geolocation.Geopoint) -> Void: ...
    @winrt_classmethod
    def get_LocationProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IMapIconStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    Location = property(get_Location, put_Location)
    _MapIcon_Meta_.LocationProperty = property(get_LocationProperty, None)
class MapLayer(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.DependencyObject
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IMapLayer
    _classid_ = 'Microsoft.UI.Xaml.Controls.MapLayer'
class _MediaPlayerElement_Meta_(ComPtr.__class__):
    pass
class MediaPlayerElement(ComPtr, metaclass=_MediaPlayerElement_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.Control
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IMediaPlayerElement
    _classid_ = 'Microsoft.UI.Xaml.Controls.MediaPlayerElement'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.MediaPlayerElement.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IMediaPlayerElementFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.MediaPlayerElement: ...
    @winrt_mixinmethod
    def get_Source(self: win32more.Microsoft.UI.Xaml.Controls.IMediaPlayerElement) -> win32more.Windows.Media.Playback.IMediaPlaybackSource: ...
    @winrt_mixinmethod
    def put_Source(self: win32more.Microsoft.UI.Xaml.Controls.IMediaPlayerElement, value: win32more.Windows.Media.Playback.IMediaPlaybackSource) -> Void: ...
    @winrt_mixinmethod
    def get_TransportControls(self: win32more.Microsoft.UI.Xaml.Controls.IMediaPlayerElement) -> win32more.Microsoft.UI.Xaml.Controls.MediaTransportControls: ...
    @winrt_mixinmethod
    def put_TransportControls(self: win32more.Microsoft.UI.Xaml.Controls.IMediaPlayerElement, value: win32more.Microsoft.UI.Xaml.Controls.MediaTransportControls) -> Void: ...
    @winrt_mixinmethod
    def get_AreTransportControlsEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IMediaPlayerElement) -> Boolean: ...
    @winrt_mixinmethod
    def put_AreTransportControlsEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IMediaPlayerElement, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_PosterSource(self: win32more.Microsoft.UI.Xaml.Controls.IMediaPlayerElement) -> win32more.Microsoft.UI.Xaml.Media.ImageSource: ...
    @winrt_mixinmethod
    def put_PosterSource(self: win32more.Microsoft.UI.Xaml.Controls.IMediaPlayerElement, value: win32more.Microsoft.UI.Xaml.Media.ImageSource) -> Void: ...
    @winrt_mixinmethod
    def get_Stretch(self: win32more.Microsoft.UI.Xaml.Controls.IMediaPlayerElement) -> win32more.Microsoft.UI.Xaml.Media.Stretch: ...
    @winrt_mixinmethod
    def put_Stretch(self: win32more.Microsoft.UI.Xaml.Controls.IMediaPlayerElement, value: win32more.Microsoft.UI.Xaml.Media.Stretch) -> Void: ...
    @winrt_mixinmethod
    def get_AutoPlay(self: win32more.Microsoft.UI.Xaml.Controls.IMediaPlayerElement) -> Boolean: ...
    @winrt_mixinmethod
    def put_AutoPlay(self: win32more.Microsoft.UI.Xaml.Controls.IMediaPlayerElement, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsFullWindow(self: win32more.Microsoft.UI.Xaml.Controls.IMediaPlayerElement) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsFullWindow(self: win32more.Microsoft.UI.Xaml.Controls.IMediaPlayerElement, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_MediaPlayer(self: win32more.Microsoft.UI.Xaml.Controls.IMediaPlayerElement) -> win32more.Windows.Media.Playback.MediaPlayer: ...
    @winrt_mixinmethod
    def SetMediaPlayer(self: win32more.Microsoft.UI.Xaml.Controls.IMediaPlayerElement, mediaPlayer: win32more.Windows.Media.Playback.MediaPlayer) -> Void: ...
    @winrt_classmethod
    def get_SourceProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IMediaPlayerElementStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_AreTransportControlsEnabledProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IMediaPlayerElementStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PosterSourceProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IMediaPlayerElementStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_StretchProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IMediaPlayerElementStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_AutoPlayProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IMediaPlayerElementStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsFullWindowProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IMediaPlayerElementStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MediaPlayerProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IMediaPlayerElementStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    AreTransportControlsEnabled = property(get_AreTransportControlsEnabled, put_AreTransportControlsEnabled)
    AutoPlay = property(get_AutoPlay, put_AutoPlay)
    IsFullWindow = property(get_IsFullWindow, put_IsFullWindow)
    MediaPlayer = property(get_MediaPlayer, None)
    PosterSource = property(get_PosterSource, put_PosterSource)
    Source = property(get_Source, put_Source)
    Stretch = property(get_Stretch, put_Stretch)
    TransportControls = property(get_TransportControls, put_TransportControls)
    _MediaPlayerElement_Meta_.AreTransportControlsEnabledProperty = property(get_AreTransportControlsEnabledProperty, None)
    _MediaPlayerElement_Meta_.AutoPlayProperty = property(get_AutoPlayProperty, None)
    _MediaPlayerElement_Meta_.IsFullWindowProperty = property(get_IsFullWindowProperty, None)
    _MediaPlayerElement_Meta_.MediaPlayerProperty = property(get_MediaPlayerProperty, None)
    _MediaPlayerElement_Meta_.PosterSourceProperty = property(get_PosterSourceProperty, None)
    _MediaPlayerElement_Meta_.SourceProperty = property(get_SourceProperty, None)
    _MediaPlayerElement_Meta_.StretchProperty = property(get_StretchProperty, None)
class _MediaPlayerPresenter_Meta_(ComPtr.__class__):
    pass
class MediaPlayerPresenter(ComPtr, metaclass=_MediaPlayerPresenter_Meta_):
    extends: win32more.Microsoft.UI.Xaml.FrameworkElement
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IMediaPlayerPresenter
    _classid_ = 'Microsoft.UI.Xaml.Controls.MediaPlayerPresenter'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.MediaPlayerPresenter.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IMediaPlayerPresenterFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.MediaPlayerPresenter: ...
    @winrt_mixinmethod
    def get_MediaPlayer(self: win32more.Microsoft.UI.Xaml.Controls.IMediaPlayerPresenter) -> win32more.Windows.Media.Playback.MediaPlayer: ...
    @winrt_mixinmethod
    def put_MediaPlayer(self: win32more.Microsoft.UI.Xaml.Controls.IMediaPlayerPresenter, value: win32more.Windows.Media.Playback.MediaPlayer) -> Void: ...
    @winrt_mixinmethod
    def get_Stretch(self: win32more.Microsoft.UI.Xaml.Controls.IMediaPlayerPresenter) -> win32more.Microsoft.UI.Xaml.Media.Stretch: ...
    @winrt_mixinmethod
    def put_Stretch(self: win32more.Microsoft.UI.Xaml.Controls.IMediaPlayerPresenter, value: win32more.Microsoft.UI.Xaml.Media.Stretch) -> Void: ...
    @winrt_mixinmethod
    def get_IsFullWindow(self: win32more.Microsoft.UI.Xaml.Controls.IMediaPlayerPresenter) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsFullWindow(self: win32more.Microsoft.UI.Xaml.Controls.IMediaPlayerPresenter, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_MediaPlayerProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IMediaPlayerPresenterStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_StretchProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IMediaPlayerPresenterStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsFullWindowProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IMediaPlayerPresenterStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    IsFullWindow = property(get_IsFullWindow, put_IsFullWindow)
    MediaPlayer = property(get_MediaPlayer, put_MediaPlayer)
    Stretch = property(get_Stretch, put_Stretch)
    _MediaPlayerPresenter_Meta_.IsFullWindowProperty = property(get_IsFullWindowProperty, None)
    _MediaPlayerPresenter_Meta_.MediaPlayerProperty = property(get_MediaPlayerProperty, None)
    _MediaPlayerPresenter_Meta_.StretchProperty = property(get_StretchProperty, None)
class _MediaTransportControls_Meta_(ComPtr.__class__):
    pass
class MediaTransportControls(ComPtr, metaclass=_MediaTransportControls_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.Control
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControls
    _classid_ = 'Microsoft.UI.Xaml.Controls.MediaTransportControls'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.MediaTransportControls.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControlsFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.MediaTransportControls: ...
    @winrt_mixinmethod
    def get_IsZoomButtonVisible(self: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControls) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsZoomButtonVisible(self: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControls, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsZoomEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControls) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsZoomEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControls, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsFastForwardButtonVisible(self: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControls) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsFastForwardButtonVisible(self: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControls, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsFastForwardEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControls) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsFastForwardEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControls, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsFastRewindButtonVisible(self: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControls) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsFastRewindButtonVisible(self: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControls, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsFastRewindEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControls) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsFastRewindEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControls, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsStopButtonVisible(self: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControls) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsStopButtonVisible(self: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControls, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsStopEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControls) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsStopEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControls, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsVolumeButtonVisible(self: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControls) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsVolumeButtonVisible(self: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControls, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsVolumeEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControls) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsVolumeEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControls, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsPlaybackRateButtonVisible(self: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControls) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsPlaybackRateButtonVisible(self: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControls, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsPlaybackRateEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControls) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsPlaybackRateEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControls, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsSeekBarVisible(self: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControls) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsSeekBarVisible(self: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControls, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsSeekEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControls) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsSeekEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControls, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsCompact(self: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControls) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsCompact(self: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControls, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsSkipForwardButtonVisible(self: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControls) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsSkipForwardButtonVisible(self: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControls, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsSkipForwardEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControls) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsSkipForwardEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControls, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsSkipBackwardButtonVisible(self: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControls) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsSkipBackwardButtonVisible(self: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControls, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsSkipBackwardEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControls) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsSkipBackwardEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControls, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsNextTrackButtonVisible(self: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControls) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsNextTrackButtonVisible(self: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControls, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsPreviousTrackButtonVisible(self: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControls) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsPreviousTrackButtonVisible(self: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControls, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_FastPlayFallbackBehaviour(self: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControls) -> win32more.Microsoft.UI.Xaml.Media.FastPlayFallbackBehaviour: ...
    @winrt_mixinmethod
    def put_FastPlayFallbackBehaviour(self: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControls, value: win32more.Microsoft.UI.Xaml.Media.FastPlayFallbackBehaviour) -> Void: ...
    @winrt_mixinmethod
    def get_ShowAndHideAutomatically(self: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControls) -> Boolean: ...
    @winrt_mixinmethod
    def put_ShowAndHideAutomatically(self: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControls, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsRepeatEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControls) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsRepeatEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControls, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsRepeatButtonVisible(self: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControls) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsRepeatButtonVisible(self: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControls, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def add_ThumbnailRequested(self: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControls, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.MediaTransportControls, win32more.Microsoft.UI.Xaml.Media.MediaTransportControlsThumbnailRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ThumbnailRequested(self: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControls, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def Show(self: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControls) -> Void: ...
    @winrt_mixinmethod
    def Hide(self: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControls) -> Void: ...
    @winrt_classmethod
    def get_IsZoomButtonVisibleProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControlsStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsZoomEnabledProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControlsStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsFastForwardButtonVisibleProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControlsStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsFastForwardEnabledProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControlsStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsFastRewindButtonVisibleProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControlsStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsFastRewindEnabledProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControlsStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsStopButtonVisibleProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControlsStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsStopEnabledProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControlsStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsVolumeButtonVisibleProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControlsStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsVolumeEnabledProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControlsStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsPlaybackRateButtonVisibleProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControlsStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsPlaybackRateEnabledProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControlsStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsSeekBarVisibleProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControlsStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsSeekEnabledProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControlsStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsCompactProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControlsStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsSkipForwardButtonVisibleProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControlsStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsSkipForwardEnabledProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControlsStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsSkipBackwardButtonVisibleProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControlsStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsSkipBackwardEnabledProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControlsStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsNextTrackButtonVisibleProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControlsStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsPreviousTrackButtonVisibleProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControlsStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FastPlayFallbackBehaviourProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControlsStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ShowAndHideAutomaticallyProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControlsStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsRepeatEnabledProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControlsStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsRepeatButtonVisibleProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControlsStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    FastPlayFallbackBehaviour = property(get_FastPlayFallbackBehaviour, put_FastPlayFallbackBehaviour)
    IsCompact = property(get_IsCompact, put_IsCompact)
    IsFastForwardButtonVisible = property(get_IsFastForwardButtonVisible, put_IsFastForwardButtonVisible)
    IsFastForwardEnabled = property(get_IsFastForwardEnabled, put_IsFastForwardEnabled)
    IsFastRewindButtonVisible = property(get_IsFastRewindButtonVisible, put_IsFastRewindButtonVisible)
    IsFastRewindEnabled = property(get_IsFastRewindEnabled, put_IsFastRewindEnabled)
    IsNextTrackButtonVisible = property(get_IsNextTrackButtonVisible, put_IsNextTrackButtonVisible)
    IsPlaybackRateButtonVisible = property(get_IsPlaybackRateButtonVisible, put_IsPlaybackRateButtonVisible)
    IsPlaybackRateEnabled = property(get_IsPlaybackRateEnabled, put_IsPlaybackRateEnabled)
    IsPreviousTrackButtonVisible = property(get_IsPreviousTrackButtonVisible, put_IsPreviousTrackButtonVisible)
    IsRepeatButtonVisible = property(get_IsRepeatButtonVisible, put_IsRepeatButtonVisible)
    IsRepeatEnabled = property(get_IsRepeatEnabled, put_IsRepeatEnabled)
    IsSeekBarVisible = property(get_IsSeekBarVisible, put_IsSeekBarVisible)
    IsSeekEnabled = property(get_IsSeekEnabled, put_IsSeekEnabled)
    IsSkipBackwardButtonVisible = property(get_IsSkipBackwardButtonVisible, put_IsSkipBackwardButtonVisible)
    IsSkipBackwardEnabled = property(get_IsSkipBackwardEnabled, put_IsSkipBackwardEnabled)
    IsSkipForwardButtonVisible = property(get_IsSkipForwardButtonVisible, put_IsSkipForwardButtonVisible)
    IsSkipForwardEnabled = property(get_IsSkipForwardEnabled, put_IsSkipForwardEnabled)
    IsStopButtonVisible = property(get_IsStopButtonVisible, put_IsStopButtonVisible)
    IsStopEnabled = property(get_IsStopEnabled, put_IsStopEnabled)
    IsVolumeButtonVisible = property(get_IsVolumeButtonVisible, put_IsVolumeButtonVisible)
    IsVolumeEnabled = property(get_IsVolumeEnabled, put_IsVolumeEnabled)
    IsZoomButtonVisible = property(get_IsZoomButtonVisible, put_IsZoomButtonVisible)
    IsZoomEnabled = property(get_IsZoomEnabled, put_IsZoomEnabled)
    ShowAndHideAutomatically = property(get_ShowAndHideAutomatically, put_ShowAndHideAutomatically)
    _MediaTransportControls_Meta_.FastPlayFallbackBehaviourProperty = property(get_FastPlayFallbackBehaviourProperty, None)
    _MediaTransportControls_Meta_.IsCompactProperty = property(get_IsCompactProperty, None)
    _MediaTransportControls_Meta_.IsFastForwardButtonVisibleProperty = property(get_IsFastForwardButtonVisibleProperty, None)
    _MediaTransportControls_Meta_.IsFastForwardEnabledProperty = property(get_IsFastForwardEnabledProperty, None)
    _MediaTransportControls_Meta_.IsFastRewindButtonVisibleProperty = property(get_IsFastRewindButtonVisibleProperty, None)
    _MediaTransportControls_Meta_.IsFastRewindEnabledProperty = property(get_IsFastRewindEnabledProperty, None)
    _MediaTransportControls_Meta_.IsNextTrackButtonVisibleProperty = property(get_IsNextTrackButtonVisibleProperty, None)
    _MediaTransportControls_Meta_.IsPlaybackRateButtonVisibleProperty = property(get_IsPlaybackRateButtonVisibleProperty, None)
    _MediaTransportControls_Meta_.IsPlaybackRateEnabledProperty = property(get_IsPlaybackRateEnabledProperty, None)
    _MediaTransportControls_Meta_.IsPreviousTrackButtonVisibleProperty = property(get_IsPreviousTrackButtonVisibleProperty, None)
    _MediaTransportControls_Meta_.IsRepeatButtonVisibleProperty = property(get_IsRepeatButtonVisibleProperty, None)
    _MediaTransportControls_Meta_.IsRepeatEnabledProperty = property(get_IsRepeatEnabledProperty, None)
    _MediaTransportControls_Meta_.IsSeekBarVisibleProperty = property(get_IsSeekBarVisibleProperty, None)
    _MediaTransportControls_Meta_.IsSeekEnabledProperty = property(get_IsSeekEnabledProperty, None)
    _MediaTransportControls_Meta_.IsSkipBackwardButtonVisibleProperty = property(get_IsSkipBackwardButtonVisibleProperty, None)
    _MediaTransportControls_Meta_.IsSkipBackwardEnabledProperty = property(get_IsSkipBackwardEnabledProperty, None)
    _MediaTransportControls_Meta_.IsSkipForwardButtonVisibleProperty = property(get_IsSkipForwardButtonVisibleProperty, None)
    _MediaTransportControls_Meta_.IsSkipForwardEnabledProperty = property(get_IsSkipForwardEnabledProperty, None)
    _MediaTransportControls_Meta_.IsStopButtonVisibleProperty = property(get_IsStopButtonVisibleProperty, None)
    _MediaTransportControls_Meta_.IsStopEnabledProperty = property(get_IsStopEnabledProperty, None)
    _MediaTransportControls_Meta_.IsVolumeButtonVisibleProperty = property(get_IsVolumeButtonVisibleProperty, None)
    _MediaTransportControls_Meta_.IsVolumeEnabledProperty = property(get_IsVolumeEnabledProperty, None)
    _MediaTransportControls_Meta_.IsZoomButtonVisibleProperty = property(get_IsZoomButtonVisibleProperty, None)
    _MediaTransportControls_Meta_.IsZoomEnabledProperty = property(get_IsZoomEnabledProperty, None)
    _MediaTransportControls_Meta_.ShowAndHideAutomaticallyProperty = property(get_ShowAndHideAutomaticallyProperty, None)
    ThumbnailRequested = event(add_ThumbnailRequested, remove_ThumbnailRequested)
class _MediaTransportControlsHelper_Meta_(ComPtr.__class__):
    pass
class MediaTransportControlsHelper(ComPtr, metaclass=_MediaTransportControlsHelper_Meta_):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControlsHelper
    _classid_ = 'Microsoft.UI.Xaml.Controls.MediaTransportControlsHelper'
    @winrt_classmethod
    def get_DropoutOrderProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControlsHelperStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetDropoutOrder(cls: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControlsHelperStatics, element: win32more.Microsoft.UI.Xaml.UIElement) -> win32more.Windows.Foundation.IReference[Int32]: ...
    @winrt_classmethod
    def SetDropoutOrder(cls: win32more.Microsoft.UI.Xaml.Controls.IMediaTransportControlsHelperStatics, element: win32more.Microsoft.UI.Xaml.UIElement, value: win32more.Windows.Foundation.IReference[Int32]) -> Void: ...
    _MediaTransportControlsHelper_Meta_.DropoutOrderProperty = property(get_DropoutOrderProperty, None)
class _MenuBar_Meta_(ComPtr.__class__):
    pass
class MenuBar(ComPtr, metaclass=_MenuBar_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.Control
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IMenuBar
    _classid_ = 'Microsoft.UI.Xaml.Controls.MenuBar'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.MenuBar.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IMenuBarFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.MenuBar: ...
    @winrt_mixinmethod
    def get_Items(self: win32more.Microsoft.UI.Xaml.Controls.IMenuBar) -> win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.MenuBarItem]: ...
    @winrt_classmethod
    def get_ItemsProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IMenuBarStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    Items = property(get_Items, None)
    _MenuBar_Meta_.ItemsProperty = property(get_ItemsProperty, None)
class _MenuBarItem_Meta_(ComPtr.__class__):
    pass
class MenuBarItem(ComPtr, metaclass=_MenuBarItem_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.Control
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IMenuBarItem
    _classid_ = 'Microsoft.UI.Xaml.Controls.MenuBarItem'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.MenuBarItem.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IMenuBarItemFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.MenuBarItem: ...
    @winrt_mixinmethod
    def get_Title(self: win32more.Microsoft.UI.Xaml.Controls.IMenuBarItem) -> hstr: ...
    @winrt_mixinmethod
    def put_Title(self: win32more.Microsoft.UI.Xaml.Controls.IMenuBarItem, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def get_Items(self: win32more.Microsoft.UI.Xaml.Controls.IMenuBarItem) -> win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.MenuFlyoutItemBase]: ...
    @winrt_classmethod
    def get_TitleProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IMenuBarItemStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ItemsProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IMenuBarItemStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    Items = property(get_Items, None)
    Title = property(get_Title, put_Title)
    _MenuBarItem_Meta_.ItemsProperty = property(get_ItemsProperty, None)
    _MenuBarItem_Meta_.TitleProperty = property(get_TitleProperty, None)
class MenuBarItemFlyout(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.Controls.MenuFlyout
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IMenuBarItemFlyout
    _classid_ = 'Microsoft.UI.Xaml.Controls.MenuBarItemFlyout'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.MenuBarItemFlyout.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IMenuBarItemFlyoutFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.MenuBarItemFlyout: ...
class _MenuFlyout_Meta_(ComPtr.__class__):
    pass
class MenuFlyout(ComPtr, metaclass=_MenuFlyout_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.Primitives.FlyoutBase
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IMenuFlyout
    _classid_ = 'Microsoft.UI.Xaml.Controls.MenuFlyout'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.MenuFlyout.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IMenuFlyoutFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.MenuFlyout: ...
    @winrt_mixinmethod
    def get_Items(self: win32more.Microsoft.UI.Xaml.Controls.IMenuFlyout) -> win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.MenuFlyoutItemBase]: ...
    @winrt_mixinmethod
    def get_MenuFlyoutPresenterStyle(self: win32more.Microsoft.UI.Xaml.Controls.IMenuFlyout) -> win32more.Microsoft.UI.Xaml.Style: ...
    @winrt_mixinmethod
    def put_MenuFlyoutPresenterStyle(self: win32more.Microsoft.UI.Xaml.Controls.IMenuFlyout, value: win32more.Microsoft.UI.Xaml.Style) -> Void: ...
    @winrt_mixinmethod
    def ShowAt(self: win32more.Microsoft.UI.Xaml.Controls.IMenuFlyout, targetElement: win32more.Microsoft.UI.Xaml.UIElement, point: win32more.Windows.Foundation.Point) -> Void: ...
    @winrt_classmethod
    def get_MenuFlyoutPresenterStyleProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IMenuFlyoutStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    Items = property(get_Items, None)
    MenuFlyoutPresenterStyle = property(get_MenuFlyoutPresenterStyle, put_MenuFlyoutPresenterStyle)
    _MenuFlyout_Meta_.MenuFlyoutPresenterStyleProperty = property(get_MenuFlyoutPresenterStyleProperty, None)
class _MenuFlyoutItem_Meta_(ComPtr.__class__):
    pass
class MenuFlyoutItem(ComPtr, metaclass=_MenuFlyoutItem_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.MenuFlyoutItemBase
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IMenuFlyoutItem
    _classid_ = 'Microsoft.UI.Xaml.Controls.MenuFlyoutItem'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.MenuFlyoutItem.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IMenuFlyoutItemFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.MenuFlyoutItem: ...
    @winrt_mixinmethod
    def get_Text(self: win32more.Microsoft.UI.Xaml.Controls.IMenuFlyoutItem) -> hstr: ...
    @winrt_mixinmethod
    def put_Text(self: win32more.Microsoft.UI.Xaml.Controls.IMenuFlyoutItem, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def get_Command(self: win32more.Microsoft.UI.Xaml.Controls.IMenuFlyoutItem) -> win32more.Microsoft.UI.Xaml.Input.ICommand: ...
    @winrt_mixinmethod
    def put_Command(self: win32more.Microsoft.UI.Xaml.Controls.IMenuFlyoutItem, value: win32more.Microsoft.UI.Xaml.Input.ICommand) -> Void: ...
    @winrt_mixinmethod
    def get_CommandParameter(self: win32more.Microsoft.UI.Xaml.Controls.IMenuFlyoutItem) -> IInspectable: ...
    @winrt_mixinmethod
    def put_CommandParameter(self: win32more.Microsoft.UI.Xaml.Controls.IMenuFlyoutItem, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_Icon(self: win32more.Microsoft.UI.Xaml.Controls.IMenuFlyoutItem) -> win32more.Microsoft.UI.Xaml.Controls.IconElement: ...
    @winrt_mixinmethod
    def put_Icon(self: win32more.Microsoft.UI.Xaml.Controls.IMenuFlyoutItem, value: win32more.Microsoft.UI.Xaml.Controls.IconElement) -> Void: ...
    @winrt_mixinmethod
    def get_KeyboardAcceleratorTextOverride(self: win32more.Microsoft.UI.Xaml.Controls.IMenuFlyoutItem) -> hstr: ...
    @winrt_mixinmethod
    def put_KeyboardAcceleratorTextOverride(self: win32more.Microsoft.UI.Xaml.Controls.IMenuFlyoutItem, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def get_TemplateSettings(self: win32more.Microsoft.UI.Xaml.Controls.IMenuFlyoutItem) -> win32more.Microsoft.UI.Xaml.Controls.Primitives.MenuFlyoutItemTemplateSettings: ...
    @winrt_mixinmethod
    def add_Click(self: win32more.Microsoft.UI.Xaml.Controls.IMenuFlyoutItem, handler: win32more.Microsoft.UI.Xaml.RoutedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Click(self: win32more.Microsoft.UI.Xaml.Controls.IMenuFlyoutItem, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def get_TextProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IMenuFlyoutItemStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CommandProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IMenuFlyoutItemStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CommandParameterProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IMenuFlyoutItemStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IconProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IMenuFlyoutItemStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_KeyboardAcceleratorTextOverrideProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IMenuFlyoutItemStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    Command = property(get_Command, put_Command)
    CommandParameter = property(get_CommandParameter, put_CommandParameter)
    Icon = property(get_Icon, put_Icon)
    KeyboardAcceleratorTextOverride = property(get_KeyboardAcceleratorTextOverride, put_KeyboardAcceleratorTextOverride)
    TemplateSettings = property(get_TemplateSettings, None)
    Text = property(get_Text, put_Text)
    _MenuFlyoutItem_Meta_.CommandParameterProperty = property(get_CommandParameterProperty, None)
    _MenuFlyoutItem_Meta_.CommandProperty = property(get_CommandProperty, None)
    _MenuFlyoutItem_Meta_.IconProperty = property(get_IconProperty, None)
    _MenuFlyoutItem_Meta_.KeyboardAcceleratorTextOverrideProperty = property(get_KeyboardAcceleratorTextOverrideProperty, None)
    _MenuFlyoutItem_Meta_.TextProperty = property(get_TextProperty, None)
    Click = event(add_Click, remove_Click)
class MenuFlyoutItemBase(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.Controls.Control
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IMenuFlyoutItemBase
    _classid_ = 'Microsoft.UI.Xaml.Controls.MenuFlyoutItemBase'
class _MenuFlyoutPresenter_Meta_(ComPtr.__class__):
    pass
class MenuFlyoutPresenter(ComPtr, metaclass=_MenuFlyoutPresenter_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.ItemsControl
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IMenuFlyoutPresenter
    _classid_ = 'Microsoft.UI.Xaml.Controls.MenuFlyoutPresenter'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.MenuFlyoutPresenter.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IMenuFlyoutPresenterFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.MenuFlyoutPresenter: ...
    @winrt_mixinmethod
    def get_TemplateSettings(self: win32more.Microsoft.UI.Xaml.Controls.IMenuFlyoutPresenter) -> win32more.Microsoft.UI.Xaml.Controls.Primitives.MenuFlyoutPresenterTemplateSettings: ...
    @winrt_mixinmethod
    def get_IsDefaultShadowEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IMenuFlyoutPresenter) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsDefaultShadowEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IMenuFlyoutPresenter, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_SystemBackdrop(self: win32more.Microsoft.UI.Xaml.Controls.IMenuFlyoutPresenter2) -> win32more.Microsoft.UI.Xaml.Media.SystemBackdrop: ...
    @winrt_mixinmethod
    def put_SystemBackdrop(self: win32more.Microsoft.UI.Xaml.Controls.IMenuFlyoutPresenter2, value: win32more.Microsoft.UI.Xaml.Media.SystemBackdrop) -> Void: ...
    @winrt_classmethod
    def get_SystemBackdropProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IMenuFlyoutPresenterStatics2) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsDefaultShadowEnabledProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IMenuFlyoutPresenterStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    IsDefaultShadowEnabled = property(get_IsDefaultShadowEnabled, put_IsDefaultShadowEnabled)
    SystemBackdrop = property(get_SystemBackdrop, put_SystemBackdrop)
    TemplateSettings = property(get_TemplateSettings, None)
    _MenuFlyoutPresenter_Meta_.IsDefaultShadowEnabledProperty = property(get_IsDefaultShadowEnabledProperty, None)
    _MenuFlyoutPresenter_Meta_.SystemBackdropProperty = property(get_SystemBackdropProperty, None)
class MenuFlyoutSeparator(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.Controls.MenuFlyoutItemBase
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IMenuFlyoutSeparator
    _classid_ = 'Microsoft.UI.Xaml.Controls.MenuFlyoutSeparator'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.MenuFlyoutSeparator.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IMenuFlyoutSeparatorFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.MenuFlyoutSeparator: ...
class _MenuFlyoutSubItem_Meta_(ComPtr.__class__):
    pass
class MenuFlyoutSubItem(ComPtr, metaclass=_MenuFlyoutSubItem_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.MenuFlyoutItemBase
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IMenuFlyoutSubItem
    _classid_ = 'Microsoft.UI.Xaml.Controls.MenuFlyoutSubItem'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.MenuFlyoutSubItem.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Controls.MenuFlyoutSubItem: ...
    @winrt_mixinmethod
    def get_Items(self: win32more.Microsoft.UI.Xaml.Controls.IMenuFlyoutSubItem) -> win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.MenuFlyoutItemBase]: ...
    @winrt_mixinmethod
    def get_Text(self: win32more.Microsoft.UI.Xaml.Controls.IMenuFlyoutSubItem) -> hstr: ...
    @winrt_mixinmethod
    def put_Text(self: win32more.Microsoft.UI.Xaml.Controls.IMenuFlyoutSubItem, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def get_Icon(self: win32more.Microsoft.UI.Xaml.Controls.IMenuFlyoutSubItem) -> win32more.Microsoft.UI.Xaml.Controls.IconElement: ...
    @winrt_mixinmethod
    def put_Icon(self: win32more.Microsoft.UI.Xaml.Controls.IMenuFlyoutSubItem, value: win32more.Microsoft.UI.Xaml.Controls.IconElement) -> Void: ...
    @winrt_classmethod
    def get_TextProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IMenuFlyoutSubItemStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IconProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IMenuFlyoutSubItemStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    Icon = property(get_Icon, put_Icon)
    Items = property(get_Items, None)
    Text = property(get_Text, put_Text)
    _MenuFlyoutSubItem_Meta_.IconProperty = property(get_IconProperty, None)
    _MenuFlyoutSubItem_Meta_.TextProperty = property(get_TextProperty, None)
class _NavigationView_Meta_(ComPtr.__class__):
    pass
class NavigationView(ComPtr, metaclass=_NavigationView_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.ContentControl
    default_interface: win32more.Microsoft.UI.Xaml.Controls.INavigationView
    _classid_ = 'Microsoft.UI.Xaml.Controls.NavigationView'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.NavigationView.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.INavigationViewFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.NavigationView: ...
    @winrt_mixinmethod
    def get_IsPaneOpen(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsPaneOpen(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_CompactModeThresholdWidth(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView) -> Double: ...
    @winrt_mixinmethod
    def put_CompactModeThresholdWidth(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_ExpandedModeThresholdWidth(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView) -> Double: ...
    @winrt_mixinmethod
    def put_ExpandedModeThresholdWidth(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_FooterMenuItems(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView) -> win32more.Windows.Foundation.Collections.IVector[IInspectable]: ...
    @winrt_mixinmethod
    def get_FooterMenuItemsSource(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView) -> IInspectable: ...
    @winrt_mixinmethod
    def put_FooterMenuItemsSource(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_PaneFooter(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_mixinmethod
    def put_PaneFooter(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView, value: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    @winrt_mixinmethod
    def get_Header(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView) -> IInspectable: ...
    @winrt_mixinmethod
    def put_Header(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_HeaderTemplate(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def put_HeaderTemplate(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_mixinmethod
    def get_DisplayMode(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView) -> win32more.Microsoft.UI.Xaml.Controls.NavigationViewDisplayMode: ...
    @winrt_mixinmethod
    def get_IsSettingsVisible(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsSettingsVisible(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsPaneToggleButtonVisible(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsPaneToggleButtonVisible(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_AlwaysShowHeader(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView) -> Boolean: ...
    @winrt_mixinmethod
    def put_AlwaysShowHeader(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_CompactPaneLength(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView) -> Double: ...
    @winrt_mixinmethod
    def put_CompactPaneLength(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_OpenPaneLength(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView) -> Double: ...
    @winrt_mixinmethod
    def put_OpenPaneLength(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_PaneToggleButtonStyle(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView) -> win32more.Microsoft.UI.Xaml.Style: ...
    @winrt_mixinmethod
    def put_PaneToggleButtonStyle(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView, value: win32more.Microsoft.UI.Xaml.Style) -> Void: ...
    @winrt_mixinmethod
    def get_SelectedItem(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView) -> IInspectable: ...
    @winrt_mixinmethod
    def put_SelectedItem(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_MenuItems(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView) -> win32more.Windows.Foundation.Collections.IVector[IInspectable]: ...
    @winrt_mixinmethod
    def get_MenuItemsSource(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView) -> IInspectable: ...
    @winrt_mixinmethod
    def put_MenuItemsSource(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_SettingsItem(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView) -> IInspectable: ...
    @winrt_mixinmethod
    def get_AutoSuggestBox(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView) -> win32more.Microsoft.UI.Xaml.Controls.AutoSuggestBox: ...
    @winrt_mixinmethod
    def put_AutoSuggestBox(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView, value: win32more.Microsoft.UI.Xaml.Controls.AutoSuggestBox) -> Void: ...
    @winrt_mixinmethod
    def get_MenuItemTemplate(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def put_MenuItemTemplate(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_mixinmethod
    def get_MenuItemTemplateSelector(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView) -> win32more.Microsoft.UI.Xaml.Controls.DataTemplateSelector: ...
    @winrt_mixinmethod
    def put_MenuItemTemplateSelector(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView, value: win32more.Microsoft.UI.Xaml.Controls.DataTemplateSelector) -> Void: ...
    @winrt_mixinmethod
    def get_MenuItemContainerStyle(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView) -> win32more.Microsoft.UI.Xaml.Style: ...
    @winrt_mixinmethod
    def put_MenuItemContainerStyle(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView, value: win32more.Microsoft.UI.Xaml.Style) -> Void: ...
    @winrt_mixinmethod
    def get_MenuItemContainerStyleSelector(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView) -> win32more.Microsoft.UI.Xaml.Controls.StyleSelector: ...
    @winrt_mixinmethod
    def put_MenuItemContainerStyleSelector(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView, value: win32more.Microsoft.UI.Xaml.Controls.StyleSelector) -> Void: ...
    @winrt_mixinmethod
    def MenuItemFromContainer(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView, container: win32more.Microsoft.UI.Xaml.DependencyObject) -> IInspectable: ...
    @winrt_mixinmethod
    def ContainerFromMenuItem(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView, item: IInspectable) -> win32more.Microsoft.UI.Xaml.DependencyObject: ...
    @winrt_mixinmethod
    def add_SelectionChanged(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.NavigationView, win32more.Microsoft.UI.Xaml.Controls.NavigationViewSelectionChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_SelectionChanged(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_ItemInvoked(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.NavigationView, win32more.Microsoft.UI.Xaml.Controls.NavigationViewItemInvokedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ItemInvoked(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_DisplayModeChanged(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.NavigationView, win32more.Microsoft.UI.Xaml.Controls.NavigationViewDisplayModeChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_DisplayModeChanged(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def get_IsTitleBarAutoPaddingEnabled(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsTitleBarAutoPaddingEnabled(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsBackButtonVisible(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView2) -> win32more.Microsoft.UI.Xaml.Controls.NavigationViewBackButtonVisible: ...
    @winrt_mixinmethod
    def put_IsBackButtonVisible(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView2, value: win32more.Microsoft.UI.Xaml.Controls.NavigationViewBackButtonVisible) -> Void: ...
    @winrt_mixinmethod
    def get_IsBackEnabled(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView2) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsBackEnabled(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView2, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_PaneTitle(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView2) -> hstr: ...
    @winrt_mixinmethod
    def put_PaneTitle(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView2, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def add_BackRequested(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView2, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.NavigationView, win32more.Microsoft.UI.Xaml.Controls.NavigationViewBackRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_BackRequested(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView2, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_PaneClosed(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView2, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.NavigationView, IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_PaneClosed(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView2, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_PaneClosing(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView2, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.NavigationView, win32more.Microsoft.UI.Xaml.Controls.NavigationViewPaneClosingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_PaneClosing(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView2, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_PaneOpened(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView2, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.NavigationView, IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_PaneOpened(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView2, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_PaneOpening(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView2, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.NavigationView, IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_PaneOpening(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView2, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def get_PaneDisplayMode(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView2) -> win32more.Microsoft.UI.Xaml.Controls.NavigationViewPaneDisplayMode: ...
    @winrt_mixinmethod
    def put_PaneDisplayMode(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView2, value: win32more.Microsoft.UI.Xaml.Controls.NavigationViewPaneDisplayMode) -> Void: ...
    @winrt_mixinmethod
    def get_PaneHeader(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView2) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_mixinmethod
    def put_PaneHeader(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView2, value: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    @winrt_mixinmethod
    def get_PaneCustomContent(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView2) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_mixinmethod
    def put_PaneCustomContent(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView2, value: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    @winrt_mixinmethod
    def get_ContentOverlay(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView2) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_mixinmethod
    def put_ContentOverlay(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView2, value: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    @winrt_mixinmethod
    def get_IsPaneVisible(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView2) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsPaneVisible(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView2, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_SelectionFollowsFocus(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView2) -> win32more.Microsoft.UI.Xaml.Controls.NavigationViewSelectionFollowsFocus: ...
    @winrt_mixinmethod
    def put_SelectionFollowsFocus(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView2, value: win32more.Microsoft.UI.Xaml.Controls.NavigationViewSelectionFollowsFocus) -> Void: ...
    @winrt_mixinmethod
    def get_TemplateSettings(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView2) -> win32more.Microsoft.UI.Xaml.Controls.NavigationViewTemplateSettings: ...
    @winrt_mixinmethod
    def get_ShoulderNavigationEnabled(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView2) -> win32more.Microsoft.UI.Xaml.Controls.NavigationViewShoulderNavigationEnabled: ...
    @winrt_mixinmethod
    def put_ShoulderNavigationEnabled(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView2, value: win32more.Microsoft.UI.Xaml.Controls.NavigationViewShoulderNavigationEnabled) -> Void: ...
    @winrt_mixinmethod
    def get_OverflowLabelMode(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView2) -> win32more.Microsoft.UI.Xaml.Controls.NavigationViewOverflowLabelMode: ...
    @winrt_mixinmethod
    def put_OverflowLabelMode(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView2, value: win32more.Microsoft.UI.Xaml.Controls.NavigationViewOverflowLabelMode) -> Void: ...
    @winrt_mixinmethod
    def add_Expanding(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView2, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.NavigationView, win32more.Microsoft.UI.Xaml.Controls.NavigationViewItemExpandingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Expanding(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView2, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_Collapsed(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView2, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.NavigationView, win32more.Microsoft.UI.Xaml.Controls.NavigationViewItemCollapsedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Collapsed(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView2, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def Expand(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView2, item: win32more.Microsoft.UI.Xaml.Controls.NavigationViewItem) -> Void: ...
    @winrt_mixinmethod
    def Collapse(self: win32more.Microsoft.UI.Xaml.Controls.INavigationView2, item: win32more.Microsoft.UI.Xaml.Controls.NavigationViewItem) -> Void: ...
    @winrt_classmethod
    def get_IsBackButtonVisibleProperty(cls: win32more.Microsoft.UI.Xaml.Controls.INavigationViewStatics2) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsBackEnabledProperty(cls: win32more.Microsoft.UI.Xaml.Controls.INavigationViewStatics2) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PaneTitleProperty(cls: win32more.Microsoft.UI.Xaml.Controls.INavigationViewStatics2) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PaneDisplayModeProperty(cls: win32more.Microsoft.UI.Xaml.Controls.INavigationViewStatics2) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PaneHeaderProperty(cls: win32more.Microsoft.UI.Xaml.Controls.INavigationViewStatics2) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PaneCustomContentProperty(cls: win32more.Microsoft.UI.Xaml.Controls.INavigationViewStatics2) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ContentOverlayProperty(cls: win32more.Microsoft.UI.Xaml.Controls.INavigationViewStatics2) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsPaneVisibleProperty(cls: win32more.Microsoft.UI.Xaml.Controls.INavigationViewStatics2) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectionFollowsFocusProperty(cls: win32more.Microsoft.UI.Xaml.Controls.INavigationViewStatics2) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TemplateSettingsProperty(cls: win32more.Microsoft.UI.Xaml.Controls.INavigationViewStatics2) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ShoulderNavigationEnabledProperty(cls: win32more.Microsoft.UI.Xaml.Controls.INavigationViewStatics2) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_OverflowLabelModeProperty(cls: win32more.Microsoft.UI.Xaml.Controls.INavigationViewStatics2) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsPaneOpenProperty(cls: win32more.Microsoft.UI.Xaml.Controls.INavigationViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CompactModeThresholdWidthProperty(cls: win32more.Microsoft.UI.Xaml.Controls.INavigationViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ExpandedModeThresholdWidthProperty(cls: win32more.Microsoft.UI.Xaml.Controls.INavigationViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FooterMenuItemsProperty(cls: win32more.Microsoft.UI.Xaml.Controls.INavigationViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FooterMenuItemsSourceProperty(cls: win32more.Microsoft.UI.Xaml.Controls.INavigationViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PaneFooterProperty(cls: win32more.Microsoft.UI.Xaml.Controls.INavigationViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HeaderProperty(cls: win32more.Microsoft.UI.Xaml.Controls.INavigationViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HeaderTemplateProperty(cls: win32more.Microsoft.UI.Xaml.Controls.INavigationViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DisplayModeProperty(cls: win32more.Microsoft.UI.Xaml.Controls.INavigationViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsSettingsVisibleProperty(cls: win32more.Microsoft.UI.Xaml.Controls.INavigationViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsPaneToggleButtonVisibleProperty(cls: win32more.Microsoft.UI.Xaml.Controls.INavigationViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_AlwaysShowHeaderProperty(cls: win32more.Microsoft.UI.Xaml.Controls.INavigationViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CompactPaneLengthProperty(cls: win32more.Microsoft.UI.Xaml.Controls.INavigationViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_OpenPaneLengthProperty(cls: win32more.Microsoft.UI.Xaml.Controls.INavigationViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PaneToggleButtonStyleProperty(cls: win32more.Microsoft.UI.Xaml.Controls.INavigationViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MenuItemsProperty(cls: win32more.Microsoft.UI.Xaml.Controls.INavigationViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MenuItemsSourceProperty(cls: win32more.Microsoft.UI.Xaml.Controls.INavigationViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectedItemProperty(cls: win32more.Microsoft.UI.Xaml.Controls.INavigationViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SettingsItemProperty(cls: win32more.Microsoft.UI.Xaml.Controls.INavigationViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_AutoSuggestBoxProperty(cls: win32more.Microsoft.UI.Xaml.Controls.INavigationViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MenuItemTemplateProperty(cls: win32more.Microsoft.UI.Xaml.Controls.INavigationViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MenuItemTemplateSelectorProperty(cls: win32more.Microsoft.UI.Xaml.Controls.INavigationViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MenuItemContainerStyleProperty(cls: win32more.Microsoft.UI.Xaml.Controls.INavigationViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MenuItemContainerStyleSelectorProperty(cls: win32more.Microsoft.UI.Xaml.Controls.INavigationViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsTitleBarAutoPaddingEnabledProperty(cls: win32more.Microsoft.UI.Xaml.Controls.INavigationViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    AlwaysShowHeader = property(get_AlwaysShowHeader, put_AlwaysShowHeader)
    AutoSuggestBox = property(get_AutoSuggestBox, put_AutoSuggestBox)
    CompactModeThresholdWidth = property(get_CompactModeThresholdWidth, put_CompactModeThresholdWidth)
    CompactPaneLength = property(get_CompactPaneLength, put_CompactPaneLength)
    ContentOverlay = property(get_ContentOverlay, put_ContentOverlay)
    DisplayMode = property(get_DisplayMode, None)
    ExpandedModeThresholdWidth = property(get_ExpandedModeThresholdWidth, put_ExpandedModeThresholdWidth)
    FooterMenuItems = property(get_FooterMenuItems, None)
    FooterMenuItemsSource = property(get_FooterMenuItemsSource, put_FooterMenuItemsSource)
    Header = property(get_Header, put_Header)
    HeaderTemplate = property(get_HeaderTemplate, put_HeaderTemplate)
    IsBackButtonVisible = property(get_IsBackButtonVisible, put_IsBackButtonVisible)
    IsBackEnabled = property(get_IsBackEnabled, put_IsBackEnabled)
    IsPaneOpen = property(get_IsPaneOpen, put_IsPaneOpen)
    IsPaneToggleButtonVisible = property(get_IsPaneToggleButtonVisible, put_IsPaneToggleButtonVisible)
    IsPaneVisible = property(get_IsPaneVisible, put_IsPaneVisible)
    IsSettingsVisible = property(get_IsSettingsVisible, put_IsSettingsVisible)
    IsTitleBarAutoPaddingEnabled = property(get_IsTitleBarAutoPaddingEnabled, put_IsTitleBarAutoPaddingEnabled)
    MenuItemContainerStyle = property(get_MenuItemContainerStyle, put_MenuItemContainerStyle)
    MenuItemContainerStyleSelector = property(get_MenuItemContainerStyleSelector, put_MenuItemContainerStyleSelector)
    MenuItemTemplate = property(get_MenuItemTemplate, put_MenuItemTemplate)
    MenuItemTemplateSelector = property(get_MenuItemTemplateSelector, put_MenuItemTemplateSelector)
    MenuItems = property(get_MenuItems, None)
    MenuItemsSource = property(get_MenuItemsSource, put_MenuItemsSource)
    OpenPaneLength = property(get_OpenPaneLength, put_OpenPaneLength)
    OverflowLabelMode = property(get_OverflowLabelMode, put_OverflowLabelMode)
    PaneCustomContent = property(get_PaneCustomContent, put_PaneCustomContent)
    PaneDisplayMode = property(get_PaneDisplayMode, put_PaneDisplayMode)
    PaneFooter = property(get_PaneFooter, put_PaneFooter)
    PaneHeader = property(get_PaneHeader, put_PaneHeader)
    PaneTitle = property(get_PaneTitle, put_PaneTitle)
    PaneToggleButtonStyle = property(get_PaneToggleButtonStyle, put_PaneToggleButtonStyle)
    SelectedItem = property(get_SelectedItem, put_SelectedItem)
    SelectionFollowsFocus = property(get_SelectionFollowsFocus, put_SelectionFollowsFocus)
    SettingsItem = property(get_SettingsItem, None)
    ShoulderNavigationEnabled = property(get_ShoulderNavigationEnabled, put_ShoulderNavigationEnabled)
    TemplateSettings = property(get_TemplateSettings, None)
    _NavigationView_Meta_.AlwaysShowHeaderProperty = property(get_AlwaysShowHeaderProperty, None)
    _NavigationView_Meta_.AutoSuggestBoxProperty = property(get_AutoSuggestBoxProperty, None)
    _NavigationView_Meta_.CompactModeThresholdWidthProperty = property(get_CompactModeThresholdWidthProperty, None)
    _NavigationView_Meta_.CompactPaneLengthProperty = property(get_CompactPaneLengthProperty, None)
    _NavigationView_Meta_.ContentOverlayProperty = property(get_ContentOverlayProperty, None)
    _NavigationView_Meta_.DisplayModeProperty = property(get_DisplayModeProperty, None)
    _NavigationView_Meta_.ExpandedModeThresholdWidthProperty = property(get_ExpandedModeThresholdWidthProperty, None)
    _NavigationView_Meta_.FooterMenuItemsProperty = property(get_FooterMenuItemsProperty, None)
    _NavigationView_Meta_.FooterMenuItemsSourceProperty = property(get_FooterMenuItemsSourceProperty, None)
    _NavigationView_Meta_.HeaderProperty = property(get_HeaderProperty, None)
    _NavigationView_Meta_.HeaderTemplateProperty = property(get_HeaderTemplateProperty, None)
    _NavigationView_Meta_.IsBackButtonVisibleProperty = property(get_IsBackButtonVisibleProperty, None)
    _NavigationView_Meta_.IsBackEnabledProperty = property(get_IsBackEnabledProperty, None)
    _NavigationView_Meta_.IsPaneOpenProperty = property(get_IsPaneOpenProperty, None)
    _NavigationView_Meta_.IsPaneToggleButtonVisibleProperty = property(get_IsPaneToggleButtonVisibleProperty, None)
    _NavigationView_Meta_.IsPaneVisibleProperty = property(get_IsPaneVisibleProperty, None)
    _NavigationView_Meta_.IsSettingsVisibleProperty = property(get_IsSettingsVisibleProperty, None)
    _NavigationView_Meta_.IsTitleBarAutoPaddingEnabledProperty = property(get_IsTitleBarAutoPaddingEnabledProperty, None)
    _NavigationView_Meta_.MenuItemContainerStyleProperty = property(get_MenuItemContainerStyleProperty, None)
    _NavigationView_Meta_.MenuItemContainerStyleSelectorProperty = property(get_MenuItemContainerStyleSelectorProperty, None)
    _NavigationView_Meta_.MenuItemTemplateProperty = property(get_MenuItemTemplateProperty, None)
    _NavigationView_Meta_.MenuItemTemplateSelectorProperty = property(get_MenuItemTemplateSelectorProperty, None)
    _NavigationView_Meta_.MenuItemsProperty = property(get_MenuItemsProperty, None)
    _NavigationView_Meta_.MenuItemsSourceProperty = property(get_MenuItemsSourceProperty, None)
    _NavigationView_Meta_.OpenPaneLengthProperty = property(get_OpenPaneLengthProperty, None)
    _NavigationView_Meta_.OverflowLabelModeProperty = property(get_OverflowLabelModeProperty, None)
    _NavigationView_Meta_.PaneCustomContentProperty = property(get_PaneCustomContentProperty, None)
    _NavigationView_Meta_.PaneDisplayModeProperty = property(get_PaneDisplayModeProperty, None)
    _NavigationView_Meta_.PaneFooterProperty = property(get_PaneFooterProperty, None)
    _NavigationView_Meta_.PaneHeaderProperty = property(get_PaneHeaderProperty, None)
    _NavigationView_Meta_.PaneTitleProperty = property(get_PaneTitleProperty, None)
    _NavigationView_Meta_.PaneToggleButtonStyleProperty = property(get_PaneToggleButtonStyleProperty, None)
    _NavigationView_Meta_.SelectedItemProperty = property(get_SelectedItemProperty, None)
    _NavigationView_Meta_.SelectionFollowsFocusProperty = property(get_SelectionFollowsFocusProperty, None)
    _NavigationView_Meta_.SettingsItemProperty = property(get_SettingsItemProperty, None)
    _NavigationView_Meta_.ShoulderNavigationEnabledProperty = property(get_ShoulderNavigationEnabledProperty, None)
    _NavigationView_Meta_.TemplateSettingsProperty = property(get_TemplateSettingsProperty, None)
    BackRequested = event(add_BackRequested, remove_BackRequested)
    Collapsed = event(add_Collapsed, remove_Collapsed)
    DisplayModeChanged = event(add_DisplayModeChanged, remove_DisplayModeChanged)
    Expanding = event(add_Expanding, remove_Expanding)
    ItemInvoked = event(add_ItemInvoked, remove_ItemInvoked)
    PaneClosed = event(add_PaneClosed, remove_PaneClosed)
    PaneClosing = event(add_PaneClosing, remove_PaneClosing)
    PaneOpened = event(add_PaneOpened, remove_PaneOpened)
    PaneOpening = event(add_PaneOpening, remove_PaneOpening)
    SelectionChanged = event(add_SelectionChanged, remove_SelectionChanged)
class NavigationViewBackButtonVisible(Enum, Int32):
    Collapsed = 0
    Visible = 1
    Auto = 2
class NavigationViewBackRequestedEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.INavigationViewBackRequestedEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.NavigationViewBackRequestedEventArgs'
class NavigationViewDisplayMode(Enum, Int32):
    Minimal = 0
    Compact = 1
    Expanded = 2
class NavigationViewDisplayModeChangedEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.INavigationViewDisplayModeChangedEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.NavigationViewDisplayModeChangedEventArgs'
    @winrt_mixinmethod
    def get_DisplayMode(self: win32more.Microsoft.UI.Xaml.Controls.INavigationViewDisplayModeChangedEventArgs) -> win32more.Microsoft.UI.Xaml.Controls.NavigationViewDisplayMode: ...
    DisplayMode = property(get_DisplayMode, None)
class _NavigationViewItem_Meta_(ComPtr.__class__):
    pass
class NavigationViewItem(ComPtr, metaclass=_NavigationViewItem_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.NavigationViewItemBase
    default_interface: win32more.Microsoft.UI.Xaml.Controls.INavigationViewItem
    _classid_ = 'Microsoft.UI.Xaml.Controls.NavigationViewItem'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.NavigationViewItem.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.INavigationViewItemFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.NavigationViewItem: ...
    @winrt_mixinmethod
    def get_Icon(self: win32more.Microsoft.UI.Xaml.Controls.INavigationViewItem) -> win32more.Microsoft.UI.Xaml.Controls.IconElement: ...
    @winrt_mixinmethod
    def put_Icon(self: win32more.Microsoft.UI.Xaml.Controls.INavigationViewItem, value: win32more.Microsoft.UI.Xaml.Controls.IconElement) -> Void: ...
    @winrt_mixinmethod
    def get_CompactPaneLength(self: win32more.Microsoft.UI.Xaml.Controls.INavigationViewItem) -> Double: ...
    @winrt_mixinmethod
    def get_SelectsOnInvoked(self: win32more.Microsoft.UI.Xaml.Controls.INavigationViewItem2) -> Boolean: ...
    @winrt_mixinmethod
    def put_SelectsOnInvoked(self: win32more.Microsoft.UI.Xaml.Controls.INavigationViewItem2, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsExpanded(self: win32more.Microsoft.UI.Xaml.Controls.INavigationViewItem2) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsExpanded(self: win32more.Microsoft.UI.Xaml.Controls.INavigationViewItem2, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_HasUnrealizedChildren(self: win32more.Microsoft.UI.Xaml.Controls.INavigationViewItem2) -> Boolean: ...
    @winrt_mixinmethod
    def put_HasUnrealizedChildren(self: win32more.Microsoft.UI.Xaml.Controls.INavigationViewItem2, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsChildSelected(self: win32more.Microsoft.UI.Xaml.Controls.INavigationViewItem2) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsChildSelected(self: win32more.Microsoft.UI.Xaml.Controls.INavigationViewItem2, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_MenuItems(self: win32more.Microsoft.UI.Xaml.Controls.INavigationViewItem2) -> win32more.Windows.Foundation.Collections.IVector[IInspectable]: ...
    @winrt_mixinmethod
    def get_MenuItemsSource(self: win32more.Microsoft.UI.Xaml.Controls.INavigationViewItem2) -> IInspectable: ...
    @winrt_mixinmethod
    def put_MenuItemsSource(self: win32more.Microsoft.UI.Xaml.Controls.INavigationViewItem2, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_InfoBadge(self: win32more.Microsoft.UI.Xaml.Controls.INavigationViewItem3) -> win32more.Microsoft.UI.Xaml.Controls.InfoBadge: ...
    @winrt_mixinmethod
    def put_InfoBadge(self: win32more.Microsoft.UI.Xaml.Controls.INavigationViewItem3, value: win32more.Microsoft.UI.Xaml.Controls.InfoBadge) -> Void: ...
    @winrt_classmethod
    def get_InfoBadgeProperty(cls: win32more.Microsoft.UI.Xaml.Controls.INavigationViewItemStatics3) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectsOnInvokedProperty(cls: win32more.Microsoft.UI.Xaml.Controls.INavigationViewItemStatics2) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsExpandedProperty(cls: win32more.Microsoft.UI.Xaml.Controls.INavigationViewItemStatics2) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HasUnrealizedChildrenProperty(cls: win32more.Microsoft.UI.Xaml.Controls.INavigationViewItemStatics2) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsChildSelectedProperty(cls: win32more.Microsoft.UI.Xaml.Controls.INavigationViewItemStatics2) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MenuItemsProperty(cls: win32more.Microsoft.UI.Xaml.Controls.INavigationViewItemStatics2) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MenuItemsSourceProperty(cls: win32more.Microsoft.UI.Xaml.Controls.INavigationViewItemStatics2) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IconProperty(cls: win32more.Microsoft.UI.Xaml.Controls.INavigationViewItemStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CompactPaneLengthProperty(cls: win32more.Microsoft.UI.Xaml.Controls.INavigationViewItemStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    CompactPaneLength = property(get_CompactPaneLength, None)
    HasUnrealizedChildren = property(get_HasUnrealizedChildren, put_HasUnrealizedChildren)
    Icon = property(get_Icon, put_Icon)
    InfoBadge = property(get_InfoBadge, put_InfoBadge)
    IsChildSelected = property(get_IsChildSelected, put_IsChildSelected)
    IsExpanded = property(get_IsExpanded, put_IsExpanded)
    MenuItems = property(get_MenuItems, None)
    MenuItemsSource = property(get_MenuItemsSource, put_MenuItemsSource)
    SelectsOnInvoked = property(get_SelectsOnInvoked, put_SelectsOnInvoked)
    _NavigationViewItem_Meta_.CompactPaneLengthProperty = property(get_CompactPaneLengthProperty, None)
    _NavigationViewItem_Meta_.HasUnrealizedChildrenProperty = property(get_HasUnrealizedChildrenProperty, None)
    _NavigationViewItem_Meta_.IconProperty = property(get_IconProperty, None)
    _NavigationViewItem_Meta_.InfoBadgeProperty = property(get_InfoBadgeProperty, None)
    _NavigationViewItem_Meta_.IsChildSelectedProperty = property(get_IsChildSelectedProperty, None)
    _NavigationViewItem_Meta_.IsExpandedProperty = property(get_IsExpandedProperty, None)
    _NavigationViewItem_Meta_.MenuItemsProperty = property(get_MenuItemsProperty, None)
    _NavigationViewItem_Meta_.MenuItemsSourceProperty = property(get_MenuItemsSourceProperty, None)
    _NavigationViewItem_Meta_.SelectsOnInvokedProperty = property(get_SelectsOnInvokedProperty, None)
class _NavigationViewItemBase_Meta_(ComPtr.__class__):
    pass
class NavigationViewItemBase(ComPtr, metaclass=_NavigationViewItemBase_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.ContentControl
    default_interface: win32more.Microsoft.UI.Xaml.Controls.INavigationViewItemBase
    _classid_ = 'Microsoft.UI.Xaml.Controls.NavigationViewItemBase'
    @winrt_mixinmethod
    def get_IsSelected(self: win32more.Microsoft.UI.Xaml.Controls.INavigationViewItemBase2) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsSelected(self: win32more.Microsoft.UI.Xaml.Controls.INavigationViewItemBase2, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_IsSelectedProperty(cls: win32more.Microsoft.UI.Xaml.Controls.INavigationViewItemBaseStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    IsSelected = property(get_IsSelected, put_IsSelected)
    _NavigationViewItemBase_Meta_.IsSelectedProperty = property(get_IsSelectedProperty, None)
class NavigationViewItemCollapsedEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.INavigationViewItemCollapsedEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.NavigationViewItemCollapsedEventArgs'
    @winrt_mixinmethod
    def get_CollapsedItemContainer(self: win32more.Microsoft.UI.Xaml.Controls.INavigationViewItemCollapsedEventArgs) -> win32more.Microsoft.UI.Xaml.Controls.NavigationViewItemBase: ...
    @winrt_mixinmethod
    def get_CollapsedItem(self: win32more.Microsoft.UI.Xaml.Controls.INavigationViewItemCollapsedEventArgs) -> IInspectable: ...
    CollapsedItem = property(get_CollapsedItem, None)
    CollapsedItemContainer = property(get_CollapsedItemContainer, None)
class NavigationViewItemExpandingEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.INavigationViewItemExpandingEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.NavigationViewItemExpandingEventArgs'
    @winrt_mixinmethod
    def get_ExpandingItemContainer(self: win32more.Microsoft.UI.Xaml.Controls.INavigationViewItemExpandingEventArgs) -> win32more.Microsoft.UI.Xaml.Controls.NavigationViewItemBase: ...
    @winrt_mixinmethod
    def get_ExpandingItem(self: win32more.Microsoft.UI.Xaml.Controls.INavigationViewItemExpandingEventArgs) -> IInspectable: ...
    ExpandingItem = property(get_ExpandingItem, None)
    ExpandingItemContainer = property(get_ExpandingItemContainer, None)
class NavigationViewItemHeader(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.Controls.NavigationViewItemBase
    default_interface: win32more.Microsoft.UI.Xaml.Controls.INavigationViewItemHeader
    _classid_ = 'Microsoft.UI.Xaml.Controls.NavigationViewItemHeader'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.NavigationViewItemHeader.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.INavigationViewItemHeaderFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.NavigationViewItemHeader: ...
class NavigationViewItemInvokedEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.INavigationViewItemInvokedEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.NavigationViewItemInvokedEventArgs'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.NavigationViewItemInvokedEventArgs.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Controls.NavigationViewItemInvokedEventArgs: ...
    @winrt_mixinmethod
    def get_InvokedItem(self: win32more.Microsoft.UI.Xaml.Controls.INavigationViewItemInvokedEventArgs) -> IInspectable: ...
    @winrt_mixinmethod
    def get_IsSettingsInvoked(self: win32more.Microsoft.UI.Xaml.Controls.INavigationViewItemInvokedEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def get_InvokedItemContainer(self: win32more.Microsoft.UI.Xaml.Controls.INavigationViewItemInvokedEventArgs2) -> win32more.Microsoft.UI.Xaml.Controls.NavigationViewItemBase: ...
    @winrt_mixinmethod
    def get_RecommendedNavigationTransitionInfo(self: win32more.Microsoft.UI.Xaml.Controls.INavigationViewItemInvokedEventArgs2) -> win32more.Microsoft.UI.Xaml.Media.Animation.NavigationTransitionInfo: ...
    InvokedItem = property(get_InvokedItem, None)
    InvokedItemContainer = property(get_InvokedItemContainer, None)
    IsSettingsInvoked = property(get_IsSettingsInvoked, None)
    RecommendedNavigationTransitionInfo = property(get_RecommendedNavigationTransitionInfo, None)
class NavigationViewItemSeparator(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.Controls.NavigationViewItemBase
    default_interface: win32more.Microsoft.UI.Xaml.Controls.INavigationViewItemSeparator
    _classid_ = 'Microsoft.UI.Xaml.Controls.NavigationViewItemSeparator'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.NavigationViewItemSeparator.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.INavigationViewItemSeparatorFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.NavigationViewItemSeparator: ...
class NavigationViewOverflowLabelMode(Enum, Int32):
    MoreLabel = 0
    NoLabel = 1
class NavigationViewPaneClosingEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.INavigationViewPaneClosingEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.NavigationViewPaneClosingEventArgs'
    @winrt_mixinmethod
    def get_Cancel(self: win32more.Microsoft.UI.Xaml.Controls.INavigationViewPaneClosingEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def put_Cancel(self: win32more.Microsoft.UI.Xaml.Controls.INavigationViewPaneClosingEventArgs, value: Boolean) -> Void: ...
    Cancel = property(get_Cancel, put_Cancel)
class NavigationViewPaneDisplayMode(Enum, Int32):
    Auto = 0
    Left = 1
    Top = 2
    LeftCompact = 3
    LeftMinimal = 4
class NavigationViewSelectionChangedEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.INavigationViewSelectionChangedEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.NavigationViewSelectionChangedEventArgs'
    @winrt_mixinmethod
    def get_SelectedItem(self: win32more.Microsoft.UI.Xaml.Controls.INavigationViewSelectionChangedEventArgs) -> IInspectable: ...
    @winrt_mixinmethod
    def get_IsSettingsSelected(self: win32more.Microsoft.UI.Xaml.Controls.INavigationViewSelectionChangedEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def get_SelectedItemContainer(self: win32more.Microsoft.UI.Xaml.Controls.INavigationViewSelectionChangedEventArgs2) -> win32more.Microsoft.UI.Xaml.Controls.NavigationViewItemBase: ...
    @winrt_mixinmethod
    def get_RecommendedNavigationTransitionInfo(self: win32more.Microsoft.UI.Xaml.Controls.INavigationViewSelectionChangedEventArgs2) -> win32more.Microsoft.UI.Xaml.Media.Animation.NavigationTransitionInfo: ...
    IsSettingsSelected = property(get_IsSettingsSelected, None)
    RecommendedNavigationTransitionInfo = property(get_RecommendedNavigationTransitionInfo, None)
    SelectedItem = property(get_SelectedItem, None)
    SelectedItemContainer = property(get_SelectedItemContainer, None)
class NavigationViewSelectionFollowsFocus(Enum, Int32):
    Disabled = 0
    Enabled = 1
class NavigationViewShoulderNavigationEnabled(Enum, Int32):
    WhenSelectionFollowsFocus = 0
    Always = 1
    Never = 2
class _NavigationViewTemplateSettings_Meta_(ComPtr.__class__):
    pass
class NavigationViewTemplateSettings(ComPtr, metaclass=_NavigationViewTemplateSettings_Meta_):
    extends: win32more.Microsoft.UI.Xaml.DependencyObject
    default_interface: win32more.Microsoft.UI.Xaml.Controls.INavigationViewTemplateSettings
    _classid_ = 'Microsoft.UI.Xaml.Controls.NavigationViewTemplateSettings'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.NavigationViewTemplateSettings.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.INavigationViewTemplateSettingsFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.NavigationViewTemplateSettings: ...
    @winrt_mixinmethod
    def get_TopPadding(self: win32more.Microsoft.UI.Xaml.Controls.INavigationViewTemplateSettings) -> Double: ...
    @winrt_mixinmethod
    def get_OverflowButtonVisibility(self: win32more.Microsoft.UI.Xaml.Controls.INavigationViewTemplateSettings) -> win32more.Microsoft.UI.Xaml.Visibility: ...
    @winrt_mixinmethod
    def get_PaneToggleButtonVisibility(self: win32more.Microsoft.UI.Xaml.Controls.INavigationViewTemplateSettings) -> win32more.Microsoft.UI.Xaml.Visibility: ...
    @winrt_mixinmethod
    def get_BackButtonVisibility(self: win32more.Microsoft.UI.Xaml.Controls.INavigationViewTemplateSettings) -> win32more.Microsoft.UI.Xaml.Visibility: ...
    @winrt_mixinmethod
    def get_TopPaneVisibility(self: win32more.Microsoft.UI.Xaml.Controls.INavigationViewTemplateSettings) -> win32more.Microsoft.UI.Xaml.Visibility: ...
    @winrt_mixinmethod
    def get_LeftPaneVisibility(self: win32more.Microsoft.UI.Xaml.Controls.INavigationViewTemplateSettings) -> win32more.Microsoft.UI.Xaml.Visibility: ...
    @winrt_mixinmethod
    def get_SingleSelectionFollowsFocus(self: win32more.Microsoft.UI.Xaml.Controls.INavigationViewTemplateSettings) -> Boolean: ...
    @winrt_mixinmethod
    def get_PaneToggleButtonWidth(self: win32more.Microsoft.UI.Xaml.Controls.INavigationViewTemplateSettings) -> Double: ...
    @winrt_mixinmethod
    def get_SmallerPaneToggleButtonWidth(self: win32more.Microsoft.UI.Xaml.Controls.INavigationViewTemplateSettings) -> Double: ...
    @winrt_mixinmethod
    def get_OpenPaneLength(self: win32more.Microsoft.UI.Xaml.Controls.INavigationViewTemplateSettings2) -> Double: ...
    @winrt_classmethod
    def get_OpenPaneLengthProperty(cls: win32more.Microsoft.UI.Xaml.Controls.INavigationViewTemplateSettingsStatics2) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TopPaddingProperty(cls: win32more.Microsoft.UI.Xaml.Controls.INavigationViewTemplateSettingsStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_OverflowButtonVisibilityProperty(cls: win32more.Microsoft.UI.Xaml.Controls.INavigationViewTemplateSettingsStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PaneToggleButtonVisibilityProperty(cls: win32more.Microsoft.UI.Xaml.Controls.INavigationViewTemplateSettingsStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_BackButtonVisibilityProperty(cls: win32more.Microsoft.UI.Xaml.Controls.INavigationViewTemplateSettingsStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TopPaneVisibilityProperty(cls: win32more.Microsoft.UI.Xaml.Controls.INavigationViewTemplateSettingsStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_LeftPaneVisibilityProperty(cls: win32more.Microsoft.UI.Xaml.Controls.INavigationViewTemplateSettingsStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SingleSelectionFollowsFocusProperty(cls: win32more.Microsoft.UI.Xaml.Controls.INavigationViewTemplateSettingsStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PaneToggleButtonWidthProperty(cls: win32more.Microsoft.UI.Xaml.Controls.INavigationViewTemplateSettingsStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SmallerPaneToggleButtonWidthProperty(cls: win32more.Microsoft.UI.Xaml.Controls.INavigationViewTemplateSettingsStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    BackButtonVisibility = property(get_BackButtonVisibility, None)
    LeftPaneVisibility = property(get_LeftPaneVisibility, None)
    OpenPaneLength = property(get_OpenPaneLength, None)
    OverflowButtonVisibility = property(get_OverflowButtonVisibility, None)
    PaneToggleButtonVisibility = property(get_PaneToggleButtonVisibility, None)
    PaneToggleButtonWidth = property(get_PaneToggleButtonWidth, None)
    SingleSelectionFollowsFocus = property(get_SingleSelectionFollowsFocus, None)
    SmallerPaneToggleButtonWidth = property(get_SmallerPaneToggleButtonWidth, None)
    TopPadding = property(get_TopPadding, None)
    TopPaneVisibility = property(get_TopPaneVisibility, None)
    _NavigationViewTemplateSettings_Meta_.BackButtonVisibilityProperty = property(get_BackButtonVisibilityProperty, None)
    _NavigationViewTemplateSettings_Meta_.LeftPaneVisibilityProperty = property(get_LeftPaneVisibilityProperty, None)
    _NavigationViewTemplateSettings_Meta_.OpenPaneLengthProperty = property(get_OpenPaneLengthProperty, None)
    _NavigationViewTemplateSettings_Meta_.OverflowButtonVisibilityProperty = property(get_OverflowButtonVisibilityProperty, None)
    _NavigationViewTemplateSettings_Meta_.PaneToggleButtonVisibilityProperty = property(get_PaneToggleButtonVisibilityProperty, None)
    _NavigationViewTemplateSettings_Meta_.PaneToggleButtonWidthProperty = property(get_PaneToggleButtonWidthProperty, None)
    _NavigationViewTemplateSettings_Meta_.SingleSelectionFollowsFocusProperty = property(get_SingleSelectionFollowsFocusProperty, None)
    _NavigationViewTemplateSettings_Meta_.SmallerPaneToggleButtonWidthProperty = property(get_SmallerPaneToggleButtonWidthProperty, None)
    _NavigationViewTemplateSettings_Meta_.TopPaddingProperty = property(get_TopPaddingProperty, None)
    _NavigationViewTemplateSettings_Meta_.TopPaneVisibilityProperty = property(get_TopPaneVisibilityProperty, None)
class NonVirtualizingLayout(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.Controls.Layout
    default_interface: win32more.Microsoft.UI.Xaml.Controls.INonVirtualizingLayout
    _classid_ = 'Microsoft.UI.Xaml.Controls.NonVirtualizingLayout'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.NonVirtualizingLayout.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.INonVirtualizingLayoutFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.NonVirtualizingLayout: ...
    @winrt_mixinmethod
    def InitializeForContextCore(self: win32more.Microsoft.UI.Xaml.Controls.INonVirtualizingLayoutOverrides, context: win32more.Microsoft.UI.Xaml.Controls.NonVirtualizingLayoutContext) -> Void: ...
    @winrt_mixinmethod
    def UninitializeForContextCore(self: win32more.Microsoft.UI.Xaml.Controls.INonVirtualizingLayoutOverrides, context: win32more.Microsoft.UI.Xaml.Controls.NonVirtualizingLayoutContext) -> Void: ...
    @winrt_mixinmethod
    def MeasureOverride(self: win32more.Microsoft.UI.Xaml.Controls.INonVirtualizingLayoutOverrides, context: win32more.Microsoft.UI.Xaml.Controls.NonVirtualizingLayoutContext, availableSize: win32more.Windows.Foundation.Size) -> win32more.Windows.Foundation.Size: ...
    @winrt_mixinmethod
    def ArrangeOverride(self: win32more.Microsoft.UI.Xaml.Controls.INonVirtualizingLayoutOverrides, context: win32more.Microsoft.UI.Xaml.Controls.NonVirtualizingLayoutContext, finalSize: win32more.Windows.Foundation.Size) -> win32more.Windows.Foundation.Size: ...
class NonVirtualizingLayoutContext(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.Controls.LayoutContext
    default_interface: win32more.Microsoft.UI.Xaml.Controls.INonVirtualizingLayoutContext
    _classid_ = 'Microsoft.UI.Xaml.Controls.NonVirtualizingLayoutContext'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.NonVirtualizingLayoutContext.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.INonVirtualizingLayoutContextFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.NonVirtualizingLayoutContext: ...
    @winrt_mixinmethod
    def get_Children(self: win32more.Microsoft.UI.Xaml.Controls.INonVirtualizingLayoutContext) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Microsoft.UI.Xaml.UIElement]: ...
    @winrt_mixinmethod
    def get_ChildrenCore(self: win32more.Microsoft.UI.Xaml.Controls.INonVirtualizingLayoutContextOverrides) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Microsoft.UI.Xaml.UIElement]: ...
    Children = property(get_Children, None)
    ChildrenCore = property(get_ChildrenCore, None)
class _NumberBox_Meta_(ComPtr.__class__):
    pass
class NumberBox(ComPtr, metaclass=_NumberBox_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.Control
    default_interface: win32more.Microsoft.UI.Xaml.Controls.INumberBox
    _classid_ = 'Microsoft.UI.Xaml.Controls.NumberBox'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.NumberBox.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.INumberBoxFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.NumberBox: ...
    @winrt_mixinmethod
    def get_Minimum(self: win32more.Microsoft.UI.Xaml.Controls.INumberBox) -> Double: ...
    @winrt_mixinmethod
    def put_Minimum(self: win32more.Microsoft.UI.Xaml.Controls.INumberBox, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_Maximum(self: win32more.Microsoft.UI.Xaml.Controls.INumberBox) -> Double: ...
    @winrt_mixinmethod
    def put_Maximum(self: win32more.Microsoft.UI.Xaml.Controls.INumberBox, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_Value(self: win32more.Microsoft.UI.Xaml.Controls.INumberBox) -> Double: ...
    @winrt_mixinmethod
    def put_Value(self: win32more.Microsoft.UI.Xaml.Controls.INumberBox, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_SmallChange(self: win32more.Microsoft.UI.Xaml.Controls.INumberBox) -> Double: ...
    @winrt_mixinmethod
    def put_SmallChange(self: win32more.Microsoft.UI.Xaml.Controls.INumberBox, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_LargeChange(self: win32more.Microsoft.UI.Xaml.Controls.INumberBox) -> Double: ...
    @winrt_mixinmethod
    def put_LargeChange(self: win32more.Microsoft.UI.Xaml.Controls.INumberBox, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_Text(self: win32more.Microsoft.UI.Xaml.Controls.INumberBox) -> hstr: ...
    @winrt_mixinmethod
    def put_Text(self: win32more.Microsoft.UI.Xaml.Controls.INumberBox, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def get_Header(self: win32more.Microsoft.UI.Xaml.Controls.INumberBox) -> IInspectable: ...
    @winrt_mixinmethod
    def put_Header(self: win32more.Microsoft.UI.Xaml.Controls.INumberBox, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_HeaderTemplate(self: win32more.Microsoft.UI.Xaml.Controls.INumberBox) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def put_HeaderTemplate(self: win32more.Microsoft.UI.Xaml.Controls.INumberBox, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_mixinmethod
    def get_PlaceholderText(self: win32more.Microsoft.UI.Xaml.Controls.INumberBox) -> hstr: ...
    @winrt_mixinmethod
    def put_PlaceholderText(self: win32more.Microsoft.UI.Xaml.Controls.INumberBox, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def get_SelectionFlyout(self: win32more.Microsoft.UI.Xaml.Controls.INumberBox) -> win32more.Microsoft.UI.Xaml.Controls.Primitives.FlyoutBase: ...
    @winrt_mixinmethod
    def put_SelectionFlyout(self: win32more.Microsoft.UI.Xaml.Controls.INumberBox, value: win32more.Microsoft.UI.Xaml.Controls.Primitives.FlyoutBase) -> Void: ...
    @winrt_mixinmethod
    def get_SelectionHighlightColor(self: win32more.Microsoft.UI.Xaml.Controls.INumberBox) -> win32more.Microsoft.UI.Xaml.Media.SolidColorBrush: ...
    @winrt_mixinmethod
    def put_SelectionHighlightColor(self: win32more.Microsoft.UI.Xaml.Controls.INumberBox, value: win32more.Microsoft.UI.Xaml.Media.SolidColorBrush) -> Void: ...
    @winrt_mixinmethod
    def get_TextReadingOrder(self: win32more.Microsoft.UI.Xaml.Controls.INumberBox) -> win32more.Microsoft.UI.Xaml.TextReadingOrder: ...
    @winrt_mixinmethod
    def put_TextReadingOrder(self: win32more.Microsoft.UI.Xaml.Controls.INumberBox, value: win32more.Microsoft.UI.Xaml.TextReadingOrder) -> Void: ...
    @winrt_mixinmethod
    def get_PreventKeyboardDisplayOnProgrammaticFocus(self: win32more.Microsoft.UI.Xaml.Controls.INumberBox) -> Boolean: ...
    @winrt_mixinmethod
    def put_PreventKeyboardDisplayOnProgrammaticFocus(self: win32more.Microsoft.UI.Xaml.Controls.INumberBox, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_Description(self: win32more.Microsoft.UI.Xaml.Controls.INumberBox) -> IInspectable: ...
    @winrt_mixinmethod
    def put_Description(self: win32more.Microsoft.UI.Xaml.Controls.INumberBox, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_ValidationMode(self: win32more.Microsoft.UI.Xaml.Controls.INumberBox) -> win32more.Microsoft.UI.Xaml.Controls.NumberBoxValidationMode: ...
    @winrt_mixinmethod
    def put_ValidationMode(self: win32more.Microsoft.UI.Xaml.Controls.INumberBox, value: win32more.Microsoft.UI.Xaml.Controls.NumberBoxValidationMode) -> Void: ...
    @winrt_mixinmethod
    def get_SpinButtonPlacementMode(self: win32more.Microsoft.UI.Xaml.Controls.INumberBox) -> win32more.Microsoft.UI.Xaml.Controls.NumberBoxSpinButtonPlacementMode: ...
    @winrt_mixinmethod
    def put_SpinButtonPlacementMode(self: win32more.Microsoft.UI.Xaml.Controls.INumberBox, value: win32more.Microsoft.UI.Xaml.Controls.NumberBoxSpinButtonPlacementMode) -> Void: ...
    @winrt_mixinmethod
    def get_IsWrapEnabled(self: win32more.Microsoft.UI.Xaml.Controls.INumberBox) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsWrapEnabled(self: win32more.Microsoft.UI.Xaml.Controls.INumberBox, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_AcceptsExpression(self: win32more.Microsoft.UI.Xaml.Controls.INumberBox) -> Boolean: ...
    @winrt_mixinmethod
    def put_AcceptsExpression(self: win32more.Microsoft.UI.Xaml.Controls.INumberBox, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_NumberFormatter(self: win32more.Microsoft.UI.Xaml.Controls.INumberBox) -> win32more.Windows.Globalization.NumberFormatting.INumberFormatter2: ...
    @winrt_mixinmethod
    def put_NumberFormatter(self: win32more.Microsoft.UI.Xaml.Controls.INumberBox, value: win32more.Windows.Globalization.NumberFormatting.INumberFormatter2) -> Void: ...
    @winrt_mixinmethod
    def add_ValueChanged(self: win32more.Microsoft.UI.Xaml.Controls.INumberBox, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.NumberBox, win32more.Microsoft.UI.Xaml.Controls.NumberBoxValueChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ValueChanged(self: win32more.Microsoft.UI.Xaml.Controls.INumberBox, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def get_MinimumProperty(cls: win32more.Microsoft.UI.Xaml.Controls.INumberBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MaximumProperty(cls: win32more.Microsoft.UI.Xaml.Controls.INumberBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ValueProperty(cls: win32more.Microsoft.UI.Xaml.Controls.INumberBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SmallChangeProperty(cls: win32more.Microsoft.UI.Xaml.Controls.INumberBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_LargeChangeProperty(cls: win32more.Microsoft.UI.Xaml.Controls.INumberBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TextProperty(cls: win32more.Microsoft.UI.Xaml.Controls.INumberBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HeaderProperty(cls: win32more.Microsoft.UI.Xaml.Controls.INumberBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HeaderTemplateProperty(cls: win32more.Microsoft.UI.Xaml.Controls.INumberBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PlaceholderTextProperty(cls: win32more.Microsoft.UI.Xaml.Controls.INumberBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectionFlyoutProperty(cls: win32more.Microsoft.UI.Xaml.Controls.INumberBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectionHighlightColorProperty(cls: win32more.Microsoft.UI.Xaml.Controls.INumberBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TextReadingOrderProperty(cls: win32more.Microsoft.UI.Xaml.Controls.INumberBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PreventKeyboardDisplayOnProgrammaticFocusProperty(cls: win32more.Microsoft.UI.Xaml.Controls.INumberBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DescriptionProperty(cls: win32more.Microsoft.UI.Xaml.Controls.INumberBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ValidationModeProperty(cls: win32more.Microsoft.UI.Xaml.Controls.INumberBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SpinButtonPlacementModeProperty(cls: win32more.Microsoft.UI.Xaml.Controls.INumberBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsWrapEnabledProperty(cls: win32more.Microsoft.UI.Xaml.Controls.INumberBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_AcceptsExpressionProperty(cls: win32more.Microsoft.UI.Xaml.Controls.INumberBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_NumberFormatterProperty(cls: win32more.Microsoft.UI.Xaml.Controls.INumberBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    AcceptsExpression = property(get_AcceptsExpression, put_AcceptsExpression)
    Description = property(get_Description, put_Description)
    Header = property(get_Header, put_Header)
    HeaderTemplate = property(get_HeaderTemplate, put_HeaderTemplate)
    IsWrapEnabled = property(get_IsWrapEnabled, put_IsWrapEnabled)
    LargeChange = property(get_LargeChange, put_LargeChange)
    Maximum = property(get_Maximum, put_Maximum)
    Minimum = property(get_Minimum, put_Minimum)
    NumberFormatter = property(get_NumberFormatter, put_NumberFormatter)
    PlaceholderText = property(get_PlaceholderText, put_PlaceholderText)
    PreventKeyboardDisplayOnProgrammaticFocus = property(get_PreventKeyboardDisplayOnProgrammaticFocus, put_PreventKeyboardDisplayOnProgrammaticFocus)
    SelectionFlyout = property(get_SelectionFlyout, put_SelectionFlyout)
    SelectionHighlightColor = property(get_SelectionHighlightColor, put_SelectionHighlightColor)
    SmallChange = property(get_SmallChange, put_SmallChange)
    SpinButtonPlacementMode = property(get_SpinButtonPlacementMode, put_SpinButtonPlacementMode)
    Text = property(get_Text, put_Text)
    TextReadingOrder = property(get_TextReadingOrder, put_TextReadingOrder)
    ValidationMode = property(get_ValidationMode, put_ValidationMode)
    Value = property(get_Value, put_Value)
    _NumberBox_Meta_.AcceptsExpressionProperty = property(get_AcceptsExpressionProperty, None)
    _NumberBox_Meta_.DescriptionProperty = property(get_DescriptionProperty, None)
    _NumberBox_Meta_.HeaderProperty = property(get_HeaderProperty, None)
    _NumberBox_Meta_.HeaderTemplateProperty = property(get_HeaderTemplateProperty, None)
    _NumberBox_Meta_.IsWrapEnabledProperty = property(get_IsWrapEnabledProperty, None)
    _NumberBox_Meta_.LargeChangeProperty = property(get_LargeChangeProperty, None)
    _NumberBox_Meta_.MaximumProperty = property(get_MaximumProperty, None)
    _NumberBox_Meta_.MinimumProperty = property(get_MinimumProperty, None)
    _NumberBox_Meta_.NumberFormatterProperty = property(get_NumberFormatterProperty, None)
    _NumberBox_Meta_.PlaceholderTextProperty = property(get_PlaceholderTextProperty, None)
    _NumberBox_Meta_.PreventKeyboardDisplayOnProgrammaticFocusProperty = property(get_PreventKeyboardDisplayOnProgrammaticFocusProperty, None)
    _NumberBox_Meta_.SelectionFlyoutProperty = property(get_SelectionFlyoutProperty, None)
    _NumberBox_Meta_.SelectionHighlightColorProperty = property(get_SelectionHighlightColorProperty, None)
    _NumberBox_Meta_.SmallChangeProperty = property(get_SmallChangeProperty, None)
    _NumberBox_Meta_.SpinButtonPlacementModeProperty = property(get_SpinButtonPlacementModeProperty, None)
    _NumberBox_Meta_.TextProperty = property(get_TextProperty, None)
    _NumberBox_Meta_.TextReadingOrderProperty = property(get_TextReadingOrderProperty, None)
    _NumberBox_Meta_.ValidationModeProperty = property(get_ValidationModeProperty, None)
    _NumberBox_Meta_.ValueProperty = property(get_ValueProperty, None)
    ValueChanged = event(add_ValueChanged, remove_ValueChanged)
class NumberBoxSpinButtonPlacementMode(Enum, Int32):
    Hidden = 0
    Compact = 1
    Inline = 2
class NumberBoxValidationMode(Enum, Int32):
    InvalidInputOverwritten = 0
    Disabled = 1
class NumberBoxValueChangedEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.INumberBoxValueChangedEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.NumberBoxValueChangedEventArgs'
    @winrt_mixinmethod
    def get_OldValue(self: win32more.Microsoft.UI.Xaml.Controls.INumberBoxValueChangedEventArgs) -> Double: ...
    @winrt_mixinmethod
    def get_NewValue(self: win32more.Microsoft.UI.Xaml.Controls.INumberBoxValueChangedEventArgs) -> Double: ...
    NewValue = property(get_NewValue, None)
    OldValue = property(get_OldValue, None)
class Orientation(Enum, Int32):
    Vertical = 0
    Horizontal = 1
class _Page_Meta_(ComPtr.__class__):
    pass
class Page(ComPtr, metaclass=_Page_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.UserControl
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IPage
    _classid_ = 'Microsoft.UI.Xaml.Controls.Page'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.Page.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IPageFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.Page: ...
    @winrt_mixinmethod
    def get_Frame(self: win32more.Microsoft.UI.Xaml.Controls.IPage) -> win32more.Microsoft.UI.Xaml.Controls.Frame: ...
    @winrt_mixinmethod
    def get_NavigationCacheMode(self: win32more.Microsoft.UI.Xaml.Controls.IPage) -> win32more.Microsoft.UI.Xaml.Navigation.NavigationCacheMode: ...
    @winrt_mixinmethod
    def put_NavigationCacheMode(self: win32more.Microsoft.UI.Xaml.Controls.IPage, value: win32more.Microsoft.UI.Xaml.Navigation.NavigationCacheMode) -> Void: ...
    @winrt_mixinmethod
    def get_TopAppBar(self: win32more.Microsoft.UI.Xaml.Controls.IPage) -> win32more.Microsoft.UI.Xaml.Controls.AppBar: ...
    @winrt_mixinmethod
    def put_TopAppBar(self: win32more.Microsoft.UI.Xaml.Controls.IPage, value: win32more.Microsoft.UI.Xaml.Controls.AppBar) -> Void: ...
    @winrt_mixinmethod
    def get_BottomAppBar(self: win32more.Microsoft.UI.Xaml.Controls.IPage) -> win32more.Microsoft.UI.Xaml.Controls.AppBar: ...
    @winrt_mixinmethod
    def put_BottomAppBar(self: win32more.Microsoft.UI.Xaml.Controls.IPage, value: win32more.Microsoft.UI.Xaml.Controls.AppBar) -> Void: ...
    @winrt_mixinmethod
    def OnNavigatedFrom(self: win32more.Microsoft.UI.Xaml.Controls.IPageOverrides, e: win32more.Microsoft.UI.Xaml.Navigation.NavigationEventArgs) -> Void: ...
    @winrt_mixinmethod
    def OnNavigatedTo(self: win32more.Microsoft.UI.Xaml.Controls.IPageOverrides, e: win32more.Microsoft.UI.Xaml.Navigation.NavigationEventArgs) -> Void: ...
    @winrt_mixinmethod
    def OnNavigatingFrom(self: win32more.Microsoft.UI.Xaml.Controls.IPageOverrides, e: win32more.Microsoft.UI.Xaml.Navigation.NavigatingCancelEventArgs) -> Void: ...
    @winrt_classmethod
    def get_FrameProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IPageStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TopAppBarProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IPageStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_BottomAppBarProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IPageStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    BottomAppBar = property(get_BottomAppBar, put_BottomAppBar)
    Frame = property(get_Frame, None)
    NavigationCacheMode = property(get_NavigationCacheMode, put_NavigationCacheMode)
    TopAppBar = property(get_TopAppBar, put_TopAppBar)
    _Page_Meta_.BottomAppBarProperty = property(get_BottomAppBarProperty, None)
    _Page_Meta_.FrameProperty = property(get_FrameProperty, None)
    _Page_Meta_.TopAppBarProperty = property(get_TopAppBarProperty, None)
class _Panel_Meta_(ComPtr.__class__):
    pass
class Panel(ComPtr, metaclass=_Panel_Meta_):
    extends: win32more.Microsoft.UI.Xaml.FrameworkElement
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IPanel
    _classid_ = 'Microsoft.UI.Xaml.Controls.Panel'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.Panel.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IPanelFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.Panel: ...
    @winrt_mixinmethod
    def get_Children(self: win32more.Microsoft.UI.Xaml.Controls.IPanel) -> win32more.Microsoft.UI.Xaml.Controls.UIElementCollection: ...
    @winrt_mixinmethod
    def get_Background(self: win32more.Microsoft.UI.Xaml.Controls.IPanel) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_Background(self: win32more.Microsoft.UI.Xaml.Controls.IPanel, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_IsItemsHost(self: win32more.Microsoft.UI.Xaml.Controls.IPanel) -> Boolean: ...
    @winrt_mixinmethod
    def get_ChildrenTransitions(self: win32more.Microsoft.UI.Xaml.Controls.IPanel) -> win32more.Microsoft.UI.Xaml.Media.Animation.TransitionCollection: ...
    @winrt_mixinmethod
    def put_ChildrenTransitions(self: win32more.Microsoft.UI.Xaml.Controls.IPanel, value: win32more.Microsoft.UI.Xaml.Media.Animation.TransitionCollection) -> Void: ...
    @winrt_mixinmethod
    def get_BackgroundTransition(self: win32more.Microsoft.UI.Xaml.Controls.IPanel) -> win32more.Microsoft.UI.Xaml.BrushTransition: ...
    @winrt_mixinmethod
    def put_BackgroundTransition(self: win32more.Microsoft.UI.Xaml.Controls.IPanel, value: win32more.Microsoft.UI.Xaml.BrushTransition) -> Void: ...
    @winrt_classmethod
    def get_BackgroundProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IPanelStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsItemsHostProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IPanelStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ChildrenTransitionsProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IPanelStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    Background = property(get_Background, put_Background)
    BackgroundTransition = property(get_BackgroundTransition, put_BackgroundTransition)
    Children = property(get_Children, None)
    ChildrenTransitions = property(get_ChildrenTransitions, put_ChildrenTransitions)
    IsItemsHost = property(get_IsItemsHost, None)
    _Panel_Meta_.BackgroundProperty = property(get_BackgroundProperty, None)
    _Panel_Meta_.ChildrenTransitionsProperty = property(get_ChildrenTransitionsProperty, None)
    _Panel_Meta_.IsItemsHostProperty = property(get_IsItemsHostProperty, None)
class PanelScrollingDirection(Enum, Int32):
    None_ = 0
    Forward = 1
    Backward = 2
class ParallaxSourceOffsetKind(Enum, Int32):
    Absolute = 0
    Relative = 1
class _ParallaxView_Meta_(ComPtr.__class__):
    pass
class ParallaxView(ComPtr, metaclass=_ParallaxView_Meta_):
    extends: win32more.Microsoft.UI.Xaml.FrameworkElement
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IParallaxView
    _classid_ = 'Microsoft.UI.Xaml.Controls.ParallaxView'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.ParallaxView.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IParallaxViewFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.ParallaxView: ...
    @winrt_mixinmethod
    def get_Child(self: win32more.Microsoft.UI.Xaml.Controls.IParallaxView) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_mixinmethod
    def put_Child(self: win32more.Microsoft.UI.Xaml.Controls.IParallaxView, value: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    @winrt_mixinmethod
    def get_HorizontalShift(self: win32more.Microsoft.UI.Xaml.Controls.IParallaxView) -> Double: ...
    @winrt_mixinmethod
    def put_HorizontalShift(self: win32more.Microsoft.UI.Xaml.Controls.IParallaxView, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_HorizontalSourceEndOffset(self: win32more.Microsoft.UI.Xaml.Controls.IParallaxView) -> Double: ...
    @winrt_mixinmethod
    def put_HorizontalSourceEndOffset(self: win32more.Microsoft.UI.Xaml.Controls.IParallaxView, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_HorizontalSourceOffsetKind(self: win32more.Microsoft.UI.Xaml.Controls.IParallaxView) -> win32more.Microsoft.UI.Xaml.Controls.ParallaxSourceOffsetKind: ...
    @winrt_mixinmethod
    def put_HorizontalSourceOffsetKind(self: win32more.Microsoft.UI.Xaml.Controls.IParallaxView, value: win32more.Microsoft.UI.Xaml.Controls.ParallaxSourceOffsetKind) -> Void: ...
    @winrt_mixinmethod
    def get_HorizontalSourceStartOffset(self: win32more.Microsoft.UI.Xaml.Controls.IParallaxView) -> Double: ...
    @winrt_mixinmethod
    def put_HorizontalSourceStartOffset(self: win32more.Microsoft.UI.Xaml.Controls.IParallaxView, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_IsHorizontalShiftClamped(self: win32more.Microsoft.UI.Xaml.Controls.IParallaxView) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsHorizontalShiftClamped(self: win32more.Microsoft.UI.Xaml.Controls.IParallaxView, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsVerticalShiftClamped(self: win32more.Microsoft.UI.Xaml.Controls.IParallaxView) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsVerticalShiftClamped(self: win32more.Microsoft.UI.Xaml.Controls.IParallaxView, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_MaxHorizontalShiftRatio(self: win32more.Microsoft.UI.Xaml.Controls.IParallaxView) -> Double: ...
    @winrt_mixinmethod
    def put_MaxHorizontalShiftRatio(self: win32more.Microsoft.UI.Xaml.Controls.IParallaxView, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_MaxVerticalShiftRatio(self: win32more.Microsoft.UI.Xaml.Controls.IParallaxView) -> Double: ...
    @winrt_mixinmethod
    def put_MaxVerticalShiftRatio(self: win32more.Microsoft.UI.Xaml.Controls.IParallaxView, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_Source(self: win32more.Microsoft.UI.Xaml.Controls.IParallaxView) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_mixinmethod
    def put_Source(self: win32more.Microsoft.UI.Xaml.Controls.IParallaxView, value: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    @winrt_mixinmethod
    def get_VerticalShift(self: win32more.Microsoft.UI.Xaml.Controls.IParallaxView) -> Double: ...
    @winrt_mixinmethod
    def put_VerticalShift(self: win32more.Microsoft.UI.Xaml.Controls.IParallaxView, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_VerticalSourceEndOffset(self: win32more.Microsoft.UI.Xaml.Controls.IParallaxView) -> Double: ...
    @winrt_mixinmethod
    def put_VerticalSourceEndOffset(self: win32more.Microsoft.UI.Xaml.Controls.IParallaxView, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_VerticalSourceOffsetKind(self: win32more.Microsoft.UI.Xaml.Controls.IParallaxView) -> win32more.Microsoft.UI.Xaml.Controls.ParallaxSourceOffsetKind: ...
    @winrt_mixinmethod
    def put_VerticalSourceOffsetKind(self: win32more.Microsoft.UI.Xaml.Controls.IParallaxView, value: win32more.Microsoft.UI.Xaml.Controls.ParallaxSourceOffsetKind) -> Void: ...
    @winrt_mixinmethod
    def get_VerticalSourceStartOffset(self: win32more.Microsoft.UI.Xaml.Controls.IParallaxView) -> Double: ...
    @winrt_mixinmethod
    def put_VerticalSourceStartOffset(self: win32more.Microsoft.UI.Xaml.Controls.IParallaxView, value: Double) -> Void: ...
    @winrt_mixinmethod
    def RefreshAutomaticHorizontalOffsets(self: win32more.Microsoft.UI.Xaml.Controls.IParallaxView) -> Void: ...
    @winrt_mixinmethod
    def RefreshAutomaticVerticalOffsets(self: win32more.Microsoft.UI.Xaml.Controls.IParallaxView) -> Void: ...
    @winrt_classmethod
    def get_ChildProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IParallaxViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HorizontalSourceEndOffsetProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IParallaxViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HorizontalSourceOffsetKindProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IParallaxViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HorizontalSourceStartOffsetProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IParallaxViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MaxHorizontalShiftRatioProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IParallaxViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HorizontalShiftProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IParallaxViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsHorizontalShiftClampedProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IParallaxViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsVerticalShiftClampedProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IParallaxViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SourceProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IParallaxViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_VerticalSourceEndOffsetProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IParallaxViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_VerticalSourceOffsetKindProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IParallaxViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_VerticalSourceStartOffsetProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IParallaxViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MaxVerticalShiftRatioProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IParallaxViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_VerticalShiftProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IParallaxViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    Child = property(get_Child, put_Child)
    HorizontalShift = property(get_HorizontalShift, put_HorizontalShift)
    HorizontalSourceEndOffset = property(get_HorizontalSourceEndOffset, put_HorizontalSourceEndOffset)
    HorizontalSourceOffsetKind = property(get_HorizontalSourceOffsetKind, put_HorizontalSourceOffsetKind)
    HorizontalSourceStartOffset = property(get_HorizontalSourceStartOffset, put_HorizontalSourceStartOffset)
    IsHorizontalShiftClamped = property(get_IsHorizontalShiftClamped, put_IsHorizontalShiftClamped)
    IsVerticalShiftClamped = property(get_IsVerticalShiftClamped, put_IsVerticalShiftClamped)
    MaxHorizontalShiftRatio = property(get_MaxHorizontalShiftRatio, put_MaxHorizontalShiftRatio)
    MaxVerticalShiftRatio = property(get_MaxVerticalShiftRatio, put_MaxVerticalShiftRatio)
    Source = property(get_Source, put_Source)
    VerticalShift = property(get_VerticalShift, put_VerticalShift)
    VerticalSourceEndOffset = property(get_VerticalSourceEndOffset, put_VerticalSourceEndOffset)
    VerticalSourceOffsetKind = property(get_VerticalSourceOffsetKind, put_VerticalSourceOffsetKind)
    VerticalSourceStartOffset = property(get_VerticalSourceStartOffset, put_VerticalSourceStartOffset)
    _ParallaxView_Meta_.ChildProperty = property(get_ChildProperty, None)
    _ParallaxView_Meta_.HorizontalShiftProperty = property(get_HorizontalShiftProperty, None)
    _ParallaxView_Meta_.HorizontalSourceEndOffsetProperty = property(get_HorizontalSourceEndOffsetProperty, None)
    _ParallaxView_Meta_.HorizontalSourceOffsetKindProperty = property(get_HorizontalSourceOffsetKindProperty, None)
    _ParallaxView_Meta_.HorizontalSourceStartOffsetProperty = property(get_HorizontalSourceStartOffsetProperty, None)
    _ParallaxView_Meta_.IsHorizontalShiftClampedProperty = property(get_IsHorizontalShiftClampedProperty, None)
    _ParallaxView_Meta_.IsVerticalShiftClampedProperty = property(get_IsVerticalShiftClampedProperty, None)
    _ParallaxView_Meta_.MaxHorizontalShiftRatioProperty = property(get_MaxHorizontalShiftRatioProperty, None)
    _ParallaxView_Meta_.MaxVerticalShiftRatioProperty = property(get_MaxVerticalShiftRatioProperty, None)
    _ParallaxView_Meta_.SourceProperty = property(get_SourceProperty, None)
    _ParallaxView_Meta_.VerticalShiftProperty = property(get_VerticalShiftProperty, None)
    _ParallaxView_Meta_.VerticalSourceEndOffsetProperty = property(get_VerticalSourceEndOffsetProperty, None)
    _ParallaxView_Meta_.VerticalSourceOffsetKindProperty = property(get_VerticalSourceOffsetKindProperty, None)
    _ParallaxView_Meta_.VerticalSourceStartOffsetProperty = property(get_VerticalSourceStartOffsetProperty, None)
class _PasswordBox_Meta_(ComPtr.__class__):
    pass
class PasswordBox(ComPtr, metaclass=_PasswordBox_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.Control
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IPasswordBox
    _classid_ = 'Microsoft.UI.Xaml.Controls.PasswordBox'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.PasswordBox.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Controls.PasswordBox: ...
    @winrt_mixinmethod
    def get_Password(self: win32more.Microsoft.UI.Xaml.Controls.IPasswordBox) -> hstr: ...
    @winrt_mixinmethod
    def put_Password(self: win32more.Microsoft.UI.Xaml.Controls.IPasswordBox, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def get_PasswordChar(self: win32more.Microsoft.UI.Xaml.Controls.IPasswordBox) -> hstr: ...
    @winrt_mixinmethod
    def put_PasswordChar(self: win32more.Microsoft.UI.Xaml.Controls.IPasswordBox, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def get_IsPasswordRevealButtonEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IPasswordBox) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsPasswordRevealButtonEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IPasswordBox, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_MaxLength(self: win32more.Microsoft.UI.Xaml.Controls.IPasswordBox) -> Int32: ...
    @winrt_mixinmethod
    def put_MaxLength(self: win32more.Microsoft.UI.Xaml.Controls.IPasswordBox, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_Header(self: win32more.Microsoft.UI.Xaml.Controls.IPasswordBox) -> IInspectable: ...
    @winrt_mixinmethod
    def put_Header(self: win32more.Microsoft.UI.Xaml.Controls.IPasswordBox, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_HeaderTemplate(self: win32more.Microsoft.UI.Xaml.Controls.IPasswordBox) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def put_HeaderTemplate(self: win32more.Microsoft.UI.Xaml.Controls.IPasswordBox, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_mixinmethod
    def get_PlaceholderText(self: win32more.Microsoft.UI.Xaml.Controls.IPasswordBox) -> hstr: ...
    @winrt_mixinmethod
    def put_PlaceholderText(self: win32more.Microsoft.UI.Xaml.Controls.IPasswordBox, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def get_SelectionHighlightColor(self: win32more.Microsoft.UI.Xaml.Controls.IPasswordBox) -> win32more.Microsoft.UI.Xaml.Media.SolidColorBrush: ...
    @winrt_mixinmethod
    def put_SelectionHighlightColor(self: win32more.Microsoft.UI.Xaml.Controls.IPasswordBox, value: win32more.Microsoft.UI.Xaml.Media.SolidColorBrush) -> Void: ...
    @winrt_mixinmethod
    def get_PreventKeyboardDisplayOnProgrammaticFocus(self: win32more.Microsoft.UI.Xaml.Controls.IPasswordBox) -> Boolean: ...
    @winrt_mixinmethod
    def put_PreventKeyboardDisplayOnProgrammaticFocus(self: win32more.Microsoft.UI.Xaml.Controls.IPasswordBox, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_PasswordRevealMode(self: win32more.Microsoft.UI.Xaml.Controls.IPasswordBox) -> win32more.Microsoft.UI.Xaml.Controls.PasswordRevealMode: ...
    @winrt_mixinmethod
    def put_PasswordRevealMode(self: win32more.Microsoft.UI.Xaml.Controls.IPasswordBox, value: win32more.Microsoft.UI.Xaml.Controls.PasswordRevealMode) -> Void: ...
    @winrt_mixinmethod
    def get_TextReadingOrder(self: win32more.Microsoft.UI.Xaml.Controls.IPasswordBox) -> win32more.Microsoft.UI.Xaml.TextReadingOrder: ...
    @winrt_mixinmethod
    def put_TextReadingOrder(self: win32more.Microsoft.UI.Xaml.Controls.IPasswordBox, value: win32more.Microsoft.UI.Xaml.TextReadingOrder) -> Void: ...
    @winrt_mixinmethod
    def get_InputScope(self: win32more.Microsoft.UI.Xaml.Controls.IPasswordBox) -> win32more.Microsoft.UI.Xaml.Input.InputScope: ...
    @winrt_mixinmethod
    def put_InputScope(self: win32more.Microsoft.UI.Xaml.Controls.IPasswordBox, value: win32more.Microsoft.UI.Xaml.Input.InputScope) -> Void: ...
    @winrt_mixinmethod
    def get_CanPasteClipboardContent(self: win32more.Microsoft.UI.Xaml.Controls.IPasswordBox) -> Boolean: ...
    @winrt_mixinmethod
    def get_SelectionFlyout(self: win32more.Microsoft.UI.Xaml.Controls.IPasswordBox) -> win32more.Microsoft.UI.Xaml.Controls.Primitives.FlyoutBase: ...
    @winrt_mixinmethod
    def put_SelectionFlyout(self: win32more.Microsoft.UI.Xaml.Controls.IPasswordBox, value: win32more.Microsoft.UI.Xaml.Controls.Primitives.FlyoutBase) -> Void: ...
    @winrt_mixinmethod
    def get_Description(self: win32more.Microsoft.UI.Xaml.Controls.IPasswordBox) -> IInspectable: ...
    @winrt_mixinmethod
    def put_Description(self: win32more.Microsoft.UI.Xaml.Controls.IPasswordBox, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def add_PasswordChanged(self: win32more.Microsoft.UI.Xaml.Controls.IPasswordBox, handler: win32more.Microsoft.UI.Xaml.RoutedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_PasswordChanged(self: win32more.Microsoft.UI.Xaml.Controls.IPasswordBox, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_ContextMenuOpening(self: win32more.Microsoft.UI.Xaml.Controls.IPasswordBox, handler: win32more.Microsoft.UI.Xaml.Controls.ContextMenuOpeningEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ContextMenuOpening(self: win32more.Microsoft.UI.Xaml.Controls.IPasswordBox, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_Paste(self: win32more.Microsoft.UI.Xaml.Controls.IPasswordBox, handler: win32more.Microsoft.UI.Xaml.Controls.TextControlPasteEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Paste(self: win32more.Microsoft.UI.Xaml.Controls.IPasswordBox, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_PasswordChanging(self: win32more.Microsoft.UI.Xaml.Controls.IPasswordBox, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.PasswordBox, win32more.Microsoft.UI.Xaml.Controls.PasswordBoxPasswordChangingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_PasswordChanging(self: win32more.Microsoft.UI.Xaml.Controls.IPasswordBox, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def SelectAll(self: win32more.Microsoft.UI.Xaml.Controls.IPasswordBox) -> Void: ...
    @winrt_mixinmethod
    def PasteFromClipboard(self: win32more.Microsoft.UI.Xaml.Controls.IPasswordBox) -> Void: ...
    @winrt_classmethod
    def get_PasswordProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IPasswordBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PasswordCharProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IPasswordBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsPasswordRevealButtonEnabledProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IPasswordBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MaxLengthProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IPasswordBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HeaderProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IPasswordBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HeaderTemplateProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IPasswordBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PlaceholderTextProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IPasswordBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectionHighlightColorProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IPasswordBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PreventKeyboardDisplayOnProgrammaticFocusProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IPasswordBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PasswordRevealModeProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IPasswordBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TextReadingOrderProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IPasswordBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_InputScopeProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IPasswordBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CanPasteClipboardContentProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IPasswordBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectionFlyoutProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IPasswordBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DescriptionProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IPasswordBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    CanPasteClipboardContent = property(get_CanPasteClipboardContent, None)
    Description = property(get_Description, put_Description)
    Header = property(get_Header, put_Header)
    HeaderTemplate = property(get_HeaderTemplate, put_HeaderTemplate)
    InputScope = property(get_InputScope, put_InputScope)
    IsPasswordRevealButtonEnabled = property(get_IsPasswordRevealButtonEnabled, put_IsPasswordRevealButtonEnabled)
    MaxLength = property(get_MaxLength, put_MaxLength)
    Password = property(get_Password, put_Password)
    PasswordChar = property(get_PasswordChar, put_PasswordChar)
    PasswordRevealMode = property(get_PasswordRevealMode, put_PasswordRevealMode)
    PlaceholderText = property(get_PlaceholderText, put_PlaceholderText)
    PreventKeyboardDisplayOnProgrammaticFocus = property(get_PreventKeyboardDisplayOnProgrammaticFocus, put_PreventKeyboardDisplayOnProgrammaticFocus)
    SelectionFlyout = property(get_SelectionFlyout, put_SelectionFlyout)
    SelectionHighlightColor = property(get_SelectionHighlightColor, put_SelectionHighlightColor)
    TextReadingOrder = property(get_TextReadingOrder, put_TextReadingOrder)
    _PasswordBox_Meta_.CanPasteClipboardContentProperty = property(get_CanPasteClipboardContentProperty, None)
    _PasswordBox_Meta_.DescriptionProperty = property(get_DescriptionProperty, None)
    _PasswordBox_Meta_.HeaderProperty = property(get_HeaderProperty, None)
    _PasswordBox_Meta_.HeaderTemplateProperty = property(get_HeaderTemplateProperty, None)
    _PasswordBox_Meta_.InputScopeProperty = property(get_InputScopeProperty, None)
    _PasswordBox_Meta_.IsPasswordRevealButtonEnabledProperty = property(get_IsPasswordRevealButtonEnabledProperty, None)
    _PasswordBox_Meta_.MaxLengthProperty = property(get_MaxLengthProperty, None)
    _PasswordBox_Meta_.PasswordCharProperty = property(get_PasswordCharProperty, None)
    _PasswordBox_Meta_.PasswordProperty = property(get_PasswordProperty, None)
    _PasswordBox_Meta_.PasswordRevealModeProperty = property(get_PasswordRevealModeProperty, None)
    _PasswordBox_Meta_.PlaceholderTextProperty = property(get_PlaceholderTextProperty, None)
    _PasswordBox_Meta_.PreventKeyboardDisplayOnProgrammaticFocusProperty = property(get_PreventKeyboardDisplayOnProgrammaticFocusProperty, None)
    _PasswordBox_Meta_.SelectionFlyoutProperty = property(get_SelectionFlyoutProperty, None)
    _PasswordBox_Meta_.SelectionHighlightColorProperty = property(get_SelectionHighlightColorProperty, None)
    _PasswordBox_Meta_.TextReadingOrderProperty = property(get_TextReadingOrderProperty, None)
    ContextMenuOpening = event(add_ContextMenuOpening, remove_ContextMenuOpening)
    PasswordChanged = event(add_PasswordChanged, remove_PasswordChanged)
    PasswordChanging = event(add_PasswordChanging, remove_PasswordChanging)
    Paste = event(add_Paste, remove_Paste)
class PasswordBoxPasswordChangingEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IPasswordBoxPasswordChangingEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.PasswordBoxPasswordChangingEventArgs'
    @winrt_mixinmethod
    def get_IsContentChanging(self: win32more.Microsoft.UI.Xaml.Controls.IPasswordBoxPasswordChangingEventArgs) -> Boolean: ...
    IsContentChanging = property(get_IsContentChanging, None)
class PasswordRevealMode(Enum, Int32):
    Peek = 0
    Hidden = 1
    Visible = 2
class _PathIcon_Meta_(ComPtr.__class__):
    pass
class PathIcon(ComPtr, metaclass=_PathIcon_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.IconElement
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IPathIcon
    _classid_ = 'Microsoft.UI.Xaml.Controls.PathIcon'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.PathIcon.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IPathIconFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.PathIcon: ...
    @winrt_mixinmethod
    def get_Data(self: win32more.Microsoft.UI.Xaml.Controls.IPathIcon) -> win32more.Microsoft.UI.Xaml.Media.Geometry: ...
    @winrt_mixinmethod
    def put_Data(self: win32more.Microsoft.UI.Xaml.Controls.IPathIcon, value: win32more.Microsoft.UI.Xaml.Media.Geometry) -> Void: ...
    @winrt_classmethod
    def get_DataProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IPathIconStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    Data = property(get_Data, put_Data)
    _PathIcon_Meta_.DataProperty = property(get_DataProperty, None)
class _PathIconSource_Meta_(ComPtr.__class__):
    pass
class PathIconSource(ComPtr, metaclass=_PathIconSource_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.IconSource
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IPathIconSource
    _classid_ = 'Microsoft.UI.Xaml.Controls.PathIconSource'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.PathIconSource.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IPathIconSourceFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.PathIconSource: ...
    @winrt_mixinmethod
    def get_Data(self: win32more.Microsoft.UI.Xaml.Controls.IPathIconSource) -> win32more.Microsoft.UI.Xaml.Media.Geometry: ...
    @winrt_mixinmethod
    def put_Data(self: win32more.Microsoft.UI.Xaml.Controls.IPathIconSource, value: win32more.Microsoft.UI.Xaml.Media.Geometry) -> Void: ...
    @winrt_classmethod
    def get_DataProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IPathIconSourceStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    Data = property(get_Data, put_Data)
    _PathIconSource_Meta_.DataProperty = property(get_DataProperty, None)
class _PersonPicture_Meta_(ComPtr.__class__):
    pass
class PersonPicture(ComPtr, metaclass=_PersonPicture_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.Control
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IPersonPicture
    _classid_ = 'Microsoft.UI.Xaml.Controls.PersonPicture'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.PersonPicture.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IPersonPictureFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.PersonPicture: ...
    @winrt_mixinmethod
    def get_BadgeNumber(self: win32more.Microsoft.UI.Xaml.Controls.IPersonPicture) -> Int32: ...
    @winrt_mixinmethod
    def put_BadgeNumber(self: win32more.Microsoft.UI.Xaml.Controls.IPersonPicture, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_BadgeGlyph(self: win32more.Microsoft.UI.Xaml.Controls.IPersonPicture) -> hstr: ...
    @winrt_mixinmethod
    def put_BadgeGlyph(self: win32more.Microsoft.UI.Xaml.Controls.IPersonPicture, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def get_BadgeImageSource(self: win32more.Microsoft.UI.Xaml.Controls.IPersonPicture) -> win32more.Microsoft.UI.Xaml.Media.ImageSource: ...
    @winrt_mixinmethod
    def put_BadgeImageSource(self: win32more.Microsoft.UI.Xaml.Controls.IPersonPicture, value: win32more.Microsoft.UI.Xaml.Media.ImageSource) -> Void: ...
    @winrt_mixinmethod
    def get_BadgeText(self: win32more.Microsoft.UI.Xaml.Controls.IPersonPicture) -> hstr: ...
    @winrt_mixinmethod
    def put_BadgeText(self: win32more.Microsoft.UI.Xaml.Controls.IPersonPicture, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def get_IsGroup(self: win32more.Microsoft.UI.Xaml.Controls.IPersonPicture) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsGroup(self: win32more.Microsoft.UI.Xaml.Controls.IPersonPicture, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_Contact(self: win32more.Microsoft.UI.Xaml.Controls.IPersonPicture) -> win32more.Windows.ApplicationModel.Contacts.Contact: ...
    @winrt_mixinmethod
    def put_Contact(self: win32more.Microsoft.UI.Xaml.Controls.IPersonPicture, value: win32more.Windows.ApplicationModel.Contacts.Contact) -> Void: ...
    @winrt_mixinmethod
    def get_DisplayName(self: win32more.Microsoft.UI.Xaml.Controls.IPersonPicture) -> hstr: ...
    @winrt_mixinmethod
    def put_DisplayName(self: win32more.Microsoft.UI.Xaml.Controls.IPersonPicture, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def get_Initials(self: win32more.Microsoft.UI.Xaml.Controls.IPersonPicture) -> hstr: ...
    @winrt_mixinmethod
    def put_Initials(self: win32more.Microsoft.UI.Xaml.Controls.IPersonPicture, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def get_PreferSmallImage(self: win32more.Microsoft.UI.Xaml.Controls.IPersonPicture) -> Boolean: ...
    @winrt_mixinmethod
    def put_PreferSmallImage(self: win32more.Microsoft.UI.Xaml.Controls.IPersonPicture, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_ProfilePicture(self: win32more.Microsoft.UI.Xaml.Controls.IPersonPicture) -> win32more.Microsoft.UI.Xaml.Media.ImageSource: ...
    @winrt_mixinmethod
    def put_ProfilePicture(self: win32more.Microsoft.UI.Xaml.Controls.IPersonPicture, value: win32more.Microsoft.UI.Xaml.Media.ImageSource) -> Void: ...
    @winrt_mixinmethod
    def get_TemplateSettings(self: win32more.Microsoft.UI.Xaml.Controls.IPersonPicture) -> win32more.Microsoft.UI.Xaml.Controls.PersonPictureTemplateSettings: ...
    @winrt_classmethod
    def get_BadgeNumberProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IPersonPictureStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_BadgeGlyphProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IPersonPictureStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_BadgeImageSourceProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IPersonPictureStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_BadgeTextProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IPersonPictureStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsGroupProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IPersonPictureStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ContactProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IPersonPictureStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DisplayNameProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IPersonPictureStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_InitialsProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IPersonPictureStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PreferSmallImageProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IPersonPictureStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ProfilePictureProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IPersonPictureStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    BadgeGlyph = property(get_BadgeGlyph, put_BadgeGlyph)
    BadgeImageSource = property(get_BadgeImageSource, put_BadgeImageSource)
    BadgeNumber = property(get_BadgeNumber, put_BadgeNumber)
    BadgeText = property(get_BadgeText, put_BadgeText)
    Contact = property(get_Contact, put_Contact)
    DisplayName = property(get_DisplayName, put_DisplayName)
    Initials = property(get_Initials, put_Initials)
    IsGroup = property(get_IsGroup, put_IsGroup)
    PreferSmallImage = property(get_PreferSmallImage, put_PreferSmallImage)
    ProfilePicture = property(get_ProfilePicture, put_ProfilePicture)
    TemplateSettings = property(get_TemplateSettings, None)
    _PersonPicture_Meta_.BadgeGlyphProperty = property(get_BadgeGlyphProperty, None)
    _PersonPicture_Meta_.BadgeImageSourceProperty = property(get_BadgeImageSourceProperty, None)
    _PersonPicture_Meta_.BadgeNumberProperty = property(get_BadgeNumberProperty, None)
    _PersonPicture_Meta_.BadgeTextProperty = property(get_BadgeTextProperty, None)
    _PersonPicture_Meta_.ContactProperty = property(get_ContactProperty, None)
    _PersonPicture_Meta_.DisplayNameProperty = property(get_DisplayNameProperty, None)
    _PersonPicture_Meta_.InitialsProperty = property(get_InitialsProperty, None)
    _PersonPicture_Meta_.IsGroupProperty = property(get_IsGroupProperty, None)
    _PersonPicture_Meta_.PreferSmallImageProperty = property(get_PreferSmallImageProperty, None)
    _PersonPicture_Meta_.ProfilePictureProperty = property(get_ProfilePictureProperty, None)
class PersonPictureTemplateSettings(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.DependencyObject
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IPersonPictureTemplateSettings
    _classid_ = 'Microsoft.UI.Xaml.Controls.PersonPictureTemplateSettings'
    @winrt_mixinmethod
    def get_ActualInitials(self: win32more.Microsoft.UI.Xaml.Controls.IPersonPictureTemplateSettings) -> hstr: ...
    @winrt_mixinmethod
    def get_ActualImageBrush(self: win32more.Microsoft.UI.Xaml.Controls.IPersonPictureTemplateSettings) -> win32more.Microsoft.UI.Xaml.Media.ImageBrush: ...
    ActualImageBrush = property(get_ActualImageBrush, None)
    ActualInitials = property(get_ActualInitials, None)
class PickerConfirmedEventArgs(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.DependencyObject
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IPickerConfirmedEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.PickerConfirmedEventArgs'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.PickerConfirmedEventArgs.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Controls.PickerConfirmedEventArgs: ...
class _PickerFlyout_Meta_(ComPtr.__class__):
    pass
class PickerFlyout(ComPtr, metaclass=_PickerFlyout_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.Primitives.PickerFlyoutBase
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IPickerFlyout
    _classid_ = 'Microsoft.UI.Xaml.Controls.PickerFlyout'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.PickerFlyout.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Controls.PickerFlyout: ...
    @winrt_mixinmethod
    def get_Content(self: win32more.Microsoft.UI.Xaml.Controls.IPickerFlyout) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_mixinmethod
    def put_Content(self: win32more.Microsoft.UI.Xaml.Controls.IPickerFlyout, value: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    @winrt_mixinmethod
    def get_ConfirmationButtonsVisible(self: win32more.Microsoft.UI.Xaml.Controls.IPickerFlyout) -> Boolean: ...
    @winrt_mixinmethod
    def put_ConfirmationButtonsVisible(self: win32more.Microsoft.UI.Xaml.Controls.IPickerFlyout, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def add_Confirmed(self: win32more.Microsoft.UI.Xaml.Controls.IPickerFlyout, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.PickerFlyout, win32more.Microsoft.UI.Xaml.Controls.PickerConfirmedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Confirmed(self: win32more.Microsoft.UI.Xaml.Controls.IPickerFlyout, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def ShowAtAsync(self: win32more.Microsoft.UI.Xaml.Controls.IPickerFlyout, target: win32more.Microsoft.UI.Xaml.FrameworkElement) -> win32more.Windows.Foundation.IAsyncOperation[Boolean]: ...
    @winrt_classmethod
    def get_ContentProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IPickerFlyoutStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ConfirmationButtonsVisibleProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IPickerFlyoutStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    ConfirmationButtonsVisible = property(get_ConfirmationButtonsVisible, put_ConfirmationButtonsVisible)
    Content = property(get_Content, put_Content)
    _PickerFlyout_Meta_.ConfirmationButtonsVisibleProperty = property(get_ConfirmationButtonsVisibleProperty, None)
    _PickerFlyout_Meta_.ContentProperty = property(get_ContentProperty, None)
    Confirmed = event(add_Confirmed, remove_Confirmed)
class PickerFlyoutPresenter(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.Controls.ContentControl
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IPickerFlyoutPresenter
    _classid_ = 'Microsoft.UI.Xaml.Controls.PickerFlyoutPresenter'
class _PipsPager_Meta_(ComPtr.__class__):
    pass
class PipsPager(ComPtr, metaclass=_PipsPager_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.Control
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IPipsPager
    _classid_ = 'Microsoft.UI.Xaml.Controls.PipsPager'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.PipsPager.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IPipsPagerFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.PipsPager: ...
    @winrt_mixinmethod
    def get_NumberOfPages(self: win32more.Microsoft.UI.Xaml.Controls.IPipsPager) -> Int32: ...
    @winrt_mixinmethod
    def put_NumberOfPages(self: win32more.Microsoft.UI.Xaml.Controls.IPipsPager, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_SelectedPageIndex(self: win32more.Microsoft.UI.Xaml.Controls.IPipsPager) -> Int32: ...
    @winrt_mixinmethod
    def put_SelectedPageIndex(self: win32more.Microsoft.UI.Xaml.Controls.IPipsPager, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_MaxVisiblePips(self: win32more.Microsoft.UI.Xaml.Controls.IPipsPager) -> Int32: ...
    @winrt_mixinmethod
    def put_MaxVisiblePips(self: win32more.Microsoft.UI.Xaml.Controls.IPipsPager, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_Orientation(self: win32more.Microsoft.UI.Xaml.Controls.IPipsPager) -> win32more.Microsoft.UI.Xaml.Controls.Orientation: ...
    @winrt_mixinmethod
    def put_Orientation(self: win32more.Microsoft.UI.Xaml.Controls.IPipsPager, value: win32more.Microsoft.UI.Xaml.Controls.Orientation) -> Void: ...
    @winrt_mixinmethod
    def get_PreviousButtonVisibility(self: win32more.Microsoft.UI.Xaml.Controls.IPipsPager) -> win32more.Microsoft.UI.Xaml.Controls.PipsPagerButtonVisibility: ...
    @winrt_mixinmethod
    def put_PreviousButtonVisibility(self: win32more.Microsoft.UI.Xaml.Controls.IPipsPager, value: win32more.Microsoft.UI.Xaml.Controls.PipsPagerButtonVisibility) -> Void: ...
    @winrt_mixinmethod
    def get_NextButtonVisibility(self: win32more.Microsoft.UI.Xaml.Controls.IPipsPager) -> win32more.Microsoft.UI.Xaml.Controls.PipsPagerButtonVisibility: ...
    @winrt_mixinmethod
    def put_NextButtonVisibility(self: win32more.Microsoft.UI.Xaml.Controls.IPipsPager, value: win32more.Microsoft.UI.Xaml.Controls.PipsPagerButtonVisibility) -> Void: ...
    @winrt_mixinmethod
    def get_PreviousButtonStyle(self: win32more.Microsoft.UI.Xaml.Controls.IPipsPager) -> win32more.Microsoft.UI.Xaml.Style: ...
    @winrt_mixinmethod
    def put_PreviousButtonStyle(self: win32more.Microsoft.UI.Xaml.Controls.IPipsPager, value: win32more.Microsoft.UI.Xaml.Style) -> Void: ...
    @winrt_mixinmethod
    def get_NextButtonStyle(self: win32more.Microsoft.UI.Xaml.Controls.IPipsPager) -> win32more.Microsoft.UI.Xaml.Style: ...
    @winrt_mixinmethod
    def put_NextButtonStyle(self: win32more.Microsoft.UI.Xaml.Controls.IPipsPager, value: win32more.Microsoft.UI.Xaml.Style) -> Void: ...
    @winrt_mixinmethod
    def get_SelectedPipStyle(self: win32more.Microsoft.UI.Xaml.Controls.IPipsPager) -> win32more.Microsoft.UI.Xaml.Style: ...
    @winrt_mixinmethod
    def put_SelectedPipStyle(self: win32more.Microsoft.UI.Xaml.Controls.IPipsPager, value: win32more.Microsoft.UI.Xaml.Style) -> Void: ...
    @winrt_mixinmethod
    def get_NormalPipStyle(self: win32more.Microsoft.UI.Xaml.Controls.IPipsPager) -> win32more.Microsoft.UI.Xaml.Style: ...
    @winrt_mixinmethod
    def put_NormalPipStyle(self: win32more.Microsoft.UI.Xaml.Controls.IPipsPager, value: win32more.Microsoft.UI.Xaml.Style) -> Void: ...
    @winrt_mixinmethod
    def add_SelectedIndexChanged(self: win32more.Microsoft.UI.Xaml.Controls.IPipsPager, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.PipsPager, win32more.Microsoft.UI.Xaml.Controls.PipsPagerSelectedIndexChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_SelectedIndexChanged(self: win32more.Microsoft.UI.Xaml.Controls.IPipsPager, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def get_TemplateSettings(self: win32more.Microsoft.UI.Xaml.Controls.IPipsPager) -> win32more.Microsoft.UI.Xaml.Controls.PipsPagerTemplateSettings: ...
    @winrt_classmethod
    def get_NumberOfPagesProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IPipsPagerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectedPageIndexProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IPipsPagerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MaxVisiblePipsProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IPipsPagerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_OrientationProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IPipsPagerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PreviousButtonVisibilityProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IPipsPagerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_NextButtonVisibilityProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IPipsPagerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PreviousButtonStyleProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IPipsPagerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_NextButtonStyleProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IPipsPagerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectedPipStyleProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IPipsPagerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_NormalPipStyleProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IPipsPagerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    MaxVisiblePips = property(get_MaxVisiblePips, put_MaxVisiblePips)
    NextButtonStyle = property(get_NextButtonStyle, put_NextButtonStyle)
    NextButtonVisibility = property(get_NextButtonVisibility, put_NextButtonVisibility)
    NormalPipStyle = property(get_NormalPipStyle, put_NormalPipStyle)
    NumberOfPages = property(get_NumberOfPages, put_NumberOfPages)
    Orientation = property(get_Orientation, put_Orientation)
    PreviousButtonStyle = property(get_PreviousButtonStyle, put_PreviousButtonStyle)
    PreviousButtonVisibility = property(get_PreviousButtonVisibility, put_PreviousButtonVisibility)
    SelectedPageIndex = property(get_SelectedPageIndex, put_SelectedPageIndex)
    SelectedPipStyle = property(get_SelectedPipStyle, put_SelectedPipStyle)
    TemplateSettings = property(get_TemplateSettings, None)
    _PipsPager_Meta_.MaxVisiblePipsProperty = property(get_MaxVisiblePipsProperty, None)
    _PipsPager_Meta_.NextButtonStyleProperty = property(get_NextButtonStyleProperty, None)
    _PipsPager_Meta_.NextButtonVisibilityProperty = property(get_NextButtonVisibilityProperty, None)
    _PipsPager_Meta_.NormalPipStyleProperty = property(get_NormalPipStyleProperty, None)
    _PipsPager_Meta_.NumberOfPagesProperty = property(get_NumberOfPagesProperty, None)
    _PipsPager_Meta_.OrientationProperty = property(get_OrientationProperty, None)
    _PipsPager_Meta_.PreviousButtonStyleProperty = property(get_PreviousButtonStyleProperty, None)
    _PipsPager_Meta_.PreviousButtonVisibilityProperty = property(get_PreviousButtonVisibilityProperty, None)
    _PipsPager_Meta_.SelectedPageIndexProperty = property(get_SelectedPageIndexProperty, None)
    _PipsPager_Meta_.SelectedPipStyleProperty = property(get_SelectedPipStyleProperty, None)
    SelectedIndexChanged = event(add_SelectedIndexChanged, remove_SelectedIndexChanged)
class PipsPagerButtonVisibility(Enum, Int32):
    Visible = 0
    VisibleOnPointerOver = 1
    Collapsed = 2
class PipsPagerSelectedIndexChangedEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IPipsPagerSelectedIndexChangedEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.PipsPagerSelectedIndexChangedEventArgs'
class PipsPagerTemplateSettings(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.DependencyObject
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IPipsPagerTemplateSettings
    _classid_ = 'Microsoft.UI.Xaml.Controls.PipsPagerTemplateSettings'
    @winrt_mixinmethod
    def get_PipsPagerItems(self: win32more.Microsoft.UI.Xaml.Controls.IPipsPagerTemplateSettings) -> win32more.Windows.Foundation.Collections.IVector[Int32]: ...
    PipsPagerItems = property(get_PipsPagerItems, None)
class _Pivot_Meta_(ComPtr.__class__):
    pass
class Pivot(ComPtr, metaclass=_Pivot_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.ItemsControl
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IPivot
    _classid_ = 'Microsoft.UI.Xaml.Controls.Pivot'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.Pivot.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IPivotFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.Pivot: ...
    @winrt_mixinmethod
    def get_Title(self: win32more.Microsoft.UI.Xaml.Controls.IPivot) -> IInspectable: ...
    @winrt_mixinmethod
    def put_Title(self: win32more.Microsoft.UI.Xaml.Controls.IPivot, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_TitleTemplate(self: win32more.Microsoft.UI.Xaml.Controls.IPivot) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def put_TitleTemplate(self: win32more.Microsoft.UI.Xaml.Controls.IPivot, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_mixinmethod
    def get_LeftHeader(self: win32more.Microsoft.UI.Xaml.Controls.IPivot) -> IInspectable: ...
    @winrt_mixinmethod
    def put_LeftHeader(self: win32more.Microsoft.UI.Xaml.Controls.IPivot, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_LeftHeaderTemplate(self: win32more.Microsoft.UI.Xaml.Controls.IPivot) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def put_LeftHeaderTemplate(self: win32more.Microsoft.UI.Xaml.Controls.IPivot, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_mixinmethod
    def get_RightHeader(self: win32more.Microsoft.UI.Xaml.Controls.IPivot) -> IInspectable: ...
    @winrt_mixinmethod
    def put_RightHeader(self: win32more.Microsoft.UI.Xaml.Controls.IPivot, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_RightHeaderTemplate(self: win32more.Microsoft.UI.Xaml.Controls.IPivot) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def put_RightHeaderTemplate(self: win32more.Microsoft.UI.Xaml.Controls.IPivot, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_mixinmethod
    def get_HeaderTemplate(self: win32more.Microsoft.UI.Xaml.Controls.IPivot) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def put_HeaderTemplate(self: win32more.Microsoft.UI.Xaml.Controls.IPivot, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_mixinmethod
    def get_SelectedIndex(self: win32more.Microsoft.UI.Xaml.Controls.IPivot) -> Int32: ...
    @winrt_mixinmethod
    def put_SelectedIndex(self: win32more.Microsoft.UI.Xaml.Controls.IPivot, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_SelectedItem(self: win32more.Microsoft.UI.Xaml.Controls.IPivot) -> IInspectable: ...
    @winrt_mixinmethod
    def put_SelectedItem(self: win32more.Microsoft.UI.Xaml.Controls.IPivot, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_IsLocked(self: win32more.Microsoft.UI.Xaml.Controls.IPivot) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsLocked(self: win32more.Microsoft.UI.Xaml.Controls.IPivot, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_HeaderFocusVisualPlacement(self: win32more.Microsoft.UI.Xaml.Controls.IPivot) -> win32more.Microsoft.UI.Xaml.Controls.PivotHeaderFocusVisualPlacement: ...
    @winrt_mixinmethod
    def put_HeaderFocusVisualPlacement(self: win32more.Microsoft.UI.Xaml.Controls.IPivot, value: win32more.Microsoft.UI.Xaml.Controls.PivotHeaderFocusVisualPlacement) -> Void: ...
    @winrt_mixinmethod
    def get_IsHeaderItemsCarouselEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IPivot) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsHeaderItemsCarouselEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IPivot, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def add_SelectionChanged(self: win32more.Microsoft.UI.Xaml.Controls.IPivot, handler: win32more.Microsoft.UI.Xaml.Controls.SelectionChangedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_SelectionChanged(self: win32more.Microsoft.UI.Xaml.Controls.IPivot, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_PivotItemLoading(self: win32more.Microsoft.UI.Xaml.Controls.IPivot, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.Pivot, win32more.Microsoft.UI.Xaml.Controls.PivotItemEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_PivotItemLoading(self: win32more.Microsoft.UI.Xaml.Controls.IPivot, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_PivotItemLoaded(self: win32more.Microsoft.UI.Xaml.Controls.IPivot, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.Pivot, win32more.Microsoft.UI.Xaml.Controls.PivotItemEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_PivotItemLoaded(self: win32more.Microsoft.UI.Xaml.Controls.IPivot, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_PivotItemUnloading(self: win32more.Microsoft.UI.Xaml.Controls.IPivot, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.Pivot, win32more.Microsoft.UI.Xaml.Controls.PivotItemEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_PivotItemUnloading(self: win32more.Microsoft.UI.Xaml.Controls.IPivot, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_PivotItemUnloaded(self: win32more.Microsoft.UI.Xaml.Controls.IPivot, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.Pivot, win32more.Microsoft.UI.Xaml.Controls.PivotItemEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_PivotItemUnloaded(self: win32more.Microsoft.UI.Xaml.Controls.IPivot, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def get_TitleProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IPivotStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TitleTemplateProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IPivotStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_LeftHeaderProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IPivotStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_LeftHeaderTemplateProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IPivotStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_RightHeaderProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IPivotStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_RightHeaderTemplateProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IPivotStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HeaderTemplateProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IPivotStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectedIndexProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IPivotStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectedItemProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IPivotStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsLockedProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IPivotStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HeaderFocusVisualPlacementProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IPivotStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsHeaderItemsCarouselEnabledProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IPivotStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SlideInAnimationGroupProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IPivotStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetSlideInAnimationGroup(cls: win32more.Microsoft.UI.Xaml.Controls.IPivotStatics, element: win32more.Microsoft.UI.Xaml.FrameworkElement) -> win32more.Microsoft.UI.Xaml.Controls.PivotSlideInAnimationGroup: ...
    @winrt_classmethod
    def SetSlideInAnimationGroup(cls: win32more.Microsoft.UI.Xaml.Controls.IPivotStatics, element: win32more.Microsoft.UI.Xaml.FrameworkElement, value: win32more.Microsoft.UI.Xaml.Controls.PivotSlideInAnimationGroup) -> Void: ...
    HeaderFocusVisualPlacement = property(get_HeaderFocusVisualPlacement, put_HeaderFocusVisualPlacement)
    HeaderTemplate = property(get_HeaderTemplate, put_HeaderTemplate)
    IsHeaderItemsCarouselEnabled = property(get_IsHeaderItemsCarouselEnabled, put_IsHeaderItemsCarouselEnabled)
    IsLocked = property(get_IsLocked, put_IsLocked)
    LeftHeader = property(get_LeftHeader, put_LeftHeader)
    LeftHeaderTemplate = property(get_LeftHeaderTemplate, put_LeftHeaderTemplate)
    RightHeader = property(get_RightHeader, put_RightHeader)
    RightHeaderTemplate = property(get_RightHeaderTemplate, put_RightHeaderTemplate)
    SelectedIndex = property(get_SelectedIndex, put_SelectedIndex)
    SelectedItem = property(get_SelectedItem, put_SelectedItem)
    Title = property(get_Title, put_Title)
    TitleTemplate = property(get_TitleTemplate, put_TitleTemplate)
    _Pivot_Meta_.HeaderFocusVisualPlacementProperty = property(get_HeaderFocusVisualPlacementProperty, None)
    _Pivot_Meta_.HeaderTemplateProperty = property(get_HeaderTemplateProperty, None)
    _Pivot_Meta_.IsHeaderItemsCarouselEnabledProperty = property(get_IsHeaderItemsCarouselEnabledProperty, None)
    _Pivot_Meta_.IsLockedProperty = property(get_IsLockedProperty, None)
    _Pivot_Meta_.LeftHeaderProperty = property(get_LeftHeaderProperty, None)
    _Pivot_Meta_.LeftHeaderTemplateProperty = property(get_LeftHeaderTemplateProperty, None)
    _Pivot_Meta_.RightHeaderProperty = property(get_RightHeaderProperty, None)
    _Pivot_Meta_.RightHeaderTemplateProperty = property(get_RightHeaderTemplateProperty, None)
    _Pivot_Meta_.SelectedIndexProperty = property(get_SelectedIndexProperty, None)
    _Pivot_Meta_.SelectedItemProperty = property(get_SelectedItemProperty, None)
    _Pivot_Meta_.SlideInAnimationGroupProperty = property(get_SlideInAnimationGroupProperty, None)
    _Pivot_Meta_.TitleProperty = property(get_TitleProperty, None)
    _Pivot_Meta_.TitleTemplateProperty = property(get_TitleTemplateProperty, None)
    PivotItemLoaded = event(add_PivotItemLoaded, remove_PivotItemLoaded)
    PivotItemLoading = event(add_PivotItemLoading, remove_PivotItemLoading)
    PivotItemUnloaded = event(add_PivotItemUnloaded, remove_PivotItemUnloaded)
    PivotItemUnloading = event(add_PivotItemUnloading, remove_PivotItemUnloading)
    SelectionChanged = event(add_SelectionChanged, remove_SelectionChanged)
class PivotHeaderFocusVisualPlacement(Enum, Int32):
    ItemHeaders = 0
    SelectedItemHeader = 1
class _PivotItem_Meta_(ComPtr.__class__):
    pass
class PivotItem(ComPtr, metaclass=_PivotItem_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.ContentControl
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IPivotItem
    _classid_ = 'Microsoft.UI.Xaml.Controls.PivotItem'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.PivotItem.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IPivotItemFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.PivotItem: ...
    @winrt_mixinmethod
    def get_Header(self: win32more.Microsoft.UI.Xaml.Controls.IPivotItem) -> IInspectable: ...
    @winrt_mixinmethod
    def put_Header(self: win32more.Microsoft.UI.Xaml.Controls.IPivotItem, value: IInspectable) -> Void: ...
    @winrt_classmethod
    def get_HeaderProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IPivotItemStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    Header = property(get_Header, put_Header)
    _PivotItem_Meta_.HeaderProperty = property(get_HeaderProperty, None)
class PivotItemEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IPivotItemEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.PivotItemEventArgs'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.PivotItemEventArgs.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Controls.PivotItemEventArgs: ...
    @winrt_mixinmethod
    def get_Item(self: win32more.Microsoft.UI.Xaml.Controls.IPivotItemEventArgs) -> win32more.Microsoft.UI.Xaml.Controls.PivotItem: ...
    @winrt_mixinmethod
    def put_Item(self: win32more.Microsoft.UI.Xaml.Controls.IPivotItemEventArgs, value: win32more.Microsoft.UI.Xaml.Controls.PivotItem) -> Void: ...
    Item = property(get_Item, put_Item)
class PivotSlideInAnimationGroup(Enum, Int32):
    Default = 0
    GroupOne = 1
    GroupTwo = 2
    GroupThree = 3
class PlayerAnimationOptimization(Enum, Int32):
    Latency = 0
    Resources = 1
class _ProgressBar_Meta_(ComPtr.__class__):
    pass
class ProgressBar(ComPtr, metaclass=_ProgressBar_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.Primitives.RangeBase
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IProgressBar
    _classid_ = 'Microsoft.UI.Xaml.Controls.ProgressBar'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.ProgressBar.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IProgressBarFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.ProgressBar: ...
    @winrt_mixinmethod
    def get_IsIndeterminate(self: win32more.Microsoft.UI.Xaml.Controls.IProgressBar) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsIndeterminate(self: win32more.Microsoft.UI.Xaml.Controls.IProgressBar, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_ShowError(self: win32more.Microsoft.UI.Xaml.Controls.IProgressBar) -> Boolean: ...
    @winrt_mixinmethod
    def put_ShowError(self: win32more.Microsoft.UI.Xaml.Controls.IProgressBar, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_ShowPaused(self: win32more.Microsoft.UI.Xaml.Controls.IProgressBar) -> Boolean: ...
    @winrt_mixinmethod
    def put_ShowPaused(self: win32more.Microsoft.UI.Xaml.Controls.IProgressBar, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_TemplateSettings(self: win32more.Microsoft.UI.Xaml.Controls.IProgressBar) -> win32more.Microsoft.UI.Xaml.Controls.ProgressBarTemplateSettings: ...
    @winrt_classmethod
    def get_IsIndeterminateProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IProgressBarStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ShowErrorProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IProgressBarStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ShowPausedProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IProgressBarStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    IsIndeterminate = property(get_IsIndeterminate, put_IsIndeterminate)
    ShowError = property(get_ShowError, put_ShowError)
    ShowPaused = property(get_ShowPaused, put_ShowPaused)
    TemplateSettings = property(get_TemplateSettings, None)
    _ProgressBar_Meta_.IsIndeterminateProperty = property(get_IsIndeterminateProperty, None)
    _ProgressBar_Meta_.ShowErrorProperty = property(get_ShowErrorProperty, None)
    _ProgressBar_Meta_.ShowPausedProperty = property(get_ShowPausedProperty, None)
class ProgressBarTemplateSettings(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.DependencyObject
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IProgressBarTemplateSettings
    _classid_ = 'Microsoft.UI.Xaml.Controls.ProgressBarTemplateSettings'
    @winrt_mixinmethod
    def get_ContainerAnimationStartPosition(self: win32more.Microsoft.UI.Xaml.Controls.IProgressBarTemplateSettings) -> Double: ...
    @winrt_mixinmethod
    def get_ContainerAnimationEndPosition(self: win32more.Microsoft.UI.Xaml.Controls.IProgressBarTemplateSettings) -> Double: ...
    @winrt_mixinmethod
    def get_Container2AnimationStartPosition(self: win32more.Microsoft.UI.Xaml.Controls.IProgressBarTemplateSettings) -> Double: ...
    @winrt_mixinmethod
    def get_Container2AnimationEndPosition(self: win32more.Microsoft.UI.Xaml.Controls.IProgressBarTemplateSettings) -> Double: ...
    @winrt_mixinmethod
    def get_ContainerAnimationMidPosition(self: win32more.Microsoft.UI.Xaml.Controls.IProgressBarTemplateSettings) -> Double: ...
    @winrt_mixinmethod
    def get_IndicatorLengthDelta(self: win32more.Microsoft.UI.Xaml.Controls.IProgressBarTemplateSettings) -> Double: ...
    @winrt_mixinmethod
    def get_ClipRect(self: win32more.Microsoft.UI.Xaml.Controls.IProgressBarTemplateSettings) -> win32more.Microsoft.UI.Xaml.Media.RectangleGeometry: ...
    @winrt_mixinmethod
    def get_EllipseAnimationEndPosition(self: win32more.Microsoft.UI.Xaml.Controls.IProgressBarTemplateSettings) -> Double: ...
    @winrt_mixinmethod
    def get_EllipseAnimationWellPosition(self: win32more.Microsoft.UI.Xaml.Controls.IProgressBarTemplateSettings) -> Double: ...
    @winrt_mixinmethod
    def get_EllipseDiameter(self: win32more.Microsoft.UI.Xaml.Controls.IProgressBarTemplateSettings) -> Double: ...
    @winrt_mixinmethod
    def get_EllipseOffset(self: win32more.Microsoft.UI.Xaml.Controls.IProgressBarTemplateSettings) -> Double: ...
    ClipRect = property(get_ClipRect, None)
    Container2AnimationEndPosition = property(get_Container2AnimationEndPosition, None)
    Container2AnimationStartPosition = property(get_Container2AnimationStartPosition, None)
    ContainerAnimationEndPosition = property(get_ContainerAnimationEndPosition, None)
    ContainerAnimationMidPosition = property(get_ContainerAnimationMidPosition, None)
    ContainerAnimationStartPosition = property(get_ContainerAnimationStartPosition, None)
    EllipseAnimationEndPosition = property(get_EllipseAnimationEndPosition, None)
    EllipseAnimationWellPosition = property(get_EllipseAnimationWellPosition, None)
    EllipseDiameter = property(get_EllipseDiameter, None)
    EllipseOffset = property(get_EllipseOffset, None)
    IndicatorLengthDelta = property(get_IndicatorLengthDelta, None)
class _ProgressRing_Meta_(ComPtr.__class__):
    pass
class ProgressRing(ComPtr, metaclass=_ProgressRing_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.Control
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IProgressRing
    _classid_ = 'Microsoft.UI.Xaml.Controls.ProgressRing'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.ProgressRing.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IProgressRingFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.ProgressRing: ...
    @winrt_mixinmethod
    def get_IsActive(self: win32more.Microsoft.UI.Xaml.Controls.IProgressRing) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsActive(self: win32more.Microsoft.UI.Xaml.Controls.IProgressRing, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsIndeterminate(self: win32more.Microsoft.UI.Xaml.Controls.IProgressRing) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsIndeterminate(self: win32more.Microsoft.UI.Xaml.Controls.IProgressRing, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_TemplateSettings(self: win32more.Microsoft.UI.Xaml.Controls.IProgressRing) -> win32more.Microsoft.UI.Xaml.Controls.ProgressRingTemplateSettings: ...
    @winrt_mixinmethod
    def get_Value(self: win32more.Microsoft.UI.Xaml.Controls.IProgressRing) -> Double: ...
    @winrt_mixinmethod
    def put_Value(self: win32more.Microsoft.UI.Xaml.Controls.IProgressRing, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_Minimum(self: win32more.Microsoft.UI.Xaml.Controls.IProgressRing) -> Double: ...
    @winrt_mixinmethod
    def put_Minimum(self: win32more.Microsoft.UI.Xaml.Controls.IProgressRing, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_Maximum(self: win32more.Microsoft.UI.Xaml.Controls.IProgressRing) -> Double: ...
    @winrt_mixinmethod
    def put_Maximum(self: win32more.Microsoft.UI.Xaml.Controls.IProgressRing, value: Double) -> Void: ...
    @winrt_classmethod
    def get_IsActiveProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IProgressRingStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsIndeterminateProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IProgressRingStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ValueProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IProgressRingStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MinimumProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IProgressRingStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MaximumProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IProgressRingStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    IsActive = property(get_IsActive, put_IsActive)
    IsIndeterminate = property(get_IsIndeterminate, put_IsIndeterminate)
    Maximum = property(get_Maximum, put_Maximum)
    Minimum = property(get_Minimum, put_Minimum)
    TemplateSettings = property(get_TemplateSettings, None)
    Value = property(get_Value, put_Value)
    _ProgressRing_Meta_.IsActiveProperty = property(get_IsActiveProperty, None)
    _ProgressRing_Meta_.IsIndeterminateProperty = property(get_IsIndeterminateProperty, None)
    _ProgressRing_Meta_.MaximumProperty = property(get_MaximumProperty, None)
    _ProgressRing_Meta_.MinimumProperty = property(get_MinimumProperty, None)
    _ProgressRing_Meta_.ValueProperty = property(get_ValueProperty, None)
class ProgressRingTemplateSettings(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.DependencyObject
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IProgressRingTemplateSettings
    _classid_ = 'Microsoft.UI.Xaml.Controls.ProgressRingTemplateSettings'
    @winrt_mixinmethod
    def get_EllipseDiameter(self: win32more.Microsoft.UI.Xaml.Controls.IProgressRingTemplateSettings) -> Double: ...
    @winrt_mixinmethod
    def get_EllipseOffset(self: win32more.Microsoft.UI.Xaml.Controls.IProgressRingTemplateSettings) -> win32more.Microsoft.UI.Xaml.Thickness: ...
    @winrt_mixinmethod
    def get_MaxSideLength(self: win32more.Microsoft.UI.Xaml.Controls.IProgressRingTemplateSettings) -> Double: ...
    EllipseDiameter = property(get_EllipseDiameter, None)
    EllipseOffset = property(get_EllipseOffset, None)
    MaxSideLength = property(get_MaxSideLength, None)
class _RadioButton_Meta_(ComPtr.__class__):
    pass
class RadioButton(ComPtr, metaclass=_RadioButton_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.Primitives.ToggleButton
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IRadioButton
    _classid_ = 'Microsoft.UI.Xaml.Controls.RadioButton'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.RadioButton.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IRadioButtonFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.RadioButton: ...
    @winrt_mixinmethod
    def get_GroupName(self: win32more.Microsoft.UI.Xaml.Controls.IRadioButton) -> hstr: ...
    @winrt_mixinmethod
    def put_GroupName(self: win32more.Microsoft.UI.Xaml.Controls.IRadioButton, value: hstr) -> Void: ...
    @winrt_classmethod
    def get_GroupNameProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRadioButtonStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    GroupName = property(get_GroupName, put_GroupName)
    _RadioButton_Meta_.GroupNameProperty = property(get_GroupNameProperty, None)
class _RadioButtons_Meta_(ComPtr.__class__):
    pass
class RadioButtons(ComPtr, metaclass=_RadioButtons_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.Control
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IRadioButtons
    _classid_ = 'Microsoft.UI.Xaml.Controls.RadioButtons'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.RadioButtons.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IRadioButtonsFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.RadioButtons: ...
    @winrt_mixinmethod
    def get_ItemsSource(self: win32more.Microsoft.UI.Xaml.Controls.IRadioButtons) -> IInspectable: ...
    @winrt_mixinmethod
    def put_ItemsSource(self: win32more.Microsoft.UI.Xaml.Controls.IRadioButtons, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_Items(self: win32more.Microsoft.UI.Xaml.Controls.IRadioButtons) -> win32more.Windows.Foundation.Collections.IVector[IInspectable]: ...
    @winrt_mixinmethod
    def get_ItemTemplate(self: win32more.Microsoft.UI.Xaml.Controls.IRadioButtons) -> IInspectable: ...
    @winrt_mixinmethod
    def put_ItemTemplate(self: win32more.Microsoft.UI.Xaml.Controls.IRadioButtons, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def ContainerFromIndex(self: win32more.Microsoft.UI.Xaml.Controls.IRadioButtons, index: Int32) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_mixinmethod
    def get_SelectedIndex(self: win32more.Microsoft.UI.Xaml.Controls.IRadioButtons) -> Int32: ...
    @winrt_mixinmethod
    def put_SelectedIndex(self: win32more.Microsoft.UI.Xaml.Controls.IRadioButtons, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_SelectedItem(self: win32more.Microsoft.UI.Xaml.Controls.IRadioButtons) -> IInspectable: ...
    @winrt_mixinmethod
    def put_SelectedItem(self: win32more.Microsoft.UI.Xaml.Controls.IRadioButtons, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def add_SelectionChanged(self: win32more.Microsoft.UI.Xaml.Controls.IRadioButtons, handler: win32more.Microsoft.UI.Xaml.Controls.SelectionChangedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_SelectionChanged(self: win32more.Microsoft.UI.Xaml.Controls.IRadioButtons, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def get_MaxColumns(self: win32more.Microsoft.UI.Xaml.Controls.IRadioButtons) -> Int32: ...
    @winrt_mixinmethod
    def put_MaxColumns(self: win32more.Microsoft.UI.Xaml.Controls.IRadioButtons, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_Header(self: win32more.Microsoft.UI.Xaml.Controls.IRadioButtons) -> IInspectable: ...
    @winrt_mixinmethod
    def put_Header(self: win32more.Microsoft.UI.Xaml.Controls.IRadioButtons, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_HeaderTemplate(self: win32more.Microsoft.UI.Xaml.Controls.IRadioButtons) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def put_HeaderTemplate(self: win32more.Microsoft.UI.Xaml.Controls.IRadioButtons, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_classmethod
    def get_ItemsSourceProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRadioButtonsStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ItemsProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRadioButtonsStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ItemTemplateProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRadioButtonsStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectedIndexProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRadioButtonsStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectedItemProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRadioButtonsStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MaxColumnsProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRadioButtonsStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HeaderProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRadioButtonsStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HeaderTemplateProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRadioButtonsStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    Header = property(get_Header, put_Header)
    HeaderTemplate = property(get_HeaderTemplate, put_HeaderTemplate)
    ItemTemplate = property(get_ItemTemplate, put_ItemTemplate)
    Items = property(get_Items, None)
    ItemsSource = property(get_ItemsSource, put_ItemsSource)
    MaxColumns = property(get_MaxColumns, put_MaxColumns)
    SelectedIndex = property(get_SelectedIndex, put_SelectedIndex)
    SelectedItem = property(get_SelectedItem, put_SelectedItem)
    _RadioButtons_Meta_.HeaderProperty = property(get_HeaderProperty, None)
    _RadioButtons_Meta_.HeaderTemplateProperty = property(get_HeaderTemplateProperty, None)
    _RadioButtons_Meta_.ItemTemplateProperty = property(get_ItemTemplateProperty, None)
    _RadioButtons_Meta_.ItemsProperty = property(get_ItemsProperty, None)
    _RadioButtons_Meta_.ItemsSourceProperty = property(get_ItemsSourceProperty, None)
    _RadioButtons_Meta_.MaxColumnsProperty = property(get_MaxColumnsProperty, None)
    _RadioButtons_Meta_.SelectedIndexProperty = property(get_SelectedIndexProperty, None)
    _RadioButtons_Meta_.SelectedItemProperty = property(get_SelectedItemProperty, None)
    SelectionChanged = event(add_SelectionChanged, remove_SelectionChanged)
class _RadioMenuFlyoutItem_Meta_(ComPtr.__class__):
    pass
class RadioMenuFlyoutItem(ComPtr, metaclass=_RadioMenuFlyoutItem_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.MenuFlyoutItem
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IRadioMenuFlyoutItem
    _classid_ = 'Microsoft.UI.Xaml.Controls.RadioMenuFlyoutItem'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.RadioMenuFlyoutItem.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IRadioMenuFlyoutItemFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.RadioMenuFlyoutItem: ...
    @winrt_mixinmethod
    def get_IsChecked(self: win32more.Microsoft.UI.Xaml.Controls.IRadioMenuFlyoutItem) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsChecked(self: win32more.Microsoft.UI.Xaml.Controls.IRadioMenuFlyoutItem, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_GroupName(self: win32more.Microsoft.UI.Xaml.Controls.IRadioMenuFlyoutItem) -> hstr: ...
    @winrt_mixinmethod
    def put_GroupName(self: win32more.Microsoft.UI.Xaml.Controls.IRadioMenuFlyoutItem, value: hstr) -> Void: ...
    @winrt_classmethod
    def get_AreCheckStatesEnabledProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRadioMenuFlyoutItemStatics2) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def SetAreCheckStatesEnabled(cls: win32more.Microsoft.UI.Xaml.Controls.IRadioMenuFlyoutItemStatics2, object: win32more.Microsoft.UI.Xaml.Controls.MenuFlyoutSubItem, value: Boolean) -> Void: ...
    @winrt_classmethod
    def GetAreCheckStatesEnabled(cls: win32more.Microsoft.UI.Xaml.Controls.IRadioMenuFlyoutItemStatics2, object: win32more.Microsoft.UI.Xaml.Controls.MenuFlyoutSubItem) -> Boolean: ...
    @winrt_classmethod
    def get_IsCheckedProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRadioMenuFlyoutItemStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_GroupNameProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRadioMenuFlyoutItemStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    GroupName = property(get_GroupName, put_GroupName)
    IsChecked = property(get_IsChecked, put_IsChecked)
    _RadioMenuFlyoutItem_Meta_.AreCheckStatesEnabledProperty = property(get_AreCheckStatesEnabledProperty, None)
    _RadioMenuFlyoutItem_Meta_.GroupNameProperty = property(get_GroupNameProperty, None)
    _RadioMenuFlyoutItem_Meta_.IsCheckedProperty = property(get_IsCheckedProperty, None)
class _RatingControl_Meta_(ComPtr.__class__):
    pass
class RatingControl(ComPtr, metaclass=_RatingControl_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.Control
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IRatingControl
    _classid_ = 'Microsoft.UI.Xaml.Controls.RatingControl'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.RatingControl.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IRatingControlFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.RatingControl: ...
    @winrt_mixinmethod
    def get_Caption(self: win32more.Microsoft.UI.Xaml.Controls.IRatingControl) -> hstr: ...
    @winrt_mixinmethod
    def put_Caption(self: win32more.Microsoft.UI.Xaml.Controls.IRatingControl, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def get_InitialSetValue(self: win32more.Microsoft.UI.Xaml.Controls.IRatingControl) -> Int32: ...
    @winrt_mixinmethod
    def put_InitialSetValue(self: win32more.Microsoft.UI.Xaml.Controls.IRatingControl, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_IsClearEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IRatingControl) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsClearEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IRatingControl, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsReadOnly(self: win32more.Microsoft.UI.Xaml.Controls.IRatingControl) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsReadOnly(self: win32more.Microsoft.UI.Xaml.Controls.IRatingControl, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_MaxRating(self: win32more.Microsoft.UI.Xaml.Controls.IRatingControl) -> Int32: ...
    @winrt_mixinmethod
    def put_MaxRating(self: win32more.Microsoft.UI.Xaml.Controls.IRatingControl, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_PlaceholderValue(self: win32more.Microsoft.UI.Xaml.Controls.IRatingControl) -> Double: ...
    @winrt_mixinmethod
    def put_PlaceholderValue(self: win32more.Microsoft.UI.Xaml.Controls.IRatingControl, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_ItemInfo(self: win32more.Microsoft.UI.Xaml.Controls.IRatingControl) -> win32more.Microsoft.UI.Xaml.Controls.RatingItemInfo: ...
    @winrt_mixinmethod
    def put_ItemInfo(self: win32more.Microsoft.UI.Xaml.Controls.IRatingControl, value: win32more.Microsoft.UI.Xaml.Controls.RatingItemInfo) -> Void: ...
    @winrt_mixinmethod
    def get_Value(self: win32more.Microsoft.UI.Xaml.Controls.IRatingControl) -> Double: ...
    @winrt_mixinmethod
    def put_Value(self: win32more.Microsoft.UI.Xaml.Controls.IRatingControl, value: Double) -> Void: ...
    @winrt_mixinmethod
    def add_ValueChanged(self: win32more.Microsoft.UI.Xaml.Controls.IRatingControl, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.RatingControl, IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ValueChanged(self: win32more.Microsoft.UI.Xaml.Controls.IRatingControl, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def get_CaptionProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRatingControlStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_InitialSetValueProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRatingControlStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsClearEnabledProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRatingControlStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsReadOnlyProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRatingControlStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MaxRatingProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRatingControlStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PlaceholderValueProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRatingControlStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ItemInfoProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRatingControlStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ValueProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRatingControlStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    Caption = property(get_Caption, put_Caption)
    InitialSetValue = property(get_InitialSetValue, put_InitialSetValue)
    IsClearEnabled = property(get_IsClearEnabled, put_IsClearEnabled)
    IsReadOnly = property(get_IsReadOnly, put_IsReadOnly)
    ItemInfo = property(get_ItemInfo, put_ItemInfo)
    MaxRating = property(get_MaxRating, put_MaxRating)
    PlaceholderValue = property(get_PlaceholderValue, put_PlaceholderValue)
    Value = property(get_Value, put_Value)
    _RatingControl_Meta_.CaptionProperty = property(get_CaptionProperty, None)
    _RatingControl_Meta_.InitialSetValueProperty = property(get_InitialSetValueProperty, None)
    _RatingControl_Meta_.IsClearEnabledProperty = property(get_IsClearEnabledProperty, None)
    _RatingControl_Meta_.IsReadOnlyProperty = property(get_IsReadOnlyProperty, None)
    _RatingControl_Meta_.ItemInfoProperty = property(get_ItemInfoProperty, None)
    _RatingControl_Meta_.MaxRatingProperty = property(get_MaxRatingProperty, None)
    _RatingControl_Meta_.PlaceholderValueProperty = property(get_PlaceholderValueProperty, None)
    _RatingControl_Meta_.ValueProperty = property(get_ValueProperty, None)
    ValueChanged = event(add_ValueChanged, remove_ValueChanged)
class _RatingItemFontInfo_Meta_(ComPtr.__class__):
    pass
class RatingItemFontInfo(ComPtr, metaclass=_RatingItemFontInfo_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.RatingItemInfo
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IRatingItemFontInfo
    _classid_ = 'Microsoft.UI.Xaml.Controls.RatingItemFontInfo'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.RatingItemFontInfo.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IRatingItemFontInfoFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.RatingItemFontInfo: ...
    @winrt_mixinmethod
    def get_DisabledGlyph(self: win32more.Microsoft.UI.Xaml.Controls.IRatingItemFontInfo) -> hstr: ...
    @winrt_mixinmethod
    def put_DisabledGlyph(self: win32more.Microsoft.UI.Xaml.Controls.IRatingItemFontInfo, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def get_Glyph(self: win32more.Microsoft.UI.Xaml.Controls.IRatingItemFontInfo) -> hstr: ...
    @winrt_mixinmethod
    def put_Glyph(self: win32more.Microsoft.UI.Xaml.Controls.IRatingItemFontInfo, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def get_PointerOverGlyph(self: win32more.Microsoft.UI.Xaml.Controls.IRatingItemFontInfo) -> hstr: ...
    @winrt_mixinmethod
    def put_PointerOverGlyph(self: win32more.Microsoft.UI.Xaml.Controls.IRatingItemFontInfo, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def get_PointerOverPlaceholderGlyph(self: win32more.Microsoft.UI.Xaml.Controls.IRatingItemFontInfo) -> hstr: ...
    @winrt_mixinmethod
    def put_PointerOverPlaceholderGlyph(self: win32more.Microsoft.UI.Xaml.Controls.IRatingItemFontInfo, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def get_PlaceholderGlyph(self: win32more.Microsoft.UI.Xaml.Controls.IRatingItemFontInfo) -> hstr: ...
    @winrt_mixinmethod
    def put_PlaceholderGlyph(self: win32more.Microsoft.UI.Xaml.Controls.IRatingItemFontInfo, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def get_UnsetGlyph(self: win32more.Microsoft.UI.Xaml.Controls.IRatingItemFontInfo) -> hstr: ...
    @winrt_mixinmethod
    def put_UnsetGlyph(self: win32more.Microsoft.UI.Xaml.Controls.IRatingItemFontInfo, value: hstr) -> Void: ...
    @winrt_classmethod
    def get_DisabledGlyphProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRatingItemFontInfoStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_GlyphProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRatingItemFontInfoStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PlaceholderGlyphProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRatingItemFontInfoStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PointerOverGlyphProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRatingItemFontInfoStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PointerOverPlaceholderGlyphProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRatingItemFontInfoStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_UnsetGlyphProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRatingItemFontInfoStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    DisabledGlyph = property(get_DisabledGlyph, put_DisabledGlyph)
    Glyph = property(get_Glyph, put_Glyph)
    PlaceholderGlyph = property(get_PlaceholderGlyph, put_PlaceholderGlyph)
    PointerOverGlyph = property(get_PointerOverGlyph, put_PointerOverGlyph)
    PointerOverPlaceholderGlyph = property(get_PointerOverPlaceholderGlyph, put_PointerOverPlaceholderGlyph)
    UnsetGlyph = property(get_UnsetGlyph, put_UnsetGlyph)
    _RatingItemFontInfo_Meta_.DisabledGlyphProperty = property(get_DisabledGlyphProperty, None)
    _RatingItemFontInfo_Meta_.GlyphProperty = property(get_GlyphProperty, None)
    _RatingItemFontInfo_Meta_.PlaceholderGlyphProperty = property(get_PlaceholderGlyphProperty, None)
    _RatingItemFontInfo_Meta_.PointerOverGlyphProperty = property(get_PointerOverGlyphProperty, None)
    _RatingItemFontInfo_Meta_.PointerOverPlaceholderGlyphProperty = property(get_PointerOverPlaceholderGlyphProperty, None)
    _RatingItemFontInfo_Meta_.UnsetGlyphProperty = property(get_UnsetGlyphProperty, None)
class _RatingItemImageInfo_Meta_(ComPtr.__class__):
    pass
class RatingItemImageInfo(ComPtr, metaclass=_RatingItemImageInfo_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.RatingItemInfo
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IRatingItemImageInfo
    _classid_ = 'Microsoft.UI.Xaml.Controls.RatingItemImageInfo'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.RatingItemImageInfo.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IRatingItemImageInfoFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.RatingItemImageInfo: ...
    @winrt_mixinmethod
    def get_DisabledImage(self: win32more.Microsoft.UI.Xaml.Controls.IRatingItemImageInfo) -> win32more.Microsoft.UI.Xaml.Media.ImageSource: ...
    @winrt_mixinmethod
    def put_DisabledImage(self: win32more.Microsoft.UI.Xaml.Controls.IRatingItemImageInfo, value: win32more.Microsoft.UI.Xaml.Media.ImageSource) -> Void: ...
    @winrt_mixinmethod
    def get_Image(self: win32more.Microsoft.UI.Xaml.Controls.IRatingItemImageInfo) -> win32more.Microsoft.UI.Xaml.Media.ImageSource: ...
    @winrt_mixinmethod
    def put_Image(self: win32more.Microsoft.UI.Xaml.Controls.IRatingItemImageInfo, value: win32more.Microsoft.UI.Xaml.Media.ImageSource) -> Void: ...
    @winrt_mixinmethod
    def get_PlaceholderImage(self: win32more.Microsoft.UI.Xaml.Controls.IRatingItemImageInfo) -> win32more.Microsoft.UI.Xaml.Media.ImageSource: ...
    @winrt_mixinmethod
    def put_PlaceholderImage(self: win32more.Microsoft.UI.Xaml.Controls.IRatingItemImageInfo, value: win32more.Microsoft.UI.Xaml.Media.ImageSource) -> Void: ...
    @winrt_mixinmethod
    def get_PointerOverImage(self: win32more.Microsoft.UI.Xaml.Controls.IRatingItemImageInfo) -> win32more.Microsoft.UI.Xaml.Media.ImageSource: ...
    @winrt_mixinmethod
    def put_PointerOverImage(self: win32more.Microsoft.UI.Xaml.Controls.IRatingItemImageInfo, value: win32more.Microsoft.UI.Xaml.Media.ImageSource) -> Void: ...
    @winrt_mixinmethod
    def get_PointerOverPlaceholderImage(self: win32more.Microsoft.UI.Xaml.Controls.IRatingItemImageInfo) -> win32more.Microsoft.UI.Xaml.Media.ImageSource: ...
    @winrt_mixinmethod
    def put_PointerOverPlaceholderImage(self: win32more.Microsoft.UI.Xaml.Controls.IRatingItemImageInfo, value: win32more.Microsoft.UI.Xaml.Media.ImageSource) -> Void: ...
    @winrt_mixinmethod
    def get_UnsetImage(self: win32more.Microsoft.UI.Xaml.Controls.IRatingItemImageInfo) -> win32more.Microsoft.UI.Xaml.Media.ImageSource: ...
    @winrt_mixinmethod
    def put_UnsetImage(self: win32more.Microsoft.UI.Xaml.Controls.IRatingItemImageInfo, value: win32more.Microsoft.UI.Xaml.Media.ImageSource) -> Void: ...
    @winrt_classmethod
    def get_DisabledImageProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRatingItemImageInfoStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ImageProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRatingItemImageInfoStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PlaceholderImageProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRatingItemImageInfoStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PointerOverImageProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRatingItemImageInfoStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PointerOverPlaceholderImageProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRatingItemImageInfoStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_UnsetImageProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRatingItemImageInfoStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    DisabledImage = property(get_DisabledImage, put_DisabledImage)
    Image = property(get_Image, put_Image)
    PlaceholderImage = property(get_PlaceholderImage, put_PlaceholderImage)
    PointerOverImage = property(get_PointerOverImage, put_PointerOverImage)
    PointerOverPlaceholderImage = property(get_PointerOverPlaceholderImage, put_PointerOverPlaceholderImage)
    UnsetImage = property(get_UnsetImage, put_UnsetImage)
    _RatingItemImageInfo_Meta_.DisabledImageProperty = property(get_DisabledImageProperty, None)
    _RatingItemImageInfo_Meta_.ImageProperty = property(get_ImageProperty, None)
    _RatingItemImageInfo_Meta_.PlaceholderImageProperty = property(get_PlaceholderImageProperty, None)
    _RatingItemImageInfo_Meta_.PointerOverImageProperty = property(get_PointerOverImageProperty, None)
    _RatingItemImageInfo_Meta_.PointerOverPlaceholderImageProperty = property(get_PointerOverPlaceholderImageProperty, None)
    _RatingItemImageInfo_Meta_.UnsetImageProperty = property(get_UnsetImageProperty, None)
class RatingItemInfo(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.DependencyObject
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IRatingItemInfo
    _classid_ = 'Microsoft.UI.Xaml.Controls.RatingItemInfo'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.RatingItemInfo.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IRatingItemInfoFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.RatingItemInfo: ...
class _RefreshContainer_Meta_(ComPtr.__class__):
    pass
class RefreshContainer(ComPtr, metaclass=_RefreshContainer_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.ContentControl
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IRefreshContainer
    _classid_ = 'Microsoft.UI.Xaml.Controls.RefreshContainer'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.RefreshContainer.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IRefreshContainerFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.RefreshContainer: ...
    @winrt_mixinmethod
    def get_Visualizer(self: win32more.Microsoft.UI.Xaml.Controls.IRefreshContainer) -> win32more.Microsoft.UI.Xaml.Controls.RefreshVisualizer: ...
    @winrt_mixinmethod
    def put_Visualizer(self: win32more.Microsoft.UI.Xaml.Controls.IRefreshContainer, value: win32more.Microsoft.UI.Xaml.Controls.RefreshVisualizer) -> Void: ...
    @winrt_mixinmethod
    def get_PullDirection(self: win32more.Microsoft.UI.Xaml.Controls.IRefreshContainer) -> win32more.Microsoft.UI.Xaml.Controls.RefreshPullDirection: ...
    @winrt_mixinmethod
    def put_PullDirection(self: win32more.Microsoft.UI.Xaml.Controls.IRefreshContainer, value: win32more.Microsoft.UI.Xaml.Controls.RefreshPullDirection) -> Void: ...
    @winrt_mixinmethod
    def add_RefreshRequested(self: win32more.Microsoft.UI.Xaml.Controls.IRefreshContainer, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.RefreshContainer, win32more.Microsoft.UI.Xaml.Controls.RefreshRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_RefreshRequested(self: win32more.Microsoft.UI.Xaml.Controls.IRefreshContainer, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def RequestRefresh(self: win32more.Microsoft.UI.Xaml.Controls.IRefreshContainer) -> Void: ...
    @winrt_classmethod
    def get_VisualizerProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRefreshContainerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PullDirectionProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRefreshContainerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    PullDirection = property(get_PullDirection, put_PullDirection)
    Visualizer = property(get_Visualizer, put_Visualizer)
    _RefreshContainer_Meta_.PullDirectionProperty = property(get_PullDirectionProperty, None)
    _RefreshContainer_Meta_.VisualizerProperty = property(get_VisualizerProperty, None)
    RefreshRequested = event(add_RefreshRequested, remove_RefreshRequested)
class RefreshInteractionRatioChangedEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IRefreshInteractionRatioChangedEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.RefreshInteractionRatioChangedEventArgs'
    @winrt_mixinmethod
    def get_InteractionRatio(self: win32more.Microsoft.UI.Xaml.Controls.IRefreshInteractionRatioChangedEventArgs) -> Double: ...
    InteractionRatio = property(get_InteractionRatio, None)
class RefreshPullDirection(Enum, Int32):
    LeftToRight = 0
    TopToBottom = 1
    RightToLeft = 2
    BottomToTop = 3
class RefreshRequestedEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IRefreshRequestedEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.RefreshRequestedEventArgs'
    @winrt_mixinmethod
    def GetDeferral(self: win32more.Microsoft.UI.Xaml.Controls.IRefreshRequestedEventArgs) -> win32more.Windows.Foundation.Deferral: ...
class RefreshStateChangedEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IRefreshStateChangedEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.RefreshStateChangedEventArgs'
    @winrt_mixinmethod
    def get_OldState(self: win32more.Microsoft.UI.Xaml.Controls.IRefreshStateChangedEventArgs) -> win32more.Microsoft.UI.Xaml.Controls.RefreshVisualizerState: ...
    @winrt_mixinmethod
    def get_NewState(self: win32more.Microsoft.UI.Xaml.Controls.IRefreshStateChangedEventArgs) -> win32more.Microsoft.UI.Xaml.Controls.RefreshVisualizerState: ...
    NewState = property(get_NewState, None)
    OldState = property(get_OldState, None)
class _RefreshVisualizer_Meta_(ComPtr.__class__):
    pass
class RefreshVisualizer(ComPtr, metaclass=_RefreshVisualizer_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.Control
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IRefreshVisualizer
    _classid_ = 'Microsoft.UI.Xaml.Controls.RefreshVisualizer'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.RefreshVisualizer.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IRefreshVisualizerFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.RefreshVisualizer: ...
    @winrt_mixinmethod
    def RequestRefresh(self: win32more.Microsoft.UI.Xaml.Controls.IRefreshVisualizer) -> Void: ...
    @winrt_mixinmethod
    def get_Orientation(self: win32more.Microsoft.UI.Xaml.Controls.IRefreshVisualizer) -> win32more.Microsoft.UI.Xaml.Controls.RefreshVisualizerOrientation: ...
    @winrt_mixinmethod
    def put_Orientation(self: win32more.Microsoft.UI.Xaml.Controls.IRefreshVisualizer, value: win32more.Microsoft.UI.Xaml.Controls.RefreshVisualizerOrientation) -> Void: ...
    @winrt_mixinmethod
    def get_Content(self: win32more.Microsoft.UI.Xaml.Controls.IRefreshVisualizer) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_mixinmethod
    def put_Content(self: win32more.Microsoft.UI.Xaml.Controls.IRefreshVisualizer, value: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    @winrt_mixinmethod
    def get_State(self: win32more.Microsoft.UI.Xaml.Controls.IRefreshVisualizer) -> win32more.Microsoft.UI.Xaml.Controls.RefreshVisualizerState: ...
    @winrt_mixinmethod
    def add_RefreshRequested(self: win32more.Microsoft.UI.Xaml.Controls.IRefreshVisualizer, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.RefreshVisualizer, win32more.Microsoft.UI.Xaml.Controls.RefreshRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_RefreshRequested(self: win32more.Microsoft.UI.Xaml.Controls.IRefreshVisualizer, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_RefreshStateChanged(self: win32more.Microsoft.UI.Xaml.Controls.IRefreshVisualizer, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.RefreshVisualizer, win32more.Microsoft.UI.Xaml.Controls.RefreshStateChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_RefreshStateChanged(self: win32more.Microsoft.UI.Xaml.Controls.IRefreshVisualizer, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def get_InfoProviderProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRefreshVisualizerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_OrientationProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRefreshVisualizerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ContentProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRefreshVisualizerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_StateProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRefreshVisualizerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    Content = property(get_Content, put_Content)
    Orientation = property(get_Orientation, put_Orientation)
    State = property(get_State, None)
    _RefreshVisualizer_Meta_.ContentProperty = property(get_ContentProperty, None)
    _RefreshVisualizer_Meta_.InfoProviderProperty = property(get_InfoProviderProperty, None)
    _RefreshVisualizer_Meta_.OrientationProperty = property(get_OrientationProperty, None)
    _RefreshVisualizer_Meta_.StateProperty = property(get_StateProperty, None)
    RefreshRequested = event(add_RefreshRequested, remove_RefreshRequested)
    RefreshStateChanged = event(add_RefreshStateChanged, remove_RefreshStateChanged)
class RefreshVisualizerOrientation(Enum, Int32):
    Auto = 0
    Normal = 1
    Rotate90DegreesCounterclockwise = 2
    Rotate270DegreesCounterclockwise = 3
class RefreshVisualizerState(Enum, Int32):
    Idle = 0
    Peeking = 1
    Interacting = 2
    Pending = 3
    Refreshing = 4
class _RelativePanel_Meta_(ComPtr.__class__):
    pass
class RelativePanel(ComPtr, metaclass=_RelativePanel_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.Panel
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IRelativePanel
    _classid_ = 'Microsoft.UI.Xaml.Controls.RelativePanel'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.RelativePanel.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IRelativePanelFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.RelativePanel: ...
    @winrt_mixinmethod
    def get_BackgroundSizing(self: win32more.Microsoft.UI.Xaml.Controls.IRelativePanel) -> win32more.Microsoft.UI.Xaml.Controls.BackgroundSizing: ...
    @winrt_mixinmethod
    def put_BackgroundSizing(self: win32more.Microsoft.UI.Xaml.Controls.IRelativePanel, value: win32more.Microsoft.UI.Xaml.Controls.BackgroundSizing) -> Void: ...
    @winrt_mixinmethod
    def get_BorderBrush(self: win32more.Microsoft.UI.Xaml.Controls.IRelativePanel) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_BorderBrush(self: win32more.Microsoft.UI.Xaml.Controls.IRelativePanel, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_BorderThickness(self: win32more.Microsoft.UI.Xaml.Controls.IRelativePanel) -> win32more.Microsoft.UI.Xaml.Thickness: ...
    @winrt_mixinmethod
    def put_BorderThickness(self: win32more.Microsoft.UI.Xaml.Controls.IRelativePanel, value: win32more.Microsoft.UI.Xaml.Thickness) -> Void: ...
    @winrt_mixinmethod
    def get_CornerRadius(self: win32more.Microsoft.UI.Xaml.Controls.IRelativePanel) -> win32more.Microsoft.UI.Xaml.CornerRadius: ...
    @winrt_mixinmethod
    def put_CornerRadius(self: win32more.Microsoft.UI.Xaml.Controls.IRelativePanel, value: win32more.Microsoft.UI.Xaml.CornerRadius) -> Void: ...
    @winrt_mixinmethod
    def get_Padding(self: win32more.Microsoft.UI.Xaml.Controls.IRelativePanel) -> win32more.Microsoft.UI.Xaml.Thickness: ...
    @winrt_mixinmethod
    def put_Padding(self: win32more.Microsoft.UI.Xaml.Controls.IRelativePanel, value: win32more.Microsoft.UI.Xaml.Thickness) -> Void: ...
    @winrt_classmethod
    def get_BackgroundSizingProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRelativePanelStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_LeftOfProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRelativePanelStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetLeftOf(cls: win32more.Microsoft.UI.Xaml.Controls.IRelativePanelStatics, element: win32more.Microsoft.UI.Xaml.UIElement) -> IInspectable: ...
    @winrt_classmethod
    def SetLeftOf(cls: win32more.Microsoft.UI.Xaml.Controls.IRelativePanelStatics, element: win32more.Microsoft.UI.Xaml.UIElement, value: IInspectable) -> Void: ...
    @winrt_classmethod
    def get_AboveProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRelativePanelStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetAbove(cls: win32more.Microsoft.UI.Xaml.Controls.IRelativePanelStatics, element: win32more.Microsoft.UI.Xaml.UIElement) -> IInspectable: ...
    @winrt_classmethod
    def SetAbove(cls: win32more.Microsoft.UI.Xaml.Controls.IRelativePanelStatics, element: win32more.Microsoft.UI.Xaml.UIElement, value: IInspectable) -> Void: ...
    @winrt_classmethod
    def get_RightOfProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRelativePanelStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetRightOf(cls: win32more.Microsoft.UI.Xaml.Controls.IRelativePanelStatics, element: win32more.Microsoft.UI.Xaml.UIElement) -> IInspectable: ...
    @winrt_classmethod
    def SetRightOf(cls: win32more.Microsoft.UI.Xaml.Controls.IRelativePanelStatics, element: win32more.Microsoft.UI.Xaml.UIElement, value: IInspectable) -> Void: ...
    @winrt_classmethod
    def get_BelowProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRelativePanelStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetBelow(cls: win32more.Microsoft.UI.Xaml.Controls.IRelativePanelStatics, element: win32more.Microsoft.UI.Xaml.UIElement) -> IInspectable: ...
    @winrt_classmethod
    def SetBelow(cls: win32more.Microsoft.UI.Xaml.Controls.IRelativePanelStatics, element: win32more.Microsoft.UI.Xaml.UIElement, value: IInspectable) -> Void: ...
    @winrt_classmethod
    def get_AlignHorizontalCenterWithProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRelativePanelStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetAlignHorizontalCenterWith(cls: win32more.Microsoft.UI.Xaml.Controls.IRelativePanelStatics, element: win32more.Microsoft.UI.Xaml.UIElement) -> IInspectable: ...
    @winrt_classmethod
    def SetAlignHorizontalCenterWith(cls: win32more.Microsoft.UI.Xaml.Controls.IRelativePanelStatics, element: win32more.Microsoft.UI.Xaml.UIElement, value: IInspectable) -> Void: ...
    @winrt_classmethod
    def get_AlignVerticalCenterWithProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRelativePanelStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetAlignVerticalCenterWith(cls: win32more.Microsoft.UI.Xaml.Controls.IRelativePanelStatics, element: win32more.Microsoft.UI.Xaml.UIElement) -> IInspectable: ...
    @winrt_classmethod
    def SetAlignVerticalCenterWith(cls: win32more.Microsoft.UI.Xaml.Controls.IRelativePanelStatics, element: win32more.Microsoft.UI.Xaml.UIElement, value: IInspectable) -> Void: ...
    @winrt_classmethod
    def get_AlignLeftWithProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRelativePanelStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetAlignLeftWith(cls: win32more.Microsoft.UI.Xaml.Controls.IRelativePanelStatics, element: win32more.Microsoft.UI.Xaml.UIElement) -> IInspectable: ...
    @winrt_classmethod
    def SetAlignLeftWith(cls: win32more.Microsoft.UI.Xaml.Controls.IRelativePanelStatics, element: win32more.Microsoft.UI.Xaml.UIElement, value: IInspectable) -> Void: ...
    @winrt_classmethod
    def get_AlignTopWithProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRelativePanelStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetAlignTopWith(cls: win32more.Microsoft.UI.Xaml.Controls.IRelativePanelStatics, element: win32more.Microsoft.UI.Xaml.UIElement) -> IInspectable: ...
    @winrt_classmethod
    def SetAlignTopWith(cls: win32more.Microsoft.UI.Xaml.Controls.IRelativePanelStatics, element: win32more.Microsoft.UI.Xaml.UIElement, value: IInspectable) -> Void: ...
    @winrt_classmethod
    def get_AlignRightWithProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRelativePanelStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetAlignRightWith(cls: win32more.Microsoft.UI.Xaml.Controls.IRelativePanelStatics, element: win32more.Microsoft.UI.Xaml.UIElement) -> IInspectable: ...
    @winrt_classmethod
    def SetAlignRightWith(cls: win32more.Microsoft.UI.Xaml.Controls.IRelativePanelStatics, element: win32more.Microsoft.UI.Xaml.UIElement, value: IInspectable) -> Void: ...
    @winrt_classmethod
    def get_AlignBottomWithProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRelativePanelStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetAlignBottomWith(cls: win32more.Microsoft.UI.Xaml.Controls.IRelativePanelStatics, element: win32more.Microsoft.UI.Xaml.UIElement) -> IInspectable: ...
    @winrt_classmethod
    def SetAlignBottomWith(cls: win32more.Microsoft.UI.Xaml.Controls.IRelativePanelStatics, element: win32more.Microsoft.UI.Xaml.UIElement, value: IInspectable) -> Void: ...
    @winrt_classmethod
    def get_AlignLeftWithPanelProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRelativePanelStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetAlignLeftWithPanel(cls: win32more.Microsoft.UI.Xaml.Controls.IRelativePanelStatics, element: win32more.Microsoft.UI.Xaml.UIElement) -> Boolean: ...
    @winrt_classmethod
    def SetAlignLeftWithPanel(cls: win32more.Microsoft.UI.Xaml.Controls.IRelativePanelStatics, element: win32more.Microsoft.UI.Xaml.UIElement, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_AlignTopWithPanelProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRelativePanelStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetAlignTopWithPanel(cls: win32more.Microsoft.UI.Xaml.Controls.IRelativePanelStatics, element: win32more.Microsoft.UI.Xaml.UIElement) -> Boolean: ...
    @winrt_classmethod
    def SetAlignTopWithPanel(cls: win32more.Microsoft.UI.Xaml.Controls.IRelativePanelStatics, element: win32more.Microsoft.UI.Xaml.UIElement, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_AlignRightWithPanelProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRelativePanelStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetAlignRightWithPanel(cls: win32more.Microsoft.UI.Xaml.Controls.IRelativePanelStatics, element: win32more.Microsoft.UI.Xaml.UIElement) -> Boolean: ...
    @winrt_classmethod
    def SetAlignRightWithPanel(cls: win32more.Microsoft.UI.Xaml.Controls.IRelativePanelStatics, element: win32more.Microsoft.UI.Xaml.UIElement, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_AlignBottomWithPanelProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRelativePanelStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetAlignBottomWithPanel(cls: win32more.Microsoft.UI.Xaml.Controls.IRelativePanelStatics, element: win32more.Microsoft.UI.Xaml.UIElement) -> Boolean: ...
    @winrt_classmethod
    def SetAlignBottomWithPanel(cls: win32more.Microsoft.UI.Xaml.Controls.IRelativePanelStatics, element: win32more.Microsoft.UI.Xaml.UIElement, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_AlignHorizontalCenterWithPanelProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRelativePanelStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetAlignHorizontalCenterWithPanel(cls: win32more.Microsoft.UI.Xaml.Controls.IRelativePanelStatics, element: win32more.Microsoft.UI.Xaml.UIElement) -> Boolean: ...
    @winrt_classmethod
    def SetAlignHorizontalCenterWithPanel(cls: win32more.Microsoft.UI.Xaml.Controls.IRelativePanelStatics, element: win32more.Microsoft.UI.Xaml.UIElement, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_AlignVerticalCenterWithPanelProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRelativePanelStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetAlignVerticalCenterWithPanel(cls: win32more.Microsoft.UI.Xaml.Controls.IRelativePanelStatics, element: win32more.Microsoft.UI.Xaml.UIElement) -> Boolean: ...
    @winrt_classmethod
    def SetAlignVerticalCenterWithPanel(cls: win32more.Microsoft.UI.Xaml.Controls.IRelativePanelStatics, element: win32more.Microsoft.UI.Xaml.UIElement, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_BorderBrushProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRelativePanelStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_BorderThicknessProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRelativePanelStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CornerRadiusProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRelativePanelStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PaddingProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRelativePanelStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    BackgroundSizing = property(get_BackgroundSizing, put_BackgroundSizing)
    BorderBrush = property(get_BorderBrush, put_BorderBrush)
    BorderThickness = property(get_BorderThickness, put_BorderThickness)
    CornerRadius = property(get_CornerRadius, put_CornerRadius)
    Padding = property(get_Padding, put_Padding)
    _RelativePanel_Meta_.AboveProperty = property(get_AboveProperty, None)
    _RelativePanel_Meta_.AlignBottomWithPanelProperty = property(get_AlignBottomWithPanelProperty, None)
    _RelativePanel_Meta_.AlignBottomWithProperty = property(get_AlignBottomWithProperty, None)
    _RelativePanel_Meta_.AlignHorizontalCenterWithPanelProperty = property(get_AlignHorizontalCenterWithPanelProperty, None)
    _RelativePanel_Meta_.AlignHorizontalCenterWithProperty = property(get_AlignHorizontalCenterWithProperty, None)
    _RelativePanel_Meta_.AlignLeftWithPanelProperty = property(get_AlignLeftWithPanelProperty, None)
    _RelativePanel_Meta_.AlignLeftWithProperty = property(get_AlignLeftWithProperty, None)
    _RelativePanel_Meta_.AlignRightWithPanelProperty = property(get_AlignRightWithPanelProperty, None)
    _RelativePanel_Meta_.AlignRightWithProperty = property(get_AlignRightWithProperty, None)
    _RelativePanel_Meta_.AlignTopWithPanelProperty = property(get_AlignTopWithPanelProperty, None)
    _RelativePanel_Meta_.AlignTopWithProperty = property(get_AlignTopWithProperty, None)
    _RelativePanel_Meta_.AlignVerticalCenterWithPanelProperty = property(get_AlignVerticalCenterWithPanelProperty, None)
    _RelativePanel_Meta_.AlignVerticalCenterWithProperty = property(get_AlignVerticalCenterWithProperty, None)
    _RelativePanel_Meta_.BackgroundSizingProperty = property(get_BackgroundSizingProperty, None)
    _RelativePanel_Meta_.BelowProperty = property(get_BelowProperty, None)
    _RelativePanel_Meta_.BorderBrushProperty = property(get_BorderBrushProperty, None)
    _RelativePanel_Meta_.BorderThicknessProperty = property(get_BorderThicknessProperty, None)
    _RelativePanel_Meta_.CornerRadiusProperty = property(get_CornerRadiusProperty, None)
    _RelativePanel_Meta_.LeftOfProperty = property(get_LeftOfProperty, None)
    _RelativePanel_Meta_.PaddingProperty = property(get_PaddingProperty, None)
    _RelativePanel_Meta_.RightOfProperty = property(get_RightOfProperty, None)
class RequiresPointer(Enum, Int32):
    Never = 0
    WhenEngaged = 1
    WhenFocused = 2
class RevealListViewItemPresenter(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.Controls.Primitives.ListViewItemPresenter
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IRevealListViewItemPresenter
    _classid_ = 'Microsoft.UI.Xaml.Controls.RevealListViewItemPresenter'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.RevealListViewItemPresenter.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IRevealListViewItemPresenterFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.RevealListViewItemPresenter: ...
class _RichEditBox_Meta_(ComPtr.__class__):
    pass
class RichEditBox(ComPtr, metaclass=_RichEditBox_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.Control
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IRichEditBox
    _classid_ = 'Microsoft.UI.Xaml.Controls.RichEditBox'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.RichEditBox.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IRichEditBoxFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.RichEditBox: ...
    @winrt_mixinmethod
    def get_IsReadOnly(self: win32more.Microsoft.UI.Xaml.Controls.IRichEditBox) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsReadOnly(self: win32more.Microsoft.UI.Xaml.Controls.IRichEditBox, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_AcceptsReturn(self: win32more.Microsoft.UI.Xaml.Controls.IRichEditBox) -> Boolean: ...
    @winrt_mixinmethod
    def put_AcceptsReturn(self: win32more.Microsoft.UI.Xaml.Controls.IRichEditBox, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_TextAlignment(self: win32more.Microsoft.UI.Xaml.Controls.IRichEditBox) -> win32more.Microsoft.UI.Xaml.TextAlignment: ...
    @winrt_mixinmethod
    def put_TextAlignment(self: win32more.Microsoft.UI.Xaml.Controls.IRichEditBox, value: win32more.Microsoft.UI.Xaml.TextAlignment) -> Void: ...
    @winrt_mixinmethod
    def get_TextWrapping(self: win32more.Microsoft.UI.Xaml.Controls.IRichEditBox) -> win32more.Microsoft.UI.Xaml.TextWrapping: ...
    @winrt_mixinmethod
    def put_TextWrapping(self: win32more.Microsoft.UI.Xaml.Controls.IRichEditBox, value: win32more.Microsoft.UI.Xaml.TextWrapping) -> Void: ...
    @winrt_mixinmethod
    def get_IsSpellCheckEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IRichEditBox) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsSpellCheckEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IRichEditBox, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsTextPredictionEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IRichEditBox) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsTextPredictionEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IRichEditBox, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_Document(self: win32more.Microsoft.UI.Xaml.Controls.IRichEditBox) -> win32more.Microsoft.UI.Text.RichEditTextDocument: ...
    @winrt_mixinmethod
    def get_InputScope(self: win32more.Microsoft.UI.Xaml.Controls.IRichEditBox) -> win32more.Microsoft.UI.Xaml.Input.InputScope: ...
    @winrt_mixinmethod
    def put_InputScope(self: win32more.Microsoft.UI.Xaml.Controls.IRichEditBox, value: win32more.Microsoft.UI.Xaml.Input.InputScope) -> Void: ...
    @winrt_mixinmethod
    def get_Header(self: win32more.Microsoft.UI.Xaml.Controls.IRichEditBox) -> IInspectable: ...
    @winrt_mixinmethod
    def put_Header(self: win32more.Microsoft.UI.Xaml.Controls.IRichEditBox, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_HeaderTemplate(self: win32more.Microsoft.UI.Xaml.Controls.IRichEditBox) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def put_HeaderTemplate(self: win32more.Microsoft.UI.Xaml.Controls.IRichEditBox, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_mixinmethod
    def get_PlaceholderText(self: win32more.Microsoft.UI.Xaml.Controls.IRichEditBox) -> hstr: ...
    @winrt_mixinmethod
    def put_PlaceholderText(self: win32more.Microsoft.UI.Xaml.Controls.IRichEditBox, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def get_SelectionHighlightColor(self: win32more.Microsoft.UI.Xaml.Controls.IRichEditBox) -> win32more.Microsoft.UI.Xaml.Media.SolidColorBrush: ...
    @winrt_mixinmethod
    def put_SelectionHighlightColor(self: win32more.Microsoft.UI.Xaml.Controls.IRichEditBox, value: win32more.Microsoft.UI.Xaml.Media.SolidColorBrush) -> Void: ...
    @winrt_mixinmethod
    def get_PreventKeyboardDisplayOnProgrammaticFocus(self: win32more.Microsoft.UI.Xaml.Controls.IRichEditBox) -> Boolean: ...
    @winrt_mixinmethod
    def put_PreventKeyboardDisplayOnProgrammaticFocus(self: win32more.Microsoft.UI.Xaml.Controls.IRichEditBox, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsColorFontEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IRichEditBox) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsColorFontEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IRichEditBox, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_SelectionHighlightColorWhenNotFocused(self: win32more.Microsoft.UI.Xaml.Controls.IRichEditBox) -> win32more.Microsoft.UI.Xaml.Media.SolidColorBrush: ...
    @winrt_mixinmethod
    def put_SelectionHighlightColorWhenNotFocused(self: win32more.Microsoft.UI.Xaml.Controls.IRichEditBox, value: win32more.Microsoft.UI.Xaml.Media.SolidColorBrush) -> Void: ...
    @winrt_mixinmethod
    def get_MaxLength(self: win32more.Microsoft.UI.Xaml.Controls.IRichEditBox) -> Int32: ...
    @winrt_mixinmethod
    def put_MaxLength(self: win32more.Microsoft.UI.Xaml.Controls.IRichEditBox, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_HorizontalTextAlignment(self: win32more.Microsoft.UI.Xaml.Controls.IRichEditBox) -> win32more.Microsoft.UI.Xaml.TextAlignment: ...
    @winrt_mixinmethod
    def put_HorizontalTextAlignment(self: win32more.Microsoft.UI.Xaml.Controls.IRichEditBox, value: win32more.Microsoft.UI.Xaml.TextAlignment) -> Void: ...
    @winrt_mixinmethod
    def get_CharacterCasing(self: win32more.Microsoft.UI.Xaml.Controls.IRichEditBox) -> win32more.Microsoft.UI.Xaml.Controls.CharacterCasing: ...
    @winrt_mixinmethod
    def put_CharacterCasing(self: win32more.Microsoft.UI.Xaml.Controls.IRichEditBox, value: win32more.Microsoft.UI.Xaml.Controls.CharacterCasing) -> Void: ...
    @winrt_mixinmethod
    def get_DisabledFormattingAccelerators(self: win32more.Microsoft.UI.Xaml.Controls.IRichEditBox) -> win32more.Microsoft.UI.Xaml.Controls.DisabledFormattingAccelerators: ...
    @winrt_mixinmethod
    def put_DisabledFormattingAccelerators(self: win32more.Microsoft.UI.Xaml.Controls.IRichEditBox, value: win32more.Microsoft.UI.Xaml.Controls.DisabledFormattingAccelerators) -> Void: ...
    @winrt_mixinmethod
    def get_TextDocument(self: win32more.Microsoft.UI.Xaml.Controls.IRichEditBox) -> win32more.Microsoft.UI.Text.RichEditTextDocument: ...
    @winrt_mixinmethod
    def get_SelectionFlyout(self: win32more.Microsoft.UI.Xaml.Controls.IRichEditBox) -> win32more.Microsoft.UI.Xaml.Controls.Primitives.FlyoutBase: ...
    @winrt_mixinmethod
    def put_SelectionFlyout(self: win32more.Microsoft.UI.Xaml.Controls.IRichEditBox, value: win32more.Microsoft.UI.Xaml.Controls.Primitives.FlyoutBase) -> Void: ...
    @winrt_mixinmethod
    def get_ProofingMenuFlyout(self: win32more.Microsoft.UI.Xaml.Controls.IRichEditBox) -> win32more.Microsoft.UI.Xaml.Controls.Primitives.FlyoutBase: ...
    @winrt_mixinmethod
    def get_Description(self: win32more.Microsoft.UI.Xaml.Controls.IRichEditBox) -> IInspectable: ...
    @winrt_mixinmethod
    def put_Description(self: win32more.Microsoft.UI.Xaml.Controls.IRichEditBox, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def add_TextChanged(self: win32more.Microsoft.UI.Xaml.Controls.IRichEditBox, handler: win32more.Microsoft.UI.Xaml.RoutedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_TextChanged(self: win32more.Microsoft.UI.Xaml.Controls.IRichEditBox, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_SelectionChanged(self: win32more.Microsoft.UI.Xaml.Controls.IRichEditBox, handler: win32more.Microsoft.UI.Xaml.RoutedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_SelectionChanged(self: win32more.Microsoft.UI.Xaml.Controls.IRichEditBox, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_ContextMenuOpening(self: win32more.Microsoft.UI.Xaml.Controls.IRichEditBox, handler: win32more.Microsoft.UI.Xaml.Controls.ContextMenuOpeningEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ContextMenuOpening(self: win32more.Microsoft.UI.Xaml.Controls.IRichEditBox, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_Paste(self: win32more.Microsoft.UI.Xaml.Controls.IRichEditBox, handler: win32more.Microsoft.UI.Xaml.Controls.TextControlPasteEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Paste(self: win32more.Microsoft.UI.Xaml.Controls.IRichEditBox, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_TextCompositionStarted(self: win32more.Microsoft.UI.Xaml.Controls.IRichEditBox, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.RichEditBox, win32more.Microsoft.UI.Xaml.Controls.TextCompositionStartedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_TextCompositionStarted(self: win32more.Microsoft.UI.Xaml.Controls.IRichEditBox, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_TextCompositionChanged(self: win32more.Microsoft.UI.Xaml.Controls.IRichEditBox, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.RichEditBox, win32more.Microsoft.UI.Xaml.Controls.TextCompositionChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_TextCompositionChanged(self: win32more.Microsoft.UI.Xaml.Controls.IRichEditBox, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_TextCompositionEnded(self: win32more.Microsoft.UI.Xaml.Controls.IRichEditBox, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.RichEditBox, win32more.Microsoft.UI.Xaml.Controls.TextCompositionEndedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_TextCompositionEnded(self: win32more.Microsoft.UI.Xaml.Controls.IRichEditBox, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_CopyingToClipboard(self: win32more.Microsoft.UI.Xaml.Controls.IRichEditBox, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.RichEditBox, win32more.Microsoft.UI.Xaml.Controls.TextControlCopyingToClipboardEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_CopyingToClipboard(self: win32more.Microsoft.UI.Xaml.Controls.IRichEditBox, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_CuttingToClipboard(self: win32more.Microsoft.UI.Xaml.Controls.IRichEditBox, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.RichEditBox, win32more.Microsoft.UI.Xaml.Controls.TextControlCuttingToClipboardEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_CuttingToClipboard(self: win32more.Microsoft.UI.Xaml.Controls.IRichEditBox, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_SelectionChanging(self: win32more.Microsoft.UI.Xaml.Controls.IRichEditBox, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.RichEditBox, win32more.Microsoft.UI.Xaml.Controls.RichEditBoxSelectionChangingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_SelectionChanging(self: win32more.Microsoft.UI.Xaml.Controls.IRichEditBox, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def GetLinguisticAlternativesAsync(self: win32more.Microsoft.UI.Xaml.Controls.IRichEditBox) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[hstr]]: ...
    @winrt_mixinmethod
    def get_TextReadingOrder(self: win32more.Microsoft.UI.Xaml.Controls.IRichEditBox) -> win32more.Microsoft.UI.Xaml.TextReadingOrder: ...
    @winrt_mixinmethod
    def put_TextReadingOrder(self: win32more.Microsoft.UI.Xaml.Controls.IRichEditBox, value: win32more.Microsoft.UI.Xaml.TextReadingOrder) -> Void: ...
    @winrt_mixinmethod
    def get_ClipboardCopyFormat(self: win32more.Microsoft.UI.Xaml.Controls.IRichEditBox) -> win32more.Microsoft.UI.Xaml.Controls.RichEditClipboardFormat: ...
    @winrt_mixinmethod
    def put_ClipboardCopyFormat(self: win32more.Microsoft.UI.Xaml.Controls.IRichEditBox, value: win32more.Microsoft.UI.Xaml.Controls.RichEditClipboardFormat) -> Void: ...
    @winrt_mixinmethod
    def get_DesiredCandidateWindowAlignment(self: win32more.Microsoft.UI.Xaml.Controls.IRichEditBox) -> win32more.Microsoft.UI.Xaml.Controls.CandidateWindowAlignment: ...
    @winrt_mixinmethod
    def put_DesiredCandidateWindowAlignment(self: win32more.Microsoft.UI.Xaml.Controls.IRichEditBox, value: win32more.Microsoft.UI.Xaml.Controls.CandidateWindowAlignment) -> Void: ...
    @winrt_mixinmethod
    def add_CandidateWindowBoundsChanged(self: win32more.Microsoft.UI.Xaml.Controls.IRichEditBox, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.RichEditBox, win32more.Microsoft.UI.Xaml.Controls.CandidateWindowBoundsChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_CandidateWindowBoundsChanged(self: win32more.Microsoft.UI.Xaml.Controls.IRichEditBox, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_TextChanging(self: win32more.Microsoft.UI.Xaml.Controls.IRichEditBox, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.RichEditBox, win32more.Microsoft.UI.Xaml.Controls.RichEditBoxTextChangingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_TextChanging(self: win32more.Microsoft.UI.Xaml.Controls.IRichEditBox, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def get_IsReadOnlyProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRichEditBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_AcceptsReturnProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRichEditBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TextAlignmentProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRichEditBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TextWrappingProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRichEditBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsSpellCheckEnabledProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRichEditBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsTextPredictionEnabledProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRichEditBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_InputScopeProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRichEditBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HeaderProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRichEditBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HeaderTemplateProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRichEditBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PlaceholderTextProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRichEditBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectionHighlightColorProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRichEditBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PreventKeyboardDisplayOnProgrammaticFocusProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRichEditBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsColorFontEnabledProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRichEditBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectionHighlightColorWhenNotFocusedProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRichEditBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MaxLengthProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRichEditBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HorizontalTextAlignmentProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRichEditBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CharacterCasingProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRichEditBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DisabledFormattingAcceleratorsProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRichEditBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectionFlyoutProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRichEditBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ProofingMenuFlyoutProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRichEditBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DescriptionProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRichEditBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DesiredCandidateWindowAlignmentProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRichEditBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TextReadingOrderProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRichEditBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ClipboardCopyFormatProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRichEditBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    AcceptsReturn = property(get_AcceptsReturn, put_AcceptsReturn)
    CharacterCasing = property(get_CharacterCasing, put_CharacterCasing)
    ClipboardCopyFormat = property(get_ClipboardCopyFormat, put_ClipboardCopyFormat)
    Description = property(get_Description, put_Description)
    DesiredCandidateWindowAlignment = property(get_DesiredCandidateWindowAlignment, put_DesiredCandidateWindowAlignment)
    DisabledFormattingAccelerators = property(get_DisabledFormattingAccelerators, put_DisabledFormattingAccelerators)
    Document = property(get_Document, None)
    Header = property(get_Header, put_Header)
    HeaderTemplate = property(get_HeaderTemplate, put_HeaderTemplate)
    HorizontalTextAlignment = property(get_HorizontalTextAlignment, put_HorizontalTextAlignment)
    InputScope = property(get_InputScope, put_InputScope)
    IsColorFontEnabled = property(get_IsColorFontEnabled, put_IsColorFontEnabled)
    IsReadOnly = property(get_IsReadOnly, put_IsReadOnly)
    IsSpellCheckEnabled = property(get_IsSpellCheckEnabled, put_IsSpellCheckEnabled)
    IsTextPredictionEnabled = property(get_IsTextPredictionEnabled, put_IsTextPredictionEnabled)
    MaxLength = property(get_MaxLength, put_MaxLength)
    PlaceholderText = property(get_PlaceholderText, put_PlaceholderText)
    PreventKeyboardDisplayOnProgrammaticFocus = property(get_PreventKeyboardDisplayOnProgrammaticFocus, put_PreventKeyboardDisplayOnProgrammaticFocus)
    ProofingMenuFlyout = property(get_ProofingMenuFlyout, None)
    SelectionFlyout = property(get_SelectionFlyout, put_SelectionFlyout)
    SelectionHighlightColor = property(get_SelectionHighlightColor, put_SelectionHighlightColor)
    SelectionHighlightColorWhenNotFocused = property(get_SelectionHighlightColorWhenNotFocused, put_SelectionHighlightColorWhenNotFocused)
    TextAlignment = property(get_TextAlignment, put_TextAlignment)
    TextDocument = property(get_TextDocument, None)
    TextReadingOrder = property(get_TextReadingOrder, put_TextReadingOrder)
    TextWrapping = property(get_TextWrapping, put_TextWrapping)
    _RichEditBox_Meta_.AcceptsReturnProperty = property(get_AcceptsReturnProperty, None)
    _RichEditBox_Meta_.CharacterCasingProperty = property(get_CharacterCasingProperty, None)
    _RichEditBox_Meta_.ClipboardCopyFormatProperty = property(get_ClipboardCopyFormatProperty, None)
    _RichEditBox_Meta_.DescriptionProperty = property(get_DescriptionProperty, None)
    _RichEditBox_Meta_.DesiredCandidateWindowAlignmentProperty = property(get_DesiredCandidateWindowAlignmentProperty, None)
    _RichEditBox_Meta_.DisabledFormattingAcceleratorsProperty = property(get_DisabledFormattingAcceleratorsProperty, None)
    _RichEditBox_Meta_.HeaderProperty = property(get_HeaderProperty, None)
    _RichEditBox_Meta_.HeaderTemplateProperty = property(get_HeaderTemplateProperty, None)
    _RichEditBox_Meta_.HorizontalTextAlignmentProperty = property(get_HorizontalTextAlignmentProperty, None)
    _RichEditBox_Meta_.InputScopeProperty = property(get_InputScopeProperty, None)
    _RichEditBox_Meta_.IsColorFontEnabledProperty = property(get_IsColorFontEnabledProperty, None)
    _RichEditBox_Meta_.IsReadOnlyProperty = property(get_IsReadOnlyProperty, None)
    _RichEditBox_Meta_.IsSpellCheckEnabledProperty = property(get_IsSpellCheckEnabledProperty, None)
    _RichEditBox_Meta_.IsTextPredictionEnabledProperty = property(get_IsTextPredictionEnabledProperty, None)
    _RichEditBox_Meta_.MaxLengthProperty = property(get_MaxLengthProperty, None)
    _RichEditBox_Meta_.PlaceholderTextProperty = property(get_PlaceholderTextProperty, None)
    _RichEditBox_Meta_.PreventKeyboardDisplayOnProgrammaticFocusProperty = property(get_PreventKeyboardDisplayOnProgrammaticFocusProperty, None)
    _RichEditBox_Meta_.ProofingMenuFlyoutProperty = property(get_ProofingMenuFlyoutProperty, None)
    _RichEditBox_Meta_.SelectionFlyoutProperty = property(get_SelectionFlyoutProperty, None)
    _RichEditBox_Meta_.SelectionHighlightColorProperty = property(get_SelectionHighlightColorProperty, None)
    _RichEditBox_Meta_.SelectionHighlightColorWhenNotFocusedProperty = property(get_SelectionHighlightColorWhenNotFocusedProperty, None)
    _RichEditBox_Meta_.TextAlignmentProperty = property(get_TextAlignmentProperty, None)
    _RichEditBox_Meta_.TextReadingOrderProperty = property(get_TextReadingOrderProperty, None)
    _RichEditBox_Meta_.TextWrappingProperty = property(get_TextWrappingProperty, None)
    CandidateWindowBoundsChanged = event(add_CandidateWindowBoundsChanged, remove_CandidateWindowBoundsChanged)
    ContextMenuOpening = event(add_ContextMenuOpening, remove_ContextMenuOpening)
    CopyingToClipboard = event(add_CopyingToClipboard, remove_CopyingToClipboard)
    CuttingToClipboard = event(add_CuttingToClipboard, remove_CuttingToClipboard)
    Paste = event(add_Paste, remove_Paste)
    SelectionChanged = event(add_SelectionChanged, remove_SelectionChanged)
    SelectionChanging = event(add_SelectionChanging, remove_SelectionChanging)
    TextChanged = event(add_TextChanged, remove_TextChanged)
    TextChanging = event(add_TextChanging, remove_TextChanging)
    TextCompositionChanged = event(add_TextCompositionChanged, remove_TextCompositionChanged)
    TextCompositionEnded = event(add_TextCompositionEnded, remove_TextCompositionEnded)
    TextCompositionStarted = event(add_TextCompositionStarted, remove_TextCompositionStarted)
class RichEditBoxSelectionChangingEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IRichEditBoxSelectionChangingEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.RichEditBoxSelectionChangingEventArgs'
    @winrt_mixinmethod
    def get_SelectionStart(self: win32more.Microsoft.UI.Xaml.Controls.IRichEditBoxSelectionChangingEventArgs) -> Int32: ...
    @winrt_mixinmethod
    def get_SelectionLength(self: win32more.Microsoft.UI.Xaml.Controls.IRichEditBoxSelectionChangingEventArgs) -> Int32: ...
    @winrt_mixinmethod
    def get_Cancel(self: win32more.Microsoft.UI.Xaml.Controls.IRichEditBoxSelectionChangingEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def put_Cancel(self: win32more.Microsoft.UI.Xaml.Controls.IRichEditBoxSelectionChangingEventArgs, value: Boolean) -> Void: ...
    Cancel = property(get_Cancel, put_Cancel)
    SelectionLength = property(get_SelectionLength, None)
    SelectionStart = property(get_SelectionStart, None)
class RichEditBoxTextChangingEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IRichEditBoxTextChangingEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.RichEditBoxTextChangingEventArgs'
    @winrt_mixinmethod
    def get_IsContentChanging(self: win32more.Microsoft.UI.Xaml.Controls.IRichEditBoxTextChangingEventArgs) -> Boolean: ...
    IsContentChanging = property(get_IsContentChanging, None)
class RichEditClipboardFormat(Enum, Int32):
    AllFormats = 0
    PlainText = 1
class _RichTextBlock_Meta_(ComPtr.__class__):
    pass
class RichTextBlock(ComPtr, metaclass=_RichTextBlock_Meta_):
    extends: win32more.Microsoft.UI.Xaml.FrameworkElement
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlock
    _classid_ = 'Microsoft.UI.Xaml.Controls.RichTextBlock'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.RichTextBlock.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Controls.RichTextBlock: ...
    @winrt_mixinmethod
    def get_FontSize(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlock) -> Double: ...
    @winrt_mixinmethod
    def put_FontSize(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlock, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_FontFamily(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlock) -> win32more.Microsoft.UI.Xaml.Media.FontFamily: ...
    @winrt_mixinmethod
    def put_FontFamily(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlock, value: win32more.Microsoft.UI.Xaml.Media.FontFamily) -> Void: ...
    @winrt_mixinmethod
    def get_FontWeight(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlock) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_mixinmethod
    def put_FontWeight(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlock, value: win32more.Windows.UI.Text.FontWeight) -> Void: ...
    @winrt_mixinmethod
    def get_FontStyle(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlock) -> win32more.Windows.UI.Text.FontStyle: ...
    @winrt_mixinmethod
    def put_FontStyle(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlock, value: win32more.Windows.UI.Text.FontStyle) -> Void: ...
    @winrt_mixinmethod
    def get_FontStretch(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlock) -> win32more.Windows.UI.Text.FontStretch: ...
    @winrt_mixinmethod
    def put_FontStretch(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlock, value: win32more.Windows.UI.Text.FontStretch) -> Void: ...
    @winrt_mixinmethod
    def get_Foreground(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlock) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_Foreground(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlock, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_TextWrapping(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlock) -> win32more.Microsoft.UI.Xaml.TextWrapping: ...
    @winrt_mixinmethod
    def put_TextWrapping(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlock, value: win32more.Microsoft.UI.Xaml.TextWrapping) -> Void: ...
    @winrt_mixinmethod
    def get_TextTrimming(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlock) -> win32more.Microsoft.UI.Xaml.TextTrimming: ...
    @winrt_mixinmethod
    def put_TextTrimming(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlock, value: win32more.Microsoft.UI.Xaml.TextTrimming) -> Void: ...
    @winrt_mixinmethod
    def get_TextAlignment(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlock) -> win32more.Microsoft.UI.Xaml.TextAlignment: ...
    @winrt_mixinmethod
    def put_TextAlignment(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlock, value: win32more.Microsoft.UI.Xaml.TextAlignment) -> Void: ...
    @winrt_mixinmethod
    def get_Blocks(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlock) -> win32more.Microsoft.UI.Xaml.Documents.BlockCollection: ...
    @winrt_mixinmethod
    def get_Padding(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlock) -> win32more.Microsoft.UI.Xaml.Thickness: ...
    @winrt_mixinmethod
    def put_Padding(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlock, value: win32more.Microsoft.UI.Xaml.Thickness) -> Void: ...
    @winrt_mixinmethod
    def get_LineHeight(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlock) -> Double: ...
    @winrt_mixinmethod
    def put_LineHeight(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlock, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_LineStackingStrategy(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlock) -> win32more.Microsoft.UI.Xaml.LineStackingStrategy: ...
    @winrt_mixinmethod
    def put_LineStackingStrategy(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlock, value: win32more.Microsoft.UI.Xaml.LineStackingStrategy) -> Void: ...
    @winrt_mixinmethod
    def get_CharacterSpacing(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlock) -> Int32: ...
    @winrt_mixinmethod
    def put_CharacterSpacing(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlock, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_OverflowContentTarget(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlock) -> win32more.Microsoft.UI.Xaml.Controls.RichTextBlockOverflow: ...
    @winrt_mixinmethod
    def put_OverflowContentTarget(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlock, value: win32more.Microsoft.UI.Xaml.Controls.RichTextBlockOverflow) -> Void: ...
    @winrt_mixinmethod
    def get_IsTextSelectionEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlock) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsTextSelectionEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlock, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_HasOverflowContent(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlock) -> Boolean: ...
    @winrt_mixinmethod
    def get_SelectedText(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlock) -> hstr: ...
    @winrt_mixinmethod
    def get_ContentStart(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlock) -> win32more.Microsoft.UI.Xaml.Documents.TextPointer: ...
    @winrt_mixinmethod
    def get_ContentEnd(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlock) -> win32more.Microsoft.UI.Xaml.Documents.TextPointer: ...
    @winrt_mixinmethod
    def get_SelectionStart(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlock) -> win32more.Microsoft.UI.Xaml.Documents.TextPointer: ...
    @winrt_mixinmethod
    def get_SelectionEnd(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlock) -> win32more.Microsoft.UI.Xaml.Documents.TextPointer: ...
    @winrt_mixinmethod
    def get_BaselineOffset(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlock) -> Double: ...
    @winrt_mixinmethod
    def get_MaxLines(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlock) -> Int32: ...
    @winrt_mixinmethod
    def put_MaxLines(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlock, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_TextLineBounds(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlock) -> win32more.Microsoft.UI.Xaml.TextLineBounds: ...
    @winrt_mixinmethod
    def put_TextLineBounds(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlock, value: win32more.Microsoft.UI.Xaml.TextLineBounds) -> Void: ...
    @winrt_mixinmethod
    def get_SelectionHighlightColor(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlock) -> win32more.Microsoft.UI.Xaml.Media.SolidColorBrush: ...
    @winrt_mixinmethod
    def put_SelectionHighlightColor(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlock, value: win32more.Microsoft.UI.Xaml.Media.SolidColorBrush) -> Void: ...
    @winrt_mixinmethod
    def get_OpticalMarginAlignment(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlock) -> win32more.Microsoft.UI.Xaml.OpticalMarginAlignment: ...
    @winrt_mixinmethod
    def put_OpticalMarginAlignment(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlock, value: win32more.Microsoft.UI.Xaml.OpticalMarginAlignment) -> Void: ...
    @winrt_mixinmethod
    def get_IsColorFontEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlock) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsColorFontEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlock, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_TextReadingOrder(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlock) -> win32more.Microsoft.UI.Xaml.TextReadingOrder: ...
    @winrt_mixinmethod
    def put_TextReadingOrder(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlock, value: win32more.Microsoft.UI.Xaml.TextReadingOrder) -> Void: ...
    @winrt_mixinmethod
    def get_IsTextScaleFactorEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlock) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsTextScaleFactorEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlock, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_TextDecorations(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlock) -> win32more.Windows.UI.Text.TextDecorations: ...
    @winrt_mixinmethod
    def put_TextDecorations(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlock, value: win32more.Windows.UI.Text.TextDecorations) -> Void: ...
    @winrt_mixinmethod
    def get_IsTextTrimmed(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlock) -> Boolean: ...
    @winrt_mixinmethod
    def get_HorizontalTextAlignment(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlock) -> win32more.Microsoft.UI.Xaml.TextAlignment: ...
    @winrt_mixinmethod
    def put_HorizontalTextAlignment(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlock, value: win32more.Microsoft.UI.Xaml.TextAlignment) -> Void: ...
    @winrt_mixinmethod
    def get_TextHighlighters(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlock) -> win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Documents.TextHighlighter]: ...
    @winrt_mixinmethod
    def get_SelectionFlyout(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlock) -> win32more.Microsoft.UI.Xaml.Controls.Primitives.FlyoutBase: ...
    @winrt_mixinmethod
    def put_SelectionFlyout(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlock, value: win32more.Microsoft.UI.Xaml.Controls.Primitives.FlyoutBase) -> Void: ...
    @winrt_mixinmethod
    def add_SelectionChanged(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlock, handler: win32more.Microsoft.UI.Xaml.RoutedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_SelectionChanged(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlock, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_ContextMenuOpening(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlock, handler: win32more.Microsoft.UI.Xaml.Controls.ContextMenuOpeningEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ContextMenuOpening(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlock, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_IsTextTrimmedChanged(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlock, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.RichTextBlock, win32more.Microsoft.UI.Xaml.Controls.IsTextTrimmedChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_IsTextTrimmedChanged(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlock, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def SelectAll(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlock) -> Void: ...
    @winrt_mixinmethod
    def Select(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlock, start: win32more.Microsoft.UI.Xaml.Documents.TextPointer, end: win32more.Microsoft.UI.Xaml.Documents.TextPointer) -> Void: ...
    @winrt_mixinmethod
    def GetPositionFromPoint(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlock, point: win32more.Windows.Foundation.Point) -> win32more.Microsoft.UI.Xaml.Documents.TextPointer: ...
    @winrt_mixinmethod
    def CopySelectionToClipboard(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlock) -> Void: ...
    @winrt_mixinmethod
    def get_TextIndent(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlock) -> Double: ...
    @winrt_mixinmethod
    def put_TextIndent(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlock, value: Double) -> Void: ...
    @winrt_classmethod
    def get_FontSizeProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlockStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FontFamilyProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlockStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FontWeightProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlockStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FontStyleProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlockStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FontStretchProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlockStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ForegroundProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlockStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TextWrappingProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlockStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TextTrimmingProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlockStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TextAlignmentProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlockStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PaddingProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlockStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_LineHeightProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlockStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_LineStackingStrategyProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlockStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CharacterSpacingProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlockStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_OverflowContentTargetProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlockStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsTextSelectionEnabledProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlockStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HasOverflowContentProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlockStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectedTextProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlockStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MaxLinesProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlockStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TextLineBoundsProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlockStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectionHighlightColorProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlockStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_OpticalMarginAlignmentProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlockStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsColorFontEnabledProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlockStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TextReadingOrderProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlockStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsTextScaleFactorEnabledProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlockStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TextDecorationsProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlockStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsTextTrimmedProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlockStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HorizontalTextAlignmentProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlockStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectionFlyoutProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlockStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TextIndentProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlockStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    BaselineOffset = property(get_BaselineOffset, None)
    Blocks = property(get_Blocks, None)
    CharacterSpacing = property(get_CharacterSpacing, put_CharacterSpacing)
    ContentEnd = property(get_ContentEnd, None)
    ContentStart = property(get_ContentStart, None)
    FontFamily = property(get_FontFamily, put_FontFamily)
    FontSize = property(get_FontSize, put_FontSize)
    FontStretch = property(get_FontStretch, put_FontStretch)
    FontStyle = property(get_FontStyle, put_FontStyle)
    FontWeight = property(get_FontWeight, put_FontWeight)
    Foreground = property(get_Foreground, put_Foreground)
    HasOverflowContent = property(get_HasOverflowContent, None)
    HorizontalTextAlignment = property(get_HorizontalTextAlignment, put_HorizontalTextAlignment)
    IsColorFontEnabled = property(get_IsColorFontEnabled, put_IsColorFontEnabled)
    IsTextScaleFactorEnabled = property(get_IsTextScaleFactorEnabled, put_IsTextScaleFactorEnabled)
    IsTextSelectionEnabled = property(get_IsTextSelectionEnabled, put_IsTextSelectionEnabled)
    IsTextTrimmed = property(get_IsTextTrimmed, None)
    LineHeight = property(get_LineHeight, put_LineHeight)
    LineStackingStrategy = property(get_LineStackingStrategy, put_LineStackingStrategy)
    MaxLines = property(get_MaxLines, put_MaxLines)
    OpticalMarginAlignment = property(get_OpticalMarginAlignment, put_OpticalMarginAlignment)
    OverflowContentTarget = property(get_OverflowContentTarget, put_OverflowContentTarget)
    Padding = property(get_Padding, put_Padding)
    SelectedText = property(get_SelectedText, None)
    SelectionEnd = property(get_SelectionEnd, None)
    SelectionFlyout = property(get_SelectionFlyout, put_SelectionFlyout)
    SelectionHighlightColor = property(get_SelectionHighlightColor, put_SelectionHighlightColor)
    SelectionStart = property(get_SelectionStart, None)
    TextAlignment = property(get_TextAlignment, put_TextAlignment)
    TextDecorations = property(get_TextDecorations, put_TextDecorations)
    TextHighlighters = property(get_TextHighlighters, None)
    TextIndent = property(get_TextIndent, put_TextIndent)
    TextLineBounds = property(get_TextLineBounds, put_TextLineBounds)
    TextReadingOrder = property(get_TextReadingOrder, put_TextReadingOrder)
    TextTrimming = property(get_TextTrimming, put_TextTrimming)
    TextWrapping = property(get_TextWrapping, put_TextWrapping)
    _RichTextBlock_Meta_.CharacterSpacingProperty = property(get_CharacterSpacingProperty, None)
    _RichTextBlock_Meta_.FontFamilyProperty = property(get_FontFamilyProperty, None)
    _RichTextBlock_Meta_.FontSizeProperty = property(get_FontSizeProperty, None)
    _RichTextBlock_Meta_.FontStretchProperty = property(get_FontStretchProperty, None)
    _RichTextBlock_Meta_.FontStyleProperty = property(get_FontStyleProperty, None)
    _RichTextBlock_Meta_.FontWeightProperty = property(get_FontWeightProperty, None)
    _RichTextBlock_Meta_.ForegroundProperty = property(get_ForegroundProperty, None)
    _RichTextBlock_Meta_.HasOverflowContentProperty = property(get_HasOverflowContentProperty, None)
    _RichTextBlock_Meta_.HorizontalTextAlignmentProperty = property(get_HorizontalTextAlignmentProperty, None)
    _RichTextBlock_Meta_.IsColorFontEnabledProperty = property(get_IsColorFontEnabledProperty, None)
    _RichTextBlock_Meta_.IsTextScaleFactorEnabledProperty = property(get_IsTextScaleFactorEnabledProperty, None)
    _RichTextBlock_Meta_.IsTextSelectionEnabledProperty = property(get_IsTextSelectionEnabledProperty, None)
    _RichTextBlock_Meta_.IsTextTrimmedProperty = property(get_IsTextTrimmedProperty, None)
    _RichTextBlock_Meta_.LineHeightProperty = property(get_LineHeightProperty, None)
    _RichTextBlock_Meta_.LineStackingStrategyProperty = property(get_LineStackingStrategyProperty, None)
    _RichTextBlock_Meta_.MaxLinesProperty = property(get_MaxLinesProperty, None)
    _RichTextBlock_Meta_.OpticalMarginAlignmentProperty = property(get_OpticalMarginAlignmentProperty, None)
    _RichTextBlock_Meta_.OverflowContentTargetProperty = property(get_OverflowContentTargetProperty, None)
    _RichTextBlock_Meta_.PaddingProperty = property(get_PaddingProperty, None)
    _RichTextBlock_Meta_.SelectedTextProperty = property(get_SelectedTextProperty, None)
    _RichTextBlock_Meta_.SelectionFlyoutProperty = property(get_SelectionFlyoutProperty, None)
    _RichTextBlock_Meta_.SelectionHighlightColorProperty = property(get_SelectionHighlightColorProperty, None)
    _RichTextBlock_Meta_.TextAlignmentProperty = property(get_TextAlignmentProperty, None)
    _RichTextBlock_Meta_.TextDecorationsProperty = property(get_TextDecorationsProperty, None)
    _RichTextBlock_Meta_.TextIndentProperty = property(get_TextIndentProperty, None)
    _RichTextBlock_Meta_.TextLineBoundsProperty = property(get_TextLineBoundsProperty, None)
    _RichTextBlock_Meta_.TextReadingOrderProperty = property(get_TextReadingOrderProperty, None)
    _RichTextBlock_Meta_.TextTrimmingProperty = property(get_TextTrimmingProperty, None)
    _RichTextBlock_Meta_.TextWrappingProperty = property(get_TextWrappingProperty, None)
    ContextMenuOpening = event(add_ContextMenuOpening, remove_ContextMenuOpening)
    IsTextTrimmedChanged = event(add_IsTextTrimmedChanged, remove_IsTextTrimmedChanged)
    SelectionChanged = event(add_SelectionChanged, remove_SelectionChanged)
class _RichTextBlockOverflow_Meta_(ComPtr.__class__):
    pass
class RichTextBlockOverflow(ComPtr, metaclass=_RichTextBlockOverflow_Meta_):
    extends: win32more.Microsoft.UI.Xaml.FrameworkElement
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlockOverflow
    _classid_ = 'Microsoft.UI.Xaml.Controls.RichTextBlockOverflow'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.RichTextBlockOverflow.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Controls.RichTextBlockOverflow: ...
    @winrt_mixinmethod
    def get_OverflowContentTarget(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlockOverflow) -> win32more.Microsoft.UI.Xaml.Controls.RichTextBlockOverflow: ...
    @winrt_mixinmethod
    def put_OverflowContentTarget(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlockOverflow, value: win32more.Microsoft.UI.Xaml.Controls.RichTextBlockOverflow) -> Void: ...
    @winrt_mixinmethod
    def get_Padding(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlockOverflow) -> win32more.Microsoft.UI.Xaml.Thickness: ...
    @winrt_mixinmethod
    def put_Padding(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlockOverflow, value: win32more.Microsoft.UI.Xaml.Thickness) -> Void: ...
    @winrt_mixinmethod
    def get_ContentSource(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlockOverflow) -> win32more.Microsoft.UI.Xaml.Controls.RichTextBlock: ...
    @winrt_mixinmethod
    def get_HasOverflowContent(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlockOverflow) -> Boolean: ...
    @winrt_mixinmethod
    def get_ContentStart(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlockOverflow) -> win32more.Microsoft.UI.Xaml.Documents.TextPointer: ...
    @winrt_mixinmethod
    def get_ContentEnd(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlockOverflow) -> win32more.Microsoft.UI.Xaml.Documents.TextPointer: ...
    @winrt_mixinmethod
    def get_BaselineOffset(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlockOverflow) -> Double: ...
    @winrt_mixinmethod
    def get_MaxLines(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlockOverflow) -> Int32: ...
    @winrt_mixinmethod
    def put_MaxLines(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlockOverflow, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_IsTextTrimmed(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlockOverflow) -> Boolean: ...
    @winrt_mixinmethod
    def add_IsTextTrimmedChanged(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlockOverflow, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.RichTextBlockOverflow, win32more.Microsoft.UI.Xaml.Controls.IsTextTrimmedChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_IsTextTrimmedChanged(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlockOverflow, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def GetPositionFromPoint(self: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlockOverflow, point: win32more.Windows.Foundation.Point) -> win32more.Microsoft.UI.Xaml.Documents.TextPointer: ...
    @winrt_classmethod
    def get_OverflowContentTargetProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlockOverflowStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PaddingProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlockOverflowStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HasOverflowContentProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlockOverflowStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MaxLinesProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlockOverflowStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsTextTrimmedProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRichTextBlockOverflowStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    BaselineOffset = property(get_BaselineOffset, None)
    ContentEnd = property(get_ContentEnd, None)
    ContentSource = property(get_ContentSource, None)
    ContentStart = property(get_ContentStart, None)
    HasOverflowContent = property(get_HasOverflowContent, None)
    IsTextTrimmed = property(get_IsTextTrimmed, None)
    MaxLines = property(get_MaxLines, put_MaxLines)
    OverflowContentTarget = property(get_OverflowContentTarget, put_OverflowContentTarget)
    Padding = property(get_Padding, put_Padding)
    _RichTextBlockOverflow_Meta_.HasOverflowContentProperty = property(get_HasOverflowContentProperty, None)
    _RichTextBlockOverflow_Meta_.IsTextTrimmedProperty = property(get_IsTextTrimmedProperty, None)
    _RichTextBlockOverflow_Meta_.MaxLinesProperty = property(get_MaxLinesProperty, None)
    _RichTextBlockOverflow_Meta_.OverflowContentTargetProperty = property(get_OverflowContentTargetProperty, None)
    _RichTextBlockOverflow_Meta_.PaddingProperty = property(get_PaddingProperty, None)
    IsTextTrimmedChanged = event(add_IsTextTrimmedChanged, remove_IsTextTrimmedChanged)
class _RowDefinition_Meta_(ComPtr.__class__):
    pass
class RowDefinition(ComPtr, metaclass=_RowDefinition_Meta_):
    extends: win32more.Microsoft.UI.Xaml.DependencyObject
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IRowDefinition
    _classid_ = 'Microsoft.UI.Xaml.Controls.RowDefinition'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.RowDefinition.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Controls.RowDefinition: ...
    @winrt_mixinmethod
    def get_Height(self: win32more.Microsoft.UI.Xaml.Controls.IRowDefinition) -> win32more.Microsoft.UI.Xaml.GridLength: ...
    @winrt_mixinmethod
    def put_Height(self: win32more.Microsoft.UI.Xaml.Controls.IRowDefinition, value: win32more.Microsoft.UI.Xaml.GridLength) -> Void: ...
    @winrt_mixinmethod
    def get_MaxHeight(self: win32more.Microsoft.UI.Xaml.Controls.IRowDefinition) -> Double: ...
    @winrt_mixinmethod
    def put_MaxHeight(self: win32more.Microsoft.UI.Xaml.Controls.IRowDefinition, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_MinHeight(self: win32more.Microsoft.UI.Xaml.Controls.IRowDefinition) -> Double: ...
    @winrt_mixinmethod
    def put_MinHeight(self: win32more.Microsoft.UI.Xaml.Controls.IRowDefinition, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_ActualHeight(self: win32more.Microsoft.UI.Xaml.Controls.IRowDefinition) -> Double: ...
    @winrt_classmethod
    def get_HeightProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRowDefinitionStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MaxHeightProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRowDefinitionStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MinHeightProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IRowDefinitionStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    ActualHeight = property(get_ActualHeight, None)
    Height = property(get_Height, put_Height)
    MaxHeight = property(get_MaxHeight, put_MaxHeight)
    MinHeight = property(get_MinHeight, put_MinHeight)
    _RowDefinition_Meta_.HeightProperty = property(get_HeightProperty, None)
    _RowDefinition_Meta_.MaxHeightProperty = property(get_MaxHeightProperty, None)
    _RowDefinition_Meta_.MinHeightProperty = property(get_MinHeightProperty, None)
class RowDefinitionCollection(ComPtr):
    extends: IInspectable
    implements: Tuple[SequenceProtocol[win32more.Microsoft.UI.Xaml.Controls.RowDefinition]]
    default_interface: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.RowDefinition]
    _classid_ = 'Microsoft.UI.Xaml.Controls.RowDefinitionCollection'
    @winrt_mixinmethod
    def GetAt(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.RowDefinition], index: UInt32) -> win32more.Microsoft.UI.Xaml.Controls.RowDefinition: ...
    @winrt_mixinmethod
    def get_Size(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.RowDefinition]) -> UInt32: ...
    @winrt_mixinmethod
    def GetView(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.RowDefinition]) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Microsoft.UI.Xaml.Controls.RowDefinition]: ...
    @winrt_mixinmethod
    def IndexOf(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.RowDefinition], value: win32more.Microsoft.UI.Xaml.Controls.RowDefinition, index: POINTER(UInt32)) -> Boolean: ...
    @winrt_mixinmethod
    def SetAt(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.RowDefinition], index: UInt32, value: win32more.Microsoft.UI.Xaml.Controls.RowDefinition) -> Void: ...
    @winrt_mixinmethod
    def InsertAt(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.RowDefinition], index: UInt32, value: win32more.Microsoft.UI.Xaml.Controls.RowDefinition) -> Void: ...
    @winrt_mixinmethod
    def RemoveAt(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.RowDefinition], index: UInt32) -> Void: ...
    @winrt_mixinmethod
    def Append(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.RowDefinition], value: win32more.Microsoft.UI.Xaml.Controls.RowDefinition) -> Void: ...
    @winrt_mixinmethod
    def RemoveAtEnd(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.RowDefinition]) -> Void: ...
    @winrt_mixinmethod
    def Clear(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.RowDefinition]) -> Void: ...
    @winrt_mixinmethod
    def GetMany(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.RowDefinition], startIndex: UInt32, items: FillArray[win32more.Microsoft.UI.Xaml.Controls.RowDefinition]) -> UInt32: ...
    @winrt_mixinmethod
    def ReplaceAll(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.RowDefinition], items: PassArray[win32more.Microsoft.UI.Xaml.Controls.RowDefinition]) -> Void: ...
    @winrt_mixinmethod
    def First(self: win32more.Windows.Foundation.Collections.IIterable[win32more.Microsoft.UI.Xaml.Controls.RowDefinition]) -> win32more.Windows.Foundation.Collections.IIterator[win32more.Microsoft.UI.Xaml.Controls.RowDefinition]: ...
    Size = property(get_Size, None)
class ScrollBarVisibility(Enum, Int32):
    Disabled = 0
    Auto = 1
    Hidden = 2
    Visible = 3
class _ScrollContentPresenter_Meta_(ComPtr.__class__):
    pass
class ScrollContentPresenter(ComPtr, metaclass=_ScrollContentPresenter_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.ContentPresenter
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IScrollContentPresenter
    _classid_ = 'Microsoft.UI.Xaml.Controls.ScrollContentPresenter'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.ScrollContentPresenter.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Controls.ScrollContentPresenter: ...
    @winrt_mixinmethod
    def get_CanVerticallyScroll(self: win32more.Microsoft.UI.Xaml.Controls.IScrollContentPresenter) -> Boolean: ...
    @winrt_mixinmethod
    def put_CanVerticallyScroll(self: win32more.Microsoft.UI.Xaml.Controls.IScrollContentPresenter, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_CanHorizontallyScroll(self: win32more.Microsoft.UI.Xaml.Controls.IScrollContentPresenter) -> Boolean: ...
    @winrt_mixinmethod
    def put_CanHorizontallyScroll(self: win32more.Microsoft.UI.Xaml.Controls.IScrollContentPresenter, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_ExtentWidth(self: win32more.Microsoft.UI.Xaml.Controls.IScrollContentPresenter) -> Double: ...
    @winrt_mixinmethod
    def get_ExtentHeight(self: win32more.Microsoft.UI.Xaml.Controls.IScrollContentPresenter) -> Double: ...
    @winrt_mixinmethod
    def get_ViewportWidth(self: win32more.Microsoft.UI.Xaml.Controls.IScrollContentPresenter) -> Double: ...
    @winrt_mixinmethod
    def get_ViewportHeight(self: win32more.Microsoft.UI.Xaml.Controls.IScrollContentPresenter) -> Double: ...
    @winrt_mixinmethod
    def get_HorizontalOffset(self: win32more.Microsoft.UI.Xaml.Controls.IScrollContentPresenter) -> Double: ...
    @winrt_mixinmethod
    def get_VerticalOffset(self: win32more.Microsoft.UI.Xaml.Controls.IScrollContentPresenter) -> Double: ...
    @winrt_mixinmethod
    def get_ScrollOwner(self: win32more.Microsoft.UI.Xaml.Controls.IScrollContentPresenter) -> IInspectable: ...
    @winrt_mixinmethod
    def put_ScrollOwner(self: win32more.Microsoft.UI.Xaml.Controls.IScrollContentPresenter, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_CanContentRenderOutsideBounds(self: win32more.Microsoft.UI.Xaml.Controls.IScrollContentPresenter) -> Boolean: ...
    @winrt_mixinmethod
    def put_CanContentRenderOutsideBounds(self: win32more.Microsoft.UI.Xaml.Controls.IScrollContentPresenter, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_SizesContentToTemplatedParent(self: win32more.Microsoft.UI.Xaml.Controls.IScrollContentPresenter) -> Boolean: ...
    @winrt_mixinmethod
    def put_SizesContentToTemplatedParent(self: win32more.Microsoft.UI.Xaml.Controls.IScrollContentPresenter, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def LineUp(self: win32more.Microsoft.UI.Xaml.Controls.IScrollContentPresenter) -> Void: ...
    @winrt_mixinmethod
    def LineDown(self: win32more.Microsoft.UI.Xaml.Controls.IScrollContentPresenter) -> Void: ...
    @winrt_mixinmethod
    def LineLeft(self: win32more.Microsoft.UI.Xaml.Controls.IScrollContentPresenter) -> Void: ...
    @winrt_mixinmethod
    def LineRight(self: win32more.Microsoft.UI.Xaml.Controls.IScrollContentPresenter) -> Void: ...
    @winrt_mixinmethod
    def PageUp(self: win32more.Microsoft.UI.Xaml.Controls.IScrollContentPresenter) -> Void: ...
    @winrt_mixinmethod
    def PageDown(self: win32more.Microsoft.UI.Xaml.Controls.IScrollContentPresenter) -> Void: ...
    @winrt_mixinmethod
    def PageLeft(self: win32more.Microsoft.UI.Xaml.Controls.IScrollContentPresenter) -> Void: ...
    @winrt_mixinmethod
    def PageRight(self: win32more.Microsoft.UI.Xaml.Controls.IScrollContentPresenter) -> Void: ...
    @winrt_mixinmethod
    def MouseWheelUp(self: win32more.Microsoft.UI.Xaml.Controls.IScrollContentPresenter) -> Void: ...
    @winrt_mixinmethod
    def MouseWheelDown(self: win32more.Microsoft.UI.Xaml.Controls.IScrollContentPresenter) -> Void: ...
    @winrt_mixinmethod
    def MouseWheelLeft(self: win32more.Microsoft.UI.Xaml.Controls.IScrollContentPresenter) -> Void: ...
    @winrt_mixinmethod
    def MouseWheelRight(self: win32more.Microsoft.UI.Xaml.Controls.IScrollContentPresenter) -> Void: ...
    @winrt_mixinmethod
    def SetHorizontalOffset(self: win32more.Microsoft.UI.Xaml.Controls.IScrollContentPresenter, offset: Double) -> Void: ...
    @winrt_mixinmethod
    def SetVerticalOffset(self: win32more.Microsoft.UI.Xaml.Controls.IScrollContentPresenter, offset: Double) -> Void: ...
    @winrt_mixinmethod
    def MakeVisible(self: win32more.Microsoft.UI.Xaml.Controls.IScrollContentPresenter, visual: win32more.Microsoft.UI.Xaml.UIElement, rectangle: win32more.Windows.Foundation.Rect) -> win32more.Windows.Foundation.Rect: ...
    @winrt_classmethod
    def get_CanContentRenderOutsideBoundsProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollContentPresenterStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SizesContentToTemplatedParentProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollContentPresenterStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    CanContentRenderOutsideBounds = property(get_CanContentRenderOutsideBounds, put_CanContentRenderOutsideBounds)
    CanHorizontallyScroll = property(get_CanHorizontallyScroll, put_CanHorizontallyScroll)
    CanVerticallyScroll = property(get_CanVerticallyScroll, put_CanVerticallyScroll)
    ExtentHeight = property(get_ExtentHeight, None)
    ExtentWidth = property(get_ExtentWidth, None)
    HorizontalOffset = property(get_HorizontalOffset, None)
    ScrollOwner = property(get_ScrollOwner, put_ScrollOwner)
    SizesContentToTemplatedParent = property(get_SizesContentToTemplatedParent, put_SizesContentToTemplatedParent)
    VerticalOffset = property(get_VerticalOffset, None)
    ViewportHeight = property(get_ViewportHeight, None)
    ViewportWidth = property(get_ViewportWidth, None)
    _ScrollContentPresenter_Meta_.CanContentRenderOutsideBoundsProperty = property(get_CanContentRenderOutsideBoundsProperty, None)
    _ScrollContentPresenter_Meta_.SizesContentToTemplatedParentProperty = property(get_SizesContentToTemplatedParentProperty, None)
class ScrollIntoViewAlignment(Enum, Int32):
    Default = 0
    Leading = 1
class ScrollMode(Enum, Int32):
    Disabled = 0
    Enabled = 1
    Auto = 2
class _ScrollView_Meta_(ComPtr.__class__):
    pass
class ScrollView(ComPtr, metaclass=_ScrollView_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.Control
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IScrollView
    _classid_ = 'Microsoft.UI.Xaml.Controls.ScrollView'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.ScrollView.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.ScrollView: ...
    @winrt_mixinmethod
    def get_Content(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_mixinmethod
    def put_Content(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView, value: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    @winrt_mixinmethod
    def get_CurrentAnchor(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_mixinmethod
    def get_ScrollPresenter(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView) -> win32more.Microsoft.UI.Xaml.Controls.Primitives.ScrollPresenter: ...
    @winrt_mixinmethod
    def get_ExpressionAnimationSources(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView) -> win32more.Microsoft.UI.Composition.CompositionPropertySet: ...
    @winrt_mixinmethod
    def get_HorizontalOffset(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView) -> Double: ...
    @winrt_mixinmethod
    def get_VerticalOffset(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView) -> Double: ...
    @winrt_mixinmethod
    def get_ZoomFactor(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView) -> Single: ...
    @winrt_mixinmethod
    def get_ExtentWidth(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView) -> Double: ...
    @winrt_mixinmethod
    def get_ExtentHeight(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView) -> Double: ...
    @winrt_mixinmethod
    def get_ViewportWidth(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView) -> Double: ...
    @winrt_mixinmethod
    def get_ViewportHeight(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView) -> Double: ...
    @winrt_mixinmethod
    def get_ScrollableWidth(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView) -> Double: ...
    @winrt_mixinmethod
    def get_ScrollableHeight(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView) -> Double: ...
    @winrt_mixinmethod
    def get_State(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView) -> win32more.Microsoft.UI.Xaml.Controls.ScrollingInteractionState: ...
    @winrt_mixinmethod
    def get_HorizontalScrollBarVisibility(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView) -> win32more.Microsoft.UI.Xaml.Controls.ScrollingScrollBarVisibility: ...
    @winrt_mixinmethod
    def put_HorizontalScrollBarVisibility(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView, value: win32more.Microsoft.UI.Xaml.Controls.ScrollingScrollBarVisibility) -> Void: ...
    @winrt_mixinmethod
    def get_VerticalScrollBarVisibility(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView) -> win32more.Microsoft.UI.Xaml.Controls.ScrollingScrollBarVisibility: ...
    @winrt_mixinmethod
    def put_VerticalScrollBarVisibility(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView, value: win32more.Microsoft.UI.Xaml.Controls.ScrollingScrollBarVisibility) -> Void: ...
    @winrt_mixinmethod
    def get_ContentOrientation(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView) -> win32more.Microsoft.UI.Xaml.Controls.ScrollingContentOrientation: ...
    @winrt_mixinmethod
    def put_ContentOrientation(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView, value: win32more.Microsoft.UI.Xaml.Controls.ScrollingContentOrientation) -> Void: ...
    @winrt_mixinmethod
    def get_HorizontalScrollChainMode(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView) -> win32more.Microsoft.UI.Xaml.Controls.ScrollingChainMode: ...
    @winrt_mixinmethod
    def put_HorizontalScrollChainMode(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView, value: win32more.Microsoft.UI.Xaml.Controls.ScrollingChainMode) -> Void: ...
    @winrt_mixinmethod
    def get_VerticalScrollChainMode(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView) -> win32more.Microsoft.UI.Xaml.Controls.ScrollingChainMode: ...
    @winrt_mixinmethod
    def put_VerticalScrollChainMode(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView, value: win32more.Microsoft.UI.Xaml.Controls.ScrollingChainMode) -> Void: ...
    @winrt_mixinmethod
    def get_HorizontalScrollRailMode(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView) -> win32more.Microsoft.UI.Xaml.Controls.ScrollingRailMode: ...
    @winrt_mixinmethod
    def put_HorizontalScrollRailMode(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView, value: win32more.Microsoft.UI.Xaml.Controls.ScrollingRailMode) -> Void: ...
    @winrt_mixinmethod
    def get_VerticalScrollRailMode(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView) -> win32more.Microsoft.UI.Xaml.Controls.ScrollingRailMode: ...
    @winrt_mixinmethod
    def put_VerticalScrollRailMode(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView, value: win32more.Microsoft.UI.Xaml.Controls.ScrollingRailMode) -> Void: ...
    @winrt_mixinmethod
    def get_HorizontalScrollMode(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView) -> win32more.Microsoft.UI.Xaml.Controls.ScrollingScrollMode: ...
    @winrt_mixinmethod
    def put_HorizontalScrollMode(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView, value: win32more.Microsoft.UI.Xaml.Controls.ScrollingScrollMode) -> Void: ...
    @winrt_mixinmethod
    def get_VerticalScrollMode(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView) -> win32more.Microsoft.UI.Xaml.Controls.ScrollingScrollMode: ...
    @winrt_mixinmethod
    def put_VerticalScrollMode(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView, value: win32more.Microsoft.UI.Xaml.Controls.ScrollingScrollMode) -> Void: ...
    @winrt_mixinmethod
    def get_ComputedHorizontalScrollBarVisibility(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView) -> win32more.Microsoft.UI.Xaml.Visibility: ...
    @winrt_mixinmethod
    def get_ComputedVerticalScrollBarVisibility(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView) -> win32more.Microsoft.UI.Xaml.Visibility: ...
    @winrt_mixinmethod
    def get_ComputedHorizontalScrollMode(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView) -> win32more.Microsoft.UI.Xaml.Controls.ScrollingScrollMode: ...
    @winrt_mixinmethod
    def get_ComputedVerticalScrollMode(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView) -> win32more.Microsoft.UI.Xaml.Controls.ScrollingScrollMode: ...
    @winrt_mixinmethod
    def get_ZoomChainMode(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView) -> win32more.Microsoft.UI.Xaml.Controls.ScrollingChainMode: ...
    @winrt_mixinmethod
    def put_ZoomChainMode(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView, value: win32more.Microsoft.UI.Xaml.Controls.ScrollingChainMode) -> Void: ...
    @winrt_mixinmethod
    def get_ZoomMode(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView) -> win32more.Microsoft.UI.Xaml.Controls.ScrollingZoomMode: ...
    @winrt_mixinmethod
    def put_ZoomMode(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView, value: win32more.Microsoft.UI.Xaml.Controls.ScrollingZoomMode) -> Void: ...
    @winrt_mixinmethod
    def get_IgnoredInputKinds(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView) -> win32more.Microsoft.UI.Xaml.Controls.ScrollingInputKinds: ...
    @winrt_mixinmethod
    def put_IgnoredInputKinds(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView, value: win32more.Microsoft.UI.Xaml.Controls.ScrollingInputKinds) -> Void: ...
    @winrt_mixinmethod
    def get_MinZoomFactor(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView) -> Double: ...
    @winrt_mixinmethod
    def put_MinZoomFactor(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_MaxZoomFactor(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView) -> Double: ...
    @winrt_mixinmethod
    def put_MaxZoomFactor(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_HorizontalAnchorRatio(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView) -> Double: ...
    @winrt_mixinmethod
    def put_HorizontalAnchorRatio(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_VerticalAnchorRatio(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView) -> Double: ...
    @winrt_mixinmethod
    def put_VerticalAnchorRatio(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView, value: Double) -> Void: ...
    @winrt_mixinmethod
    def RegisterAnchorCandidate(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView, element: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    @winrt_mixinmethod
    def UnregisterAnchorCandidate(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView, element: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    @winrt_mixinmethod
    def ScrollTo(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView, horizontalOffset: Double, verticalOffset: Double) -> Int32: ...
    @winrt_mixinmethod
    def ScrollToWithOptions(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView, horizontalOffset: Double, verticalOffset: Double, options: win32more.Microsoft.UI.Xaml.Controls.ScrollingScrollOptions) -> Int32: ...
    @winrt_mixinmethod
    def ScrollBy(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView, horizontalOffsetDelta: Double, verticalOffsetDelta: Double) -> Int32: ...
    @winrt_mixinmethod
    def ScrollByWithOptions(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView, horizontalOffsetDelta: Double, verticalOffsetDelta: Double, options: win32more.Microsoft.UI.Xaml.Controls.ScrollingScrollOptions) -> Int32: ...
    @winrt_mixinmethod
    def AddScrollVelocity(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView, offsetsVelocity: win32more.Windows.Foundation.Numerics.Vector2, inertiaDecayRate: win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.Numerics.Vector2]) -> Int32: ...
    @winrt_mixinmethod
    def ZoomTo(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView, zoomFactor: Single, centerPoint: win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.Numerics.Vector2]) -> Int32: ...
    @winrt_mixinmethod
    def ZoomToWithOptions(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView, zoomFactor: Single, centerPoint: win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.Numerics.Vector2], options: win32more.Microsoft.UI.Xaml.Controls.ScrollingZoomOptions) -> Int32: ...
    @winrt_mixinmethod
    def ZoomBy(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView, zoomFactorDelta: Single, centerPoint: win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.Numerics.Vector2]) -> Int32: ...
    @winrt_mixinmethod
    def ZoomByWithOptions(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView, zoomFactorDelta: Single, centerPoint: win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.Numerics.Vector2], options: win32more.Microsoft.UI.Xaml.Controls.ScrollingZoomOptions) -> Int32: ...
    @winrt_mixinmethod
    def AddZoomVelocity(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView, zoomFactorVelocity: Single, centerPoint: win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.Numerics.Vector2], inertiaDecayRate: win32more.Windows.Foundation.IReference[Single]) -> Int32: ...
    @winrt_mixinmethod
    def add_ExtentChanged(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.ScrollView, IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ExtentChanged(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_StateChanged(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.ScrollView, IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_StateChanged(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_ViewChanged(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.ScrollView, IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ViewChanged(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_ScrollAnimationStarting(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.ScrollView, win32more.Microsoft.UI.Xaml.Controls.ScrollingScrollAnimationStartingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ScrollAnimationStarting(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_ZoomAnimationStarting(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.ScrollView, win32more.Microsoft.UI.Xaml.Controls.ScrollingZoomAnimationStartingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ZoomAnimationStarting(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_ScrollCompleted(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.ScrollView, win32more.Microsoft.UI.Xaml.Controls.ScrollingScrollCompletedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ScrollCompleted(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_ZoomCompleted(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.ScrollView, win32more.Microsoft.UI.Xaml.Controls.ScrollingZoomCompletedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ZoomCompleted(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_BringingIntoView(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.ScrollView, win32more.Microsoft.UI.Xaml.Controls.ScrollingBringingIntoViewEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_BringingIntoView(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_AnchorRequested(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.ScrollView, win32more.Microsoft.UI.Xaml.Controls.ScrollingAnchorRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_AnchorRequested(self: win32more.Microsoft.UI.Xaml.Controls.IScrollView, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def get_ContentProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ScrollPresenterProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HorizontalScrollBarVisibilityProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_VerticalScrollBarVisibilityProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ContentOrientationProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HorizontalScrollChainModeProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_VerticalScrollChainModeProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HorizontalScrollRailModeProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_VerticalScrollRailModeProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HorizontalScrollModeProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_VerticalScrollModeProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ComputedHorizontalScrollBarVisibilityProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ComputedVerticalScrollBarVisibilityProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ComputedHorizontalScrollModeProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ComputedVerticalScrollModeProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ZoomChainModeProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ZoomModeProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IgnoredInputKindsProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MinZoomFactorProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MaxZoomFactorProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HorizontalAnchorRatioProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_VerticalAnchorRatioProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    ComputedHorizontalScrollBarVisibility = property(get_ComputedHorizontalScrollBarVisibility, None)
    ComputedHorizontalScrollMode = property(get_ComputedHorizontalScrollMode, None)
    ComputedVerticalScrollBarVisibility = property(get_ComputedVerticalScrollBarVisibility, None)
    ComputedVerticalScrollMode = property(get_ComputedVerticalScrollMode, None)
    Content = property(get_Content, put_Content)
    ContentOrientation = property(get_ContentOrientation, put_ContentOrientation)
    CurrentAnchor = property(get_CurrentAnchor, None)
    ExpressionAnimationSources = property(get_ExpressionAnimationSources, None)
    ExtentHeight = property(get_ExtentHeight, None)
    ExtentWidth = property(get_ExtentWidth, None)
    HorizontalAnchorRatio = property(get_HorizontalAnchorRatio, put_HorizontalAnchorRatio)
    HorizontalOffset = property(get_HorizontalOffset, None)
    HorizontalScrollBarVisibility = property(get_HorizontalScrollBarVisibility, put_HorizontalScrollBarVisibility)
    HorizontalScrollChainMode = property(get_HorizontalScrollChainMode, put_HorizontalScrollChainMode)
    HorizontalScrollMode = property(get_HorizontalScrollMode, put_HorizontalScrollMode)
    HorizontalScrollRailMode = property(get_HorizontalScrollRailMode, put_HorizontalScrollRailMode)
    IgnoredInputKinds = property(get_IgnoredInputKinds, put_IgnoredInputKinds)
    MaxZoomFactor = property(get_MaxZoomFactor, put_MaxZoomFactor)
    MinZoomFactor = property(get_MinZoomFactor, put_MinZoomFactor)
    ScrollPresenter = property(get_ScrollPresenter, None)
    ScrollableHeight = property(get_ScrollableHeight, None)
    ScrollableWidth = property(get_ScrollableWidth, None)
    State = property(get_State, None)
    VerticalAnchorRatio = property(get_VerticalAnchorRatio, put_VerticalAnchorRatio)
    VerticalOffset = property(get_VerticalOffset, None)
    VerticalScrollBarVisibility = property(get_VerticalScrollBarVisibility, put_VerticalScrollBarVisibility)
    VerticalScrollChainMode = property(get_VerticalScrollChainMode, put_VerticalScrollChainMode)
    VerticalScrollMode = property(get_VerticalScrollMode, put_VerticalScrollMode)
    VerticalScrollRailMode = property(get_VerticalScrollRailMode, put_VerticalScrollRailMode)
    ViewportHeight = property(get_ViewportHeight, None)
    ViewportWidth = property(get_ViewportWidth, None)
    ZoomChainMode = property(get_ZoomChainMode, put_ZoomChainMode)
    ZoomFactor = property(get_ZoomFactor, None)
    ZoomMode = property(get_ZoomMode, put_ZoomMode)
    _ScrollView_Meta_.ComputedHorizontalScrollBarVisibilityProperty = property(get_ComputedHorizontalScrollBarVisibilityProperty, None)
    _ScrollView_Meta_.ComputedHorizontalScrollModeProperty = property(get_ComputedHorizontalScrollModeProperty, None)
    _ScrollView_Meta_.ComputedVerticalScrollBarVisibilityProperty = property(get_ComputedVerticalScrollBarVisibilityProperty, None)
    _ScrollView_Meta_.ComputedVerticalScrollModeProperty = property(get_ComputedVerticalScrollModeProperty, None)
    _ScrollView_Meta_.ContentOrientationProperty = property(get_ContentOrientationProperty, None)
    _ScrollView_Meta_.ContentProperty = property(get_ContentProperty, None)
    _ScrollView_Meta_.HorizontalAnchorRatioProperty = property(get_HorizontalAnchorRatioProperty, None)
    _ScrollView_Meta_.HorizontalScrollBarVisibilityProperty = property(get_HorizontalScrollBarVisibilityProperty, None)
    _ScrollView_Meta_.HorizontalScrollChainModeProperty = property(get_HorizontalScrollChainModeProperty, None)
    _ScrollView_Meta_.HorizontalScrollModeProperty = property(get_HorizontalScrollModeProperty, None)
    _ScrollView_Meta_.HorizontalScrollRailModeProperty = property(get_HorizontalScrollRailModeProperty, None)
    _ScrollView_Meta_.IgnoredInputKindsProperty = property(get_IgnoredInputKindsProperty, None)
    _ScrollView_Meta_.MaxZoomFactorProperty = property(get_MaxZoomFactorProperty, None)
    _ScrollView_Meta_.MinZoomFactorProperty = property(get_MinZoomFactorProperty, None)
    _ScrollView_Meta_.ScrollPresenterProperty = property(get_ScrollPresenterProperty, None)
    _ScrollView_Meta_.VerticalAnchorRatioProperty = property(get_VerticalAnchorRatioProperty, None)
    _ScrollView_Meta_.VerticalScrollBarVisibilityProperty = property(get_VerticalScrollBarVisibilityProperty, None)
    _ScrollView_Meta_.VerticalScrollChainModeProperty = property(get_VerticalScrollChainModeProperty, None)
    _ScrollView_Meta_.VerticalScrollModeProperty = property(get_VerticalScrollModeProperty, None)
    _ScrollView_Meta_.VerticalScrollRailModeProperty = property(get_VerticalScrollRailModeProperty, None)
    _ScrollView_Meta_.ZoomChainModeProperty = property(get_ZoomChainModeProperty, None)
    _ScrollView_Meta_.ZoomModeProperty = property(get_ZoomModeProperty, None)
    AnchorRequested = event(add_AnchorRequested, remove_AnchorRequested)
    BringingIntoView = event(add_BringingIntoView, remove_BringingIntoView)
    ExtentChanged = event(add_ExtentChanged, remove_ExtentChanged)
    ScrollAnimationStarting = event(add_ScrollAnimationStarting, remove_ScrollAnimationStarting)
    ScrollCompleted = event(add_ScrollCompleted, remove_ScrollCompleted)
    StateChanged = event(add_StateChanged, remove_StateChanged)
    ViewChanged = event(add_ViewChanged, remove_ViewChanged)
    ZoomAnimationStarting = event(add_ZoomAnimationStarting, remove_ZoomAnimationStarting)
    ZoomCompleted = event(add_ZoomCompleted, remove_ZoomCompleted)
class _ScrollViewer_Meta_(ComPtr.__class__):
    pass
class ScrollViewer(ComPtr, metaclass=_ScrollViewer_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.ContentControl
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer
    _classid_ = 'Microsoft.UI.Xaml.Controls.ScrollViewer'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.ScrollViewer.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Controls.ScrollViewer: ...
    @winrt_mixinmethod
    def get_HorizontalScrollBarVisibility(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer) -> win32more.Microsoft.UI.Xaml.Controls.ScrollBarVisibility: ...
    @winrt_mixinmethod
    def put_HorizontalScrollBarVisibility(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer, value: win32more.Microsoft.UI.Xaml.Controls.ScrollBarVisibility) -> Void: ...
    @winrt_mixinmethod
    def get_VerticalScrollBarVisibility(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer) -> win32more.Microsoft.UI.Xaml.Controls.ScrollBarVisibility: ...
    @winrt_mixinmethod
    def put_VerticalScrollBarVisibility(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer, value: win32more.Microsoft.UI.Xaml.Controls.ScrollBarVisibility) -> Void: ...
    @winrt_mixinmethod
    def get_IsHorizontalRailEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsHorizontalRailEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsVerticalRailEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsVerticalRailEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsHorizontalScrollChainingEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsHorizontalScrollChainingEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsVerticalScrollChainingEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsVerticalScrollChainingEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsZoomChainingEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsZoomChainingEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsScrollInertiaEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsScrollInertiaEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsZoomInertiaEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsZoomInertiaEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_HorizontalScrollMode(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer) -> win32more.Microsoft.UI.Xaml.Controls.ScrollMode: ...
    @winrt_mixinmethod
    def put_HorizontalScrollMode(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer, value: win32more.Microsoft.UI.Xaml.Controls.ScrollMode) -> Void: ...
    @winrt_mixinmethod
    def get_VerticalScrollMode(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer) -> win32more.Microsoft.UI.Xaml.Controls.ScrollMode: ...
    @winrt_mixinmethod
    def put_VerticalScrollMode(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer, value: win32more.Microsoft.UI.Xaml.Controls.ScrollMode) -> Void: ...
    @winrt_mixinmethod
    def get_ZoomMode(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer) -> win32more.Microsoft.UI.Xaml.Controls.ZoomMode: ...
    @winrt_mixinmethod
    def put_ZoomMode(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer, value: win32more.Microsoft.UI.Xaml.Controls.ZoomMode) -> Void: ...
    @winrt_mixinmethod
    def get_HorizontalSnapPointsAlignment(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer) -> win32more.Microsoft.UI.Xaml.Controls.Primitives.SnapPointsAlignment: ...
    @winrt_mixinmethod
    def put_HorizontalSnapPointsAlignment(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer, value: win32more.Microsoft.UI.Xaml.Controls.Primitives.SnapPointsAlignment) -> Void: ...
    @winrt_mixinmethod
    def get_VerticalSnapPointsAlignment(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer) -> win32more.Microsoft.UI.Xaml.Controls.Primitives.SnapPointsAlignment: ...
    @winrt_mixinmethod
    def put_VerticalSnapPointsAlignment(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer, value: win32more.Microsoft.UI.Xaml.Controls.Primitives.SnapPointsAlignment) -> Void: ...
    @winrt_mixinmethod
    def get_HorizontalSnapPointsType(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer) -> win32more.Microsoft.UI.Xaml.Controls.SnapPointsType: ...
    @winrt_mixinmethod
    def put_HorizontalSnapPointsType(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer, value: win32more.Microsoft.UI.Xaml.Controls.SnapPointsType) -> Void: ...
    @winrt_mixinmethod
    def get_VerticalSnapPointsType(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer) -> win32more.Microsoft.UI.Xaml.Controls.SnapPointsType: ...
    @winrt_mixinmethod
    def put_VerticalSnapPointsType(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer, value: win32more.Microsoft.UI.Xaml.Controls.SnapPointsType) -> Void: ...
    @winrt_mixinmethod
    def get_ZoomSnapPointsType(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer) -> win32more.Microsoft.UI.Xaml.Controls.SnapPointsType: ...
    @winrt_mixinmethod
    def put_ZoomSnapPointsType(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer, value: win32more.Microsoft.UI.Xaml.Controls.SnapPointsType) -> Void: ...
    @winrt_mixinmethod
    def get_HorizontalOffset(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer) -> Double: ...
    @winrt_mixinmethod
    def get_ViewportWidth(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer) -> Double: ...
    @winrt_mixinmethod
    def get_ScrollableWidth(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer) -> Double: ...
    @winrt_mixinmethod
    def get_ComputedHorizontalScrollBarVisibility(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer) -> win32more.Microsoft.UI.Xaml.Visibility: ...
    @winrt_mixinmethod
    def get_ExtentWidth(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer) -> Double: ...
    @winrt_mixinmethod
    def get_VerticalOffset(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer) -> Double: ...
    @winrt_mixinmethod
    def get_ViewportHeight(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer) -> Double: ...
    @winrt_mixinmethod
    def get_ScrollableHeight(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer) -> Double: ...
    @winrt_mixinmethod
    def get_ComputedVerticalScrollBarVisibility(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer) -> win32more.Microsoft.UI.Xaml.Visibility: ...
    @winrt_mixinmethod
    def get_ExtentHeight(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer) -> Double: ...
    @winrt_mixinmethod
    def get_MinZoomFactor(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer) -> Single: ...
    @winrt_mixinmethod
    def put_MinZoomFactor(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer, value: Single) -> Void: ...
    @winrt_mixinmethod
    def get_MaxZoomFactor(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer) -> Single: ...
    @winrt_mixinmethod
    def put_MaxZoomFactor(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer, value: Single) -> Void: ...
    @winrt_mixinmethod
    def get_ZoomFactor(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer) -> Single: ...
    @winrt_mixinmethod
    def get_ZoomSnapPoints(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer) -> win32more.Windows.Foundation.Collections.IVector[Single]: ...
    @winrt_mixinmethod
    def get_TopLeftHeader(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_mixinmethod
    def put_TopLeftHeader(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer, value: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    @winrt_mixinmethod
    def get_LeftHeader(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_mixinmethod
    def put_LeftHeader(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer, value: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    @winrt_mixinmethod
    def get_TopHeader(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_mixinmethod
    def put_TopHeader(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer, value: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    @winrt_mixinmethod
    def get_ReduceViewportForCoreInputViewOcclusions(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer) -> Boolean: ...
    @winrt_mixinmethod
    def put_ReduceViewportForCoreInputViewOcclusions(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_HorizontalAnchorRatio(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer) -> Double: ...
    @winrt_mixinmethod
    def put_HorizontalAnchorRatio(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_VerticalAnchorRatio(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer) -> Double: ...
    @winrt_mixinmethod
    def put_VerticalAnchorRatio(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_CanContentRenderOutsideBounds(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer) -> Boolean: ...
    @winrt_mixinmethod
    def put_CanContentRenderOutsideBounds(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def add_AnchorRequested(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.ScrollViewer, win32more.Microsoft.UI.Xaml.Controls.AnchorRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_AnchorRequested(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_ViewChanging(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer, handler: win32more.Windows.Foundation.EventHandler[win32more.Microsoft.UI.Xaml.Controls.ScrollViewerViewChangingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ViewChanging(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_ViewChanged(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer, handler: win32more.Windows.Foundation.EventHandler[win32more.Microsoft.UI.Xaml.Controls.ScrollViewerViewChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ViewChanged(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_DirectManipulationStarted(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer, handler: win32more.Windows.Foundation.EventHandler[IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_DirectManipulationStarted(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_DirectManipulationCompleted(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer, handler: win32more.Windows.Foundation.EventHandler[IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_DirectManipulationCompleted(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def ScrollToHorizontalOffset(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer, offset: Double) -> Void: ...
    @winrt_mixinmethod
    def ScrollToVerticalOffset(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer, offset: Double) -> Void: ...
    @winrt_mixinmethod
    def ZoomToFactor(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer, factor: Single) -> Void: ...
    @winrt_mixinmethod
    def ChangeView(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer, horizontalOffset: win32more.Windows.Foundation.IReference[Double], verticalOffset: win32more.Windows.Foundation.IReference[Double], zoomFactor: win32more.Windows.Foundation.IReference[Single]) -> Boolean: ...
    @winrt_mixinmethod
    def ChangeViewWithOptionalAnimation(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer, horizontalOffset: win32more.Windows.Foundation.IReference[Double], verticalOffset: win32more.Windows.Foundation.IReference[Double], zoomFactor: win32more.Windows.Foundation.IReference[Single], disableAnimation: Boolean) -> Boolean: ...
    @winrt_mixinmethod
    def InvalidateScrollInfo(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer) -> Void: ...
    @winrt_mixinmethod
    def get_IsDeferredScrollingEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsDeferredScrollingEnabled(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_BringIntoViewOnFocusChange(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer) -> Boolean: ...
    @winrt_mixinmethod
    def put_BringIntoViewOnFocusChange(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewer, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_CurrentAnchor(self: win32more.Microsoft.UI.Xaml.Controls.IScrollAnchorProvider) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_mixinmethod
    def RegisterAnchorCandidate(self: win32more.Microsoft.UI.Xaml.Controls.IScrollAnchorProvider, element: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    @winrt_mixinmethod
    def UnregisterAnchorCandidate(self: win32more.Microsoft.UI.Xaml.Controls.IScrollAnchorProvider, element: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    @winrt_classmethod
    def get_HorizontalSnapPointsAlignmentProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_VerticalSnapPointsAlignmentProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HorizontalSnapPointsTypeProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_VerticalSnapPointsTypeProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ZoomSnapPointsTypeProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HorizontalOffsetProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ViewportWidthProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ScrollableWidthProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ComputedHorizontalScrollBarVisibilityProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ExtentWidthProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_VerticalOffsetProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ViewportHeightProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ScrollableHeightProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ComputedVerticalScrollBarVisibilityProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ExtentHeightProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MinZoomFactorProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MaxZoomFactorProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ZoomFactorProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ZoomSnapPointsProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TopLeftHeaderProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_LeftHeaderProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TopHeaderProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ReduceViewportForCoreInputViewOcclusionsProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HorizontalAnchorRatioProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_VerticalAnchorRatioProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HorizontalScrollBarVisibilityProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetHorizontalScrollBarVisibility(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> win32more.Microsoft.UI.Xaml.Controls.ScrollBarVisibility: ...
    @winrt_classmethod
    def SetHorizontalScrollBarVisibility(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject, horizontalScrollBarVisibility: win32more.Microsoft.UI.Xaml.Controls.ScrollBarVisibility) -> Void: ...
    @winrt_classmethod
    def get_VerticalScrollBarVisibilityProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetVerticalScrollBarVisibility(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> win32more.Microsoft.UI.Xaml.Controls.ScrollBarVisibility: ...
    @winrt_classmethod
    def SetVerticalScrollBarVisibility(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject, verticalScrollBarVisibility: win32more.Microsoft.UI.Xaml.Controls.ScrollBarVisibility) -> Void: ...
    @winrt_classmethod
    def get_IsHorizontalRailEnabledProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetIsHorizontalRailEnabled(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_classmethod
    def SetIsHorizontalRailEnabled(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject, isHorizontalRailEnabled: Boolean) -> Void: ...
    @winrt_classmethod
    def get_IsVerticalRailEnabledProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetIsVerticalRailEnabled(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_classmethod
    def SetIsVerticalRailEnabled(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject, isVerticalRailEnabled: Boolean) -> Void: ...
    @winrt_classmethod
    def get_IsHorizontalScrollChainingEnabledProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetIsHorizontalScrollChainingEnabled(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_classmethod
    def SetIsHorizontalScrollChainingEnabled(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject, isHorizontalScrollChainingEnabled: Boolean) -> Void: ...
    @winrt_classmethod
    def get_IsVerticalScrollChainingEnabledProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetIsVerticalScrollChainingEnabled(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_classmethod
    def SetIsVerticalScrollChainingEnabled(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject, isVerticalScrollChainingEnabled: Boolean) -> Void: ...
    @winrt_classmethod
    def get_IsZoomChainingEnabledProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetIsZoomChainingEnabled(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_classmethod
    def SetIsZoomChainingEnabled(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject, isZoomChainingEnabled: Boolean) -> Void: ...
    @winrt_classmethod
    def get_IsScrollInertiaEnabledProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetIsScrollInertiaEnabled(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_classmethod
    def SetIsScrollInertiaEnabled(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject, isScrollInertiaEnabled: Boolean) -> Void: ...
    @winrt_classmethod
    def get_IsZoomInertiaEnabledProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetIsZoomInertiaEnabled(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_classmethod
    def SetIsZoomInertiaEnabled(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject, isZoomInertiaEnabled: Boolean) -> Void: ...
    @winrt_classmethod
    def get_HorizontalScrollModeProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetHorizontalScrollMode(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> win32more.Microsoft.UI.Xaml.Controls.ScrollMode: ...
    @winrt_classmethod
    def SetHorizontalScrollMode(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject, horizontalScrollMode: win32more.Microsoft.UI.Xaml.Controls.ScrollMode) -> Void: ...
    @winrt_classmethod
    def get_VerticalScrollModeProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetVerticalScrollMode(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> win32more.Microsoft.UI.Xaml.Controls.ScrollMode: ...
    @winrt_classmethod
    def SetVerticalScrollMode(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject, verticalScrollMode: win32more.Microsoft.UI.Xaml.Controls.ScrollMode) -> Void: ...
    @winrt_classmethod
    def get_ZoomModeProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetZoomMode(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> win32more.Microsoft.UI.Xaml.Controls.ZoomMode: ...
    @winrt_classmethod
    def SetZoomMode(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject, zoomMode: win32more.Microsoft.UI.Xaml.Controls.ZoomMode) -> Void: ...
    @winrt_classmethod
    def get_CanContentRenderOutsideBoundsProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetCanContentRenderOutsideBounds(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_classmethod
    def SetCanContentRenderOutsideBounds(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject, canContentRenderOutsideBounds: Boolean) -> Void: ...
    @winrt_classmethod
    def get_IsDeferredScrollingEnabledProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetIsDeferredScrollingEnabled(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_classmethod
    def SetIsDeferredScrollingEnabled(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject, isDeferredScrollingEnabled: Boolean) -> Void: ...
    @winrt_classmethod
    def get_BringIntoViewOnFocusChangeProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetBringIntoViewOnFocusChange(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    @winrt_classmethod
    def SetBringIntoViewOnFocusChange(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject, bringIntoViewOnFocusChange: Boolean) -> Void: ...
    BringIntoViewOnFocusChange = property(get_BringIntoViewOnFocusChange, put_BringIntoViewOnFocusChange)
    CanContentRenderOutsideBounds = property(get_CanContentRenderOutsideBounds, put_CanContentRenderOutsideBounds)
    ComputedHorizontalScrollBarVisibility = property(get_ComputedHorizontalScrollBarVisibility, None)
    ComputedVerticalScrollBarVisibility = property(get_ComputedVerticalScrollBarVisibility, None)
    CurrentAnchor = property(get_CurrentAnchor, None)
    ExtentHeight = property(get_ExtentHeight, None)
    ExtentWidth = property(get_ExtentWidth, None)
    HorizontalAnchorRatio = property(get_HorizontalAnchorRatio, put_HorizontalAnchorRatio)
    HorizontalOffset = property(get_HorizontalOffset, None)
    HorizontalScrollBarVisibility = property(get_HorizontalScrollBarVisibility, put_HorizontalScrollBarVisibility)
    HorizontalScrollMode = property(get_HorizontalScrollMode, put_HorizontalScrollMode)
    HorizontalSnapPointsAlignment = property(get_HorizontalSnapPointsAlignment, put_HorizontalSnapPointsAlignment)
    HorizontalSnapPointsType = property(get_HorizontalSnapPointsType, put_HorizontalSnapPointsType)
    IsDeferredScrollingEnabled = property(get_IsDeferredScrollingEnabled, put_IsDeferredScrollingEnabled)
    IsHorizontalRailEnabled = property(get_IsHorizontalRailEnabled, put_IsHorizontalRailEnabled)
    IsHorizontalScrollChainingEnabled = property(get_IsHorizontalScrollChainingEnabled, put_IsHorizontalScrollChainingEnabled)
    IsScrollInertiaEnabled = property(get_IsScrollInertiaEnabled, put_IsScrollInertiaEnabled)
    IsVerticalRailEnabled = property(get_IsVerticalRailEnabled, put_IsVerticalRailEnabled)
    IsVerticalScrollChainingEnabled = property(get_IsVerticalScrollChainingEnabled, put_IsVerticalScrollChainingEnabled)
    IsZoomChainingEnabled = property(get_IsZoomChainingEnabled, put_IsZoomChainingEnabled)
    IsZoomInertiaEnabled = property(get_IsZoomInertiaEnabled, put_IsZoomInertiaEnabled)
    LeftHeader = property(get_LeftHeader, put_LeftHeader)
    MaxZoomFactor = property(get_MaxZoomFactor, put_MaxZoomFactor)
    MinZoomFactor = property(get_MinZoomFactor, put_MinZoomFactor)
    ReduceViewportForCoreInputViewOcclusions = property(get_ReduceViewportForCoreInputViewOcclusions, put_ReduceViewportForCoreInputViewOcclusions)
    ScrollableHeight = property(get_ScrollableHeight, None)
    ScrollableWidth = property(get_ScrollableWidth, None)
    TopHeader = property(get_TopHeader, put_TopHeader)
    TopLeftHeader = property(get_TopLeftHeader, put_TopLeftHeader)
    VerticalAnchorRatio = property(get_VerticalAnchorRatio, put_VerticalAnchorRatio)
    VerticalOffset = property(get_VerticalOffset, None)
    VerticalScrollBarVisibility = property(get_VerticalScrollBarVisibility, put_VerticalScrollBarVisibility)
    VerticalScrollMode = property(get_VerticalScrollMode, put_VerticalScrollMode)
    VerticalSnapPointsAlignment = property(get_VerticalSnapPointsAlignment, put_VerticalSnapPointsAlignment)
    VerticalSnapPointsType = property(get_VerticalSnapPointsType, put_VerticalSnapPointsType)
    ViewportHeight = property(get_ViewportHeight, None)
    ViewportWidth = property(get_ViewportWidth, None)
    ZoomFactor = property(get_ZoomFactor, None)
    ZoomMode = property(get_ZoomMode, put_ZoomMode)
    ZoomSnapPoints = property(get_ZoomSnapPoints, None)
    ZoomSnapPointsType = property(get_ZoomSnapPointsType, put_ZoomSnapPointsType)
    _ScrollViewer_Meta_.BringIntoViewOnFocusChangeProperty = property(get_BringIntoViewOnFocusChangeProperty, None)
    _ScrollViewer_Meta_.CanContentRenderOutsideBoundsProperty = property(get_CanContentRenderOutsideBoundsProperty, None)
    _ScrollViewer_Meta_.ComputedHorizontalScrollBarVisibilityProperty = property(get_ComputedHorizontalScrollBarVisibilityProperty, None)
    _ScrollViewer_Meta_.ComputedVerticalScrollBarVisibilityProperty = property(get_ComputedVerticalScrollBarVisibilityProperty, None)
    _ScrollViewer_Meta_.ExtentHeightProperty = property(get_ExtentHeightProperty, None)
    _ScrollViewer_Meta_.ExtentWidthProperty = property(get_ExtentWidthProperty, None)
    _ScrollViewer_Meta_.HorizontalAnchorRatioProperty = property(get_HorizontalAnchorRatioProperty, None)
    _ScrollViewer_Meta_.HorizontalOffsetProperty = property(get_HorizontalOffsetProperty, None)
    _ScrollViewer_Meta_.HorizontalScrollBarVisibilityProperty = property(get_HorizontalScrollBarVisibilityProperty, None)
    _ScrollViewer_Meta_.HorizontalScrollModeProperty = property(get_HorizontalScrollModeProperty, None)
    _ScrollViewer_Meta_.HorizontalSnapPointsAlignmentProperty = property(get_HorizontalSnapPointsAlignmentProperty, None)
    _ScrollViewer_Meta_.HorizontalSnapPointsTypeProperty = property(get_HorizontalSnapPointsTypeProperty, None)
    _ScrollViewer_Meta_.IsDeferredScrollingEnabledProperty = property(get_IsDeferredScrollingEnabledProperty, None)
    _ScrollViewer_Meta_.IsHorizontalRailEnabledProperty = property(get_IsHorizontalRailEnabledProperty, None)
    _ScrollViewer_Meta_.IsHorizontalScrollChainingEnabledProperty = property(get_IsHorizontalScrollChainingEnabledProperty, None)
    _ScrollViewer_Meta_.IsScrollInertiaEnabledProperty = property(get_IsScrollInertiaEnabledProperty, None)
    _ScrollViewer_Meta_.IsVerticalRailEnabledProperty = property(get_IsVerticalRailEnabledProperty, None)
    _ScrollViewer_Meta_.IsVerticalScrollChainingEnabledProperty = property(get_IsVerticalScrollChainingEnabledProperty, None)
    _ScrollViewer_Meta_.IsZoomChainingEnabledProperty = property(get_IsZoomChainingEnabledProperty, None)
    _ScrollViewer_Meta_.IsZoomInertiaEnabledProperty = property(get_IsZoomInertiaEnabledProperty, None)
    _ScrollViewer_Meta_.LeftHeaderProperty = property(get_LeftHeaderProperty, None)
    _ScrollViewer_Meta_.MaxZoomFactorProperty = property(get_MaxZoomFactorProperty, None)
    _ScrollViewer_Meta_.MinZoomFactorProperty = property(get_MinZoomFactorProperty, None)
    _ScrollViewer_Meta_.ReduceViewportForCoreInputViewOcclusionsProperty = property(get_ReduceViewportForCoreInputViewOcclusionsProperty, None)
    _ScrollViewer_Meta_.ScrollableHeightProperty = property(get_ScrollableHeightProperty, None)
    _ScrollViewer_Meta_.ScrollableWidthProperty = property(get_ScrollableWidthProperty, None)
    _ScrollViewer_Meta_.TopHeaderProperty = property(get_TopHeaderProperty, None)
    _ScrollViewer_Meta_.TopLeftHeaderProperty = property(get_TopLeftHeaderProperty, None)
    _ScrollViewer_Meta_.VerticalAnchorRatioProperty = property(get_VerticalAnchorRatioProperty, None)
    _ScrollViewer_Meta_.VerticalOffsetProperty = property(get_VerticalOffsetProperty, None)
    _ScrollViewer_Meta_.VerticalScrollBarVisibilityProperty = property(get_VerticalScrollBarVisibilityProperty, None)
    _ScrollViewer_Meta_.VerticalScrollModeProperty = property(get_VerticalScrollModeProperty, None)
    _ScrollViewer_Meta_.VerticalSnapPointsAlignmentProperty = property(get_VerticalSnapPointsAlignmentProperty, None)
    _ScrollViewer_Meta_.VerticalSnapPointsTypeProperty = property(get_VerticalSnapPointsTypeProperty, None)
    _ScrollViewer_Meta_.ViewportHeightProperty = property(get_ViewportHeightProperty, None)
    _ScrollViewer_Meta_.ViewportWidthProperty = property(get_ViewportWidthProperty, None)
    _ScrollViewer_Meta_.ZoomFactorProperty = property(get_ZoomFactorProperty, None)
    _ScrollViewer_Meta_.ZoomModeProperty = property(get_ZoomModeProperty, None)
    _ScrollViewer_Meta_.ZoomSnapPointsProperty = property(get_ZoomSnapPointsProperty, None)
    _ScrollViewer_Meta_.ZoomSnapPointsTypeProperty = property(get_ZoomSnapPointsTypeProperty, None)
    AnchorRequested = event(add_AnchorRequested, remove_AnchorRequested)
    DirectManipulationCompleted = event(add_DirectManipulationCompleted, remove_DirectManipulationCompleted)
    DirectManipulationStarted = event(add_DirectManipulationStarted, remove_DirectManipulationStarted)
    ViewChanged = event(add_ViewChanged, remove_ViewChanged)
    ViewChanging = event(add_ViewChanging, remove_ViewChanging)
class ScrollViewerView(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerView
    _classid_ = 'Microsoft.UI.Xaml.Controls.ScrollViewerView'
    @winrt_mixinmethod
    def get_HorizontalOffset(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerView) -> Double: ...
    @winrt_mixinmethod
    def get_VerticalOffset(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerView) -> Double: ...
    @winrt_mixinmethod
    def get_ZoomFactor(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerView) -> Single: ...
    HorizontalOffset = property(get_HorizontalOffset, None)
    VerticalOffset = property(get_VerticalOffset, None)
    ZoomFactor = property(get_ZoomFactor, None)
class ScrollViewerViewChangedEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerViewChangedEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.ScrollViewerViewChangedEventArgs'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.ScrollViewerViewChangedEventArgs.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Controls.ScrollViewerViewChangedEventArgs: ...
    @winrt_mixinmethod
    def get_IsIntermediate(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerViewChangedEventArgs) -> Boolean: ...
    IsIntermediate = property(get_IsIntermediate, None)
class ScrollViewerViewChangingEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerViewChangingEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.ScrollViewerViewChangingEventArgs'
    @winrt_mixinmethod
    def get_NextView(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerViewChangingEventArgs) -> win32more.Microsoft.UI.Xaml.Controls.ScrollViewerView: ...
    @winrt_mixinmethod
    def get_FinalView(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerViewChangingEventArgs) -> win32more.Microsoft.UI.Xaml.Controls.ScrollViewerView: ...
    @winrt_mixinmethod
    def get_IsInertial(self: win32more.Microsoft.UI.Xaml.Controls.IScrollViewerViewChangingEventArgs) -> Boolean: ...
    FinalView = property(get_FinalView, None)
    IsInertial = property(get_IsInertial, None)
    NextView = property(get_NextView, None)
class ScrollingAnchorRequestedEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IScrollingAnchorRequestedEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.ScrollingAnchorRequestedEventArgs'
    @winrt_mixinmethod
    def get_AnchorCandidates(self: win32more.Microsoft.UI.Xaml.Controls.IScrollingAnchorRequestedEventArgs) -> win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.UIElement]: ...
    @winrt_mixinmethod
    def get_AnchorElement(self: win32more.Microsoft.UI.Xaml.Controls.IScrollingAnchorRequestedEventArgs) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_mixinmethod
    def put_AnchorElement(self: win32more.Microsoft.UI.Xaml.Controls.IScrollingAnchorRequestedEventArgs, value: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    AnchorCandidates = property(get_AnchorCandidates, None)
    AnchorElement = property(get_AnchorElement, put_AnchorElement)
class ScrollingAnimationMode(Enum, Int32):
    Disabled = 0
    Enabled = 1
    Auto = 2
class ScrollingBringingIntoViewEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IScrollingBringingIntoViewEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.ScrollingBringingIntoViewEventArgs'
    @winrt_mixinmethod
    def get_SnapPointsMode(self: win32more.Microsoft.UI.Xaml.Controls.IScrollingBringingIntoViewEventArgs) -> win32more.Microsoft.UI.Xaml.Controls.ScrollingSnapPointsMode: ...
    @winrt_mixinmethod
    def put_SnapPointsMode(self: win32more.Microsoft.UI.Xaml.Controls.IScrollingBringingIntoViewEventArgs, value: win32more.Microsoft.UI.Xaml.Controls.ScrollingSnapPointsMode) -> Void: ...
    @winrt_mixinmethod
    def get_RequestEventArgs(self: win32more.Microsoft.UI.Xaml.Controls.IScrollingBringingIntoViewEventArgs) -> win32more.Microsoft.UI.Xaml.BringIntoViewRequestedEventArgs: ...
    @winrt_mixinmethod
    def get_TargetHorizontalOffset(self: win32more.Microsoft.UI.Xaml.Controls.IScrollingBringingIntoViewEventArgs) -> Double: ...
    @winrt_mixinmethod
    def get_TargetVerticalOffset(self: win32more.Microsoft.UI.Xaml.Controls.IScrollingBringingIntoViewEventArgs) -> Double: ...
    @winrt_mixinmethod
    def get_CorrelationId(self: win32more.Microsoft.UI.Xaml.Controls.IScrollingBringingIntoViewEventArgs) -> Int32: ...
    @winrt_mixinmethod
    def get_Cancel(self: win32more.Microsoft.UI.Xaml.Controls.IScrollingBringingIntoViewEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def put_Cancel(self: win32more.Microsoft.UI.Xaml.Controls.IScrollingBringingIntoViewEventArgs, value: Boolean) -> Void: ...
    Cancel = property(get_Cancel, put_Cancel)
    CorrelationId = property(get_CorrelationId, None)
    RequestEventArgs = property(get_RequestEventArgs, None)
    SnapPointsMode = property(get_SnapPointsMode, put_SnapPointsMode)
    TargetHorizontalOffset = property(get_TargetHorizontalOffset, None)
    TargetVerticalOffset = property(get_TargetVerticalOffset, None)
class ScrollingChainMode(Enum, Int32):
    Auto = 0
    Always = 1
    Never = 2
class ScrollingContentOrientation(Enum, Int32):
    Vertical = 0
    Horizontal = 1
    None_ = 2
    Both = 3
class ScrollingInputKinds(Enum, UInt32):
    None_ = 0
    Touch = 1
    Pen = 2
    MouseWheel = 4
    Keyboard = 8
    Gamepad = 16
    All = 255
class ScrollingInteractionState(Enum, Int32):
    Idle = 0
    Interaction = 1
    Inertia = 2
    Animation = 3
class ScrollingRailMode(Enum, Int32):
    Enabled = 0
    Disabled = 1
class ScrollingScrollAnimationStartingEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IScrollingScrollAnimationStartingEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.ScrollingScrollAnimationStartingEventArgs'
    @winrt_mixinmethod
    def get_Animation(self: win32more.Microsoft.UI.Xaml.Controls.IScrollingScrollAnimationStartingEventArgs) -> win32more.Microsoft.UI.Composition.CompositionAnimation: ...
    @winrt_mixinmethod
    def put_Animation(self: win32more.Microsoft.UI.Xaml.Controls.IScrollingScrollAnimationStartingEventArgs, value: win32more.Microsoft.UI.Composition.CompositionAnimation) -> Void: ...
    @winrt_mixinmethod
    def get_StartPosition(self: win32more.Microsoft.UI.Xaml.Controls.IScrollingScrollAnimationStartingEventArgs) -> win32more.Windows.Foundation.Numerics.Vector2: ...
    @winrt_mixinmethod
    def get_EndPosition(self: win32more.Microsoft.UI.Xaml.Controls.IScrollingScrollAnimationStartingEventArgs) -> win32more.Windows.Foundation.Numerics.Vector2: ...
    @winrt_mixinmethod
    def get_CorrelationId(self: win32more.Microsoft.UI.Xaml.Controls.IScrollingScrollAnimationStartingEventArgs) -> Int32: ...
    Animation = property(get_Animation, put_Animation)
    CorrelationId = property(get_CorrelationId, None)
    EndPosition = property(get_EndPosition, None)
    StartPosition = property(get_StartPosition, None)
class ScrollingScrollBarVisibility(Enum, Int32):
    Auto = 0
    Visible = 1
    Hidden = 2
class ScrollingScrollCompletedEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IScrollingScrollCompletedEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.ScrollingScrollCompletedEventArgs'
    @winrt_mixinmethod
    def get_CorrelationId(self: win32more.Microsoft.UI.Xaml.Controls.IScrollingScrollCompletedEventArgs) -> Int32: ...
    CorrelationId = property(get_CorrelationId, None)
class ScrollingScrollMode(Enum, Int32):
    Enabled = 0
    Disabled = 1
    Auto = 2
class ScrollingScrollOptions(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IScrollingScrollOptions
    _classid_ = 'Microsoft.UI.Xaml.Controls.ScrollingScrollOptions'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 1:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.ScrollingScrollOptions.CreateInstance(*args, None, None))
        elif len(args) == 2:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.ScrollingScrollOptions.CreateInstance2(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollingScrollOptionsFactory, animationMode: win32more.Microsoft.UI.Xaml.Controls.ScrollingAnimationMode, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.ScrollingScrollOptions: ...
    @winrt_factorymethod
    def CreateInstance2(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollingScrollOptionsFactory, animationMode: win32more.Microsoft.UI.Xaml.Controls.ScrollingAnimationMode, snapPointsMode: win32more.Microsoft.UI.Xaml.Controls.ScrollingSnapPointsMode, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.ScrollingScrollOptions: ...
    @winrt_mixinmethod
    def get_AnimationMode(self: win32more.Microsoft.UI.Xaml.Controls.IScrollingScrollOptions) -> win32more.Microsoft.UI.Xaml.Controls.ScrollingAnimationMode: ...
    @winrt_mixinmethod
    def put_AnimationMode(self: win32more.Microsoft.UI.Xaml.Controls.IScrollingScrollOptions, value: win32more.Microsoft.UI.Xaml.Controls.ScrollingAnimationMode) -> Void: ...
    @winrt_mixinmethod
    def get_SnapPointsMode(self: win32more.Microsoft.UI.Xaml.Controls.IScrollingScrollOptions) -> win32more.Microsoft.UI.Xaml.Controls.ScrollingSnapPointsMode: ...
    @winrt_mixinmethod
    def put_SnapPointsMode(self: win32more.Microsoft.UI.Xaml.Controls.IScrollingScrollOptions, value: win32more.Microsoft.UI.Xaml.Controls.ScrollingSnapPointsMode) -> Void: ...
    AnimationMode = property(get_AnimationMode, put_AnimationMode)
    SnapPointsMode = property(get_SnapPointsMode, put_SnapPointsMode)
class ScrollingSnapPointsMode(Enum, Int32):
    Default = 0
    Ignore = 1
class ScrollingZoomAnimationStartingEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IScrollingZoomAnimationStartingEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.ScrollingZoomAnimationStartingEventArgs'
    @winrt_mixinmethod
    def get_CenterPoint(self: win32more.Microsoft.UI.Xaml.Controls.IScrollingZoomAnimationStartingEventArgs) -> win32more.Windows.Foundation.Numerics.Vector2: ...
    @winrt_mixinmethod
    def get_StartZoomFactor(self: win32more.Microsoft.UI.Xaml.Controls.IScrollingZoomAnimationStartingEventArgs) -> Single: ...
    @winrt_mixinmethod
    def get_EndZoomFactor(self: win32more.Microsoft.UI.Xaml.Controls.IScrollingZoomAnimationStartingEventArgs) -> Single: ...
    @winrt_mixinmethod
    def get_Animation(self: win32more.Microsoft.UI.Xaml.Controls.IScrollingZoomAnimationStartingEventArgs) -> win32more.Microsoft.UI.Composition.CompositionAnimation: ...
    @winrt_mixinmethod
    def put_Animation(self: win32more.Microsoft.UI.Xaml.Controls.IScrollingZoomAnimationStartingEventArgs, value: win32more.Microsoft.UI.Composition.CompositionAnimation) -> Void: ...
    @winrt_mixinmethod
    def get_CorrelationId(self: win32more.Microsoft.UI.Xaml.Controls.IScrollingZoomAnimationStartingEventArgs) -> Int32: ...
    Animation = property(get_Animation, put_Animation)
    CenterPoint = property(get_CenterPoint, None)
    CorrelationId = property(get_CorrelationId, None)
    EndZoomFactor = property(get_EndZoomFactor, None)
    StartZoomFactor = property(get_StartZoomFactor, None)
class ScrollingZoomCompletedEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IScrollingZoomCompletedEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.ScrollingZoomCompletedEventArgs'
    @winrt_mixinmethod
    def get_CorrelationId(self: win32more.Microsoft.UI.Xaml.Controls.IScrollingZoomCompletedEventArgs) -> Int32: ...
    CorrelationId = property(get_CorrelationId, None)
class ScrollingZoomMode(Enum, Int32):
    Enabled = 0
    Disabled = 1
class ScrollingZoomOptions(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IScrollingZoomOptions
    _classid_ = 'Microsoft.UI.Xaml.Controls.ScrollingZoomOptions'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 1:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.ScrollingZoomOptions.CreateInstance(*args, None, None))
        elif len(args) == 2:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.ScrollingZoomOptions.CreateInstance2(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollingZoomOptionsFactory, animationMode: win32more.Microsoft.UI.Xaml.Controls.ScrollingAnimationMode, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.ScrollingZoomOptions: ...
    @winrt_factorymethod
    def CreateInstance2(cls: win32more.Microsoft.UI.Xaml.Controls.IScrollingZoomOptionsFactory, animationMode: win32more.Microsoft.UI.Xaml.Controls.ScrollingAnimationMode, snapPointsMode: win32more.Microsoft.UI.Xaml.Controls.ScrollingSnapPointsMode, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.ScrollingZoomOptions: ...
    @winrt_mixinmethod
    def get_AnimationMode(self: win32more.Microsoft.UI.Xaml.Controls.IScrollingZoomOptions) -> win32more.Microsoft.UI.Xaml.Controls.ScrollingAnimationMode: ...
    @winrt_mixinmethod
    def put_AnimationMode(self: win32more.Microsoft.UI.Xaml.Controls.IScrollingZoomOptions, value: win32more.Microsoft.UI.Xaml.Controls.ScrollingAnimationMode) -> Void: ...
    @winrt_mixinmethod
    def get_SnapPointsMode(self: win32more.Microsoft.UI.Xaml.Controls.IScrollingZoomOptions) -> win32more.Microsoft.UI.Xaml.Controls.ScrollingSnapPointsMode: ...
    @winrt_mixinmethod
    def put_SnapPointsMode(self: win32more.Microsoft.UI.Xaml.Controls.IScrollingZoomOptions, value: win32more.Microsoft.UI.Xaml.Controls.ScrollingSnapPointsMode) -> Void: ...
    AnimationMode = property(get_AnimationMode, put_AnimationMode)
    SnapPointsMode = property(get_SnapPointsMode, put_SnapPointsMode)
class SectionsInViewChangedEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ISectionsInViewChangedEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.SectionsInViewChangedEventArgs'
    @winrt_mixinmethod
    def get_AddedSections(self: win32more.Microsoft.UI.Xaml.Controls.ISectionsInViewChangedEventArgs) -> win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.HubSection]: ...
    @winrt_mixinmethod
    def get_RemovedSections(self: win32more.Microsoft.UI.Xaml.Controls.ISectionsInViewChangedEventArgs) -> win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.HubSection]: ...
    AddedSections = property(get_AddedSections, None)
    RemovedSections = property(get_RemovedSections, None)
class SectionsInViewChangedEventHandler(MulticastDelegate):
    extends: IUnknown
    _iid_ = Guid('{830d582c-80fb-5aea-bcb2-f151740ff792}')
    @winrt_commethod(3)
    def Invoke(self, sender: IInspectable, e: win32more.Microsoft.UI.Xaml.Controls.SectionsInViewChangedEventArgs) -> Void: ...
class SelectionChangedEventArgs(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.RoutedEventArgs
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ISelectionChangedEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.SelectionChangedEventArgs'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 2:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.SelectionChangedEventArgs.CreateInstanceWithRemovedItemsAndAddedItems(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstanceWithRemovedItemsAndAddedItems(cls: win32more.Microsoft.UI.Xaml.Controls.ISelectionChangedEventArgsFactory, removedItems: win32more.Windows.Foundation.Collections.IVector[IInspectable], addedItems: win32more.Windows.Foundation.Collections.IVector[IInspectable], baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.SelectionChangedEventArgs: ...
    @winrt_mixinmethod
    def get_AddedItems(self: win32more.Microsoft.UI.Xaml.Controls.ISelectionChangedEventArgs) -> win32more.Windows.Foundation.Collections.IVector[IInspectable]: ...
    @winrt_mixinmethod
    def get_RemovedItems(self: win32more.Microsoft.UI.Xaml.Controls.ISelectionChangedEventArgs) -> win32more.Windows.Foundation.Collections.IVector[IInspectable]: ...
    AddedItems = property(get_AddedItems, None)
    RemovedItems = property(get_RemovedItems, None)
class SelectionChangedEventHandler(MulticastDelegate):
    extends: IUnknown
    _iid_ = Guid('{a232390d-0e34-595e-8931-fa928a9909f4}')
    @winrt_commethod(3)
    def Invoke(self, sender: IInspectable, e: win32more.Microsoft.UI.Xaml.Controls.SelectionChangedEventArgs) -> Void: ...
class SelectionMode(Enum, Int32):
    Single = 0
    Multiple = 1
    Extended = 2
class _SelectorBar_Meta_(ComPtr.__class__):
    pass
class SelectorBar(ComPtr, metaclass=_SelectorBar_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.Control
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ISelectorBar
    _classid_ = 'Microsoft.UI.Xaml.Controls.SelectorBar'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.SelectorBar.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.ISelectorBarFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.SelectorBar: ...
    @winrt_mixinmethod
    def get_Items(self: win32more.Microsoft.UI.Xaml.Controls.ISelectorBar) -> win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.SelectorBarItem]: ...
    @winrt_mixinmethod
    def get_SelectedItem(self: win32more.Microsoft.UI.Xaml.Controls.ISelectorBar) -> win32more.Microsoft.UI.Xaml.Controls.SelectorBarItem: ...
    @winrt_mixinmethod
    def put_SelectedItem(self: win32more.Microsoft.UI.Xaml.Controls.ISelectorBar, value: win32more.Microsoft.UI.Xaml.Controls.SelectorBarItem) -> Void: ...
    @winrt_mixinmethod
    def add_SelectionChanged(self: win32more.Microsoft.UI.Xaml.Controls.ISelectorBar, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.SelectorBar, win32more.Microsoft.UI.Xaml.Controls.SelectorBarSelectionChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_SelectionChanged(self: win32more.Microsoft.UI.Xaml.Controls.ISelectorBar, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def get_ItemsProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ISelectorBarStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectedItemProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ISelectorBarStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    Items = property(get_Items, None)
    SelectedItem = property(get_SelectedItem, put_SelectedItem)
    _SelectorBar_Meta_.ItemsProperty = property(get_ItemsProperty, None)
    _SelectorBar_Meta_.SelectedItemProperty = property(get_SelectedItemProperty, None)
    SelectionChanged = event(add_SelectionChanged, remove_SelectionChanged)
class _SelectorBarItem_Meta_(ComPtr.__class__):
    pass
class SelectorBarItem(ComPtr, metaclass=_SelectorBarItem_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.ItemContainer
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ISelectorBarItem
    _classid_ = 'Microsoft.UI.Xaml.Controls.SelectorBarItem'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.SelectorBarItem.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.ISelectorBarItemFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.SelectorBarItem: ...
    @winrt_mixinmethod
    def get_Text(self: win32more.Microsoft.UI.Xaml.Controls.ISelectorBarItem) -> hstr: ...
    @winrt_mixinmethod
    def put_Text(self: win32more.Microsoft.UI.Xaml.Controls.ISelectorBarItem, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def get_Icon(self: win32more.Microsoft.UI.Xaml.Controls.ISelectorBarItem) -> win32more.Microsoft.UI.Xaml.Controls.IconElement: ...
    @winrt_mixinmethod
    def put_Icon(self: win32more.Microsoft.UI.Xaml.Controls.ISelectorBarItem, value: win32more.Microsoft.UI.Xaml.Controls.IconElement) -> Void: ...
    @winrt_classmethod
    def get_TextProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ISelectorBarItemStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IconProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ISelectorBarItemStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    Icon = property(get_Icon, put_Icon)
    Text = property(get_Text, put_Text)
    _SelectorBarItem_Meta_.IconProperty = property(get_IconProperty, None)
    _SelectorBarItem_Meta_.TextProperty = property(get_TextProperty, None)
class SelectorBarSelectionChangedEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ISelectorBarSelectionChangedEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.SelectorBarSelectionChangedEventArgs'
class _SemanticZoom_Meta_(ComPtr.__class__):
    pass
class SemanticZoom(ComPtr, metaclass=_SemanticZoom_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.Control
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ISemanticZoom
    _classid_ = 'Microsoft.UI.Xaml.Controls.SemanticZoom'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.SemanticZoom.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Controls.SemanticZoom: ...
    @winrt_mixinmethod
    def get_ZoomedInView(self: win32more.Microsoft.UI.Xaml.Controls.ISemanticZoom) -> win32more.Microsoft.UI.Xaml.Controls.ISemanticZoomInformation: ...
    @winrt_mixinmethod
    def put_ZoomedInView(self: win32more.Microsoft.UI.Xaml.Controls.ISemanticZoom, value: win32more.Microsoft.UI.Xaml.Controls.ISemanticZoomInformation) -> Void: ...
    @winrt_mixinmethod
    def get_ZoomedOutView(self: win32more.Microsoft.UI.Xaml.Controls.ISemanticZoom) -> win32more.Microsoft.UI.Xaml.Controls.ISemanticZoomInformation: ...
    @winrt_mixinmethod
    def put_ZoomedOutView(self: win32more.Microsoft.UI.Xaml.Controls.ISemanticZoom, value: win32more.Microsoft.UI.Xaml.Controls.ISemanticZoomInformation) -> Void: ...
    @winrt_mixinmethod
    def get_IsZoomedInViewActive(self: win32more.Microsoft.UI.Xaml.Controls.ISemanticZoom) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsZoomedInViewActive(self: win32more.Microsoft.UI.Xaml.Controls.ISemanticZoom, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_CanChangeViews(self: win32more.Microsoft.UI.Xaml.Controls.ISemanticZoom) -> Boolean: ...
    @winrt_mixinmethod
    def put_CanChangeViews(self: win32more.Microsoft.UI.Xaml.Controls.ISemanticZoom, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def add_ViewChangeStarted(self: win32more.Microsoft.UI.Xaml.Controls.ISemanticZoom, handler: win32more.Microsoft.UI.Xaml.Controls.SemanticZoomViewChangedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ViewChangeStarted(self: win32more.Microsoft.UI.Xaml.Controls.ISemanticZoom, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_ViewChangeCompleted(self: win32more.Microsoft.UI.Xaml.Controls.ISemanticZoom, handler: win32more.Microsoft.UI.Xaml.Controls.SemanticZoomViewChangedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ViewChangeCompleted(self: win32more.Microsoft.UI.Xaml.Controls.ISemanticZoom, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def ToggleActiveView(self: win32more.Microsoft.UI.Xaml.Controls.ISemanticZoom) -> Void: ...
    @winrt_mixinmethod
    def get_IsZoomOutButtonEnabled(self: win32more.Microsoft.UI.Xaml.Controls.ISemanticZoom) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsZoomOutButtonEnabled(self: win32more.Microsoft.UI.Xaml.Controls.ISemanticZoom, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_ZoomedInViewProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ISemanticZoomStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ZoomedOutViewProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ISemanticZoomStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsZoomedInViewActiveProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ISemanticZoomStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CanChangeViewsProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ISemanticZoomStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsZoomOutButtonEnabledProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ISemanticZoomStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    CanChangeViews = property(get_CanChangeViews, put_CanChangeViews)
    IsZoomOutButtonEnabled = property(get_IsZoomOutButtonEnabled, put_IsZoomOutButtonEnabled)
    IsZoomedInViewActive = property(get_IsZoomedInViewActive, put_IsZoomedInViewActive)
    ZoomedInView = property(get_ZoomedInView, put_ZoomedInView)
    ZoomedOutView = property(get_ZoomedOutView, put_ZoomedOutView)
    _SemanticZoom_Meta_.CanChangeViewsProperty = property(get_CanChangeViewsProperty, None)
    _SemanticZoom_Meta_.IsZoomOutButtonEnabledProperty = property(get_IsZoomOutButtonEnabledProperty, None)
    _SemanticZoom_Meta_.IsZoomedInViewActiveProperty = property(get_IsZoomedInViewActiveProperty, None)
    _SemanticZoom_Meta_.ZoomedInViewProperty = property(get_ZoomedInViewProperty, None)
    _SemanticZoom_Meta_.ZoomedOutViewProperty = property(get_ZoomedOutViewProperty, None)
    ViewChangeCompleted = event(add_ViewChangeCompleted, remove_ViewChangeCompleted)
    ViewChangeStarted = event(add_ViewChangeStarted, remove_ViewChangeStarted)
class SemanticZoomLocation(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ISemanticZoomLocation
    _classid_ = 'Microsoft.UI.Xaml.Controls.SemanticZoomLocation'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.SemanticZoomLocation.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Controls.SemanticZoomLocation: ...
    @winrt_mixinmethod
    def get_Item(self: win32more.Microsoft.UI.Xaml.Controls.ISemanticZoomLocation) -> IInspectable: ...
    @winrt_mixinmethod
    def put_Item(self: win32more.Microsoft.UI.Xaml.Controls.ISemanticZoomLocation, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_Bounds(self: win32more.Microsoft.UI.Xaml.Controls.ISemanticZoomLocation) -> win32more.Windows.Foundation.Rect: ...
    @winrt_mixinmethod
    def put_Bounds(self: win32more.Microsoft.UI.Xaml.Controls.ISemanticZoomLocation, value: win32more.Windows.Foundation.Rect) -> Void: ...
    Bounds = property(get_Bounds, put_Bounds)
    Item = property(get_Item, put_Item)
class SemanticZoomViewChangedEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ISemanticZoomViewChangedEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.SemanticZoomViewChangedEventArgs'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.SemanticZoomViewChangedEventArgs.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Controls.SemanticZoomViewChangedEventArgs: ...
    @winrt_mixinmethod
    def get_IsSourceZoomedInView(self: win32more.Microsoft.UI.Xaml.Controls.ISemanticZoomViewChangedEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsSourceZoomedInView(self: win32more.Microsoft.UI.Xaml.Controls.ISemanticZoomViewChangedEventArgs, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_SourceItem(self: win32more.Microsoft.UI.Xaml.Controls.ISemanticZoomViewChangedEventArgs) -> win32more.Microsoft.UI.Xaml.Controls.SemanticZoomLocation: ...
    @winrt_mixinmethod
    def put_SourceItem(self: win32more.Microsoft.UI.Xaml.Controls.ISemanticZoomViewChangedEventArgs, value: win32more.Microsoft.UI.Xaml.Controls.SemanticZoomLocation) -> Void: ...
    @winrt_mixinmethod
    def get_DestinationItem(self: win32more.Microsoft.UI.Xaml.Controls.ISemanticZoomViewChangedEventArgs) -> win32more.Microsoft.UI.Xaml.Controls.SemanticZoomLocation: ...
    @winrt_mixinmethod
    def put_DestinationItem(self: win32more.Microsoft.UI.Xaml.Controls.ISemanticZoomViewChangedEventArgs, value: win32more.Microsoft.UI.Xaml.Controls.SemanticZoomLocation) -> Void: ...
    DestinationItem = property(get_DestinationItem, put_DestinationItem)
    IsSourceZoomedInView = property(get_IsSourceZoomedInView, put_IsSourceZoomedInView)
    SourceItem = property(get_SourceItem, put_SourceItem)
class SemanticZoomViewChangedEventHandler(MulticastDelegate):
    extends: IUnknown
    _iid_ = Guid('{4cc95c52-8a54-53b7-9251-0b3efa605398}')
    @winrt_commethod(3)
    def Invoke(self, sender: IInspectable, e: win32more.Microsoft.UI.Xaml.Controls.SemanticZoomViewChangedEventArgs) -> Void: ...
class _Slider_Meta_(ComPtr.__class__):
    pass
class Slider(ComPtr, metaclass=_Slider_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.Primitives.RangeBase
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ISlider
    _classid_ = 'Microsoft.UI.Xaml.Controls.Slider'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.Slider.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.ISliderFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.Slider: ...
    @winrt_mixinmethod
    def get_IntermediateValue(self: win32more.Microsoft.UI.Xaml.Controls.ISlider) -> Double: ...
    @winrt_mixinmethod
    def put_IntermediateValue(self: win32more.Microsoft.UI.Xaml.Controls.ISlider, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_StepFrequency(self: win32more.Microsoft.UI.Xaml.Controls.ISlider) -> Double: ...
    @winrt_mixinmethod
    def put_StepFrequency(self: win32more.Microsoft.UI.Xaml.Controls.ISlider, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_SnapsTo(self: win32more.Microsoft.UI.Xaml.Controls.ISlider) -> win32more.Microsoft.UI.Xaml.Controls.Primitives.SliderSnapsTo: ...
    @winrt_mixinmethod
    def put_SnapsTo(self: win32more.Microsoft.UI.Xaml.Controls.ISlider, value: win32more.Microsoft.UI.Xaml.Controls.Primitives.SliderSnapsTo) -> Void: ...
    @winrt_mixinmethod
    def get_TickFrequency(self: win32more.Microsoft.UI.Xaml.Controls.ISlider) -> Double: ...
    @winrt_mixinmethod
    def put_TickFrequency(self: win32more.Microsoft.UI.Xaml.Controls.ISlider, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_TickPlacement(self: win32more.Microsoft.UI.Xaml.Controls.ISlider) -> win32more.Microsoft.UI.Xaml.Controls.Primitives.TickPlacement: ...
    @winrt_mixinmethod
    def put_TickPlacement(self: win32more.Microsoft.UI.Xaml.Controls.ISlider, value: win32more.Microsoft.UI.Xaml.Controls.Primitives.TickPlacement) -> Void: ...
    @winrt_mixinmethod
    def get_Orientation(self: win32more.Microsoft.UI.Xaml.Controls.ISlider) -> win32more.Microsoft.UI.Xaml.Controls.Orientation: ...
    @winrt_mixinmethod
    def put_Orientation(self: win32more.Microsoft.UI.Xaml.Controls.ISlider, value: win32more.Microsoft.UI.Xaml.Controls.Orientation) -> Void: ...
    @winrt_mixinmethod
    def get_IsDirectionReversed(self: win32more.Microsoft.UI.Xaml.Controls.ISlider) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsDirectionReversed(self: win32more.Microsoft.UI.Xaml.Controls.ISlider, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsThumbToolTipEnabled(self: win32more.Microsoft.UI.Xaml.Controls.ISlider) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsThumbToolTipEnabled(self: win32more.Microsoft.UI.Xaml.Controls.ISlider, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_ThumbToolTipValueConverter(self: win32more.Microsoft.UI.Xaml.Controls.ISlider) -> win32more.Microsoft.UI.Xaml.Data.IValueConverter: ...
    @winrt_mixinmethod
    def put_ThumbToolTipValueConverter(self: win32more.Microsoft.UI.Xaml.Controls.ISlider, value: win32more.Microsoft.UI.Xaml.Data.IValueConverter) -> Void: ...
    @winrt_mixinmethod
    def get_Header(self: win32more.Microsoft.UI.Xaml.Controls.ISlider) -> IInspectable: ...
    @winrt_mixinmethod
    def put_Header(self: win32more.Microsoft.UI.Xaml.Controls.ISlider, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_HeaderTemplate(self: win32more.Microsoft.UI.Xaml.Controls.ISlider) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def put_HeaderTemplate(self: win32more.Microsoft.UI.Xaml.Controls.ISlider, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_classmethod
    def get_IntermediateValueProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ISliderStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_StepFrequencyProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ISliderStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SnapsToProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ISliderStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TickFrequencyProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ISliderStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TickPlacementProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ISliderStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_OrientationProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ISliderStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsDirectionReversedProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ISliderStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsThumbToolTipEnabledProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ISliderStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ThumbToolTipValueConverterProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ISliderStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HeaderProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ISliderStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HeaderTemplateProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ISliderStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    Header = property(get_Header, put_Header)
    HeaderTemplate = property(get_HeaderTemplate, put_HeaderTemplate)
    IntermediateValue = property(get_IntermediateValue, put_IntermediateValue)
    IsDirectionReversed = property(get_IsDirectionReversed, put_IsDirectionReversed)
    IsThumbToolTipEnabled = property(get_IsThumbToolTipEnabled, put_IsThumbToolTipEnabled)
    Orientation = property(get_Orientation, put_Orientation)
    SnapsTo = property(get_SnapsTo, put_SnapsTo)
    StepFrequency = property(get_StepFrequency, put_StepFrequency)
    ThumbToolTipValueConverter = property(get_ThumbToolTipValueConverter, put_ThumbToolTipValueConverter)
    TickFrequency = property(get_TickFrequency, put_TickFrequency)
    TickPlacement = property(get_TickPlacement, put_TickPlacement)
    _Slider_Meta_.HeaderProperty = property(get_HeaderProperty, None)
    _Slider_Meta_.HeaderTemplateProperty = property(get_HeaderTemplateProperty, None)
    _Slider_Meta_.IntermediateValueProperty = property(get_IntermediateValueProperty, None)
    _Slider_Meta_.IsDirectionReversedProperty = property(get_IsDirectionReversedProperty, None)
    _Slider_Meta_.IsThumbToolTipEnabledProperty = property(get_IsThumbToolTipEnabledProperty, None)
    _Slider_Meta_.OrientationProperty = property(get_OrientationProperty, None)
    _Slider_Meta_.SnapsToProperty = property(get_SnapsToProperty, None)
    _Slider_Meta_.StepFrequencyProperty = property(get_StepFrequencyProperty, None)
    _Slider_Meta_.ThumbToolTipValueConverterProperty = property(get_ThumbToolTipValueConverterProperty, None)
    _Slider_Meta_.TickFrequencyProperty = property(get_TickFrequencyProperty, None)
    _Slider_Meta_.TickPlacementProperty = property(get_TickPlacementProperty, None)
class SnapPointsType(Enum, Int32):
    None_ = 0
    Optional = 1
    Mandatory = 2
    OptionalSingle = 3
    MandatorySingle = 4
class _SplitButton_Meta_(ComPtr.__class__):
    pass
class SplitButton(ComPtr, metaclass=_SplitButton_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.ContentControl
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ISplitButton
    _classid_ = 'Microsoft.UI.Xaml.Controls.SplitButton'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.SplitButton.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.ISplitButtonFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.SplitButton: ...
    @winrt_mixinmethod
    def get_Flyout(self: win32more.Microsoft.UI.Xaml.Controls.ISplitButton) -> win32more.Microsoft.UI.Xaml.Controls.Primitives.FlyoutBase: ...
    @winrt_mixinmethod
    def put_Flyout(self: win32more.Microsoft.UI.Xaml.Controls.ISplitButton, value: win32more.Microsoft.UI.Xaml.Controls.Primitives.FlyoutBase) -> Void: ...
    @winrt_mixinmethod
    def get_Command(self: win32more.Microsoft.UI.Xaml.Controls.ISplitButton) -> win32more.Microsoft.UI.Xaml.Input.ICommand: ...
    @winrt_mixinmethod
    def put_Command(self: win32more.Microsoft.UI.Xaml.Controls.ISplitButton, value: win32more.Microsoft.UI.Xaml.Input.ICommand) -> Void: ...
    @winrt_mixinmethod
    def get_CommandParameter(self: win32more.Microsoft.UI.Xaml.Controls.ISplitButton) -> IInspectable: ...
    @winrt_mixinmethod
    def put_CommandParameter(self: win32more.Microsoft.UI.Xaml.Controls.ISplitButton, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def add_Click(self: win32more.Microsoft.UI.Xaml.Controls.ISplitButton, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.SplitButton, win32more.Microsoft.UI.Xaml.Controls.SplitButtonClickEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Click(self: win32more.Microsoft.UI.Xaml.Controls.ISplitButton, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def get_FlyoutProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ISplitButtonStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CommandProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ISplitButtonStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CommandParameterProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ISplitButtonStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    Command = property(get_Command, put_Command)
    CommandParameter = property(get_CommandParameter, put_CommandParameter)
    Flyout = property(get_Flyout, put_Flyout)
    _SplitButton_Meta_.CommandParameterProperty = property(get_CommandParameterProperty, None)
    _SplitButton_Meta_.CommandProperty = property(get_CommandProperty, None)
    _SplitButton_Meta_.FlyoutProperty = property(get_FlyoutProperty, None)
    Click = event(add_Click, remove_Click)
class SplitButtonClickEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ISplitButtonClickEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.SplitButtonClickEventArgs'
class _SplitView_Meta_(ComPtr.__class__):
    pass
class SplitView(ComPtr, metaclass=_SplitView_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.Control
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ISplitView
    _classid_ = 'Microsoft.UI.Xaml.Controls.SplitView'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.SplitView.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.ISplitViewFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.SplitView: ...
    @winrt_mixinmethod
    def get_Content(self: win32more.Microsoft.UI.Xaml.Controls.ISplitView) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_mixinmethod
    def put_Content(self: win32more.Microsoft.UI.Xaml.Controls.ISplitView, value: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    @winrt_mixinmethod
    def get_Pane(self: win32more.Microsoft.UI.Xaml.Controls.ISplitView) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_mixinmethod
    def put_Pane(self: win32more.Microsoft.UI.Xaml.Controls.ISplitView, value: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    @winrt_mixinmethod
    def get_IsPaneOpen(self: win32more.Microsoft.UI.Xaml.Controls.ISplitView) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsPaneOpen(self: win32more.Microsoft.UI.Xaml.Controls.ISplitView, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_OpenPaneLength(self: win32more.Microsoft.UI.Xaml.Controls.ISplitView) -> Double: ...
    @winrt_mixinmethod
    def put_OpenPaneLength(self: win32more.Microsoft.UI.Xaml.Controls.ISplitView, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_CompactPaneLength(self: win32more.Microsoft.UI.Xaml.Controls.ISplitView) -> Double: ...
    @winrt_mixinmethod
    def put_CompactPaneLength(self: win32more.Microsoft.UI.Xaml.Controls.ISplitView, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_PanePlacement(self: win32more.Microsoft.UI.Xaml.Controls.ISplitView) -> win32more.Microsoft.UI.Xaml.Controls.SplitViewPanePlacement: ...
    @winrt_mixinmethod
    def put_PanePlacement(self: win32more.Microsoft.UI.Xaml.Controls.ISplitView, value: win32more.Microsoft.UI.Xaml.Controls.SplitViewPanePlacement) -> Void: ...
    @winrt_mixinmethod
    def get_DisplayMode(self: win32more.Microsoft.UI.Xaml.Controls.ISplitView) -> win32more.Microsoft.UI.Xaml.Controls.SplitViewDisplayMode: ...
    @winrt_mixinmethod
    def put_DisplayMode(self: win32more.Microsoft.UI.Xaml.Controls.ISplitView, value: win32more.Microsoft.UI.Xaml.Controls.SplitViewDisplayMode) -> Void: ...
    @winrt_mixinmethod
    def get_TemplateSettings(self: win32more.Microsoft.UI.Xaml.Controls.ISplitView) -> win32more.Microsoft.UI.Xaml.Controls.Primitives.SplitViewTemplateSettings: ...
    @winrt_mixinmethod
    def get_PaneBackground(self: win32more.Microsoft.UI.Xaml.Controls.ISplitView) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_PaneBackground(self: win32more.Microsoft.UI.Xaml.Controls.ISplitView, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_LightDismissOverlayMode(self: win32more.Microsoft.UI.Xaml.Controls.ISplitView) -> win32more.Microsoft.UI.Xaml.Controls.LightDismissOverlayMode: ...
    @winrt_mixinmethod
    def put_LightDismissOverlayMode(self: win32more.Microsoft.UI.Xaml.Controls.ISplitView, value: win32more.Microsoft.UI.Xaml.Controls.LightDismissOverlayMode) -> Void: ...
    @winrt_mixinmethod
    def add_PaneClosing(self: win32more.Microsoft.UI.Xaml.Controls.ISplitView, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.SplitView, win32more.Microsoft.UI.Xaml.Controls.SplitViewPaneClosingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_PaneClosing(self: win32more.Microsoft.UI.Xaml.Controls.ISplitView, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_PaneClosed(self: win32more.Microsoft.UI.Xaml.Controls.ISplitView, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.SplitView, IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_PaneClosed(self: win32more.Microsoft.UI.Xaml.Controls.ISplitView, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_PaneOpening(self: win32more.Microsoft.UI.Xaml.Controls.ISplitView, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.SplitView, IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_PaneOpening(self: win32more.Microsoft.UI.Xaml.Controls.ISplitView, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_PaneOpened(self: win32more.Microsoft.UI.Xaml.Controls.ISplitView, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.SplitView, IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_PaneOpened(self: win32more.Microsoft.UI.Xaml.Controls.ISplitView, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def get_ContentProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ISplitViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PaneProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ISplitViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsPaneOpenProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ISplitViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_OpenPaneLengthProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ISplitViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CompactPaneLengthProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ISplitViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PanePlacementProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ISplitViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DisplayModeProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ISplitViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TemplateSettingsProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ISplitViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PaneBackgroundProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ISplitViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_LightDismissOverlayModeProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ISplitViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    CompactPaneLength = property(get_CompactPaneLength, put_CompactPaneLength)
    Content = property(get_Content, put_Content)
    DisplayMode = property(get_DisplayMode, put_DisplayMode)
    IsPaneOpen = property(get_IsPaneOpen, put_IsPaneOpen)
    LightDismissOverlayMode = property(get_LightDismissOverlayMode, put_LightDismissOverlayMode)
    OpenPaneLength = property(get_OpenPaneLength, put_OpenPaneLength)
    Pane = property(get_Pane, put_Pane)
    PaneBackground = property(get_PaneBackground, put_PaneBackground)
    PanePlacement = property(get_PanePlacement, put_PanePlacement)
    TemplateSettings = property(get_TemplateSettings, None)
    _SplitView_Meta_.CompactPaneLengthProperty = property(get_CompactPaneLengthProperty, None)
    _SplitView_Meta_.ContentProperty = property(get_ContentProperty, None)
    _SplitView_Meta_.DisplayModeProperty = property(get_DisplayModeProperty, None)
    _SplitView_Meta_.IsPaneOpenProperty = property(get_IsPaneOpenProperty, None)
    _SplitView_Meta_.LightDismissOverlayModeProperty = property(get_LightDismissOverlayModeProperty, None)
    _SplitView_Meta_.OpenPaneLengthProperty = property(get_OpenPaneLengthProperty, None)
    _SplitView_Meta_.PaneBackgroundProperty = property(get_PaneBackgroundProperty, None)
    _SplitView_Meta_.PanePlacementProperty = property(get_PanePlacementProperty, None)
    _SplitView_Meta_.PaneProperty = property(get_PaneProperty, None)
    _SplitView_Meta_.TemplateSettingsProperty = property(get_TemplateSettingsProperty, None)
    PaneClosed = event(add_PaneClosed, remove_PaneClosed)
    PaneClosing = event(add_PaneClosing, remove_PaneClosing)
    PaneOpened = event(add_PaneOpened, remove_PaneOpened)
    PaneOpening = event(add_PaneOpening, remove_PaneOpening)
class SplitViewDisplayMode(Enum, Int32):
    Overlay = 0
    Inline = 1
    CompactOverlay = 2
    CompactInline = 3
class SplitViewPaneClosingEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ISplitViewPaneClosingEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.SplitViewPaneClosingEventArgs'
    @winrt_mixinmethod
    def get_Cancel(self: win32more.Microsoft.UI.Xaml.Controls.ISplitViewPaneClosingEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def put_Cancel(self: win32more.Microsoft.UI.Xaml.Controls.ISplitViewPaneClosingEventArgs, value: Boolean) -> Void: ...
    Cancel = property(get_Cancel, put_Cancel)
class SplitViewPanePlacement(Enum, Int32):
    Left = 0
    Right = 1
class _StackLayout_Meta_(ComPtr.__class__):
    pass
class StackLayout(ComPtr, metaclass=_StackLayout_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.VirtualizingLayout
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IStackLayout
    _classid_ = 'Microsoft.UI.Xaml.Controls.StackLayout'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.StackLayout.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IStackLayoutFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.StackLayout: ...
    @winrt_mixinmethod
    def get_Orientation(self: win32more.Microsoft.UI.Xaml.Controls.IStackLayout) -> win32more.Microsoft.UI.Xaml.Controls.Orientation: ...
    @winrt_mixinmethod
    def put_Orientation(self: win32more.Microsoft.UI.Xaml.Controls.IStackLayout, value: win32more.Microsoft.UI.Xaml.Controls.Orientation) -> Void: ...
    @winrt_mixinmethod
    def get_Spacing(self: win32more.Microsoft.UI.Xaml.Controls.IStackLayout) -> Double: ...
    @winrt_mixinmethod
    def put_Spacing(self: win32more.Microsoft.UI.Xaml.Controls.IStackLayout, value: Double) -> Void: ...
    @winrt_classmethod
    def get_OrientationProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IStackLayoutStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SpacingProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IStackLayoutStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    Orientation = property(get_Orientation, put_Orientation)
    Spacing = property(get_Spacing, put_Spacing)
    _StackLayout_Meta_.OrientationProperty = property(get_OrientationProperty, None)
    _StackLayout_Meta_.SpacingProperty = property(get_SpacingProperty, None)
class _StackPanel_Meta_(ComPtr.__class__):
    pass
class StackPanel(ComPtr, metaclass=_StackPanel_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.Panel
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IStackPanel
    _classid_ = 'Microsoft.UI.Xaml.Controls.StackPanel'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.StackPanel.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IStackPanelFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.StackPanel: ...
    @winrt_mixinmethod
    def get_AreScrollSnapPointsRegular(self: win32more.Microsoft.UI.Xaml.Controls.IStackPanel) -> Boolean: ...
    @winrt_mixinmethod
    def put_AreScrollSnapPointsRegular(self: win32more.Microsoft.UI.Xaml.Controls.IStackPanel, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_Orientation(self: win32more.Microsoft.UI.Xaml.Controls.IStackPanel) -> win32more.Microsoft.UI.Xaml.Controls.Orientation: ...
    @winrt_mixinmethod
    def put_Orientation(self: win32more.Microsoft.UI.Xaml.Controls.IStackPanel, value: win32more.Microsoft.UI.Xaml.Controls.Orientation) -> Void: ...
    @winrt_mixinmethod
    def get_BackgroundSizing(self: win32more.Microsoft.UI.Xaml.Controls.IStackPanel) -> win32more.Microsoft.UI.Xaml.Controls.BackgroundSizing: ...
    @winrt_mixinmethod
    def put_BackgroundSizing(self: win32more.Microsoft.UI.Xaml.Controls.IStackPanel, value: win32more.Microsoft.UI.Xaml.Controls.BackgroundSizing) -> Void: ...
    @winrt_mixinmethod
    def get_BorderBrush(self: win32more.Microsoft.UI.Xaml.Controls.IStackPanel) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_BorderBrush(self: win32more.Microsoft.UI.Xaml.Controls.IStackPanel, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_BorderThickness(self: win32more.Microsoft.UI.Xaml.Controls.IStackPanel) -> win32more.Microsoft.UI.Xaml.Thickness: ...
    @winrt_mixinmethod
    def put_BorderThickness(self: win32more.Microsoft.UI.Xaml.Controls.IStackPanel, value: win32more.Microsoft.UI.Xaml.Thickness) -> Void: ...
    @winrt_mixinmethod
    def get_CornerRadius(self: win32more.Microsoft.UI.Xaml.Controls.IStackPanel) -> win32more.Microsoft.UI.Xaml.CornerRadius: ...
    @winrt_mixinmethod
    def put_CornerRadius(self: win32more.Microsoft.UI.Xaml.Controls.IStackPanel, value: win32more.Microsoft.UI.Xaml.CornerRadius) -> Void: ...
    @winrt_mixinmethod
    def get_Padding(self: win32more.Microsoft.UI.Xaml.Controls.IStackPanel) -> win32more.Microsoft.UI.Xaml.Thickness: ...
    @winrt_mixinmethod
    def put_Padding(self: win32more.Microsoft.UI.Xaml.Controls.IStackPanel, value: win32more.Microsoft.UI.Xaml.Thickness) -> Void: ...
    @winrt_mixinmethod
    def get_Spacing(self: win32more.Microsoft.UI.Xaml.Controls.IStackPanel) -> Double: ...
    @winrt_mixinmethod
    def put_Spacing(self: win32more.Microsoft.UI.Xaml.Controls.IStackPanel, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_AreHorizontalSnapPointsRegular(self: win32more.Microsoft.UI.Xaml.Controls.Primitives.IScrollSnapPointsInfo) -> Boolean: ...
    @winrt_mixinmethod
    def get_AreVerticalSnapPointsRegular(self: win32more.Microsoft.UI.Xaml.Controls.Primitives.IScrollSnapPointsInfo) -> Boolean: ...
    @winrt_mixinmethod
    def add_HorizontalSnapPointsChanged(self: win32more.Microsoft.UI.Xaml.Controls.Primitives.IScrollSnapPointsInfo, handler: win32more.Windows.Foundation.EventHandler[IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_HorizontalSnapPointsChanged(self: win32more.Microsoft.UI.Xaml.Controls.Primitives.IScrollSnapPointsInfo, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_VerticalSnapPointsChanged(self: win32more.Microsoft.UI.Xaml.Controls.Primitives.IScrollSnapPointsInfo, handler: win32more.Windows.Foundation.EventHandler[IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_VerticalSnapPointsChanged(self: win32more.Microsoft.UI.Xaml.Controls.Primitives.IScrollSnapPointsInfo, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def GetIrregularSnapPoints(self: win32more.Microsoft.UI.Xaml.Controls.Primitives.IScrollSnapPointsInfo, orientation: win32more.Microsoft.UI.Xaml.Controls.Orientation, alignment: win32more.Microsoft.UI.Xaml.Controls.Primitives.SnapPointsAlignment) -> win32more.Windows.Foundation.Collections.IVectorView[Single]: ...
    @winrt_mixinmethod
    def GetRegularSnapPoints(self: win32more.Microsoft.UI.Xaml.Controls.Primitives.IScrollSnapPointsInfo, orientation: win32more.Microsoft.UI.Xaml.Controls.Orientation, alignment: win32more.Microsoft.UI.Xaml.Controls.Primitives.SnapPointsAlignment, offset: POINTER(Single)) -> Single: ...
    @winrt_mixinmethod
    def GetInsertionIndexes(self: win32more.Microsoft.UI.Xaml.Controls.IInsertionPanel, position: win32more.Windows.Foundation.Point, first: POINTER(Int32), second: POINTER(Int32)) -> Void: ...
    @winrt_classmethod
    def get_AreScrollSnapPointsRegularProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IStackPanelStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_OrientationProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IStackPanelStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_BackgroundSizingProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IStackPanelStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_BorderBrushProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IStackPanelStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_BorderThicknessProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IStackPanelStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CornerRadiusProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IStackPanelStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PaddingProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IStackPanelStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SpacingProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IStackPanelStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    AreHorizontalSnapPointsRegular = property(get_AreHorizontalSnapPointsRegular, None)
    AreScrollSnapPointsRegular = property(get_AreScrollSnapPointsRegular, put_AreScrollSnapPointsRegular)
    AreVerticalSnapPointsRegular = property(get_AreVerticalSnapPointsRegular, None)
    BackgroundSizing = property(get_BackgroundSizing, put_BackgroundSizing)
    BorderBrush = property(get_BorderBrush, put_BorderBrush)
    BorderThickness = property(get_BorderThickness, put_BorderThickness)
    CornerRadius = property(get_CornerRadius, put_CornerRadius)
    Orientation = property(get_Orientation, put_Orientation)
    Padding = property(get_Padding, put_Padding)
    Spacing = property(get_Spacing, put_Spacing)
    _StackPanel_Meta_.AreScrollSnapPointsRegularProperty = property(get_AreScrollSnapPointsRegularProperty, None)
    _StackPanel_Meta_.BackgroundSizingProperty = property(get_BackgroundSizingProperty, None)
    _StackPanel_Meta_.BorderBrushProperty = property(get_BorderBrushProperty, None)
    _StackPanel_Meta_.BorderThicknessProperty = property(get_BorderThicknessProperty, None)
    _StackPanel_Meta_.CornerRadiusProperty = property(get_CornerRadiusProperty, None)
    _StackPanel_Meta_.OrientationProperty = property(get_OrientationProperty, None)
    _StackPanel_Meta_.PaddingProperty = property(get_PaddingProperty, None)
    _StackPanel_Meta_.SpacingProperty = property(get_SpacingProperty, None)
    HorizontalSnapPointsChanged = event(add_HorizontalSnapPointsChanged, remove_HorizontalSnapPointsChanged)
    VerticalSnapPointsChanged = event(add_VerticalSnapPointsChanged, remove_VerticalSnapPointsChanged)
class StretchDirection(Enum, Int32):
    UpOnly = 0
    DownOnly = 1
    Both = 2
class StyleSelector(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IStyleSelector
    _classid_ = 'Microsoft.UI.Xaml.Controls.StyleSelector'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.StyleSelector.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IStyleSelectorFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.StyleSelector: ...
    @winrt_mixinmethod
    def SelectStyle(self: win32more.Microsoft.UI.Xaml.Controls.IStyleSelector, item: IInspectable, container: win32more.Microsoft.UI.Xaml.DependencyObject) -> win32more.Microsoft.UI.Xaml.Style: ...
    @winrt_mixinmethod
    def SelectStyleCore(self: win32more.Microsoft.UI.Xaml.Controls.IStyleSelectorOverrides, item: IInspectable, container: win32more.Microsoft.UI.Xaml.DependencyObject) -> win32more.Microsoft.UI.Xaml.Style: ...
class SwapChainBackgroundPanel(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.Controls.Grid
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ISwapChainBackgroundPanel
    _classid_ = 'Microsoft.UI.Xaml.Controls.SwapChainBackgroundPanel'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.SwapChainBackgroundPanel.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.ISwapChainBackgroundPanelFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.SwapChainBackgroundPanel: ...
class _SwapChainPanel_Meta_(ComPtr.__class__):
    pass
class SwapChainPanel(ComPtr, metaclass=_SwapChainPanel_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.Grid
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ISwapChainPanel
    _classid_ = 'Microsoft.UI.Xaml.Controls.SwapChainPanel'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.SwapChainPanel.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.ISwapChainPanelFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.SwapChainPanel: ...
    @winrt_mixinmethod
    def get_CompositionScaleX(self: win32more.Microsoft.UI.Xaml.Controls.ISwapChainPanel) -> Single: ...
    @winrt_mixinmethod
    def get_CompositionScaleY(self: win32more.Microsoft.UI.Xaml.Controls.ISwapChainPanel) -> Single: ...
    @winrt_mixinmethod
    def add_CompositionScaleChanged(self: win32more.Microsoft.UI.Xaml.Controls.ISwapChainPanel, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.SwapChainPanel, IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_CompositionScaleChanged(self: win32more.Microsoft.UI.Xaml.Controls.ISwapChainPanel, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def CreateCoreIndependentInputSource(self: win32more.Microsoft.UI.Xaml.Controls.ISwapChainPanel, deviceKinds: win32more.Microsoft.UI.Input.InputPointerSourceDeviceKinds) -> win32more.Microsoft.UI.Input.InputPointerSource: ...
    @winrt_classmethod
    def get_CompositionScaleXProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ISwapChainPanelStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CompositionScaleYProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ISwapChainPanelStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    CompositionScaleX = property(get_CompositionScaleX, None)
    CompositionScaleY = property(get_CompositionScaleY, None)
    _SwapChainPanel_Meta_.CompositionScaleXProperty = property(get_CompositionScaleXProperty, None)
    _SwapChainPanel_Meta_.CompositionScaleYProperty = property(get_CompositionScaleYProperty, None)
    CompositionScaleChanged = event(add_CompositionScaleChanged, remove_CompositionScaleChanged)
class SwipeBehaviorOnInvoked(Enum, Int32):
    Auto = 0
    Close = 1
    RemainOpen = 2
class _SwipeControl_Meta_(ComPtr.__class__):
    pass
class SwipeControl(ComPtr, metaclass=_SwipeControl_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.ContentControl
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ISwipeControl
    _classid_ = 'Microsoft.UI.Xaml.Controls.SwipeControl'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.SwipeControl.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.ISwipeControlFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.SwipeControl: ...
    @winrt_mixinmethod
    def get_LeftItems(self: win32more.Microsoft.UI.Xaml.Controls.ISwipeControl) -> win32more.Microsoft.UI.Xaml.Controls.SwipeItems: ...
    @winrt_mixinmethod
    def put_LeftItems(self: win32more.Microsoft.UI.Xaml.Controls.ISwipeControl, value: win32more.Microsoft.UI.Xaml.Controls.SwipeItems) -> Void: ...
    @winrt_mixinmethod
    def get_RightItems(self: win32more.Microsoft.UI.Xaml.Controls.ISwipeControl) -> win32more.Microsoft.UI.Xaml.Controls.SwipeItems: ...
    @winrt_mixinmethod
    def put_RightItems(self: win32more.Microsoft.UI.Xaml.Controls.ISwipeControl, value: win32more.Microsoft.UI.Xaml.Controls.SwipeItems) -> Void: ...
    @winrt_mixinmethod
    def get_TopItems(self: win32more.Microsoft.UI.Xaml.Controls.ISwipeControl) -> win32more.Microsoft.UI.Xaml.Controls.SwipeItems: ...
    @winrt_mixinmethod
    def put_TopItems(self: win32more.Microsoft.UI.Xaml.Controls.ISwipeControl, value: win32more.Microsoft.UI.Xaml.Controls.SwipeItems) -> Void: ...
    @winrt_mixinmethod
    def get_BottomItems(self: win32more.Microsoft.UI.Xaml.Controls.ISwipeControl) -> win32more.Microsoft.UI.Xaml.Controls.SwipeItems: ...
    @winrt_mixinmethod
    def put_BottomItems(self: win32more.Microsoft.UI.Xaml.Controls.ISwipeControl, value: win32more.Microsoft.UI.Xaml.Controls.SwipeItems) -> Void: ...
    @winrt_mixinmethod
    def Close(self: win32more.Microsoft.UI.Xaml.Controls.ISwipeControl) -> Void: ...
    @winrt_classmethod
    def get_LeftItemsProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ISwipeControlStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_RightItemsProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ISwipeControlStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TopItemsProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ISwipeControlStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_BottomItemsProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ISwipeControlStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    BottomItems = property(get_BottomItems, put_BottomItems)
    LeftItems = property(get_LeftItems, put_LeftItems)
    RightItems = property(get_RightItems, put_RightItems)
    TopItems = property(get_TopItems, put_TopItems)
    _SwipeControl_Meta_.BottomItemsProperty = property(get_BottomItemsProperty, None)
    _SwipeControl_Meta_.LeftItemsProperty = property(get_LeftItemsProperty, None)
    _SwipeControl_Meta_.RightItemsProperty = property(get_RightItemsProperty, None)
    _SwipeControl_Meta_.TopItemsProperty = property(get_TopItemsProperty, None)
class _SwipeItem_Meta_(ComPtr.__class__):
    pass
class SwipeItem(ComPtr, metaclass=_SwipeItem_Meta_):
    extends: win32more.Microsoft.UI.Xaml.DependencyObject
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ISwipeItem
    _classid_ = 'Microsoft.UI.Xaml.Controls.SwipeItem'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.SwipeItem.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.ISwipeItemFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.SwipeItem: ...
    @winrt_mixinmethod
    def get_Text(self: win32more.Microsoft.UI.Xaml.Controls.ISwipeItem) -> hstr: ...
    @winrt_mixinmethod
    def put_Text(self: win32more.Microsoft.UI.Xaml.Controls.ISwipeItem, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def get_IconSource(self: win32more.Microsoft.UI.Xaml.Controls.ISwipeItem) -> win32more.Microsoft.UI.Xaml.Controls.IconSource: ...
    @winrt_mixinmethod
    def put_IconSource(self: win32more.Microsoft.UI.Xaml.Controls.ISwipeItem, value: win32more.Microsoft.UI.Xaml.Controls.IconSource) -> Void: ...
    @winrt_mixinmethod
    def get_Background(self: win32more.Microsoft.UI.Xaml.Controls.ISwipeItem) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_Background(self: win32more.Microsoft.UI.Xaml.Controls.ISwipeItem, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_Foreground(self: win32more.Microsoft.UI.Xaml.Controls.ISwipeItem) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_Foreground(self: win32more.Microsoft.UI.Xaml.Controls.ISwipeItem, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_Command(self: win32more.Microsoft.UI.Xaml.Controls.ISwipeItem) -> win32more.Microsoft.UI.Xaml.Input.ICommand: ...
    @winrt_mixinmethod
    def put_Command(self: win32more.Microsoft.UI.Xaml.Controls.ISwipeItem, value: win32more.Microsoft.UI.Xaml.Input.ICommand) -> Void: ...
    @winrt_mixinmethod
    def get_CommandParameter(self: win32more.Microsoft.UI.Xaml.Controls.ISwipeItem) -> IInspectable: ...
    @winrt_mixinmethod
    def put_CommandParameter(self: win32more.Microsoft.UI.Xaml.Controls.ISwipeItem, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_BehaviorOnInvoked(self: win32more.Microsoft.UI.Xaml.Controls.ISwipeItem) -> win32more.Microsoft.UI.Xaml.Controls.SwipeBehaviorOnInvoked: ...
    @winrt_mixinmethod
    def put_BehaviorOnInvoked(self: win32more.Microsoft.UI.Xaml.Controls.ISwipeItem, value: win32more.Microsoft.UI.Xaml.Controls.SwipeBehaviorOnInvoked) -> Void: ...
    @winrt_mixinmethod
    def add_Invoked(self: win32more.Microsoft.UI.Xaml.Controls.ISwipeItem, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.SwipeItem, win32more.Microsoft.UI.Xaml.Controls.SwipeItemInvokedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Invoked(self: win32more.Microsoft.UI.Xaml.Controls.ISwipeItem, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def get_IconSourceProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ISwipeItemStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TextProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ISwipeItemStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_BackgroundProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ISwipeItemStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ForegroundProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ISwipeItemStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CommandProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ISwipeItemStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CommandParameterProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ISwipeItemStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_BehaviorOnInvokedProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ISwipeItemStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    Background = property(get_Background, put_Background)
    BehaviorOnInvoked = property(get_BehaviorOnInvoked, put_BehaviorOnInvoked)
    Command = property(get_Command, put_Command)
    CommandParameter = property(get_CommandParameter, put_CommandParameter)
    Foreground = property(get_Foreground, put_Foreground)
    IconSource = property(get_IconSource, put_IconSource)
    Text = property(get_Text, put_Text)
    _SwipeItem_Meta_.BackgroundProperty = property(get_BackgroundProperty, None)
    _SwipeItem_Meta_.BehaviorOnInvokedProperty = property(get_BehaviorOnInvokedProperty, None)
    _SwipeItem_Meta_.CommandParameterProperty = property(get_CommandParameterProperty, None)
    _SwipeItem_Meta_.CommandProperty = property(get_CommandProperty, None)
    _SwipeItem_Meta_.ForegroundProperty = property(get_ForegroundProperty, None)
    _SwipeItem_Meta_.IconSourceProperty = property(get_IconSourceProperty, None)
    _SwipeItem_Meta_.TextProperty = property(get_TextProperty, None)
    Invoked = event(add_Invoked, remove_Invoked)
class SwipeItemInvokedEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ISwipeItemInvokedEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.SwipeItemInvokedEventArgs'
    @winrt_mixinmethod
    def get_SwipeControl(self: win32more.Microsoft.UI.Xaml.Controls.ISwipeItemInvokedEventArgs) -> win32more.Microsoft.UI.Xaml.Controls.SwipeControl: ...
    SwipeControl = property(get_SwipeControl, None)
class _SwipeItems_Meta_(ComPtr.__class__):
    pass
class SwipeItems(ComPtr, metaclass=_SwipeItems_Meta_):
    extends: win32more.Microsoft.UI.Xaml.DependencyObject
    implements: Tuple[SequenceProtocol[win32more.Microsoft.UI.Xaml.Controls.SwipeItem]]
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ISwipeItems
    _classid_ = 'Microsoft.UI.Xaml.Controls.SwipeItems'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.SwipeItems.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.ISwipeItemsFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.SwipeItems: ...
    @winrt_mixinmethod
    def get_Mode(self: win32more.Microsoft.UI.Xaml.Controls.ISwipeItems) -> win32more.Microsoft.UI.Xaml.Controls.SwipeMode: ...
    @winrt_mixinmethod
    def put_Mode(self: win32more.Microsoft.UI.Xaml.Controls.ISwipeItems, value: win32more.Microsoft.UI.Xaml.Controls.SwipeMode) -> Void: ...
    @winrt_mixinmethod
    def GetAt(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.SwipeItem], index: UInt32) -> win32more.Microsoft.UI.Xaml.Controls.SwipeItem: ...
    @winrt_mixinmethod
    def get_Size(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.SwipeItem]) -> UInt32: ...
    @winrt_mixinmethod
    def GetView(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.SwipeItem]) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Microsoft.UI.Xaml.Controls.SwipeItem]: ...
    @winrt_mixinmethod
    def IndexOf(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.SwipeItem], value: win32more.Microsoft.UI.Xaml.Controls.SwipeItem, index: POINTER(UInt32)) -> Boolean: ...
    @winrt_mixinmethod
    def SetAt(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.SwipeItem], index: UInt32, value: win32more.Microsoft.UI.Xaml.Controls.SwipeItem) -> Void: ...
    @winrt_mixinmethod
    def InsertAt(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.SwipeItem], index: UInt32, value: win32more.Microsoft.UI.Xaml.Controls.SwipeItem) -> Void: ...
    @winrt_mixinmethod
    def RemoveAt(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.SwipeItem], index: UInt32) -> Void: ...
    @winrt_mixinmethod
    def Append(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.SwipeItem], value: win32more.Microsoft.UI.Xaml.Controls.SwipeItem) -> Void: ...
    @winrt_mixinmethod
    def RemoveAtEnd(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.SwipeItem]) -> Void: ...
    @winrt_mixinmethod
    def Clear(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.SwipeItem]) -> Void: ...
    @winrt_mixinmethod
    def GetMany(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.SwipeItem], startIndex: UInt32, items: FillArray[win32more.Microsoft.UI.Xaml.Controls.SwipeItem]) -> UInt32: ...
    @winrt_mixinmethod
    def ReplaceAll(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.SwipeItem], items: PassArray[win32more.Microsoft.UI.Xaml.Controls.SwipeItem]) -> Void: ...
    @winrt_mixinmethod
    def First(self: win32more.Windows.Foundation.Collections.IIterable[win32more.Microsoft.UI.Xaml.Controls.SwipeItem]) -> win32more.Windows.Foundation.Collections.IIterator[win32more.Microsoft.UI.Xaml.Controls.SwipeItem]: ...
    @winrt_classmethod
    def get_ModeProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ISwipeItemsStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    Mode = property(get_Mode, put_Mode)
    Size = property(get_Size, None)
    _SwipeItems_Meta_.ModeProperty = property(get_ModeProperty, None)
class SwipeMode(Enum, Int32):
    Reveal = 0
    Execute = 1
class Symbol(Enum, Int32):
    Previous = 57600
    Next = 57601
    Play = 57602
    Pause = 57603
    Edit = 57604
    Save = 57605
    Clear = 57606
    Delete = 57607
    Remove = 57608
    Add = 57609
    Cancel = 57610
    Accept = 57611
    More = 57612
    Redo = 57613
    Undo = 57614
    Home = 57615
    Up = 57616
    Forward = 57617
    Back = 57618
    Favorite = 57619
    Camera = 57620
    Setting = 57621
    Video = 57622
    Sync = 57623
    Download = 57624
    Mail = 57625
    Find = 57626
    Help = 57627
    Upload = 57628
    Emoji = 57629
    TwoPage = 57630
    LeaveChat = 57631
    MailForward = 57632
    Clock = 57633
    Send = 57634
    Crop = 57635
    RotateCamera = 57636
    People = 57637
    OpenPane = 57638
    ClosePane = 57639
    World = 57640
    Flag = 57641
    PreviewLink = 57642
    Globe = 57643
    Trim = 57644
    AttachCamera = 57645
    ZoomIn = 57646
    Bookmarks = 57647
    Document = 57648
    ProtectedDocument = 57649
    Page = 57650
    Bullets = 57651
    Comment = 57652
    MailFilled = 57653
    ContactInfo = 57654
    HangUp = 57655
    ViewAll = 57656
    MapPin = 57657
    Phone = 57658
    VideoChat = 57659
    Switch = 57660
    Contact = 57661
    Rename = 57662
    Pin = 57665
    MusicInfo = 57666
    Go = 57667
    Keyboard = 57668
    DockLeft = 57669
    DockRight = 57670
    DockBottom = 57671
    Remote = 57672
    Refresh = 57673
    Rotate = 57674
    Shuffle = 57675
    List = 57676
    Shop = 57677
    SelectAll = 57678
    Orientation = 57679
    Import = 57680
    ImportAll = 57681
    BrowsePhotos = 57685
    WebCam = 57686
    Pictures = 57688
    SaveLocal = 57689
    Caption = 57690
    Stop = 57691
    ShowResults = 57692
    Volume = 57693
    Repair = 57694
    Message = 57695
    Page2 = 57696
    CalendarDay = 57697
    CalendarWeek = 57698
    Calendar = 57699
    Character = 57700
    MailReplyAll = 57701
    Read = 57702
    Link = 57703
    Account = 57704
    ShowBcc = 57705
    HideBcc = 57706
    Cut = 57707
    Attach = 57708
    Paste = 57709
    Filter = 57710
    Copy = 57711
    Emoji2 = 57712
    Important = 57713
    MailReply = 57714
    SlideShow = 57715
    Sort = 57716
    Manage = 57720
    AllApps = 57721
    DisconnectDrive = 57722
    MapDrive = 57723
    NewWindow = 57724
    OpenWith = 57725
    ContactPresence = 57729
    Priority = 57730
    GoToToday = 57732
    Font = 57733
    FontColor = 57734
    Contact2 = 57735
    Folder = 57736
    Audio = 57737
    Placeholder = 57738
    View = 57739
    SetLockScreen = 57740
    SetTile = 57741
    ClosedCaption = 57744
    StopSlideShow = 57745
    Permissions = 57746
    Highlight = 57747
    DisableUpdates = 57748
    UnFavorite = 57749
    UnPin = 57750
    OpenLocal = 57751
    Mute = 57752
    Italic = 57753
    Underline = 57754
    Bold = 57755
    MoveToFolder = 57756
    LikeDislike = 57757
    Dislike = 57758
    Like = 57759
    AlignRight = 57760
    AlignCenter = 57761
    AlignLeft = 57762
    Zoom = 57763
    ZoomOut = 57764
    OpenFile = 57765
    OtherUser = 57766
    Admin = 57767
    Street = 57795
    Map = 57796
    ClearSelection = 57797
    FontDecrease = 57798
    FontIncrease = 57799
    FontSize = 57800
    CellPhone = 57801
    ReShare = 57802
    Tag = 57803
    RepeatOne = 57804
    RepeatAll = 57805
    OutlineStar = 57806
    SolidStar = 57807
    Calculator = 57808
    Directions = 57809
    Target = 57810
    Library = 57811
    PhoneBook = 57812
    Memo = 57813
    Microphone = 57814
    PostUpdate = 57815
    BackToWindow = 57816
    FullScreen = 57817
    NewFolder = 57818
    CalendarReply = 57819
    UnSyncFolder = 57821
    ReportHacked = 57822
    SyncFolder = 57823
    BlockContact = 57824
    SwitchApps = 57825
    AddFriend = 57826
    TouchPointer = 57827
    GoToStart = 57828
    ZeroBars = 57829
    OneBar = 57830
    TwoBars = 57831
    ThreeBars = 57832
    FourBars = 57833
    Scan = 58004
    Preview = 58005
    GlobalNavigationButton = 59136
    Share = 59181
    Print = 59209
    XboxOneConsole = 59792
class _SymbolIcon_Meta_(ComPtr.__class__):
    pass
class SymbolIcon(ComPtr, metaclass=_SymbolIcon_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.IconElement
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ISymbolIcon
    _classid_ = 'Microsoft.UI.Xaml.Controls.SymbolIcon'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.SymbolIcon.CreateInstance(*args))
        elif len(args) == 1:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.SymbolIcon.CreateInstanceWithSymbol(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Controls.SymbolIcon: ...
    @winrt_factorymethod
    def CreateInstanceWithSymbol(cls: win32more.Microsoft.UI.Xaml.Controls.ISymbolIconFactory, symbol: win32more.Microsoft.UI.Xaml.Controls.Symbol) -> win32more.Microsoft.UI.Xaml.Controls.SymbolIcon: ...
    @winrt_mixinmethod
    def get_Symbol(self: win32more.Microsoft.UI.Xaml.Controls.ISymbolIcon) -> win32more.Microsoft.UI.Xaml.Controls.Symbol: ...
    @winrt_mixinmethod
    def put_Symbol(self: win32more.Microsoft.UI.Xaml.Controls.ISymbolIcon, value: win32more.Microsoft.UI.Xaml.Controls.Symbol) -> Void: ...
    @winrt_classmethod
    def get_SymbolProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ISymbolIconStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    Symbol = property(get_Symbol, put_Symbol)
    _SymbolIcon_Meta_.SymbolProperty = property(get_SymbolProperty, None)
class _SymbolIconSource_Meta_(ComPtr.__class__):
    pass
class SymbolIconSource(ComPtr, metaclass=_SymbolIconSource_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.IconSource
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ISymbolIconSource
    _classid_ = 'Microsoft.UI.Xaml.Controls.SymbolIconSource'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.SymbolIconSource.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.ISymbolIconSourceFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.SymbolIconSource: ...
    @winrt_mixinmethod
    def get_Symbol(self: win32more.Microsoft.UI.Xaml.Controls.ISymbolIconSource) -> win32more.Microsoft.UI.Xaml.Controls.Symbol: ...
    @winrt_mixinmethod
    def put_Symbol(self: win32more.Microsoft.UI.Xaml.Controls.ISymbolIconSource, value: win32more.Microsoft.UI.Xaml.Controls.Symbol) -> Void: ...
    @winrt_classmethod
    def get_SymbolProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ISymbolIconSourceStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    Symbol = property(get_Symbol, put_Symbol)
    _SymbolIconSource_Meta_.SymbolProperty = property(get_SymbolProperty, None)
class _TabView_Meta_(ComPtr.__class__):
    pass
class TabView(ComPtr, metaclass=_TabView_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.Control
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ITabView
    _classid_ = 'Microsoft.UI.Xaml.Controls.TabView'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.TabView.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.ITabViewFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.TabView: ...
    @winrt_mixinmethod
    def get_TabWidthMode(self: win32more.Microsoft.UI.Xaml.Controls.ITabView) -> win32more.Microsoft.UI.Xaml.Controls.TabViewWidthMode: ...
    @winrt_mixinmethod
    def put_TabWidthMode(self: win32more.Microsoft.UI.Xaml.Controls.ITabView, value: win32more.Microsoft.UI.Xaml.Controls.TabViewWidthMode) -> Void: ...
    @winrt_mixinmethod
    def get_CloseButtonOverlayMode(self: win32more.Microsoft.UI.Xaml.Controls.ITabView) -> win32more.Microsoft.UI.Xaml.Controls.TabViewCloseButtonOverlayMode: ...
    @winrt_mixinmethod
    def put_CloseButtonOverlayMode(self: win32more.Microsoft.UI.Xaml.Controls.ITabView, value: win32more.Microsoft.UI.Xaml.Controls.TabViewCloseButtonOverlayMode) -> Void: ...
    @winrt_mixinmethod
    def get_TabStripHeader(self: win32more.Microsoft.UI.Xaml.Controls.ITabView) -> IInspectable: ...
    @winrt_mixinmethod
    def put_TabStripHeader(self: win32more.Microsoft.UI.Xaml.Controls.ITabView, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_TabStripHeaderTemplate(self: win32more.Microsoft.UI.Xaml.Controls.ITabView) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def put_TabStripHeaderTemplate(self: win32more.Microsoft.UI.Xaml.Controls.ITabView, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_mixinmethod
    def get_TabStripFooter(self: win32more.Microsoft.UI.Xaml.Controls.ITabView) -> IInspectable: ...
    @winrt_mixinmethod
    def put_TabStripFooter(self: win32more.Microsoft.UI.Xaml.Controls.ITabView, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_TabStripFooterTemplate(self: win32more.Microsoft.UI.Xaml.Controls.ITabView) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def put_TabStripFooterTemplate(self: win32more.Microsoft.UI.Xaml.Controls.ITabView, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_mixinmethod
    def get_IsAddTabButtonVisible(self: win32more.Microsoft.UI.Xaml.Controls.ITabView) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsAddTabButtonVisible(self: win32more.Microsoft.UI.Xaml.Controls.ITabView, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_AddTabButtonCommand(self: win32more.Microsoft.UI.Xaml.Controls.ITabView) -> win32more.Microsoft.UI.Xaml.Input.ICommand: ...
    @winrt_mixinmethod
    def put_AddTabButtonCommand(self: win32more.Microsoft.UI.Xaml.Controls.ITabView, value: win32more.Microsoft.UI.Xaml.Input.ICommand) -> Void: ...
    @winrt_mixinmethod
    def get_AddTabButtonCommandParameter(self: win32more.Microsoft.UI.Xaml.Controls.ITabView) -> IInspectable: ...
    @winrt_mixinmethod
    def put_AddTabButtonCommandParameter(self: win32more.Microsoft.UI.Xaml.Controls.ITabView, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def add_TabCloseRequested(self: win32more.Microsoft.UI.Xaml.Controls.ITabView, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.TabView, win32more.Microsoft.UI.Xaml.Controls.TabViewTabCloseRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_TabCloseRequested(self: win32more.Microsoft.UI.Xaml.Controls.ITabView, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_TabDroppedOutside(self: win32more.Microsoft.UI.Xaml.Controls.ITabView, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.TabView, win32more.Microsoft.UI.Xaml.Controls.TabViewTabDroppedOutsideEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_TabDroppedOutside(self: win32more.Microsoft.UI.Xaml.Controls.ITabView, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_AddTabButtonClick(self: win32more.Microsoft.UI.Xaml.Controls.ITabView, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.TabView, IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_AddTabButtonClick(self: win32more.Microsoft.UI.Xaml.Controls.ITabView, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_TabItemsChanged(self: win32more.Microsoft.UI.Xaml.Controls.ITabView, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.TabView, win32more.Windows.Foundation.Collections.IVectorChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_TabItemsChanged(self: win32more.Microsoft.UI.Xaml.Controls.ITabView, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def get_TabItemsSource(self: win32more.Microsoft.UI.Xaml.Controls.ITabView) -> IInspectable: ...
    @winrt_mixinmethod
    def put_TabItemsSource(self: win32more.Microsoft.UI.Xaml.Controls.ITabView, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_TabItems(self: win32more.Microsoft.UI.Xaml.Controls.ITabView) -> win32more.Windows.Foundation.Collections.IVector[IInspectable]: ...
    @winrt_mixinmethod
    def get_TabItemTemplate(self: win32more.Microsoft.UI.Xaml.Controls.ITabView) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def put_TabItemTemplate(self: win32more.Microsoft.UI.Xaml.Controls.ITabView, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_mixinmethod
    def get_TabItemTemplateSelector(self: win32more.Microsoft.UI.Xaml.Controls.ITabView) -> win32more.Microsoft.UI.Xaml.Controls.DataTemplateSelector: ...
    @winrt_mixinmethod
    def put_TabItemTemplateSelector(self: win32more.Microsoft.UI.Xaml.Controls.ITabView, value: win32more.Microsoft.UI.Xaml.Controls.DataTemplateSelector) -> Void: ...
    @winrt_mixinmethod
    def get_CanDragTabs(self: win32more.Microsoft.UI.Xaml.Controls.ITabView) -> Boolean: ...
    @winrt_mixinmethod
    def put_CanDragTabs(self: win32more.Microsoft.UI.Xaml.Controls.ITabView, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_CanReorderTabs(self: win32more.Microsoft.UI.Xaml.Controls.ITabView) -> Boolean: ...
    @winrt_mixinmethod
    def put_CanReorderTabs(self: win32more.Microsoft.UI.Xaml.Controls.ITabView, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_AllowDropTabs(self: win32more.Microsoft.UI.Xaml.Controls.ITabView) -> Boolean: ...
    @winrt_mixinmethod
    def put_AllowDropTabs(self: win32more.Microsoft.UI.Xaml.Controls.ITabView, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_SelectedIndex(self: win32more.Microsoft.UI.Xaml.Controls.ITabView) -> Int32: ...
    @winrt_mixinmethod
    def put_SelectedIndex(self: win32more.Microsoft.UI.Xaml.Controls.ITabView, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_SelectedItem(self: win32more.Microsoft.UI.Xaml.Controls.ITabView) -> IInspectable: ...
    @winrt_mixinmethod
    def put_SelectedItem(self: win32more.Microsoft.UI.Xaml.Controls.ITabView, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def ContainerFromItem(self: win32more.Microsoft.UI.Xaml.Controls.ITabView, item: IInspectable) -> win32more.Microsoft.UI.Xaml.DependencyObject: ...
    @winrt_mixinmethod
    def ContainerFromIndex(self: win32more.Microsoft.UI.Xaml.Controls.ITabView, index: Int32) -> win32more.Microsoft.UI.Xaml.DependencyObject: ...
    @winrt_mixinmethod
    def add_SelectionChanged(self: win32more.Microsoft.UI.Xaml.Controls.ITabView, handler: win32more.Microsoft.UI.Xaml.Controls.SelectionChangedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_SelectionChanged(self: win32more.Microsoft.UI.Xaml.Controls.ITabView, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_TabDragStarting(self: win32more.Microsoft.UI.Xaml.Controls.ITabView, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.TabView, win32more.Microsoft.UI.Xaml.Controls.TabViewTabDragStartingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_TabDragStarting(self: win32more.Microsoft.UI.Xaml.Controls.ITabView, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_TabDragCompleted(self: win32more.Microsoft.UI.Xaml.Controls.ITabView, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.TabView, win32more.Microsoft.UI.Xaml.Controls.TabViewTabDragCompletedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_TabDragCompleted(self: win32more.Microsoft.UI.Xaml.Controls.ITabView, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_TabStripDragOver(self: win32more.Microsoft.UI.Xaml.Controls.ITabView, handler: win32more.Microsoft.UI.Xaml.DragEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_TabStripDragOver(self: win32more.Microsoft.UI.Xaml.Controls.ITabView, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_TabStripDrop(self: win32more.Microsoft.UI.Xaml.Controls.ITabView, handler: win32more.Microsoft.UI.Xaml.DragEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_TabStripDrop(self: win32more.Microsoft.UI.Xaml.Controls.ITabView, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def get_TabWidthModeProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITabViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TabStripHeaderProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITabViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TabStripHeaderTemplateProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITabViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TabStripFooterProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITabViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TabStripFooterTemplateProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITabViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsAddTabButtonVisibleProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITabViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_AddTabButtonCommandProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITabViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_AddTabButtonCommandParameterProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITabViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TabItemsSourceProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITabViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TabItemsProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITabViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TabItemTemplateProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITabViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TabItemTemplateSelectorProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITabViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CloseButtonOverlayModeProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITabViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CanDragTabsProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITabViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CanReorderTabsProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITabViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_AllowDropTabsProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITabViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectedIndexProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITabViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectedItemProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITabViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    AddTabButtonCommand = property(get_AddTabButtonCommand, put_AddTabButtonCommand)
    AddTabButtonCommandParameter = property(get_AddTabButtonCommandParameter, put_AddTabButtonCommandParameter)
    AllowDropTabs = property(get_AllowDropTabs, put_AllowDropTabs)
    CanDragTabs = property(get_CanDragTabs, put_CanDragTabs)
    CanReorderTabs = property(get_CanReorderTabs, put_CanReorderTabs)
    CloseButtonOverlayMode = property(get_CloseButtonOverlayMode, put_CloseButtonOverlayMode)
    IsAddTabButtonVisible = property(get_IsAddTabButtonVisible, put_IsAddTabButtonVisible)
    SelectedIndex = property(get_SelectedIndex, put_SelectedIndex)
    SelectedItem = property(get_SelectedItem, put_SelectedItem)
    TabItemTemplate = property(get_TabItemTemplate, put_TabItemTemplate)
    TabItemTemplateSelector = property(get_TabItemTemplateSelector, put_TabItemTemplateSelector)
    TabItems = property(get_TabItems, None)
    TabItemsSource = property(get_TabItemsSource, put_TabItemsSource)
    TabStripFooter = property(get_TabStripFooter, put_TabStripFooter)
    TabStripFooterTemplate = property(get_TabStripFooterTemplate, put_TabStripFooterTemplate)
    TabStripHeader = property(get_TabStripHeader, put_TabStripHeader)
    TabStripHeaderTemplate = property(get_TabStripHeaderTemplate, put_TabStripHeaderTemplate)
    TabWidthMode = property(get_TabWidthMode, put_TabWidthMode)
    _TabView_Meta_.AddTabButtonCommandParameterProperty = property(get_AddTabButtonCommandParameterProperty, None)
    _TabView_Meta_.AddTabButtonCommandProperty = property(get_AddTabButtonCommandProperty, None)
    _TabView_Meta_.AllowDropTabsProperty = property(get_AllowDropTabsProperty, None)
    _TabView_Meta_.CanDragTabsProperty = property(get_CanDragTabsProperty, None)
    _TabView_Meta_.CanReorderTabsProperty = property(get_CanReorderTabsProperty, None)
    _TabView_Meta_.CloseButtonOverlayModeProperty = property(get_CloseButtonOverlayModeProperty, None)
    _TabView_Meta_.IsAddTabButtonVisibleProperty = property(get_IsAddTabButtonVisibleProperty, None)
    _TabView_Meta_.SelectedIndexProperty = property(get_SelectedIndexProperty, None)
    _TabView_Meta_.SelectedItemProperty = property(get_SelectedItemProperty, None)
    _TabView_Meta_.TabItemTemplateProperty = property(get_TabItemTemplateProperty, None)
    _TabView_Meta_.TabItemTemplateSelectorProperty = property(get_TabItemTemplateSelectorProperty, None)
    _TabView_Meta_.TabItemsProperty = property(get_TabItemsProperty, None)
    _TabView_Meta_.TabItemsSourceProperty = property(get_TabItemsSourceProperty, None)
    _TabView_Meta_.TabStripFooterProperty = property(get_TabStripFooterProperty, None)
    _TabView_Meta_.TabStripFooterTemplateProperty = property(get_TabStripFooterTemplateProperty, None)
    _TabView_Meta_.TabStripHeaderProperty = property(get_TabStripHeaderProperty, None)
    _TabView_Meta_.TabStripHeaderTemplateProperty = property(get_TabStripHeaderTemplateProperty, None)
    _TabView_Meta_.TabWidthModeProperty = property(get_TabWidthModeProperty, None)
    AddTabButtonClick = event(add_AddTabButtonClick, remove_AddTabButtonClick)
    SelectionChanged = event(add_SelectionChanged, remove_SelectionChanged)
    TabCloseRequested = event(add_TabCloseRequested, remove_TabCloseRequested)
    TabDragCompleted = event(add_TabDragCompleted, remove_TabDragCompleted)
    TabDragStarting = event(add_TabDragStarting, remove_TabDragStarting)
    TabDroppedOutside = event(add_TabDroppedOutside, remove_TabDroppedOutside)
    TabItemsChanged = event(add_TabItemsChanged, remove_TabItemsChanged)
    TabStripDragOver = event(add_TabStripDragOver, remove_TabStripDragOver)
    TabStripDrop = event(add_TabStripDrop, remove_TabStripDrop)
class TabViewCloseButtonOverlayMode(Enum, Int32):
    Auto = 0
    OnPointerOver = 1
    Always = 2
class _TabViewItem_Meta_(ComPtr.__class__):
    pass
class TabViewItem(ComPtr, metaclass=_TabViewItem_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.ListViewItem
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ITabViewItem
    _classid_ = 'Microsoft.UI.Xaml.Controls.TabViewItem'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.TabViewItem.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.ITabViewItemFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.TabViewItem: ...
    @winrt_mixinmethod
    def get_Header(self: win32more.Microsoft.UI.Xaml.Controls.ITabViewItem) -> IInspectable: ...
    @winrt_mixinmethod
    def put_Header(self: win32more.Microsoft.UI.Xaml.Controls.ITabViewItem, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_HeaderTemplate(self: win32more.Microsoft.UI.Xaml.Controls.ITabViewItem) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def put_HeaderTemplate(self: win32more.Microsoft.UI.Xaml.Controls.ITabViewItem, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_mixinmethod
    def get_IconSource(self: win32more.Microsoft.UI.Xaml.Controls.ITabViewItem) -> win32more.Microsoft.UI.Xaml.Controls.IconSource: ...
    @winrt_mixinmethod
    def put_IconSource(self: win32more.Microsoft.UI.Xaml.Controls.ITabViewItem, value: win32more.Microsoft.UI.Xaml.Controls.IconSource) -> Void: ...
    @winrt_mixinmethod
    def get_IsClosable(self: win32more.Microsoft.UI.Xaml.Controls.ITabViewItem) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsClosable(self: win32more.Microsoft.UI.Xaml.Controls.ITabViewItem, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_TabViewTemplateSettings(self: win32more.Microsoft.UI.Xaml.Controls.ITabViewItem) -> win32more.Microsoft.UI.Xaml.Controls.TabViewItemTemplateSettings: ...
    @winrt_mixinmethod
    def add_CloseRequested(self: win32more.Microsoft.UI.Xaml.Controls.ITabViewItem, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.TabViewItem, win32more.Microsoft.UI.Xaml.Controls.TabViewTabCloseRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_CloseRequested(self: win32more.Microsoft.UI.Xaml.Controls.ITabViewItem, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def get_HeaderProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITabViewItemStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HeaderTemplateProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITabViewItemStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IconSourceProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITabViewItemStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsClosableProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITabViewItemStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TabViewTemplateSettingsProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITabViewItemStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    Header = property(get_Header, put_Header)
    HeaderTemplate = property(get_HeaderTemplate, put_HeaderTemplate)
    IconSource = property(get_IconSource, put_IconSource)
    IsClosable = property(get_IsClosable, put_IsClosable)
    TabViewTemplateSettings = property(get_TabViewTemplateSettings, None)
    _TabViewItem_Meta_.HeaderProperty = property(get_HeaderProperty, None)
    _TabViewItem_Meta_.HeaderTemplateProperty = property(get_HeaderTemplateProperty, None)
    _TabViewItem_Meta_.IconSourceProperty = property(get_IconSourceProperty, None)
    _TabViewItem_Meta_.IsClosableProperty = property(get_IsClosableProperty, None)
    _TabViewItem_Meta_.TabViewTemplateSettingsProperty = property(get_TabViewTemplateSettingsProperty, None)
    CloseRequested = event(add_CloseRequested, remove_CloseRequested)
class _TabViewItemTemplateSettings_Meta_(ComPtr.__class__):
    pass
class TabViewItemTemplateSettings(ComPtr, metaclass=_TabViewItemTemplateSettings_Meta_):
    extends: win32more.Microsoft.UI.Xaml.DependencyObject
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ITabViewItemTemplateSettings
    _classid_ = 'Microsoft.UI.Xaml.Controls.TabViewItemTemplateSettings'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.TabViewItemTemplateSettings.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.ITabViewItemTemplateSettingsFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.TabViewItemTemplateSettings: ...
    @winrt_mixinmethod
    def get_IconElement(self: win32more.Microsoft.UI.Xaml.Controls.ITabViewItemTemplateSettings) -> win32more.Microsoft.UI.Xaml.Controls.IconElement: ...
    @winrt_mixinmethod
    def put_IconElement(self: win32more.Microsoft.UI.Xaml.Controls.ITabViewItemTemplateSettings, value: win32more.Microsoft.UI.Xaml.Controls.IconElement) -> Void: ...
    @winrt_mixinmethod
    def get_TabGeometry(self: win32more.Microsoft.UI.Xaml.Controls.ITabViewItemTemplateSettings2) -> win32more.Microsoft.UI.Xaml.Media.Geometry: ...
    @winrt_mixinmethod
    def put_TabGeometry(self: win32more.Microsoft.UI.Xaml.Controls.ITabViewItemTemplateSettings2, value: win32more.Microsoft.UI.Xaml.Media.Geometry) -> Void: ...
    @winrt_classmethod
    def get_TabGeometryProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITabViewItemTemplateSettingsStatics2) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IconElementProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITabViewItemTemplateSettingsStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    IconElement = property(get_IconElement, put_IconElement)
    TabGeometry = property(get_TabGeometry, put_TabGeometry)
    _TabViewItemTemplateSettings_Meta_.IconElementProperty = property(get_IconElementProperty, None)
    _TabViewItemTemplateSettings_Meta_.TabGeometryProperty = property(get_TabGeometryProperty, None)
class TabViewTabCloseRequestedEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ITabViewTabCloseRequestedEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.TabViewTabCloseRequestedEventArgs'
    @winrt_mixinmethod
    def get_Item(self: win32more.Microsoft.UI.Xaml.Controls.ITabViewTabCloseRequestedEventArgs) -> IInspectable: ...
    @winrt_mixinmethod
    def get_Tab(self: win32more.Microsoft.UI.Xaml.Controls.ITabViewTabCloseRequestedEventArgs) -> win32more.Microsoft.UI.Xaml.Controls.TabViewItem: ...
    Item = property(get_Item, None)
    Tab = property(get_Tab, None)
class TabViewTabDragCompletedEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ITabViewTabDragCompletedEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.TabViewTabDragCompletedEventArgs'
    @winrt_mixinmethod
    def get_DropResult(self: win32more.Microsoft.UI.Xaml.Controls.ITabViewTabDragCompletedEventArgs) -> win32more.Windows.ApplicationModel.DataTransfer.DataPackageOperation: ...
    @winrt_mixinmethod
    def get_Item(self: win32more.Microsoft.UI.Xaml.Controls.ITabViewTabDragCompletedEventArgs) -> IInspectable: ...
    @winrt_mixinmethod
    def get_Tab(self: win32more.Microsoft.UI.Xaml.Controls.ITabViewTabDragCompletedEventArgs) -> win32more.Microsoft.UI.Xaml.Controls.TabViewItem: ...
    DropResult = property(get_DropResult, None)
    Item = property(get_Item, None)
    Tab = property(get_Tab, None)
class TabViewTabDragStartingEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ITabViewTabDragStartingEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.TabViewTabDragStartingEventArgs'
    @winrt_mixinmethod
    def get_Cancel(self: win32more.Microsoft.UI.Xaml.Controls.ITabViewTabDragStartingEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def put_Cancel(self: win32more.Microsoft.UI.Xaml.Controls.ITabViewTabDragStartingEventArgs, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_Data(self: win32more.Microsoft.UI.Xaml.Controls.ITabViewTabDragStartingEventArgs) -> win32more.Windows.ApplicationModel.DataTransfer.DataPackage: ...
    @winrt_mixinmethod
    def get_Item(self: win32more.Microsoft.UI.Xaml.Controls.ITabViewTabDragStartingEventArgs) -> IInspectable: ...
    @winrt_mixinmethod
    def get_Tab(self: win32more.Microsoft.UI.Xaml.Controls.ITabViewTabDragStartingEventArgs) -> win32more.Microsoft.UI.Xaml.Controls.TabViewItem: ...
    Cancel = property(get_Cancel, put_Cancel)
    Data = property(get_Data, None)
    Item = property(get_Item, None)
    Tab = property(get_Tab, None)
class TabViewTabDroppedOutsideEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ITabViewTabDroppedOutsideEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.TabViewTabDroppedOutsideEventArgs'
    @winrt_mixinmethod
    def get_Item(self: win32more.Microsoft.UI.Xaml.Controls.ITabViewTabDroppedOutsideEventArgs) -> IInspectable: ...
    @winrt_mixinmethod
    def get_Tab(self: win32more.Microsoft.UI.Xaml.Controls.ITabViewTabDroppedOutsideEventArgs) -> win32more.Microsoft.UI.Xaml.Controls.TabViewItem: ...
    Item = property(get_Item, None)
    Tab = property(get_Tab, None)
class TabViewWidthMode(Enum, Int32):
    Equal = 0
    SizeToContent = 1
    Compact = 2
class _TeachingTip_Meta_(ComPtr.__class__):
    pass
class TeachingTip(ComPtr, metaclass=_TeachingTip_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.ContentControl
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ITeachingTip
    _classid_ = 'Microsoft.UI.Xaml.Controls.TeachingTip'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.TeachingTip.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.ITeachingTipFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.TeachingTip: ...
    @winrt_mixinmethod
    def get_Title(self: win32more.Microsoft.UI.Xaml.Controls.ITeachingTip) -> hstr: ...
    @winrt_mixinmethod
    def put_Title(self: win32more.Microsoft.UI.Xaml.Controls.ITeachingTip, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def get_Subtitle(self: win32more.Microsoft.UI.Xaml.Controls.ITeachingTip) -> hstr: ...
    @winrt_mixinmethod
    def put_Subtitle(self: win32more.Microsoft.UI.Xaml.Controls.ITeachingTip, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def get_IsOpen(self: win32more.Microsoft.UI.Xaml.Controls.ITeachingTip) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsOpen(self: win32more.Microsoft.UI.Xaml.Controls.ITeachingTip, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_Target(self: win32more.Microsoft.UI.Xaml.Controls.ITeachingTip) -> win32more.Microsoft.UI.Xaml.FrameworkElement: ...
    @winrt_mixinmethod
    def put_Target(self: win32more.Microsoft.UI.Xaml.Controls.ITeachingTip, value: win32more.Microsoft.UI.Xaml.FrameworkElement) -> Void: ...
    @winrt_mixinmethod
    def get_TailVisibility(self: win32more.Microsoft.UI.Xaml.Controls.ITeachingTip) -> win32more.Microsoft.UI.Xaml.Controls.TeachingTipTailVisibility: ...
    @winrt_mixinmethod
    def put_TailVisibility(self: win32more.Microsoft.UI.Xaml.Controls.ITeachingTip, value: win32more.Microsoft.UI.Xaml.Controls.TeachingTipTailVisibility) -> Void: ...
    @winrt_mixinmethod
    def get_ActionButtonContent(self: win32more.Microsoft.UI.Xaml.Controls.ITeachingTip) -> IInspectable: ...
    @winrt_mixinmethod
    def put_ActionButtonContent(self: win32more.Microsoft.UI.Xaml.Controls.ITeachingTip, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_ActionButtonStyle(self: win32more.Microsoft.UI.Xaml.Controls.ITeachingTip) -> win32more.Microsoft.UI.Xaml.Style: ...
    @winrt_mixinmethod
    def put_ActionButtonStyle(self: win32more.Microsoft.UI.Xaml.Controls.ITeachingTip, value: win32more.Microsoft.UI.Xaml.Style) -> Void: ...
    @winrt_mixinmethod
    def get_ActionButtonCommand(self: win32more.Microsoft.UI.Xaml.Controls.ITeachingTip) -> win32more.Microsoft.UI.Xaml.Input.ICommand: ...
    @winrt_mixinmethod
    def put_ActionButtonCommand(self: win32more.Microsoft.UI.Xaml.Controls.ITeachingTip, value: win32more.Microsoft.UI.Xaml.Input.ICommand) -> Void: ...
    @winrt_mixinmethod
    def get_ActionButtonCommandParameter(self: win32more.Microsoft.UI.Xaml.Controls.ITeachingTip) -> IInspectable: ...
    @winrt_mixinmethod
    def put_ActionButtonCommandParameter(self: win32more.Microsoft.UI.Xaml.Controls.ITeachingTip, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_CloseButtonContent(self: win32more.Microsoft.UI.Xaml.Controls.ITeachingTip) -> IInspectable: ...
    @winrt_mixinmethod
    def put_CloseButtonContent(self: win32more.Microsoft.UI.Xaml.Controls.ITeachingTip, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_CloseButtonStyle(self: win32more.Microsoft.UI.Xaml.Controls.ITeachingTip) -> win32more.Microsoft.UI.Xaml.Style: ...
    @winrt_mixinmethod
    def put_CloseButtonStyle(self: win32more.Microsoft.UI.Xaml.Controls.ITeachingTip, value: win32more.Microsoft.UI.Xaml.Style) -> Void: ...
    @winrt_mixinmethod
    def get_CloseButtonCommand(self: win32more.Microsoft.UI.Xaml.Controls.ITeachingTip) -> win32more.Microsoft.UI.Xaml.Input.ICommand: ...
    @winrt_mixinmethod
    def put_CloseButtonCommand(self: win32more.Microsoft.UI.Xaml.Controls.ITeachingTip, value: win32more.Microsoft.UI.Xaml.Input.ICommand) -> Void: ...
    @winrt_mixinmethod
    def get_CloseButtonCommandParameter(self: win32more.Microsoft.UI.Xaml.Controls.ITeachingTip) -> IInspectable: ...
    @winrt_mixinmethod
    def put_CloseButtonCommandParameter(self: win32more.Microsoft.UI.Xaml.Controls.ITeachingTip, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_PlacementMargin(self: win32more.Microsoft.UI.Xaml.Controls.ITeachingTip) -> win32more.Microsoft.UI.Xaml.Thickness: ...
    @winrt_mixinmethod
    def put_PlacementMargin(self: win32more.Microsoft.UI.Xaml.Controls.ITeachingTip, value: win32more.Microsoft.UI.Xaml.Thickness) -> Void: ...
    @winrt_mixinmethod
    def get_ShouldConstrainToRootBounds(self: win32more.Microsoft.UI.Xaml.Controls.ITeachingTip) -> Boolean: ...
    @winrt_mixinmethod
    def put_ShouldConstrainToRootBounds(self: win32more.Microsoft.UI.Xaml.Controls.ITeachingTip, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsLightDismissEnabled(self: win32more.Microsoft.UI.Xaml.Controls.ITeachingTip) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsLightDismissEnabled(self: win32more.Microsoft.UI.Xaml.Controls.ITeachingTip, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_PreferredPlacement(self: win32more.Microsoft.UI.Xaml.Controls.ITeachingTip) -> win32more.Microsoft.UI.Xaml.Controls.TeachingTipPlacementMode: ...
    @winrt_mixinmethod
    def put_PreferredPlacement(self: win32more.Microsoft.UI.Xaml.Controls.ITeachingTip, value: win32more.Microsoft.UI.Xaml.Controls.TeachingTipPlacementMode) -> Void: ...
    @winrt_mixinmethod
    def get_HeroContentPlacement(self: win32more.Microsoft.UI.Xaml.Controls.ITeachingTip) -> win32more.Microsoft.UI.Xaml.Controls.TeachingTipHeroContentPlacementMode: ...
    @winrt_mixinmethod
    def put_HeroContentPlacement(self: win32more.Microsoft.UI.Xaml.Controls.ITeachingTip, value: win32more.Microsoft.UI.Xaml.Controls.TeachingTipHeroContentPlacementMode) -> Void: ...
    @winrt_mixinmethod
    def get_HeroContent(self: win32more.Microsoft.UI.Xaml.Controls.ITeachingTip) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_mixinmethod
    def put_HeroContent(self: win32more.Microsoft.UI.Xaml.Controls.ITeachingTip, value: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    @winrt_mixinmethod
    def get_IconSource(self: win32more.Microsoft.UI.Xaml.Controls.ITeachingTip) -> win32more.Microsoft.UI.Xaml.Controls.IconSource: ...
    @winrt_mixinmethod
    def put_IconSource(self: win32more.Microsoft.UI.Xaml.Controls.ITeachingTip, value: win32more.Microsoft.UI.Xaml.Controls.IconSource) -> Void: ...
    @winrt_mixinmethod
    def get_TemplateSettings(self: win32more.Microsoft.UI.Xaml.Controls.ITeachingTip) -> win32more.Microsoft.UI.Xaml.Controls.TeachingTipTemplateSettings: ...
    @winrt_mixinmethod
    def add_ActionButtonClick(self: win32more.Microsoft.UI.Xaml.Controls.ITeachingTip, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.TeachingTip, IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ActionButtonClick(self: win32more.Microsoft.UI.Xaml.Controls.ITeachingTip, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_CloseButtonClick(self: win32more.Microsoft.UI.Xaml.Controls.ITeachingTip, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.TeachingTip, IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_CloseButtonClick(self: win32more.Microsoft.UI.Xaml.Controls.ITeachingTip, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_Closing(self: win32more.Microsoft.UI.Xaml.Controls.ITeachingTip, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.TeachingTip, win32more.Microsoft.UI.Xaml.Controls.TeachingTipClosingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Closing(self: win32more.Microsoft.UI.Xaml.Controls.ITeachingTip, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_Closed(self: win32more.Microsoft.UI.Xaml.Controls.ITeachingTip, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.TeachingTip, win32more.Microsoft.UI.Xaml.Controls.TeachingTipClosedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Closed(self: win32more.Microsoft.UI.Xaml.Controls.ITeachingTip, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def get_IsOpenProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITeachingTipStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TargetProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITeachingTipStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TailVisibilityProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITeachingTipStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TitleProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITeachingTipStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SubtitleProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITeachingTipStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ActionButtonContentProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITeachingTipStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ActionButtonStyleProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITeachingTipStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ActionButtonCommandProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITeachingTipStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ActionButtonCommandParameterProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITeachingTipStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CloseButtonContentProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITeachingTipStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CloseButtonStyleProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITeachingTipStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CloseButtonCommandProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITeachingTipStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CloseButtonCommandParameterProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITeachingTipStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PlacementMarginProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITeachingTipStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ShouldConstrainToRootBoundsProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITeachingTipStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsLightDismissEnabledProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITeachingTipStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PreferredPlacementProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITeachingTipStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HeroContentPlacementProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITeachingTipStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HeroContentProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITeachingTipStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IconSourceProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITeachingTipStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TemplateSettingsProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITeachingTipStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    ActionButtonCommand = property(get_ActionButtonCommand, put_ActionButtonCommand)
    ActionButtonCommandParameter = property(get_ActionButtonCommandParameter, put_ActionButtonCommandParameter)
    ActionButtonContent = property(get_ActionButtonContent, put_ActionButtonContent)
    ActionButtonStyle = property(get_ActionButtonStyle, put_ActionButtonStyle)
    CloseButtonCommand = property(get_CloseButtonCommand, put_CloseButtonCommand)
    CloseButtonCommandParameter = property(get_CloseButtonCommandParameter, put_CloseButtonCommandParameter)
    CloseButtonContent = property(get_CloseButtonContent, put_CloseButtonContent)
    CloseButtonStyle = property(get_CloseButtonStyle, put_CloseButtonStyle)
    HeroContent = property(get_HeroContent, put_HeroContent)
    HeroContentPlacement = property(get_HeroContentPlacement, put_HeroContentPlacement)
    IconSource = property(get_IconSource, put_IconSource)
    IsLightDismissEnabled = property(get_IsLightDismissEnabled, put_IsLightDismissEnabled)
    IsOpen = property(get_IsOpen, put_IsOpen)
    PlacementMargin = property(get_PlacementMargin, put_PlacementMargin)
    PreferredPlacement = property(get_PreferredPlacement, put_PreferredPlacement)
    ShouldConstrainToRootBounds = property(get_ShouldConstrainToRootBounds, put_ShouldConstrainToRootBounds)
    Subtitle = property(get_Subtitle, put_Subtitle)
    TailVisibility = property(get_TailVisibility, put_TailVisibility)
    Target = property(get_Target, put_Target)
    TemplateSettings = property(get_TemplateSettings, None)
    Title = property(get_Title, put_Title)
    _TeachingTip_Meta_.ActionButtonCommandParameterProperty = property(get_ActionButtonCommandParameterProperty, None)
    _TeachingTip_Meta_.ActionButtonCommandProperty = property(get_ActionButtonCommandProperty, None)
    _TeachingTip_Meta_.ActionButtonContentProperty = property(get_ActionButtonContentProperty, None)
    _TeachingTip_Meta_.ActionButtonStyleProperty = property(get_ActionButtonStyleProperty, None)
    _TeachingTip_Meta_.CloseButtonCommandParameterProperty = property(get_CloseButtonCommandParameterProperty, None)
    _TeachingTip_Meta_.CloseButtonCommandProperty = property(get_CloseButtonCommandProperty, None)
    _TeachingTip_Meta_.CloseButtonContentProperty = property(get_CloseButtonContentProperty, None)
    _TeachingTip_Meta_.CloseButtonStyleProperty = property(get_CloseButtonStyleProperty, None)
    _TeachingTip_Meta_.HeroContentPlacementProperty = property(get_HeroContentPlacementProperty, None)
    _TeachingTip_Meta_.HeroContentProperty = property(get_HeroContentProperty, None)
    _TeachingTip_Meta_.IconSourceProperty = property(get_IconSourceProperty, None)
    _TeachingTip_Meta_.IsLightDismissEnabledProperty = property(get_IsLightDismissEnabledProperty, None)
    _TeachingTip_Meta_.IsOpenProperty = property(get_IsOpenProperty, None)
    _TeachingTip_Meta_.PlacementMarginProperty = property(get_PlacementMarginProperty, None)
    _TeachingTip_Meta_.PreferredPlacementProperty = property(get_PreferredPlacementProperty, None)
    _TeachingTip_Meta_.ShouldConstrainToRootBoundsProperty = property(get_ShouldConstrainToRootBoundsProperty, None)
    _TeachingTip_Meta_.SubtitleProperty = property(get_SubtitleProperty, None)
    _TeachingTip_Meta_.TailVisibilityProperty = property(get_TailVisibilityProperty, None)
    _TeachingTip_Meta_.TargetProperty = property(get_TargetProperty, None)
    _TeachingTip_Meta_.TemplateSettingsProperty = property(get_TemplateSettingsProperty, None)
    _TeachingTip_Meta_.TitleProperty = property(get_TitleProperty, None)
    ActionButtonClick = event(add_ActionButtonClick, remove_ActionButtonClick)
    CloseButtonClick = event(add_CloseButtonClick, remove_CloseButtonClick)
    Closed = event(add_Closed, remove_Closed)
    Closing = event(add_Closing, remove_Closing)
class TeachingTipCloseReason(Enum, Int32):
    CloseButton = 0
    LightDismiss = 1
    Programmatic = 2
class TeachingTipClosedEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ITeachingTipClosedEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.TeachingTipClosedEventArgs'
    @winrt_mixinmethod
    def get_Reason(self: win32more.Microsoft.UI.Xaml.Controls.ITeachingTipClosedEventArgs) -> win32more.Microsoft.UI.Xaml.Controls.TeachingTipCloseReason: ...
    Reason = property(get_Reason, None)
class TeachingTipClosingEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ITeachingTipClosingEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.TeachingTipClosingEventArgs'
    @winrt_mixinmethod
    def get_Reason(self: win32more.Microsoft.UI.Xaml.Controls.ITeachingTipClosingEventArgs) -> win32more.Microsoft.UI.Xaml.Controls.TeachingTipCloseReason: ...
    @winrt_mixinmethod
    def get_Cancel(self: win32more.Microsoft.UI.Xaml.Controls.ITeachingTipClosingEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def put_Cancel(self: win32more.Microsoft.UI.Xaml.Controls.ITeachingTipClosingEventArgs, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def GetDeferral(self: win32more.Microsoft.UI.Xaml.Controls.ITeachingTipClosingEventArgs) -> win32more.Windows.Foundation.Deferral: ...
    Cancel = property(get_Cancel, put_Cancel)
    Reason = property(get_Reason, None)
class TeachingTipHeroContentPlacementMode(Enum, Int32):
    Auto = 0
    Top = 1
    Bottom = 2
class TeachingTipPlacementMode(Enum, Int32):
    Auto = 0
    Top = 1
    Bottom = 2
    Left = 3
    Right = 4
    TopRight = 5
    TopLeft = 6
    BottomRight = 7
    BottomLeft = 8
    LeftTop = 9
    LeftBottom = 10
    RightTop = 11
    RightBottom = 12
    Center = 13
class TeachingTipTailVisibility(Enum, Int32):
    Auto = 0
    Visible = 1
    Collapsed = 2
class _TeachingTipTemplateSettings_Meta_(ComPtr.__class__):
    pass
class TeachingTipTemplateSettings(ComPtr, metaclass=_TeachingTipTemplateSettings_Meta_):
    extends: win32more.Microsoft.UI.Xaml.DependencyObject
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ITeachingTipTemplateSettings
    _classid_ = 'Microsoft.UI.Xaml.Controls.TeachingTipTemplateSettings'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.TeachingTipTemplateSettings.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.ITeachingTipTemplateSettingsFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.TeachingTipTemplateSettings: ...
    @winrt_mixinmethod
    def get_TopRightHighlightMargin(self: win32more.Microsoft.UI.Xaml.Controls.ITeachingTipTemplateSettings) -> win32more.Microsoft.UI.Xaml.Thickness: ...
    @winrt_mixinmethod
    def put_TopRightHighlightMargin(self: win32more.Microsoft.UI.Xaml.Controls.ITeachingTipTemplateSettings, value: win32more.Microsoft.UI.Xaml.Thickness) -> Void: ...
    @winrt_mixinmethod
    def get_TopLeftHighlightMargin(self: win32more.Microsoft.UI.Xaml.Controls.ITeachingTipTemplateSettings) -> win32more.Microsoft.UI.Xaml.Thickness: ...
    @winrt_mixinmethod
    def put_TopLeftHighlightMargin(self: win32more.Microsoft.UI.Xaml.Controls.ITeachingTipTemplateSettings, value: win32more.Microsoft.UI.Xaml.Thickness) -> Void: ...
    @winrt_mixinmethod
    def get_IconElement(self: win32more.Microsoft.UI.Xaml.Controls.ITeachingTipTemplateSettings) -> win32more.Microsoft.UI.Xaml.Controls.IconElement: ...
    @winrt_mixinmethod
    def put_IconElement(self: win32more.Microsoft.UI.Xaml.Controls.ITeachingTipTemplateSettings, value: win32more.Microsoft.UI.Xaml.Controls.IconElement) -> Void: ...
    @winrt_classmethod
    def get_TopRightHighlightMarginProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITeachingTipTemplateSettingsStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TopLeftHighlightMarginProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITeachingTipTemplateSettingsStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IconElementProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITeachingTipTemplateSettingsStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    IconElement = property(get_IconElement, put_IconElement)
    TopLeftHighlightMargin = property(get_TopLeftHighlightMargin, put_TopLeftHighlightMargin)
    TopRightHighlightMargin = property(get_TopRightHighlightMargin, put_TopRightHighlightMargin)
    _TeachingTipTemplateSettings_Meta_.IconElementProperty = property(get_IconElementProperty, None)
    _TeachingTipTemplateSettings_Meta_.TopLeftHighlightMarginProperty = property(get_TopLeftHighlightMarginProperty, None)
    _TeachingTipTemplateSettings_Meta_.TopRightHighlightMarginProperty = property(get_TopRightHighlightMarginProperty, None)
class _TextBlock_Meta_(ComPtr.__class__):
    pass
class TextBlock(ComPtr, metaclass=_TextBlock_Meta_):
    extends: win32more.Microsoft.UI.Xaml.FrameworkElement
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ITextBlock
    _classid_ = 'Microsoft.UI.Xaml.Controls.TextBlock'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.TextBlock.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Controls.TextBlock: ...
    @winrt_mixinmethod
    def get_FontSize(self: win32more.Microsoft.UI.Xaml.Controls.ITextBlock) -> Double: ...
    @winrt_mixinmethod
    def put_FontSize(self: win32more.Microsoft.UI.Xaml.Controls.ITextBlock, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_FontFamily(self: win32more.Microsoft.UI.Xaml.Controls.ITextBlock) -> win32more.Microsoft.UI.Xaml.Media.FontFamily: ...
    @winrt_mixinmethod
    def put_FontFamily(self: win32more.Microsoft.UI.Xaml.Controls.ITextBlock, value: win32more.Microsoft.UI.Xaml.Media.FontFamily) -> Void: ...
    @winrt_mixinmethod
    def get_FontWeight(self: win32more.Microsoft.UI.Xaml.Controls.ITextBlock) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_mixinmethod
    def put_FontWeight(self: win32more.Microsoft.UI.Xaml.Controls.ITextBlock, value: win32more.Windows.UI.Text.FontWeight) -> Void: ...
    @winrt_mixinmethod
    def get_FontStyle(self: win32more.Microsoft.UI.Xaml.Controls.ITextBlock) -> win32more.Windows.UI.Text.FontStyle: ...
    @winrt_mixinmethod
    def put_FontStyle(self: win32more.Microsoft.UI.Xaml.Controls.ITextBlock, value: win32more.Windows.UI.Text.FontStyle) -> Void: ...
    @winrt_mixinmethod
    def get_FontStretch(self: win32more.Microsoft.UI.Xaml.Controls.ITextBlock) -> win32more.Windows.UI.Text.FontStretch: ...
    @winrt_mixinmethod
    def put_FontStretch(self: win32more.Microsoft.UI.Xaml.Controls.ITextBlock, value: win32more.Windows.UI.Text.FontStretch) -> Void: ...
    @winrt_mixinmethod
    def get_CharacterSpacing(self: win32more.Microsoft.UI.Xaml.Controls.ITextBlock) -> Int32: ...
    @winrt_mixinmethod
    def put_CharacterSpacing(self: win32more.Microsoft.UI.Xaml.Controls.ITextBlock, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_Foreground(self: win32more.Microsoft.UI.Xaml.Controls.ITextBlock) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_Foreground(self: win32more.Microsoft.UI.Xaml.Controls.ITextBlock, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_TextWrapping(self: win32more.Microsoft.UI.Xaml.Controls.ITextBlock) -> win32more.Microsoft.UI.Xaml.TextWrapping: ...
    @winrt_mixinmethod
    def put_TextWrapping(self: win32more.Microsoft.UI.Xaml.Controls.ITextBlock, value: win32more.Microsoft.UI.Xaml.TextWrapping) -> Void: ...
    @winrt_mixinmethod
    def get_TextTrimming(self: win32more.Microsoft.UI.Xaml.Controls.ITextBlock) -> win32more.Microsoft.UI.Xaml.TextTrimming: ...
    @winrt_mixinmethod
    def put_TextTrimming(self: win32more.Microsoft.UI.Xaml.Controls.ITextBlock, value: win32more.Microsoft.UI.Xaml.TextTrimming) -> Void: ...
    @winrt_mixinmethod
    def get_TextAlignment(self: win32more.Microsoft.UI.Xaml.Controls.ITextBlock) -> win32more.Microsoft.UI.Xaml.TextAlignment: ...
    @winrt_mixinmethod
    def put_TextAlignment(self: win32more.Microsoft.UI.Xaml.Controls.ITextBlock, value: win32more.Microsoft.UI.Xaml.TextAlignment) -> Void: ...
    @winrt_mixinmethod
    def get_Text(self: win32more.Microsoft.UI.Xaml.Controls.ITextBlock) -> hstr: ...
    @winrt_mixinmethod
    def put_Text(self: win32more.Microsoft.UI.Xaml.Controls.ITextBlock, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def get_Inlines(self: win32more.Microsoft.UI.Xaml.Controls.ITextBlock) -> win32more.Microsoft.UI.Xaml.Documents.InlineCollection: ...
    @winrt_mixinmethod
    def get_Padding(self: win32more.Microsoft.UI.Xaml.Controls.ITextBlock) -> win32more.Microsoft.UI.Xaml.Thickness: ...
    @winrt_mixinmethod
    def put_Padding(self: win32more.Microsoft.UI.Xaml.Controls.ITextBlock, value: win32more.Microsoft.UI.Xaml.Thickness) -> Void: ...
    @winrt_mixinmethod
    def get_LineHeight(self: win32more.Microsoft.UI.Xaml.Controls.ITextBlock) -> Double: ...
    @winrt_mixinmethod
    def put_LineHeight(self: win32more.Microsoft.UI.Xaml.Controls.ITextBlock, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_LineStackingStrategy(self: win32more.Microsoft.UI.Xaml.Controls.ITextBlock) -> win32more.Microsoft.UI.Xaml.LineStackingStrategy: ...
    @winrt_mixinmethod
    def put_LineStackingStrategy(self: win32more.Microsoft.UI.Xaml.Controls.ITextBlock, value: win32more.Microsoft.UI.Xaml.LineStackingStrategy) -> Void: ...
    @winrt_mixinmethod
    def get_IsTextSelectionEnabled(self: win32more.Microsoft.UI.Xaml.Controls.ITextBlock) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsTextSelectionEnabled(self: win32more.Microsoft.UI.Xaml.Controls.ITextBlock, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_SelectedText(self: win32more.Microsoft.UI.Xaml.Controls.ITextBlock) -> hstr: ...
    @winrt_mixinmethod
    def get_ContentStart(self: win32more.Microsoft.UI.Xaml.Controls.ITextBlock) -> win32more.Microsoft.UI.Xaml.Documents.TextPointer: ...
    @winrt_mixinmethod
    def get_ContentEnd(self: win32more.Microsoft.UI.Xaml.Controls.ITextBlock) -> win32more.Microsoft.UI.Xaml.Documents.TextPointer: ...
    @winrt_mixinmethod
    def get_SelectionStart(self: win32more.Microsoft.UI.Xaml.Controls.ITextBlock) -> win32more.Microsoft.UI.Xaml.Documents.TextPointer: ...
    @winrt_mixinmethod
    def get_SelectionEnd(self: win32more.Microsoft.UI.Xaml.Controls.ITextBlock) -> win32more.Microsoft.UI.Xaml.Documents.TextPointer: ...
    @winrt_mixinmethod
    def get_BaselineOffset(self: win32more.Microsoft.UI.Xaml.Controls.ITextBlock) -> Double: ...
    @winrt_mixinmethod
    def get_SelectionHighlightColor(self: win32more.Microsoft.UI.Xaml.Controls.ITextBlock) -> win32more.Microsoft.UI.Xaml.Media.SolidColorBrush: ...
    @winrt_mixinmethod
    def put_SelectionHighlightColor(self: win32more.Microsoft.UI.Xaml.Controls.ITextBlock, value: win32more.Microsoft.UI.Xaml.Media.SolidColorBrush) -> Void: ...
    @winrt_mixinmethod
    def get_MaxLines(self: win32more.Microsoft.UI.Xaml.Controls.ITextBlock) -> Int32: ...
    @winrt_mixinmethod
    def put_MaxLines(self: win32more.Microsoft.UI.Xaml.Controls.ITextBlock, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_TextLineBounds(self: win32more.Microsoft.UI.Xaml.Controls.ITextBlock) -> win32more.Microsoft.UI.Xaml.TextLineBounds: ...
    @winrt_mixinmethod
    def put_TextLineBounds(self: win32more.Microsoft.UI.Xaml.Controls.ITextBlock, value: win32more.Microsoft.UI.Xaml.TextLineBounds) -> Void: ...
    @winrt_mixinmethod
    def get_OpticalMarginAlignment(self: win32more.Microsoft.UI.Xaml.Controls.ITextBlock) -> win32more.Microsoft.UI.Xaml.OpticalMarginAlignment: ...
    @winrt_mixinmethod
    def put_OpticalMarginAlignment(self: win32more.Microsoft.UI.Xaml.Controls.ITextBlock, value: win32more.Microsoft.UI.Xaml.OpticalMarginAlignment) -> Void: ...
    @winrt_mixinmethod
    def get_IsColorFontEnabled(self: win32more.Microsoft.UI.Xaml.Controls.ITextBlock) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsColorFontEnabled(self: win32more.Microsoft.UI.Xaml.Controls.ITextBlock, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_TextReadingOrder(self: win32more.Microsoft.UI.Xaml.Controls.ITextBlock) -> win32more.Microsoft.UI.Xaml.TextReadingOrder: ...
    @winrt_mixinmethod
    def put_TextReadingOrder(self: win32more.Microsoft.UI.Xaml.Controls.ITextBlock, value: win32more.Microsoft.UI.Xaml.TextReadingOrder) -> Void: ...
    @winrt_mixinmethod
    def get_IsTextScaleFactorEnabled(self: win32more.Microsoft.UI.Xaml.Controls.ITextBlock) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsTextScaleFactorEnabled(self: win32more.Microsoft.UI.Xaml.Controls.ITextBlock, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_TextDecorations(self: win32more.Microsoft.UI.Xaml.Controls.ITextBlock) -> win32more.Windows.UI.Text.TextDecorations: ...
    @winrt_mixinmethod
    def put_TextDecorations(self: win32more.Microsoft.UI.Xaml.Controls.ITextBlock, value: win32more.Windows.UI.Text.TextDecorations) -> Void: ...
    @winrt_mixinmethod
    def get_IsTextTrimmed(self: win32more.Microsoft.UI.Xaml.Controls.ITextBlock) -> Boolean: ...
    @winrt_mixinmethod
    def get_HorizontalTextAlignment(self: win32more.Microsoft.UI.Xaml.Controls.ITextBlock) -> win32more.Microsoft.UI.Xaml.TextAlignment: ...
    @winrt_mixinmethod
    def put_HorizontalTextAlignment(self: win32more.Microsoft.UI.Xaml.Controls.ITextBlock, value: win32more.Microsoft.UI.Xaml.TextAlignment) -> Void: ...
    @winrt_mixinmethod
    def get_TextHighlighters(self: win32more.Microsoft.UI.Xaml.Controls.ITextBlock) -> win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Documents.TextHighlighter]: ...
    @winrt_mixinmethod
    def get_SelectionFlyout(self: win32more.Microsoft.UI.Xaml.Controls.ITextBlock) -> win32more.Microsoft.UI.Xaml.Controls.Primitives.FlyoutBase: ...
    @winrt_mixinmethod
    def put_SelectionFlyout(self: win32more.Microsoft.UI.Xaml.Controls.ITextBlock, value: win32more.Microsoft.UI.Xaml.Controls.Primitives.FlyoutBase) -> Void: ...
    @winrt_mixinmethod
    def add_SelectionChanged(self: win32more.Microsoft.UI.Xaml.Controls.ITextBlock, handler: win32more.Microsoft.UI.Xaml.RoutedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_SelectionChanged(self: win32more.Microsoft.UI.Xaml.Controls.ITextBlock, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_ContextMenuOpening(self: win32more.Microsoft.UI.Xaml.Controls.ITextBlock, handler: win32more.Microsoft.UI.Xaml.Controls.ContextMenuOpeningEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ContextMenuOpening(self: win32more.Microsoft.UI.Xaml.Controls.ITextBlock, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_IsTextTrimmedChanged(self: win32more.Microsoft.UI.Xaml.Controls.ITextBlock, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.TextBlock, win32more.Microsoft.UI.Xaml.Controls.IsTextTrimmedChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_IsTextTrimmedChanged(self: win32more.Microsoft.UI.Xaml.Controls.ITextBlock, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def SelectAll(self: win32more.Microsoft.UI.Xaml.Controls.ITextBlock) -> Void: ...
    @winrt_mixinmethod
    def Select(self: win32more.Microsoft.UI.Xaml.Controls.ITextBlock, start: win32more.Microsoft.UI.Xaml.Documents.TextPointer, end: win32more.Microsoft.UI.Xaml.Documents.TextPointer) -> Void: ...
    @winrt_mixinmethod
    def GetAlphaMask(self: win32more.Microsoft.UI.Xaml.Controls.ITextBlock) -> win32more.Microsoft.UI.Composition.CompositionBrush: ...
    @winrt_mixinmethod
    def CopySelectionToClipboard(self: win32more.Microsoft.UI.Xaml.Controls.ITextBlock) -> Void: ...
    @winrt_classmethod
    def get_FontSizeProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITextBlockStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FontFamilyProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITextBlockStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FontWeightProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITextBlockStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FontStyleProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITextBlockStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_FontStretchProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITextBlockStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CharacterSpacingProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITextBlockStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ForegroundProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITextBlockStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TextWrappingProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITextBlockStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TextTrimmingProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITextBlockStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TextAlignmentProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITextBlockStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TextProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITextBlockStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PaddingProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITextBlockStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_LineHeightProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITextBlockStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_LineStackingStrategyProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITextBlockStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsTextSelectionEnabledProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITextBlockStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectedTextProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITextBlockStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectionHighlightColorProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITextBlockStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MaxLinesProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITextBlockStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TextLineBoundsProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITextBlockStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_OpticalMarginAlignmentProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITextBlockStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsColorFontEnabledProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITextBlockStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TextReadingOrderProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITextBlockStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsTextScaleFactorEnabledProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITextBlockStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TextDecorationsProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITextBlockStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsTextTrimmedProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITextBlockStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HorizontalTextAlignmentProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITextBlockStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectionFlyoutProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITextBlockStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    BaselineOffset = property(get_BaselineOffset, None)
    CharacterSpacing = property(get_CharacterSpacing, put_CharacterSpacing)
    ContentEnd = property(get_ContentEnd, None)
    ContentStart = property(get_ContentStart, None)
    FontFamily = property(get_FontFamily, put_FontFamily)
    FontSize = property(get_FontSize, put_FontSize)
    FontStretch = property(get_FontStretch, put_FontStretch)
    FontStyle = property(get_FontStyle, put_FontStyle)
    FontWeight = property(get_FontWeight, put_FontWeight)
    Foreground = property(get_Foreground, put_Foreground)
    HorizontalTextAlignment = property(get_HorizontalTextAlignment, put_HorizontalTextAlignment)
    Inlines = property(get_Inlines, None)
    IsColorFontEnabled = property(get_IsColorFontEnabled, put_IsColorFontEnabled)
    IsTextScaleFactorEnabled = property(get_IsTextScaleFactorEnabled, put_IsTextScaleFactorEnabled)
    IsTextSelectionEnabled = property(get_IsTextSelectionEnabled, put_IsTextSelectionEnabled)
    IsTextTrimmed = property(get_IsTextTrimmed, None)
    LineHeight = property(get_LineHeight, put_LineHeight)
    LineStackingStrategy = property(get_LineStackingStrategy, put_LineStackingStrategy)
    MaxLines = property(get_MaxLines, put_MaxLines)
    OpticalMarginAlignment = property(get_OpticalMarginAlignment, put_OpticalMarginAlignment)
    Padding = property(get_Padding, put_Padding)
    SelectedText = property(get_SelectedText, None)
    SelectionEnd = property(get_SelectionEnd, None)
    SelectionFlyout = property(get_SelectionFlyout, put_SelectionFlyout)
    SelectionHighlightColor = property(get_SelectionHighlightColor, put_SelectionHighlightColor)
    SelectionStart = property(get_SelectionStart, None)
    Text = property(get_Text, put_Text)
    TextAlignment = property(get_TextAlignment, put_TextAlignment)
    TextDecorations = property(get_TextDecorations, put_TextDecorations)
    TextHighlighters = property(get_TextHighlighters, None)
    TextLineBounds = property(get_TextLineBounds, put_TextLineBounds)
    TextReadingOrder = property(get_TextReadingOrder, put_TextReadingOrder)
    TextTrimming = property(get_TextTrimming, put_TextTrimming)
    TextWrapping = property(get_TextWrapping, put_TextWrapping)
    _TextBlock_Meta_.CharacterSpacingProperty = property(get_CharacterSpacingProperty, None)
    _TextBlock_Meta_.FontFamilyProperty = property(get_FontFamilyProperty, None)
    _TextBlock_Meta_.FontSizeProperty = property(get_FontSizeProperty, None)
    _TextBlock_Meta_.FontStretchProperty = property(get_FontStretchProperty, None)
    _TextBlock_Meta_.FontStyleProperty = property(get_FontStyleProperty, None)
    _TextBlock_Meta_.FontWeightProperty = property(get_FontWeightProperty, None)
    _TextBlock_Meta_.ForegroundProperty = property(get_ForegroundProperty, None)
    _TextBlock_Meta_.HorizontalTextAlignmentProperty = property(get_HorizontalTextAlignmentProperty, None)
    _TextBlock_Meta_.IsColorFontEnabledProperty = property(get_IsColorFontEnabledProperty, None)
    _TextBlock_Meta_.IsTextScaleFactorEnabledProperty = property(get_IsTextScaleFactorEnabledProperty, None)
    _TextBlock_Meta_.IsTextSelectionEnabledProperty = property(get_IsTextSelectionEnabledProperty, None)
    _TextBlock_Meta_.IsTextTrimmedProperty = property(get_IsTextTrimmedProperty, None)
    _TextBlock_Meta_.LineHeightProperty = property(get_LineHeightProperty, None)
    _TextBlock_Meta_.LineStackingStrategyProperty = property(get_LineStackingStrategyProperty, None)
    _TextBlock_Meta_.MaxLinesProperty = property(get_MaxLinesProperty, None)
    _TextBlock_Meta_.OpticalMarginAlignmentProperty = property(get_OpticalMarginAlignmentProperty, None)
    _TextBlock_Meta_.PaddingProperty = property(get_PaddingProperty, None)
    _TextBlock_Meta_.SelectedTextProperty = property(get_SelectedTextProperty, None)
    _TextBlock_Meta_.SelectionFlyoutProperty = property(get_SelectionFlyoutProperty, None)
    _TextBlock_Meta_.SelectionHighlightColorProperty = property(get_SelectionHighlightColorProperty, None)
    _TextBlock_Meta_.TextAlignmentProperty = property(get_TextAlignmentProperty, None)
    _TextBlock_Meta_.TextDecorationsProperty = property(get_TextDecorationsProperty, None)
    _TextBlock_Meta_.TextLineBoundsProperty = property(get_TextLineBoundsProperty, None)
    _TextBlock_Meta_.TextProperty = property(get_TextProperty, None)
    _TextBlock_Meta_.TextReadingOrderProperty = property(get_TextReadingOrderProperty, None)
    _TextBlock_Meta_.TextTrimmingProperty = property(get_TextTrimmingProperty, None)
    _TextBlock_Meta_.TextWrappingProperty = property(get_TextWrappingProperty, None)
    ContextMenuOpening = event(add_ContextMenuOpening, remove_ContextMenuOpening)
    IsTextTrimmedChanged = event(add_IsTextTrimmedChanged, remove_IsTextTrimmedChanged)
    SelectionChanged = event(add_SelectionChanged, remove_SelectionChanged)
class _TextBox_Meta_(ComPtr.__class__):
    pass
class TextBox(ComPtr, metaclass=_TextBox_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.Control
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ITextBox
    _classid_ = 'Microsoft.UI.Xaml.Controls.TextBox'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.TextBox.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.ITextBoxFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.TextBox: ...
    @winrt_mixinmethod
    def get_Text(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox) -> hstr: ...
    @winrt_mixinmethod
    def put_Text(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def get_SelectedText(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox) -> hstr: ...
    @winrt_mixinmethod
    def put_SelectedText(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def get_SelectionLength(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox) -> Int32: ...
    @winrt_mixinmethod
    def put_SelectionLength(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_SelectionStart(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox) -> Int32: ...
    @winrt_mixinmethod
    def put_SelectionStart(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_MaxLength(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox) -> Int32: ...
    @winrt_mixinmethod
    def put_MaxLength(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_IsReadOnly(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsReadOnly(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_AcceptsReturn(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox) -> Boolean: ...
    @winrt_mixinmethod
    def put_AcceptsReturn(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_TextAlignment(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox) -> win32more.Microsoft.UI.Xaml.TextAlignment: ...
    @winrt_mixinmethod
    def put_TextAlignment(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox, value: win32more.Microsoft.UI.Xaml.TextAlignment) -> Void: ...
    @winrt_mixinmethod
    def get_TextWrapping(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox) -> win32more.Microsoft.UI.Xaml.TextWrapping: ...
    @winrt_mixinmethod
    def put_TextWrapping(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox, value: win32more.Microsoft.UI.Xaml.TextWrapping) -> Void: ...
    @winrt_mixinmethod
    def get_IsSpellCheckEnabled(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsSpellCheckEnabled(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsTextPredictionEnabled(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsTextPredictionEnabled(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_InputScope(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox) -> win32more.Microsoft.UI.Xaml.Input.InputScope: ...
    @winrt_mixinmethod
    def put_InputScope(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox, value: win32more.Microsoft.UI.Xaml.Input.InputScope) -> Void: ...
    @winrt_mixinmethod
    def get_Header(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox) -> IInspectable: ...
    @winrt_mixinmethod
    def put_Header(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_HeaderTemplate(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def put_HeaderTemplate(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_mixinmethod
    def get_PlaceholderText(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox) -> hstr: ...
    @winrt_mixinmethod
    def put_PlaceholderText(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def get_SelectionHighlightColor(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox) -> win32more.Microsoft.UI.Xaml.Media.SolidColorBrush: ...
    @winrt_mixinmethod
    def put_SelectionHighlightColor(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox, value: win32more.Microsoft.UI.Xaml.Media.SolidColorBrush) -> Void: ...
    @winrt_mixinmethod
    def get_PreventKeyboardDisplayOnProgrammaticFocus(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox) -> Boolean: ...
    @winrt_mixinmethod
    def put_PreventKeyboardDisplayOnProgrammaticFocus(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsColorFontEnabled(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsColorFontEnabled(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_SelectionHighlightColorWhenNotFocused(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox) -> win32more.Microsoft.UI.Xaml.Media.SolidColorBrush: ...
    @winrt_mixinmethod
    def put_SelectionHighlightColorWhenNotFocused(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox, value: win32more.Microsoft.UI.Xaml.Media.SolidColorBrush) -> Void: ...
    @winrt_mixinmethod
    def get_HorizontalTextAlignment(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox) -> win32more.Microsoft.UI.Xaml.TextAlignment: ...
    @winrt_mixinmethod
    def put_HorizontalTextAlignment(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox, value: win32more.Microsoft.UI.Xaml.TextAlignment) -> Void: ...
    @winrt_mixinmethod
    def get_CharacterCasing(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox) -> win32more.Microsoft.UI.Xaml.Controls.CharacterCasing: ...
    @winrt_mixinmethod
    def put_CharacterCasing(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox, value: win32more.Microsoft.UI.Xaml.Controls.CharacterCasing) -> Void: ...
    @winrt_mixinmethod
    def get_PlaceholderForeground(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_PlaceholderForeground(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_CanPasteClipboardContent(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox) -> Boolean: ...
    @winrt_mixinmethod
    def get_CanUndo(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox) -> Boolean: ...
    @winrt_mixinmethod
    def get_CanRedo(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox) -> Boolean: ...
    @winrt_mixinmethod
    def get_SelectionFlyout(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox) -> win32more.Microsoft.UI.Xaml.Controls.Primitives.FlyoutBase: ...
    @winrt_mixinmethod
    def put_SelectionFlyout(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox, value: win32more.Microsoft.UI.Xaml.Controls.Primitives.FlyoutBase) -> Void: ...
    @winrt_mixinmethod
    def get_ProofingMenuFlyout(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox) -> win32more.Microsoft.UI.Xaml.Controls.Primitives.FlyoutBase: ...
    @winrt_mixinmethod
    def get_Description(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox) -> IInspectable: ...
    @winrt_mixinmethod
    def put_Description(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def add_TextChanged(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox, handler: win32more.Microsoft.UI.Xaml.Controls.TextChangedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_TextChanged(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_SelectionChanged(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox, handler: win32more.Microsoft.UI.Xaml.RoutedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_SelectionChanged(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_ContextMenuOpening(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox, handler: win32more.Microsoft.UI.Xaml.Controls.ContextMenuOpeningEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ContextMenuOpening(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_Paste(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox, handler: win32more.Microsoft.UI.Xaml.Controls.TextControlPasteEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Paste(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_TextCompositionStarted(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.TextBox, win32more.Microsoft.UI.Xaml.Controls.TextCompositionStartedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_TextCompositionStarted(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_TextCompositionChanged(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.TextBox, win32more.Microsoft.UI.Xaml.Controls.TextCompositionChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_TextCompositionChanged(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_TextCompositionEnded(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.TextBox, win32more.Microsoft.UI.Xaml.Controls.TextCompositionEndedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_TextCompositionEnded(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_CopyingToClipboard(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.TextBox, win32more.Microsoft.UI.Xaml.Controls.TextControlCopyingToClipboardEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_CopyingToClipboard(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_CuttingToClipboard(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.TextBox, win32more.Microsoft.UI.Xaml.Controls.TextControlCuttingToClipboardEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_CuttingToClipboard(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_BeforeTextChanging(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.TextBox, win32more.Microsoft.UI.Xaml.Controls.TextBoxBeforeTextChangingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_BeforeTextChanging(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_SelectionChanging(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.TextBox, win32more.Microsoft.UI.Xaml.Controls.TextBoxSelectionChangingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_SelectionChanging(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def Select(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox, start: Int32, length: Int32) -> Void: ...
    @winrt_mixinmethod
    def SelectAll(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox) -> Void: ...
    @winrt_mixinmethod
    def GetRectFromCharacterIndex(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox, charIndex: Int32, trailingEdge: Boolean) -> win32more.Windows.Foundation.Rect: ...
    @winrt_mixinmethod
    def GetLinguisticAlternativesAsync(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[hstr]]: ...
    @winrt_mixinmethod
    def Undo(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox) -> Void: ...
    @winrt_mixinmethod
    def Redo(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox) -> Void: ...
    @winrt_mixinmethod
    def PasteFromClipboard(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox) -> Void: ...
    @winrt_mixinmethod
    def CopySelectionToClipboard(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox) -> Void: ...
    @winrt_mixinmethod
    def CutSelectionToClipboard(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox) -> Void: ...
    @winrt_mixinmethod
    def ClearUndoRedoHistory(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox) -> Void: ...
    @winrt_mixinmethod
    def get_TextReadingOrder(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox) -> win32more.Microsoft.UI.Xaml.TextReadingOrder: ...
    @winrt_mixinmethod
    def put_TextReadingOrder(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox, value: win32more.Microsoft.UI.Xaml.TextReadingOrder) -> Void: ...
    @winrt_mixinmethod
    def get_DesiredCandidateWindowAlignment(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox) -> win32more.Microsoft.UI.Xaml.Controls.CandidateWindowAlignment: ...
    @winrt_mixinmethod
    def put_DesiredCandidateWindowAlignment(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox, value: win32more.Microsoft.UI.Xaml.Controls.CandidateWindowAlignment) -> Void: ...
    @winrt_mixinmethod
    def add_CandidateWindowBoundsChanged(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.TextBox, win32more.Microsoft.UI.Xaml.Controls.CandidateWindowBoundsChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_CandidateWindowBoundsChanged(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_TextChanging(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.TextBox, win32more.Microsoft.UI.Xaml.Controls.TextBoxTextChangingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_TextChanging(self: win32more.Microsoft.UI.Xaml.Controls.ITextBox, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def get_TextProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITextBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MaxLengthProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITextBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsReadOnlyProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITextBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_AcceptsReturnProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITextBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TextAlignmentProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITextBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TextWrappingProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITextBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsSpellCheckEnabledProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITextBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsTextPredictionEnabledProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITextBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_InputScopeProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITextBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HeaderProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITextBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HeaderTemplateProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITextBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PlaceholderTextProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITextBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectionHighlightColorProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITextBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PreventKeyboardDisplayOnProgrammaticFocusProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITextBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsColorFontEnabledProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITextBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectionHighlightColorWhenNotFocusedProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITextBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HorizontalTextAlignmentProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITextBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CharacterCasingProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITextBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PlaceholderForegroundProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITextBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CanPasteClipboardContentProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITextBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CanUndoProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITextBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CanRedoProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITextBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectionFlyoutProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITextBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ProofingMenuFlyoutProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITextBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DescriptionProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITextBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DesiredCandidateWindowAlignmentProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITextBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TextReadingOrderProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITextBoxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    AcceptsReturn = property(get_AcceptsReturn, put_AcceptsReturn)
    CanPasteClipboardContent = property(get_CanPasteClipboardContent, None)
    CanRedo = property(get_CanRedo, None)
    CanUndo = property(get_CanUndo, None)
    CharacterCasing = property(get_CharacterCasing, put_CharacterCasing)
    Description = property(get_Description, put_Description)
    DesiredCandidateWindowAlignment = property(get_DesiredCandidateWindowAlignment, put_DesiredCandidateWindowAlignment)
    Header = property(get_Header, put_Header)
    HeaderTemplate = property(get_HeaderTemplate, put_HeaderTemplate)
    HorizontalTextAlignment = property(get_HorizontalTextAlignment, put_HorizontalTextAlignment)
    InputScope = property(get_InputScope, put_InputScope)
    IsColorFontEnabled = property(get_IsColorFontEnabled, put_IsColorFontEnabled)
    IsReadOnly = property(get_IsReadOnly, put_IsReadOnly)
    IsSpellCheckEnabled = property(get_IsSpellCheckEnabled, put_IsSpellCheckEnabled)
    IsTextPredictionEnabled = property(get_IsTextPredictionEnabled, put_IsTextPredictionEnabled)
    MaxLength = property(get_MaxLength, put_MaxLength)
    PlaceholderForeground = property(get_PlaceholderForeground, put_PlaceholderForeground)
    PlaceholderText = property(get_PlaceholderText, put_PlaceholderText)
    PreventKeyboardDisplayOnProgrammaticFocus = property(get_PreventKeyboardDisplayOnProgrammaticFocus, put_PreventKeyboardDisplayOnProgrammaticFocus)
    ProofingMenuFlyout = property(get_ProofingMenuFlyout, None)
    SelectedText = property(get_SelectedText, put_SelectedText)
    SelectionFlyout = property(get_SelectionFlyout, put_SelectionFlyout)
    SelectionHighlightColor = property(get_SelectionHighlightColor, put_SelectionHighlightColor)
    SelectionHighlightColorWhenNotFocused = property(get_SelectionHighlightColorWhenNotFocused, put_SelectionHighlightColorWhenNotFocused)
    SelectionLength = property(get_SelectionLength, put_SelectionLength)
    SelectionStart = property(get_SelectionStart, put_SelectionStart)
    Text = property(get_Text, put_Text)
    TextAlignment = property(get_TextAlignment, put_TextAlignment)
    TextReadingOrder = property(get_TextReadingOrder, put_TextReadingOrder)
    TextWrapping = property(get_TextWrapping, put_TextWrapping)
    _TextBox_Meta_.AcceptsReturnProperty = property(get_AcceptsReturnProperty, None)
    _TextBox_Meta_.CanPasteClipboardContentProperty = property(get_CanPasteClipboardContentProperty, None)
    _TextBox_Meta_.CanRedoProperty = property(get_CanRedoProperty, None)
    _TextBox_Meta_.CanUndoProperty = property(get_CanUndoProperty, None)
    _TextBox_Meta_.CharacterCasingProperty = property(get_CharacterCasingProperty, None)
    _TextBox_Meta_.DescriptionProperty = property(get_DescriptionProperty, None)
    _TextBox_Meta_.DesiredCandidateWindowAlignmentProperty = property(get_DesiredCandidateWindowAlignmentProperty, None)
    _TextBox_Meta_.HeaderProperty = property(get_HeaderProperty, None)
    _TextBox_Meta_.HeaderTemplateProperty = property(get_HeaderTemplateProperty, None)
    _TextBox_Meta_.HorizontalTextAlignmentProperty = property(get_HorizontalTextAlignmentProperty, None)
    _TextBox_Meta_.InputScopeProperty = property(get_InputScopeProperty, None)
    _TextBox_Meta_.IsColorFontEnabledProperty = property(get_IsColorFontEnabledProperty, None)
    _TextBox_Meta_.IsReadOnlyProperty = property(get_IsReadOnlyProperty, None)
    _TextBox_Meta_.IsSpellCheckEnabledProperty = property(get_IsSpellCheckEnabledProperty, None)
    _TextBox_Meta_.IsTextPredictionEnabledProperty = property(get_IsTextPredictionEnabledProperty, None)
    _TextBox_Meta_.MaxLengthProperty = property(get_MaxLengthProperty, None)
    _TextBox_Meta_.PlaceholderForegroundProperty = property(get_PlaceholderForegroundProperty, None)
    _TextBox_Meta_.PlaceholderTextProperty = property(get_PlaceholderTextProperty, None)
    _TextBox_Meta_.PreventKeyboardDisplayOnProgrammaticFocusProperty = property(get_PreventKeyboardDisplayOnProgrammaticFocusProperty, None)
    _TextBox_Meta_.ProofingMenuFlyoutProperty = property(get_ProofingMenuFlyoutProperty, None)
    _TextBox_Meta_.SelectionFlyoutProperty = property(get_SelectionFlyoutProperty, None)
    _TextBox_Meta_.SelectionHighlightColorProperty = property(get_SelectionHighlightColorProperty, None)
    _TextBox_Meta_.SelectionHighlightColorWhenNotFocusedProperty = property(get_SelectionHighlightColorWhenNotFocusedProperty, None)
    _TextBox_Meta_.TextAlignmentProperty = property(get_TextAlignmentProperty, None)
    _TextBox_Meta_.TextProperty = property(get_TextProperty, None)
    _TextBox_Meta_.TextReadingOrderProperty = property(get_TextReadingOrderProperty, None)
    _TextBox_Meta_.TextWrappingProperty = property(get_TextWrappingProperty, None)
    BeforeTextChanging = event(add_BeforeTextChanging, remove_BeforeTextChanging)
    CandidateWindowBoundsChanged = event(add_CandidateWindowBoundsChanged, remove_CandidateWindowBoundsChanged)
    ContextMenuOpening = event(add_ContextMenuOpening, remove_ContextMenuOpening)
    CopyingToClipboard = event(add_CopyingToClipboard, remove_CopyingToClipboard)
    CuttingToClipboard = event(add_CuttingToClipboard, remove_CuttingToClipboard)
    Paste = event(add_Paste, remove_Paste)
    SelectionChanged = event(add_SelectionChanged, remove_SelectionChanged)
    SelectionChanging = event(add_SelectionChanging, remove_SelectionChanging)
    TextChanged = event(add_TextChanged, remove_TextChanged)
    TextChanging = event(add_TextChanging, remove_TextChanging)
    TextCompositionChanged = event(add_TextCompositionChanged, remove_TextCompositionChanged)
    TextCompositionEnded = event(add_TextCompositionEnded, remove_TextCompositionEnded)
    TextCompositionStarted = event(add_TextCompositionStarted, remove_TextCompositionStarted)
class TextBoxBeforeTextChangingEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ITextBoxBeforeTextChangingEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.TextBoxBeforeTextChangingEventArgs'
    @winrt_mixinmethod
    def get_NewText(self: win32more.Microsoft.UI.Xaml.Controls.ITextBoxBeforeTextChangingEventArgs) -> hstr: ...
    @winrt_mixinmethod
    def get_Cancel(self: win32more.Microsoft.UI.Xaml.Controls.ITextBoxBeforeTextChangingEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def put_Cancel(self: win32more.Microsoft.UI.Xaml.Controls.ITextBoxBeforeTextChangingEventArgs, value: Boolean) -> Void: ...
    Cancel = property(get_Cancel, put_Cancel)
    NewText = property(get_NewText, None)
class TextBoxSelectionChangingEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ITextBoxSelectionChangingEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.TextBoxSelectionChangingEventArgs'
    @winrt_mixinmethod
    def get_SelectionStart(self: win32more.Microsoft.UI.Xaml.Controls.ITextBoxSelectionChangingEventArgs) -> Int32: ...
    @winrt_mixinmethod
    def get_SelectionLength(self: win32more.Microsoft.UI.Xaml.Controls.ITextBoxSelectionChangingEventArgs) -> Int32: ...
    @winrt_mixinmethod
    def get_Cancel(self: win32more.Microsoft.UI.Xaml.Controls.ITextBoxSelectionChangingEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def put_Cancel(self: win32more.Microsoft.UI.Xaml.Controls.ITextBoxSelectionChangingEventArgs, value: Boolean) -> Void: ...
    Cancel = property(get_Cancel, put_Cancel)
    SelectionLength = property(get_SelectionLength, None)
    SelectionStart = property(get_SelectionStart, None)
class TextBoxTextChangingEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ITextBoxTextChangingEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.TextBoxTextChangingEventArgs'
    @winrt_mixinmethod
    def get_IsContentChanging(self: win32more.Microsoft.UI.Xaml.Controls.ITextBoxTextChangingEventArgs) -> Boolean: ...
    IsContentChanging = property(get_IsContentChanging, None)
class TextChangedEventArgs(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.RoutedEventArgs
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ITextChangedEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.TextChangedEventArgs'
class TextChangedEventHandler(MulticastDelegate):
    extends: IUnknown
    _iid_ = Guid('{5d8ddcff-45d8-5e7c-9b8b-c41d2893c6a1}')
    @winrt_commethod(3)
    def Invoke(self, sender: IInspectable, e: win32more.Microsoft.UI.Xaml.Controls.TextChangedEventArgs) -> Void: ...
class TextCommandBarFlyout(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.Controls.CommandBarFlyout
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ITextCommandBarFlyout
    _classid_ = 'Microsoft.UI.Xaml.Controls.TextCommandBarFlyout'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.TextCommandBarFlyout.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.ITextCommandBarFlyoutFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.TextCommandBarFlyout: ...
class TextCompositionChangedEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ITextCompositionChangedEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.TextCompositionChangedEventArgs'
    @winrt_mixinmethod
    def get_StartIndex(self: win32more.Microsoft.UI.Xaml.Controls.ITextCompositionChangedEventArgs) -> Int32: ...
    @winrt_mixinmethod
    def get_Length(self: win32more.Microsoft.UI.Xaml.Controls.ITextCompositionChangedEventArgs) -> Int32: ...
    Length = property(get_Length, None)
    StartIndex = property(get_StartIndex, None)
class TextCompositionEndedEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ITextCompositionEndedEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.TextCompositionEndedEventArgs'
    @winrt_mixinmethod
    def get_StartIndex(self: win32more.Microsoft.UI.Xaml.Controls.ITextCompositionEndedEventArgs) -> Int32: ...
    @winrt_mixinmethod
    def get_Length(self: win32more.Microsoft.UI.Xaml.Controls.ITextCompositionEndedEventArgs) -> Int32: ...
    Length = property(get_Length, None)
    StartIndex = property(get_StartIndex, None)
class TextCompositionStartedEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ITextCompositionStartedEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.TextCompositionStartedEventArgs'
    @winrt_mixinmethod
    def get_StartIndex(self: win32more.Microsoft.UI.Xaml.Controls.ITextCompositionStartedEventArgs) -> Int32: ...
    @winrt_mixinmethod
    def get_Length(self: win32more.Microsoft.UI.Xaml.Controls.ITextCompositionStartedEventArgs) -> Int32: ...
    Length = property(get_Length, None)
    StartIndex = property(get_StartIndex, None)
class TextControlCopyingToClipboardEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ITextControlCopyingToClipboardEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.TextControlCopyingToClipboardEventArgs'
    @winrt_mixinmethod
    def get_Handled(self: win32more.Microsoft.UI.Xaml.Controls.ITextControlCopyingToClipboardEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def put_Handled(self: win32more.Microsoft.UI.Xaml.Controls.ITextControlCopyingToClipboardEventArgs, value: Boolean) -> Void: ...
    Handled = property(get_Handled, put_Handled)
class TextControlCuttingToClipboardEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ITextControlCuttingToClipboardEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.TextControlCuttingToClipboardEventArgs'
    @winrt_mixinmethod
    def get_Handled(self: win32more.Microsoft.UI.Xaml.Controls.ITextControlCuttingToClipboardEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def put_Handled(self: win32more.Microsoft.UI.Xaml.Controls.ITextControlCuttingToClipboardEventArgs, value: Boolean) -> Void: ...
    Handled = property(get_Handled, put_Handled)
class TextControlPasteEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ITextControlPasteEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.TextControlPasteEventArgs'
    @winrt_mixinmethod
    def get_Handled(self: win32more.Microsoft.UI.Xaml.Controls.ITextControlPasteEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def put_Handled(self: win32more.Microsoft.UI.Xaml.Controls.ITextControlPasteEventArgs, value: Boolean) -> Void: ...
    Handled = property(get_Handled, put_Handled)
class TextControlPasteEventHandler(MulticastDelegate):
    extends: IUnknown
    _iid_ = Guid('{ddf3a6c0-5ab1-5d74-8289-892c0614658f}')
    @winrt_commethod(3)
    def Invoke(self, sender: IInspectable, e: win32more.Microsoft.UI.Xaml.Controls.TextControlPasteEventArgs) -> Void: ...
class TimePickedEventArgs(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.DependencyObject
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ITimePickedEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.TimePickedEventArgs'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.TimePickedEventArgs.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Controls.TimePickedEventArgs: ...
    @winrt_mixinmethod
    def get_OldTime(self: win32more.Microsoft.UI.Xaml.Controls.ITimePickedEventArgs) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_mixinmethod
    def get_NewTime(self: win32more.Microsoft.UI.Xaml.Controls.ITimePickedEventArgs) -> win32more.Windows.Foundation.TimeSpan: ...
    NewTime = property(get_NewTime, None)
    OldTime = property(get_OldTime, None)
class _TimePicker_Meta_(ComPtr.__class__):
    pass
class TimePicker(ComPtr, metaclass=_TimePicker_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.Control
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ITimePicker
    _classid_ = 'Microsoft.UI.Xaml.Controls.TimePicker'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.TimePicker.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.ITimePickerFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.TimePicker: ...
    @winrt_mixinmethod
    def get_Header(self: win32more.Microsoft.UI.Xaml.Controls.ITimePicker) -> IInspectable: ...
    @winrt_mixinmethod
    def put_Header(self: win32more.Microsoft.UI.Xaml.Controls.ITimePicker, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_HeaderTemplate(self: win32more.Microsoft.UI.Xaml.Controls.ITimePicker) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def put_HeaderTemplate(self: win32more.Microsoft.UI.Xaml.Controls.ITimePicker, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_mixinmethod
    def get_ClockIdentifier(self: win32more.Microsoft.UI.Xaml.Controls.ITimePicker) -> hstr: ...
    @winrt_mixinmethod
    def put_ClockIdentifier(self: win32more.Microsoft.UI.Xaml.Controls.ITimePicker, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def get_MinuteIncrement(self: win32more.Microsoft.UI.Xaml.Controls.ITimePicker) -> Int32: ...
    @winrt_mixinmethod
    def put_MinuteIncrement(self: win32more.Microsoft.UI.Xaml.Controls.ITimePicker, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_Time(self: win32more.Microsoft.UI.Xaml.Controls.ITimePicker) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_mixinmethod
    def put_Time(self: win32more.Microsoft.UI.Xaml.Controls.ITimePicker, value: win32more.Windows.Foundation.TimeSpan) -> Void: ...
    @winrt_mixinmethod
    def get_LightDismissOverlayMode(self: win32more.Microsoft.UI.Xaml.Controls.ITimePicker) -> win32more.Microsoft.UI.Xaml.Controls.LightDismissOverlayMode: ...
    @winrt_mixinmethod
    def put_LightDismissOverlayMode(self: win32more.Microsoft.UI.Xaml.Controls.ITimePicker, value: win32more.Microsoft.UI.Xaml.Controls.LightDismissOverlayMode) -> Void: ...
    @winrt_mixinmethod
    def get_SelectedTime(self: win32more.Microsoft.UI.Xaml.Controls.ITimePicker) -> win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.TimeSpan]: ...
    @winrt_mixinmethod
    def put_SelectedTime(self: win32more.Microsoft.UI.Xaml.Controls.ITimePicker, value: win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.TimeSpan]) -> Void: ...
    @winrt_mixinmethod
    def add_TimeChanged(self: win32more.Microsoft.UI.Xaml.Controls.ITimePicker, handler: win32more.Windows.Foundation.EventHandler[win32more.Microsoft.UI.Xaml.Controls.TimePickerValueChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_TimeChanged(self: win32more.Microsoft.UI.Xaml.Controls.ITimePicker, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_SelectedTimeChanged(self: win32more.Microsoft.UI.Xaml.Controls.ITimePicker, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.TimePicker, win32more.Microsoft.UI.Xaml.Controls.TimePickerSelectedValueChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_SelectedTimeChanged(self: win32more.Microsoft.UI.Xaml.Controls.ITimePicker, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def get_HeaderProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITimePickerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HeaderTemplateProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITimePickerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ClockIdentifierProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITimePickerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MinuteIncrementProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITimePickerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TimeProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITimePickerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_LightDismissOverlayModeProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITimePickerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectedTimeProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITimePickerStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    ClockIdentifier = property(get_ClockIdentifier, put_ClockIdentifier)
    Header = property(get_Header, put_Header)
    HeaderTemplate = property(get_HeaderTemplate, put_HeaderTemplate)
    LightDismissOverlayMode = property(get_LightDismissOverlayMode, put_LightDismissOverlayMode)
    MinuteIncrement = property(get_MinuteIncrement, put_MinuteIncrement)
    SelectedTime = property(get_SelectedTime, put_SelectedTime)
    Time = property(get_Time, put_Time)
    _TimePicker_Meta_.ClockIdentifierProperty = property(get_ClockIdentifierProperty, None)
    _TimePicker_Meta_.HeaderProperty = property(get_HeaderProperty, None)
    _TimePicker_Meta_.HeaderTemplateProperty = property(get_HeaderTemplateProperty, None)
    _TimePicker_Meta_.LightDismissOverlayModeProperty = property(get_LightDismissOverlayModeProperty, None)
    _TimePicker_Meta_.MinuteIncrementProperty = property(get_MinuteIncrementProperty, None)
    _TimePicker_Meta_.SelectedTimeProperty = property(get_SelectedTimeProperty, None)
    _TimePicker_Meta_.TimeProperty = property(get_TimeProperty, None)
    SelectedTimeChanged = event(add_SelectedTimeChanged, remove_SelectedTimeChanged)
    TimeChanged = event(add_TimeChanged, remove_TimeChanged)
class _TimePickerFlyout_Meta_(ComPtr.__class__):
    pass
class TimePickerFlyout(ComPtr, metaclass=_TimePickerFlyout_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.Primitives.PickerFlyoutBase
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ITimePickerFlyout
    _classid_ = 'Microsoft.UI.Xaml.Controls.TimePickerFlyout'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.TimePickerFlyout.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Controls.TimePickerFlyout: ...
    @winrt_mixinmethod
    def get_ClockIdentifier(self: win32more.Microsoft.UI.Xaml.Controls.ITimePickerFlyout) -> hstr: ...
    @winrt_mixinmethod
    def put_ClockIdentifier(self: win32more.Microsoft.UI.Xaml.Controls.ITimePickerFlyout, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def get_Time(self: win32more.Microsoft.UI.Xaml.Controls.ITimePickerFlyout) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_mixinmethod
    def put_Time(self: win32more.Microsoft.UI.Xaml.Controls.ITimePickerFlyout, value: win32more.Windows.Foundation.TimeSpan) -> Void: ...
    @winrt_mixinmethod
    def get_MinuteIncrement(self: win32more.Microsoft.UI.Xaml.Controls.ITimePickerFlyout) -> Int32: ...
    @winrt_mixinmethod
    def put_MinuteIncrement(self: win32more.Microsoft.UI.Xaml.Controls.ITimePickerFlyout, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def add_TimePicked(self: win32more.Microsoft.UI.Xaml.Controls.ITimePickerFlyout, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.TimePickerFlyout, win32more.Microsoft.UI.Xaml.Controls.TimePickedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_TimePicked(self: win32more.Microsoft.UI.Xaml.Controls.ITimePickerFlyout, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def ShowAtAsync(self: win32more.Microsoft.UI.Xaml.Controls.ITimePickerFlyout, target: win32more.Microsoft.UI.Xaml.FrameworkElement) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.TimeSpan]]: ...
    @winrt_classmethod
    def get_ClockIdentifierProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITimePickerFlyoutStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TimeProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITimePickerFlyoutStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MinuteIncrementProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITimePickerFlyoutStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    ClockIdentifier = property(get_ClockIdentifier, put_ClockIdentifier)
    MinuteIncrement = property(get_MinuteIncrement, put_MinuteIncrement)
    Time = property(get_Time, put_Time)
    _TimePickerFlyout_Meta_.ClockIdentifierProperty = property(get_ClockIdentifierProperty, None)
    _TimePickerFlyout_Meta_.MinuteIncrementProperty = property(get_MinuteIncrementProperty, None)
    _TimePickerFlyout_Meta_.TimeProperty = property(get_TimeProperty, None)
    TimePicked = event(add_TimePicked, remove_TimePicked)
class _TimePickerFlyoutPresenter_Meta_(ComPtr.__class__):
    pass
class TimePickerFlyoutPresenter(ComPtr, metaclass=_TimePickerFlyoutPresenter_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.Control
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ITimePickerFlyoutPresenter
    _classid_ = 'Microsoft.UI.Xaml.Controls.TimePickerFlyoutPresenter'
    @winrt_mixinmethod
    def get_IsDefaultShadowEnabled(self: win32more.Microsoft.UI.Xaml.Controls.ITimePickerFlyoutPresenter) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsDefaultShadowEnabled(self: win32more.Microsoft.UI.Xaml.Controls.ITimePickerFlyoutPresenter, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_IsDefaultShadowEnabledProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITimePickerFlyoutPresenterStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    IsDefaultShadowEnabled = property(get_IsDefaultShadowEnabled, put_IsDefaultShadowEnabled)
    _TimePickerFlyoutPresenter_Meta_.IsDefaultShadowEnabledProperty = property(get_IsDefaultShadowEnabledProperty, None)
class TimePickerSelectedValueChangedEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ITimePickerSelectedValueChangedEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.TimePickerSelectedValueChangedEventArgs'
    @winrt_mixinmethod
    def get_OldTime(self: win32more.Microsoft.UI.Xaml.Controls.ITimePickerSelectedValueChangedEventArgs) -> win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.TimeSpan]: ...
    @winrt_mixinmethod
    def get_NewTime(self: win32more.Microsoft.UI.Xaml.Controls.ITimePickerSelectedValueChangedEventArgs) -> win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.TimeSpan]: ...
    NewTime = property(get_NewTime, None)
    OldTime = property(get_OldTime, None)
class TimePickerValueChangedEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ITimePickerValueChangedEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.TimePickerValueChangedEventArgs'
    @winrt_mixinmethod
    def get_OldTime(self: win32more.Microsoft.UI.Xaml.Controls.ITimePickerValueChangedEventArgs) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_mixinmethod
    def get_NewTime(self: win32more.Microsoft.UI.Xaml.Controls.ITimePickerValueChangedEventArgs) -> win32more.Windows.Foundation.TimeSpan: ...
    NewTime = property(get_NewTime, None)
    OldTime = property(get_OldTime, None)
class _ToggleMenuFlyoutItem_Meta_(ComPtr.__class__):
    pass
class ToggleMenuFlyoutItem(ComPtr, metaclass=_ToggleMenuFlyoutItem_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.MenuFlyoutItem
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IToggleMenuFlyoutItem
    _classid_ = 'Microsoft.UI.Xaml.Controls.ToggleMenuFlyoutItem'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.ToggleMenuFlyoutItem.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IToggleMenuFlyoutItemFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.ToggleMenuFlyoutItem: ...
    @winrt_mixinmethod
    def get_IsChecked(self: win32more.Microsoft.UI.Xaml.Controls.IToggleMenuFlyoutItem) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsChecked(self: win32more.Microsoft.UI.Xaml.Controls.IToggleMenuFlyoutItem, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_IsCheckedProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IToggleMenuFlyoutItemStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    IsChecked = property(get_IsChecked, put_IsChecked)
    _ToggleMenuFlyoutItem_Meta_.IsCheckedProperty = property(get_IsCheckedProperty, None)
class _ToggleSplitButton_Meta_(ComPtr.__class__):
    pass
class ToggleSplitButton(ComPtr, metaclass=_ToggleSplitButton_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.SplitButton
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IToggleSplitButton
    _classid_ = 'Microsoft.UI.Xaml.Controls.ToggleSplitButton'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.ToggleSplitButton.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IToggleSplitButtonFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.ToggleSplitButton: ...
    @winrt_mixinmethod
    def get_IsChecked(self: win32more.Microsoft.UI.Xaml.Controls.IToggleSplitButton) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsChecked(self: win32more.Microsoft.UI.Xaml.Controls.IToggleSplitButton, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def add_IsCheckedChanged(self: win32more.Microsoft.UI.Xaml.Controls.IToggleSplitButton, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.ToggleSplitButton, win32more.Microsoft.UI.Xaml.Controls.ToggleSplitButtonIsCheckedChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_IsCheckedChanged(self: win32more.Microsoft.UI.Xaml.Controls.IToggleSplitButton, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def get_IsCheckedProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IToggleSplitButtonStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    IsChecked = property(get_IsChecked, put_IsChecked)
    _ToggleSplitButton_Meta_.IsCheckedProperty = property(get_IsCheckedProperty, None)
    IsCheckedChanged = event(add_IsCheckedChanged, remove_IsCheckedChanged)
class ToggleSplitButtonIsCheckedChangedEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IToggleSplitButtonIsCheckedChangedEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.ToggleSplitButtonIsCheckedChangedEventArgs'
class _ToggleSwitch_Meta_(ComPtr.__class__):
    pass
class ToggleSwitch(ComPtr, metaclass=_ToggleSwitch_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.Control
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IToggleSwitch
    _classid_ = 'Microsoft.UI.Xaml.Controls.ToggleSwitch'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.ToggleSwitch.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Controls.ToggleSwitch: ...
    @winrt_mixinmethod
    def get_IsOn(self: win32more.Microsoft.UI.Xaml.Controls.IToggleSwitch) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsOn(self: win32more.Microsoft.UI.Xaml.Controls.IToggleSwitch, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_Header(self: win32more.Microsoft.UI.Xaml.Controls.IToggleSwitch) -> IInspectable: ...
    @winrt_mixinmethod
    def put_Header(self: win32more.Microsoft.UI.Xaml.Controls.IToggleSwitch, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_HeaderTemplate(self: win32more.Microsoft.UI.Xaml.Controls.IToggleSwitch) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def put_HeaderTemplate(self: win32more.Microsoft.UI.Xaml.Controls.IToggleSwitch, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_mixinmethod
    def get_OnContent(self: win32more.Microsoft.UI.Xaml.Controls.IToggleSwitch) -> IInspectable: ...
    @winrt_mixinmethod
    def put_OnContent(self: win32more.Microsoft.UI.Xaml.Controls.IToggleSwitch, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_OnContentTemplate(self: win32more.Microsoft.UI.Xaml.Controls.IToggleSwitch) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def put_OnContentTemplate(self: win32more.Microsoft.UI.Xaml.Controls.IToggleSwitch, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_mixinmethod
    def get_OffContent(self: win32more.Microsoft.UI.Xaml.Controls.IToggleSwitch) -> IInspectable: ...
    @winrt_mixinmethod
    def put_OffContent(self: win32more.Microsoft.UI.Xaml.Controls.IToggleSwitch, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_OffContentTemplate(self: win32more.Microsoft.UI.Xaml.Controls.IToggleSwitch) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def put_OffContentTemplate(self: win32more.Microsoft.UI.Xaml.Controls.IToggleSwitch, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_mixinmethod
    def get_TemplateSettings(self: win32more.Microsoft.UI.Xaml.Controls.IToggleSwitch) -> win32more.Microsoft.UI.Xaml.Controls.Primitives.ToggleSwitchTemplateSettings: ...
    @winrt_mixinmethod
    def add_Toggled(self: win32more.Microsoft.UI.Xaml.Controls.IToggleSwitch, handler: win32more.Microsoft.UI.Xaml.RoutedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Toggled(self: win32more.Microsoft.UI.Xaml.Controls.IToggleSwitch, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def OnToggled(self: win32more.Microsoft.UI.Xaml.Controls.IToggleSwitchOverrides) -> Void: ...
    @winrt_mixinmethod
    def OnOnContentChanged(self: win32more.Microsoft.UI.Xaml.Controls.IToggleSwitchOverrides, oldContent: IInspectable, newContent: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def OnOffContentChanged(self: win32more.Microsoft.UI.Xaml.Controls.IToggleSwitchOverrides, oldContent: IInspectable, newContent: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def OnHeaderChanged(self: win32more.Microsoft.UI.Xaml.Controls.IToggleSwitchOverrides, oldContent: IInspectable, newContent: IInspectable) -> Void: ...
    @winrt_classmethod
    def get_IsOnProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IToggleSwitchStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HeaderProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IToggleSwitchStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HeaderTemplateProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IToggleSwitchStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_OnContentProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IToggleSwitchStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_OnContentTemplateProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IToggleSwitchStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_OffContentProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IToggleSwitchStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_OffContentTemplateProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IToggleSwitchStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    Header = property(get_Header, put_Header)
    HeaderTemplate = property(get_HeaderTemplate, put_HeaderTemplate)
    IsOn = property(get_IsOn, put_IsOn)
    OffContent = property(get_OffContent, put_OffContent)
    OffContentTemplate = property(get_OffContentTemplate, put_OffContentTemplate)
    OnContent = property(get_OnContent, put_OnContent)
    OnContentTemplate = property(get_OnContentTemplate, put_OnContentTemplate)
    TemplateSettings = property(get_TemplateSettings, None)
    _ToggleSwitch_Meta_.HeaderProperty = property(get_HeaderProperty, None)
    _ToggleSwitch_Meta_.HeaderTemplateProperty = property(get_HeaderTemplateProperty, None)
    _ToggleSwitch_Meta_.IsOnProperty = property(get_IsOnProperty, None)
    _ToggleSwitch_Meta_.OffContentProperty = property(get_OffContentProperty, None)
    _ToggleSwitch_Meta_.OffContentTemplateProperty = property(get_OffContentTemplateProperty, None)
    _ToggleSwitch_Meta_.OnContentProperty = property(get_OnContentProperty, None)
    _ToggleSwitch_Meta_.OnContentTemplateProperty = property(get_OnContentTemplateProperty, None)
    Toggled = event(add_Toggled, remove_Toggled)
class _ToolTip_Meta_(ComPtr.__class__):
    pass
class ToolTip(ComPtr, metaclass=_ToolTip_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.ContentControl
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IToolTip
    _classid_ = 'Microsoft.UI.Xaml.Controls.ToolTip'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.ToolTip.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IToolTipFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.ToolTip: ...
    @winrt_mixinmethod
    def get_HorizontalOffset(self: win32more.Microsoft.UI.Xaml.Controls.IToolTip) -> Double: ...
    @winrt_mixinmethod
    def put_HorizontalOffset(self: win32more.Microsoft.UI.Xaml.Controls.IToolTip, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_IsOpen(self: win32more.Microsoft.UI.Xaml.Controls.IToolTip) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsOpen(self: win32more.Microsoft.UI.Xaml.Controls.IToolTip, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_Placement(self: win32more.Microsoft.UI.Xaml.Controls.IToolTip) -> win32more.Microsoft.UI.Xaml.Controls.Primitives.PlacementMode: ...
    @winrt_mixinmethod
    def put_Placement(self: win32more.Microsoft.UI.Xaml.Controls.IToolTip, value: win32more.Microsoft.UI.Xaml.Controls.Primitives.PlacementMode) -> Void: ...
    @winrt_mixinmethod
    def get_PlacementTarget(self: win32more.Microsoft.UI.Xaml.Controls.IToolTip) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_mixinmethod
    def put_PlacementTarget(self: win32more.Microsoft.UI.Xaml.Controls.IToolTip, value: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    @winrt_mixinmethod
    def get_PlacementRect(self: win32more.Microsoft.UI.Xaml.Controls.IToolTip) -> win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.Rect]: ...
    @winrt_mixinmethod
    def put_PlacementRect(self: win32more.Microsoft.UI.Xaml.Controls.IToolTip, value: win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.Rect]) -> Void: ...
    @winrt_mixinmethod
    def get_VerticalOffset(self: win32more.Microsoft.UI.Xaml.Controls.IToolTip) -> Double: ...
    @winrt_mixinmethod
    def put_VerticalOffset(self: win32more.Microsoft.UI.Xaml.Controls.IToolTip, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_TemplateSettings(self: win32more.Microsoft.UI.Xaml.Controls.IToolTip) -> win32more.Microsoft.UI.Xaml.Controls.Primitives.ToolTipTemplateSettings: ...
    @winrt_mixinmethod
    def add_Closed(self: win32more.Microsoft.UI.Xaml.Controls.IToolTip, handler: win32more.Microsoft.UI.Xaml.RoutedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Closed(self: win32more.Microsoft.UI.Xaml.Controls.IToolTip, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_Opened(self: win32more.Microsoft.UI.Xaml.Controls.IToolTip, handler: win32more.Microsoft.UI.Xaml.RoutedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Opened(self: win32more.Microsoft.UI.Xaml.Controls.IToolTip, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def get_HorizontalOffsetProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IToolTipStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsOpenProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IToolTipStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PlacementProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IToolTipStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PlacementTargetProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IToolTipStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PlacementRectProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IToolTipStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_VerticalOffsetProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IToolTipStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    HorizontalOffset = property(get_HorizontalOffset, put_HorizontalOffset)
    IsOpen = property(get_IsOpen, put_IsOpen)
    Placement = property(get_Placement, put_Placement)
    PlacementRect = property(get_PlacementRect, put_PlacementRect)
    PlacementTarget = property(get_PlacementTarget, put_PlacementTarget)
    TemplateSettings = property(get_TemplateSettings, None)
    VerticalOffset = property(get_VerticalOffset, put_VerticalOffset)
    _ToolTip_Meta_.HorizontalOffsetProperty = property(get_HorizontalOffsetProperty, None)
    _ToolTip_Meta_.IsOpenProperty = property(get_IsOpenProperty, None)
    _ToolTip_Meta_.PlacementProperty = property(get_PlacementProperty, None)
    _ToolTip_Meta_.PlacementRectProperty = property(get_PlacementRectProperty, None)
    _ToolTip_Meta_.PlacementTargetProperty = property(get_PlacementTargetProperty, None)
    _ToolTip_Meta_.VerticalOffsetProperty = property(get_VerticalOffsetProperty, None)
    Closed = event(add_Closed, remove_Closed)
    Opened = event(add_Opened, remove_Opened)
class _ToolTipService_Meta_(ComPtr.__class__):
    pass
class ToolTipService(ComPtr, metaclass=_ToolTipService_Meta_):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IToolTipService
    _classid_ = 'Microsoft.UI.Xaml.Controls.ToolTipService'
    @winrt_classmethod
    def get_PlacementProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IToolTipServiceStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetPlacement(cls: win32more.Microsoft.UI.Xaml.Controls.IToolTipServiceStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> win32more.Microsoft.UI.Xaml.Controls.Primitives.PlacementMode: ...
    @winrt_classmethod
    def SetPlacement(cls: win32more.Microsoft.UI.Xaml.Controls.IToolTipServiceStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: win32more.Microsoft.UI.Xaml.Controls.Primitives.PlacementMode) -> Void: ...
    @winrt_classmethod
    def get_PlacementTargetProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IToolTipServiceStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetPlacementTarget(cls: win32more.Microsoft.UI.Xaml.Controls.IToolTipServiceStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_classmethod
    def SetPlacementTarget(cls: win32more.Microsoft.UI.Xaml.Controls.IToolTipServiceStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    @winrt_classmethod
    def get_ToolTipProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IToolTipServiceStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetToolTip(cls: win32more.Microsoft.UI.Xaml.Controls.IToolTipServiceStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> IInspectable: ...
    @winrt_classmethod
    def SetToolTip(cls: win32more.Microsoft.UI.Xaml.Controls.IToolTipServiceStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: IInspectable) -> Void: ...
    _ToolTipService_Meta_.PlacementProperty = property(get_PlacementProperty, None)
    _ToolTipService_Meta_.PlacementTargetProperty = property(get_PlacementTargetProperty, None)
    _ToolTipService_Meta_.ToolTipProperty = property(get_ToolTipProperty, None)
class _TreeView_Meta_(ComPtr.__class__):
    pass
class TreeView(ComPtr, metaclass=_TreeView_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.Control
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ITreeView
    _classid_ = 'Microsoft.UI.Xaml.Controls.TreeView'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.TreeView.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.ITreeViewFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.TreeView: ...
    @winrt_mixinmethod
    def get_RootNodes(self: win32more.Microsoft.UI.Xaml.Controls.ITreeView) -> win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.TreeViewNode]: ...
    @winrt_mixinmethod
    def get_SelectionMode(self: win32more.Microsoft.UI.Xaml.Controls.ITreeView) -> win32more.Microsoft.UI.Xaml.Controls.TreeViewSelectionMode: ...
    @winrt_mixinmethod
    def put_SelectionMode(self: win32more.Microsoft.UI.Xaml.Controls.ITreeView, value: win32more.Microsoft.UI.Xaml.Controls.TreeViewSelectionMode) -> Void: ...
    @winrt_mixinmethod
    def get_SelectedNodes(self: win32more.Microsoft.UI.Xaml.Controls.ITreeView) -> win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.TreeViewNode]: ...
    @winrt_mixinmethod
    def Expand(self: win32more.Microsoft.UI.Xaml.Controls.ITreeView, value: win32more.Microsoft.UI.Xaml.Controls.TreeViewNode) -> Void: ...
    @winrt_mixinmethod
    def Collapse(self: win32more.Microsoft.UI.Xaml.Controls.ITreeView, value: win32more.Microsoft.UI.Xaml.Controls.TreeViewNode) -> Void: ...
    @winrt_mixinmethod
    def SelectAll(self: win32more.Microsoft.UI.Xaml.Controls.ITreeView) -> Void: ...
    @winrt_mixinmethod
    def add_ItemInvoked(self: win32more.Microsoft.UI.Xaml.Controls.ITreeView, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.TreeView, win32more.Microsoft.UI.Xaml.Controls.TreeViewItemInvokedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ItemInvoked(self: win32more.Microsoft.UI.Xaml.Controls.ITreeView, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_Expanding(self: win32more.Microsoft.UI.Xaml.Controls.ITreeView, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.TreeView, win32more.Microsoft.UI.Xaml.Controls.TreeViewExpandingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Expanding(self: win32more.Microsoft.UI.Xaml.Controls.ITreeView, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_Collapsed(self: win32more.Microsoft.UI.Xaml.Controls.ITreeView, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.TreeView, win32more.Microsoft.UI.Xaml.Controls.TreeViewCollapsedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Collapsed(self: win32more.Microsoft.UI.Xaml.Controls.ITreeView, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def NodeFromContainer(self: win32more.Microsoft.UI.Xaml.Controls.ITreeView2, container: win32more.Microsoft.UI.Xaml.DependencyObject) -> win32more.Microsoft.UI.Xaml.Controls.TreeViewNode: ...
    @winrt_mixinmethod
    def ContainerFromNode(self: win32more.Microsoft.UI.Xaml.Controls.ITreeView2, node: win32more.Microsoft.UI.Xaml.Controls.TreeViewNode) -> win32more.Microsoft.UI.Xaml.DependencyObject: ...
    @winrt_mixinmethod
    def ItemFromContainer(self: win32more.Microsoft.UI.Xaml.Controls.ITreeView2, container: win32more.Microsoft.UI.Xaml.DependencyObject) -> IInspectable: ...
    @winrt_mixinmethod
    def ContainerFromItem(self: win32more.Microsoft.UI.Xaml.Controls.ITreeView2, item: IInspectable) -> win32more.Microsoft.UI.Xaml.DependencyObject: ...
    @winrt_mixinmethod
    def get_CanDragItems(self: win32more.Microsoft.UI.Xaml.Controls.ITreeView2) -> Boolean: ...
    @winrt_mixinmethod
    def put_CanDragItems(self: win32more.Microsoft.UI.Xaml.Controls.ITreeView2, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_CanReorderItems(self: win32more.Microsoft.UI.Xaml.Controls.ITreeView2) -> Boolean: ...
    @winrt_mixinmethod
    def put_CanReorderItems(self: win32more.Microsoft.UI.Xaml.Controls.ITreeView2, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_ItemTemplate(self: win32more.Microsoft.UI.Xaml.Controls.ITreeView2) -> win32more.Microsoft.UI.Xaml.DataTemplate: ...
    @winrt_mixinmethod
    def put_ItemTemplate(self: win32more.Microsoft.UI.Xaml.Controls.ITreeView2, value: win32more.Microsoft.UI.Xaml.DataTemplate) -> Void: ...
    @winrt_mixinmethod
    def get_ItemTemplateSelector(self: win32more.Microsoft.UI.Xaml.Controls.ITreeView2) -> win32more.Microsoft.UI.Xaml.Controls.DataTemplateSelector: ...
    @winrt_mixinmethod
    def put_ItemTemplateSelector(self: win32more.Microsoft.UI.Xaml.Controls.ITreeView2, value: win32more.Microsoft.UI.Xaml.Controls.DataTemplateSelector) -> Void: ...
    @winrt_mixinmethod
    def get_ItemContainerStyle(self: win32more.Microsoft.UI.Xaml.Controls.ITreeView2) -> win32more.Microsoft.UI.Xaml.Style: ...
    @winrt_mixinmethod
    def put_ItemContainerStyle(self: win32more.Microsoft.UI.Xaml.Controls.ITreeView2, value: win32more.Microsoft.UI.Xaml.Style) -> Void: ...
    @winrt_mixinmethod
    def get_ItemContainerStyleSelector(self: win32more.Microsoft.UI.Xaml.Controls.ITreeView2) -> win32more.Microsoft.UI.Xaml.Controls.StyleSelector: ...
    @winrt_mixinmethod
    def put_ItemContainerStyleSelector(self: win32more.Microsoft.UI.Xaml.Controls.ITreeView2, value: win32more.Microsoft.UI.Xaml.Controls.StyleSelector) -> Void: ...
    @winrt_mixinmethod
    def get_ItemContainerTransitions(self: win32more.Microsoft.UI.Xaml.Controls.ITreeView2) -> win32more.Microsoft.UI.Xaml.Media.Animation.TransitionCollection: ...
    @winrt_mixinmethod
    def put_ItemContainerTransitions(self: win32more.Microsoft.UI.Xaml.Controls.ITreeView2, value: win32more.Microsoft.UI.Xaml.Media.Animation.TransitionCollection) -> Void: ...
    @winrt_mixinmethod
    def get_ItemsSource(self: win32more.Microsoft.UI.Xaml.Controls.ITreeView2) -> IInspectable: ...
    @winrt_mixinmethod
    def put_ItemsSource(self: win32more.Microsoft.UI.Xaml.Controls.ITreeView2, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def add_DragItemsStarting(self: win32more.Microsoft.UI.Xaml.Controls.ITreeView2, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.TreeView, win32more.Microsoft.UI.Xaml.Controls.TreeViewDragItemsStartingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_DragItemsStarting(self: win32more.Microsoft.UI.Xaml.Controls.ITreeView2, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_DragItemsCompleted(self: win32more.Microsoft.UI.Xaml.Controls.ITreeView2, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.TreeView, win32more.Microsoft.UI.Xaml.Controls.TreeViewDragItemsCompletedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_DragItemsCompleted(self: win32more.Microsoft.UI.Xaml.Controls.ITreeView2, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def get_SelectedNode(self: win32more.Microsoft.UI.Xaml.Controls.ITreeView2) -> win32more.Microsoft.UI.Xaml.Controls.TreeViewNode: ...
    @winrt_mixinmethod
    def put_SelectedNode(self: win32more.Microsoft.UI.Xaml.Controls.ITreeView2, value: win32more.Microsoft.UI.Xaml.Controls.TreeViewNode) -> Void: ...
    @winrt_mixinmethod
    def get_SelectedItem(self: win32more.Microsoft.UI.Xaml.Controls.ITreeView2) -> IInspectable: ...
    @winrt_mixinmethod
    def put_SelectedItem(self: win32more.Microsoft.UI.Xaml.Controls.ITreeView2, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_SelectedItems(self: win32more.Microsoft.UI.Xaml.Controls.ITreeView2) -> win32more.Windows.Foundation.Collections.IVector[IInspectable]: ...
    @winrt_mixinmethod
    def add_SelectionChanged(self: win32more.Microsoft.UI.Xaml.Controls.ITreeView3, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.TreeView, win32more.Microsoft.UI.Xaml.Controls.TreeViewSelectionChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_SelectionChanged(self: win32more.Microsoft.UI.Xaml.Controls.ITreeView3, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def get_CanDragItemsProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITreeViewStatics2) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CanReorderItemsProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITreeViewStatics2) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ItemTemplateProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITreeViewStatics2) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ItemTemplateSelectorProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITreeViewStatics2) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ItemContainerStyleProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITreeViewStatics2) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ItemContainerStyleSelectorProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITreeViewStatics2) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ItemContainerTransitionsProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITreeViewStatics2) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ItemsSourceProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITreeViewStatics2) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectedItemProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITreeViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_SelectionModeProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITreeViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    CanDragItems = property(get_CanDragItems, put_CanDragItems)
    CanReorderItems = property(get_CanReorderItems, put_CanReorderItems)
    ItemContainerStyle = property(get_ItemContainerStyle, put_ItemContainerStyle)
    ItemContainerStyleSelector = property(get_ItemContainerStyleSelector, put_ItemContainerStyleSelector)
    ItemContainerTransitions = property(get_ItemContainerTransitions, put_ItemContainerTransitions)
    ItemTemplate = property(get_ItemTemplate, put_ItemTemplate)
    ItemTemplateSelector = property(get_ItemTemplateSelector, put_ItemTemplateSelector)
    ItemsSource = property(get_ItemsSource, put_ItemsSource)
    RootNodes = property(get_RootNodes, None)
    SelectedItem = property(get_SelectedItem, put_SelectedItem)
    SelectedItems = property(get_SelectedItems, None)
    SelectedNode = property(get_SelectedNode, put_SelectedNode)
    SelectedNodes = property(get_SelectedNodes, None)
    SelectionMode = property(get_SelectionMode, put_SelectionMode)
    _TreeView_Meta_.CanDragItemsProperty = property(get_CanDragItemsProperty, None)
    _TreeView_Meta_.CanReorderItemsProperty = property(get_CanReorderItemsProperty, None)
    _TreeView_Meta_.ItemContainerStyleProperty = property(get_ItemContainerStyleProperty, None)
    _TreeView_Meta_.ItemContainerStyleSelectorProperty = property(get_ItemContainerStyleSelectorProperty, None)
    _TreeView_Meta_.ItemContainerTransitionsProperty = property(get_ItemContainerTransitionsProperty, None)
    _TreeView_Meta_.ItemTemplateProperty = property(get_ItemTemplateProperty, None)
    _TreeView_Meta_.ItemTemplateSelectorProperty = property(get_ItemTemplateSelectorProperty, None)
    _TreeView_Meta_.ItemsSourceProperty = property(get_ItemsSourceProperty, None)
    _TreeView_Meta_.SelectedItemProperty = property(get_SelectedItemProperty, None)
    _TreeView_Meta_.SelectionModeProperty = property(get_SelectionModeProperty, None)
    Collapsed = event(add_Collapsed, remove_Collapsed)
    DragItemsCompleted = event(add_DragItemsCompleted, remove_DragItemsCompleted)
    DragItemsStarting = event(add_DragItemsStarting, remove_DragItemsStarting)
    Expanding = event(add_Expanding, remove_Expanding)
    ItemInvoked = event(add_ItemInvoked, remove_ItemInvoked)
    SelectionChanged = event(add_SelectionChanged, remove_SelectionChanged)
class TreeViewCollapsedEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ITreeViewCollapsedEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.TreeViewCollapsedEventArgs'
    @winrt_mixinmethod
    def get_Node(self: win32more.Microsoft.UI.Xaml.Controls.ITreeViewCollapsedEventArgs) -> win32more.Microsoft.UI.Xaml.Controls.TreeViewNode: ...
    @winrt_mixinmethod
    def get_Item(self: win32more.Microsoft.UI.Xaml.Controls.ITreeViewCollapsedEventArgs2) -> IInspectable: ...
    Item = property(get_Item, None)
    Node = property(get_Node, None)
class TreeViewDragItemsCompletedEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ITreeViewDragItemsCompletedEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.TreeViewDragItemsCompletedEventArgs'
    @winrt_mixinmethod
    def get_DropResult(self: win32more.Microsoft.UI.Xaml.Controls.ITreeViewDragItemsCompletedEventArgs) -> win32more.Windows.ApplicationModel.DataTransfer.DataPackageOperation: ...
    @winrt_mixinmethod
    def get_Items(self: win32more.Microsoft.UI.Xaml.Controls.ITreeViewDragItemsCompletedEventArgs) -> win32more.Windows.Foundation.Collections.IVectorView[IInspectable]: ...
    @winrt_mixinmethod
    def get_NewParentItem(self: win32more.Microsoft.UI.Xaml.Controls.ITreeViewDragItemsCompletedEventArgs2) -> IInspectable: ...
    DropResult = property(get_DropResult, None)
    Items = property(get_Items, None)
    NewParentItem = property(get_NewParentItem, None)
class TreeViewDragItemsStartingEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ITreeViewDragItemsStartingEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.TreeViewDragItemsStartingEventArgs'
    @winrt_mixinmethod
    def get_Cancel(self: win32more.Microsoft.UI.Xaml.Controls.ITreeViewDragItemsStartingEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def put_Cancel(self: win32more.Microsoft.UI.Xaml.Controls.ITreeViewDragItemsStartingEventArgs, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_Data(self: win32more.Microsoft.UI.Xaml.Controls.ITreeViewDragItemsStartingEventArgs) -> win32more.Windows.ApplicationModel.DataTransfer.DataPackage: ...
    @winrt_mixinmethod
    def get_Items(self: win32more.Microsoft.UI.Xaml.Controls.ITreeViewDragItemsStartingEventArgs) -> win32more.Windows.Foundation.Collections.IVector[IInspectable]: ...
    Cancel = property(get_Cancel, put_Cancel)
    Data = property(get_Data, None)
    Items = property(get_Items, None)
class TreeViewExpandingEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ITreeViewExpandingEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.TreeViewExpandingEventArgs'
    @winrt_mixinmethod
    def get_Node(self: win32more.Microsoft.UI.Xaml.Controls.ITreeViewExpandingEventArgs) -> win32more.Microsoft.UI.Xaml.Controls.TreeViewNode: ...
    @winrt_mixinmethod
    def get_Item(self: win32more.Microsoft.UI.Xaml.Controls.ITreeViewExpandingEventArgs2) -> IInspectable: ...
    Item = property(get_Item, None)
    Node = property(get_Node, None)
class _TreeViewItem_Meta_(ComPtr.__class__):
    pass
class TreeViewItem(ComPtr, metaclass=_TreeViewItem_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.ListViewItem
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ITreeViewItem
    _classid_ = 'Microsoft.UI.Xaml.Controls.TreeViewItem'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.TreeViewItem.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.ITreeViewItemFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.TreeViewItem: ...
    @winrt_mixinmethod
    def get_GlyphOpacity(self: win32more.Microsoft.UI.Xaml.Controls.ITreeViewItem) -> Double: ...
    @winrt_mixinmethod
    def put_GlyphOpacity(self: win32more.Microsoft.UI.Xaml.Controls.ITreeViewItem, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_GlyphBrush(self: win32more.Microsoft.UI.Xaml.Controls.ITreeViewItem) -> win32more.Microsoft.UI.Xaml.Media.Brush: ...
    @winrt_mixinmethod
    def put_GlyphBrush(self: win32more.Microsoft.UI.Xaml.Controls.ITreeViewItem, value: win32more.Microsoft.UI.Xaml.Media.Brush) -> Void: ...
    @winrt_mixinmethod
    def get_ExpandedGlyph(self: win32more.Microsoft.UI.Xaml.Controls.ITreeViewItem) -> hstr: ...
    @winrt_mixinmethod
    def put_ExpandedGlyph(self: win32more.Microsoft.UI.Xaml.Controls.ITreeViewItem, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def get_CollapsedGlyph(self: win32more.Microsoft.UI.Xaml.Controls.ITreeViewItem) -> hstr: ...
    @winrt_mixinmethod
    def put_CollapsedGlyph(self: win32more.Microsoft.UI.Xaml.Controls.ITreeViewItem, value: hstr) -> Void: ...
    @winrt_mixinmethod
    def get_GlyphSize(self: win32more.Microsoft.UI.Xaml.Controls.ITreeViewItem) -> Double: ...
    @winrt_mixinmethod
    def put_GlyphSize(self: win32more.Microsoft.UI.Xaml.Controls.ITreeViewItem, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_IsExpanded(self: win32more.Microsoft.UI.Xaml.Controls.ITreeViewItem) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsExpanded(self: win32more.Microsoft.UI.Xaml.Controls.ITreeViewItem, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_TreeViewItemTemplateSettings(self: win32more.Microsoft.UI.Xaml.Controls.ITreeViewItem) -> win32more.Microsoft.UI.Xaml.Controls.TreeViewItemTemplateSettings: ...
    @winrt_mixinmethod
    def get_HasUnrealizedChildren(self: win32more.Microsoft.UI.Xaml.Controls.ITreeViewItem2) -> Boolean: ...
    @winrt_mixinmethod
    def put_HasUnrealizedChildren(self: win32more.Microsoft.UI.Xaml.Controls.ITreeViewItem2, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_ItemsSource(self: win32more.Microsoft.UI.Xaml.Controls.ITreeViewItem2) -> IInspectable: ...
    @winrt_mixinmethod
    def put_ItemsSource(self: win32more.Microsoft.UI.Xaml.Controls.ITreeViewItem2, value: IInspectable) -> Void: ...
    @winrt_classmethod
    def get_HasUnrealizedChildrenProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITreeViewItemStatics2) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ItemsSourceProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITreeViewItemStatics2) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_GlyphOpacityProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITreeViewItemStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_GlyphBrushProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITreeViewItemStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ExpandedGlyphProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITreeViewItemStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CollapsedGlyphProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITreeViewItemStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_GlyphSizeProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITreeViewItemStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsExpandedProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITreeViewItemStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TreeViewItemTemplateSettingsProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITreeViewItemStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    CollapsedGlyph = property(get_CollapsedGlyph, put_CollapsedGlyph)
    ExpandedGlyph = property(get_ExpandedGlyph, put_ExpandedGlyph)
    GlyphBrush = property(get_GlyphBrush, put_GlyphBrush)
    GlyphOpacity = property(get_GlyphOpacity, put_GlyphOpacity)
    GlyphSize = property(get_GlyphSize, put_GlyphSize)
    HasUnrealizedChildren = property(get_HasUnrealizedChildren, put_HasUnrealizedChildren)
    IsExpanded = property(get_IsExpanded, put_IsExpanded)
    ItemsSource = property(get_ItemsSource, put_ItemsSource)
    TreeViewItemTemplateSettings = property(get_TreeViewItemTemplateSettings, None)
    _TreeViewItem_Meta_.CollapsedGlyphProperty = property(get_CollapsedGlyphProperty, None)
    _TreeViewItem_Meta_.ExpandedGlyphProperty = property(get_ExpandedGlyphProperty, None)
    _TreeViewItem_Meta_.GlyphBrushProperty = property(get_GlyphBrushProperty, None)
    _TreeViewItem_Meta_.GlyphOpacityProperty = property(get_GlyphOpacityProperty, None)
    _TreeViewItem_Meta_.GlyphSizeProperty = property(get_GlyphSizeProperty, None)
    _TreeViewItem_Meta_.HasUnrealizedChildrenProperty = property(get_HasUnrealizedChildrenProperty, None)
    _TreeViewItem_Meta_.IsExpandedProperty = property(get_IsExpandedProperty, None)
    _TreeViewItem_Meta_.ItemsSourceProperty = property(get_ItemsSourceProperty, None)
    _TreeViewItem_Meta_.TreeViewItemTemplateSettingsProperty = property(get_TreeViewItemTemplateSettingsProperty, None)
class TreeViewItemInvokedEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ITreeViewItemInvokedEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.TreeViewItemInvokedEventArgs'
    @winrt_mixinmethod
    def get_InvokedItem(self: win32more.Microsoft.UI.Xaml.Controls.ITreeViewItemInvokedEventArgs) -> IInspectable: ...
    @winrt_mixinmethod
    def put_Handled(self: win32more.Microsoft.UI.Xaml.Controls.ITreeViewItemInvokedEventArgs, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_Handled(self: win32more.Microsoft.UI.Xaml.Controls.ITreeViewItemInvokedEventArgs) -> Boolean: ...
    Handled = property(get_Handled, put_Handled)
    InvokedItem = property(get_InvokedItem, None)
class _TreeViewItemTemplateSettings_Meta_(ComPtr.__class__):
    pass
class TreeViewItemTemplateSettings(ComPtr, metaclass=_TreeViewItemTemplateSettings_Meta_):
    extends: win32more.Microsoft.UI.Xaml.DependencyObject
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ITreeViewItemTemplateSettings
    _classid_ = 'Microsoft.UI.Xaml.Controls.TreeViewItemTemplateSettings'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.TreeViewItemTemplateSettings.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.ITreeViewItemTemplateSettingsFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.TreeViewItemTemplateSettings: ...
    @winrt_mixinmethod
    def get_ExpandedGlyphVisibility(self: win32more.Microsoft.UI.Xaml.Controls.ITreeViewItemTemplateSettings) -> win32more.Microsoft.UI.Xaml.Visibility: ...
    @winrt_mixinmethod
    def get_CollapsedGlyphVisibility(self: win32more.Microsoft.UI.Xaml.Controls.ITreeViewItemTemplateSettings) -> win32more.Microsoft.UI.Xaml.Visibility: ...
    @winrt_mixinmethod
    def get_Indentation(self: win32more.Microsoft.UI.Xaml.Controls.ITreeViewItemTemplateSettings) -> win32more.Microsoft.UI.Xaml.Thickness: ...
    @winrt_mixinmethod
    def get_DragItemsCount(self: win32more.Microsoft.UI.Xaml.Controls.ITreeViewItemTemplateSettings) -> Int32: ...
    @winrt_classmethod
    def get_ExpandedGlyphVisibilityProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITreeViewItemTemplateSettingsStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CollapsedGlyphVisibilityProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITreeViewItemTemplateSettingsStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IndentationProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITreeViewItemTemplateSettingsStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DragItemsCountProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITreeViewItemTemplateSettingsStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    CollapsedGlyphVisibility = property(get_CollapsedGlyphVisibility, None)
    DragItemsCount = property(get_DragItemsCount, None)
    ExpandedGlyphVisibility = property(get_ExpandedGlyphVisibility, None)
    Indentation = property(get_Indentation, None)
    _TreeViewItemTemplateSettings_Meta_.CollapsedGlyphVisibilityProperty = property(get_CollapsedGlyphVisibilityProperty, None)
    _TreeViewItemTemplateSettings_Meta_.DragItemsCountProperty = property(get_DragItemsCountProperty, None)
    _TreeViewItemTemplateSettings_Meta_.ExpandedGlyphVisibilityProperty = property(get_ExpandedGlyphVisibilityProperty, None)
    _TreeViewItemTemplateSettings_Meta_.IndentationProperty = property(get_IndentationProperty, None)
class TreeViewList(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.Controls.ListView
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ITreeViewList
    _classid_ = 'Microsoft.UI.Xaml.Controls.TreeViewList'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.TreeViewList.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.ITreeViewListFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.TreeViewList: ...
class _TreeViewNode_Meta_(ComPtr.__class__):
    pass
class TreeViewNode(ComPtr, metaclass=_TreeViewNode_Meta_):
    extends: win32more.Microsoft.UI.Xaml.DependencyObject
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ITreeViewNode
    _classid_ = 'Microsoft.UI.Xaml.Controls.TreeViewNode'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.TreeViewNode.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.ITreeViewNodeFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.TreeViewNode: ...
    @winrt_mixinmethod
    def get_Content(self: win32more.Microsoft.UI.Xaml.Controls.ITreeViewNode) -> IInspectable: ...
    @winrt_mixinmethod
    def put_Content(self: win32more.Microsoft.UI.Xaml.Controls.ITreeViewNode, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_Parent(self: win32more.Microsoft.UI.Xaml.Controls.ITreeViewNode) -> win32more.Microsoft.UI.Xaml.Controls.TreeViewNode: ...
    @winrt_mixinmethod
    def get_IsExpanded(self: win32more.Microsoft.UI.Xaml.Controls.ITreeViewNode) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsExpanded(self: win32more.Microsoft.UI.Xaml.Controls.ITreeViewNode, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_HasChildren(self: win32more.Microsoft.UI.Xaml.Controls.ITreeViewNode) -> Boolean: ...
    @winrt_mixinmethod
    def get_Depth(self: win32more.Microsoft.UI.Xaml.Controls.ITreeViewNode) -> Int32: ...
    @winrt_mixinmethod
    def get_HasUnrealizedChildren(self: win32more.Microsoft.UI.Xaml.Controls.ITreeViewNode) -> Boolean: ...
    @winrt_mixinmethod
    def put_HasUnrealizedChildren(self: win32more.Microsoft.UI.Xaml.Controls.ITreeViewNode, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_Children(self: win32more.Microsoft.UI.Xaml.Controls.ITreeViewNode) -> win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.Controls.TreeViewNode]: ...
    @winrt_classmethod
    def get_ContentProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITreeViewNodeStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DepthProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITreeViewNodeStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsExpandedProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITreeViewNodeStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HasChildrenProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITreeViewNodeStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    Children = property(get_Children, None)
    Content = property(get_Content, put_Content)
    Depth = property(get_Depth, None)
    HasChildren = property(get_HasChildren, None)
    HasUnrealizedChildren = property(get_HasUnrealizedChildren, put_HasUnrealizedChildren)
    IsExpanded = property(get_IsExpanded, put_IsExpanded)
    Parent = property(get_Parent, None)
    _TreeViewNode_Meta_.ContentProperty = property(get_ContentProperty, None)
    _TreeViewNode_Meta_.DepthProperty = property(get_DepthProperty, None)
    _TreeViewNode_Meta_.HasChildrenProperty = property(get_HasChildrenProperty, None)
    _TreeViewNode_Meta_.IsExpandedProperty = property(get_IsExpandedProperty, None)
class TreeViewSelectionChangedEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ITreeViewSelectionChangedEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Controls.TreeViewSelectionChangedEventArgs'
    @winrt_mixinmethod
    def get_AddedItems(self: win32more.Microsoft.UI.Xaml.Controls.ITreeViewSelectionChangedEventArgs) -> win32more.Windows.Foundation.Collections.IVector[IInspectable]: ...
    @winrt_mixinmethod
    def get_RemovedItems(self: win32more.Microsoft.UI.Xaml.Controls.ITreeViewSelectionChangedEventArgs) -> win32more.Windows.Foundation.Collections.IVector[IInspectable]: ...
    AddedItems = property(get_AddedItems, None)
    RemovedItems = property(get_RemovedItems, None)
class TreeViewSelectionMode(Enum, Int32):
    None_ = 0
    Single = 1
    Multiple = 2
class _TwoPaneView_Meta_(ComPtr.__class__):
    pass
class TwoPaneView(ComPtr, metaclass=_TwoPaneView_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.Control
    default_interface: win32more.Microsoft.UI.Xaml.Controls.ITwoPaneView
    _classid_ = 'Microsoft.UI.Xaml.Controls.TwoPaneView'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.TwoPaneView.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.ITwoPaneViewFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.TwoPaneView: ...
    @winrt_mixinmethod
    def get_Pane1(self: win32more.Microsoft.UI.Xaml.Controls.ITwoPaneView) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_mixinmethod
    def put_Pane1(self: win32more.Microsoft.UI.Xaml.Controls.ITwoPaneView, value: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    @winrt_mixinmethod
    def get_Pane2(self: win32more.Microsoft.UI.Xaml.Controls.ITwoPaneView) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_mixinmethod
    def put_Pane2(self: win32more.Microsoft.UI.Xaml.Controls.ITwoPaneView, value: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    @winrt_mixinmethod
    def get_Pane1Length(self: win32more.Microsoft.UI.Xaml.Controls.ITwoPaneView) -> win32more.Microsoft.UI.Xaml.GridLength: ...
    @winrt_mixinmethod
    def put_Pane1Length(self: win32more.Microsoft.UI.Xaml.Controls.ITwoPaneView, value: win32more.Microsoft.UI.Xaml.GridLength) -> Void: ...
    @winrt_mixinmethod
    def get_Pane2Length(self: win32more.Microsoft.UI.Xaml.Controls.ITwoPaneView) -> win32more.Microsoft.UI.Xaml.GridLength: ...
    @winrt_mixinmethod
    def put_Pane2Length(self: win32more.Microsoft.UI.Xaml.Controls.ITwoPaneView, value: win32more.Microsoft.UI.Xaml.GridLength) -> Void: ...
    @winrt_mixinmethod
    def get_PanePriority(self: win32more.Microsoft.UI.Xaml.Controls.ITwoPaneView) -> win32more.Microsoft.UI.Xaml.Controls.TwoPaneViewPriority: ...
    @winrt_mixinmethod
    def put_PanePriority(self: win32more.Microsoft.UI.Xaml.Controls.ITwoPaneView, value: win32more.Microsoft.UI.Xaml.Controls.TwoPaneViewPriority) -> Void: ...
    @winrt_mixinmethod
    def get_Mode(self: win32more.Microsoft.UI.Xaml.Controls.ITwoPaneView) -> win32more.Microsoft.UI.Xaml.Controls.TwoPaneViewMode: ...
    @winrt_mixinmethod
    def get_WideModeConfiguration(self: win32more.Microsoft.UI.Xaml.Controls.ITwoPaneView) -> win32more.Microsoft.UI.Xaml.Controls.TwoPaneViewWideModeConfiguration: ...
    @winrt_mixinmethod
    def put_WideModeConfiguration(self: win32more.Microsoft.UI.Xaml.Controls.ITwoPaneView, value: win32more.Microsoft.UI.Xaml.Controls.TwoPaneViewWideModeConfiguration) -> Void: ...
    @winrt_mixinmethod
    def get_TallModeConfiguration(self: win32more.Microsoft.UI.Xaml.Controls.ITwoPaneView) -> win32more.Microsoft.UI.Xaml.Controls.TwoPaneViewTallModeConfiguration: ...
    @winrt_mixinmethod
    def put_TallModeConfiguration(self: win32more.Microsoft.UI.Xaml.Controls.ITwoPaneView, value: win32more.Microsoft.UI.Xaml.Controls.TwoPaneViewTallModeConfiguration) -> Void: ...
    @winrt_mixinmethod
    def get_MinWideModeWidth(self: win32more.Microsoft.UI.Xaml.Controls.ITwoPaneView) -> Double: ...
    @winrt_mixinmethod
    def put_MinWideModeWidth(self: win32more.Microsoft.UI.Xaml.Controls.ITwoPaneView, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_MinTallModeHeight(self: win32more.Microsoft.UI.Xaml.Controls.ITwoPaneView) -> Double: ...
    @winrt_mixinmethod
    def put_MinTallModeHeight(self: win32more.Microsoft.UI.Xaml.Controls.ITwoPaneView, value: Double) -> Void: ...
    @winrt_mixinmethod
    def add_ModeChanged(self: win32more.Microsoft.UI.Xaml.Controls.ITwoPaneView, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.TwoPaneView, IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ModeChanged(self: win32more.Microsoft.UI.Xaml.Controls.ITwoPaneView, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def get_Pane1Property(cls: win32more.Microsoft.UI.Xaml.Controls.ITwoPaneViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_Pane2Property(cls: win32more.Microsoft.UI.Xaml.Controls.ITwoPaneViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_Pane1LengthProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITwoPaneViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_Pane2LengthProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITwoPaneViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_PanePriorityProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITwoPaneViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ModeProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITwoPaneViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_WideModeConfigurationProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITwoPaneViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_TallModeConfigurationProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITwoPaneViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MinWideModeWidthProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITwoPaneViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MinTallModeHeightProperty(cls: win32more.Microsoft.UI.Xaml.Controls.ITwoPaneViewStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    MinTallModeHeight = property(get_MinTallModeHeight, put_MinTallModeHeight)
    MinWideModeWidth = property(get_MinWideModeWidth, put_MinWideModeWidth)
    Mode = property(get_Mode, None)
    Pane1 = property(get_Pane1, put_Pane1)
    Pane1Length = property(get_Pane1Length, put_Pane1Length)
    Pane2 = property(get_Pane2, put_Pane2)
    Pane2Length = property(get_Pane2Length, put_Pane2Length)
    PanePriority = property(get_PanePriority, put_PanePriority)
    TallModeConfiguration = property(get_TallModeConfiguration, put_TallModeConfiguration)
    WideModeConfiguration = property(get_WideModeConfiguration, put_WideModeConfiguration)
    _TwoPaneView_Meta_.MinTallModeHeightProperty = property(get_MinTallModeHeightProperty, None)
    _TwoPaneView_Meta_.MinWideModeWidthProperty = property(get_MinWideModeWidthProperty, None)
    _TwoPaneView_Meta_.ModeProperty = property(get_ModeProperty, None)
    _TwoPaneView_Meta_.Pane1LengthProperty = property(get_Pane1LengthProperty, None)
    _TwoPaneView_Meta_.Pane1Property = property(get_Pane1Property, None)
    _TwoPaneView_Meta_.Pane2LengthProperty = property(get_Pane2LengthProperty, None)
    _TwoPaneView_Meta_.Pane2Property = property(get_Pane2Property, None)
    _TwoPaneView_Meta_.PanePriorityProperty = property(get_PanePriorityProperty, None)
    _TwoPaneView_Meta_.TallModeConfigurationProperty = property(get_TallModeConfigurationProperty, None)
    _TwoPaneView_Meta_.WideModeConfigurationProperty = property(get_WideModeConfigurationProperty, None)
    ModeChanged = event(add_ModeChanged, remove_ModeChanged)
class TwoPaneViewMode(Enum, Int32):
    SinglePane = 0
    Wide = 1
    Tall = 2
class TwoPaneViewPriority(Enum, Int32):
    Pane1 = 0
    Pane2 = 1
class TwoPaneViewTallModeConfiguration(Enum, Int32):
    SinglePane = 0
    TopBottom = 1
    BottomTop = 2
class TwoPaneViewWideModeConfiguration(Enum, Int32):
    SinglePane = 0
    LeftRight = 1
    RightLeft = 2
class UIElementCollection(ComPtr):
    extends: IInspectable
    implements: Tuple[SequenceProtocol[win32more.Microsoft.UI.Xaml.UIElement]]
    default_interface: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.UIElement]
    _classid_ = 'Microsoft.UI.Xaml.Controls.UIElementCollection'
    @winrt_mixinmethod
    def Move(self: win32more.Microsoft.UI.Xaml.Controls.IUIElementCollection, oldIndex: UInt32, newIndex: UInt32) -> Void: ...
    @winrt_mixinmethod
    def GetAt(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.UIElement], index: UInt32) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_mixinmethod
    def get_Size(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.UIElement]) -> UInt32: ...
    @winrt_mixinmethod
    def GetView(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.UIElement]) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Microsoft.UI.Xaml.UIElement]: ...
    @winrt_mixinmethod
    def IndexOf(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.UIElement], value: win32more.Microsoft.UI.Xaml.UIElement, index: POINTER(UInt32)) -> Boolean: ...
    @winrt_mixinmethod
    def SetAt(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.UIElement], index: UInt32, value: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    @winrt_mixinmethod
    def InsertAt(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.UIElement], index: UInt32, value: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    @winrt_mixinmethod
    def RemoveAt(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.UIElement], index: UInt32) -> Void: ...
    @winrt_mixinmethod
    def Append(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.UIElement], value: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    @winrt_mixinmethod
    def RemoveAtEnd(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.UIElement]) -> Void: ...
    @winrt_mixinmethod
    def Clear(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.UIElement]) -> Void: ...
    @winrt_mixinmethod
    def GetMany(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.UIElement], startIndex: UInt32, items: FillArray[win32more.Microsoft.UI.Xaml.UIElement]) -> UInt32: ...
    @winrt_mixinmethod
    def ReplaceAll(self: win32more.Windows.Foundation.Collections.IVector[win32more.Microsoft.UI.Xaml.UIElement], items: PassArray[win32more.Microsoft.UI.Xaml.UIElement]) -> Void: ...
    @winrt_mixinmethod
    def First(self: win32more.Windows.Foundation.Collections.IIterable[win32more.Microsoft.UI.Xaml.UIElement]) -> win32more.Windows.Foundation.Collections.IIterator[win32more.Microsoft.UI.Xaml.UIElement]: ...
    Size = property(get_Size, None)
class _UniformGridLayout_Meta_(ComPtr.__class__):
    pass
class UniformGridLayout(ComPtr, metaclass=_UniformGridLayout_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.VirtualizingLayout
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IUniformGridLayout
    _classid_ = 'Microsoft.UI.Xaml.Controls.UniformGridLayout'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.UniformGridLayout.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IUniformGridLayoutFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.UniformGridLayout: ...
    @winrt_mixinmethod
    def get_Orientation(self: win32more.Microsoft.UI.Xaml.Controls.IUniformGridLayout) -> win32more.Microsoft.UI.Xaml.Controls.Orientation: ...
    @winrt_mixinmethod
    def put_Orientation(self: win32more.Microsoft.UI.Xaml.Controls.IUniformGridLayout, value: win32more.Microsoft.UI.Xaml.Controls.Orientation) -> Void: ...
    @winrt_mixinmethod
    def get_MinItemWidth(self: win32more.Microsoft.UI.Xaml.Controls.IUniformGridLayout) -> Double: ...
    @winrt_mixinmethod
    def put_MinItemWidth(self: win32more.Microsoft.UI.Xaml.Controls.IUniformGridLayout, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_MinItemHeight(self: win32more.Microsoft.UI.Xaml.Controls.IUniformGridLayout) -> Double: ...
    @winrt_mixinmethod
    def put_MinItemHeight(self: win32more.Microsoft.UI.Xaml.Controls.IUniformGridLayout, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_MinRowSpacing(self: win32more.Microsoft.UI.Xaml.Controls.IUniformGridLayout) -> Double: ...
    @winrt_mixinmethod
    def put_MinRowSpacing(self: win32more.Microsoft.UI.Xaml.Controls.IUniformGridLayout, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_MinColumnSpacing(self: win32more.Microsoft.UI.Xaml.Controls.IUniformGridLayout) -> Double: ...
    @winrt_mixinmethod
    def put_MinColumnSpacing(self: win32more.Microsoft.UI.Xaml.Controls.IUniformGridLayout, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_ItemsJustification(self: win32more.Microsoft.UI.Xaml.Controls.IUniformGridLayout) -> win32more.Microsoft.UI.Xaml.Controls.UniformGridLayoutItemsJustification: ...
    @winrt_mixinmethod
    def put_ItemsJustification(self: win32more.Microsoft.UI.Xaml.Controls.IUniformGridLayout, value: win32more.Microsoft.UI.Xaml.Controls.UniformGridLayoutItemsJustification) -> Void: ...
    @winrt_mixinmethod
    def get_ItemsStretch(self: win32more.Microsoft.UI.Xaml.Controls.IUniformGridLayout) -> win32more.Microsoft.UI.Xaml.Controls.UniformGridLayoutItemsStretch: ...
    @winrt_mixinmethod
    def put_ItemsStretch(self: win32more.Microsoft.UI.Xaml.Controls.IUniformGridLayout, value: win32more.Microsoft.UI.Xaml.Controls.UniformGridLayoutItemsStretch) -> Void: ...
    @winrt_mixinmethod
    def get_MaximumRowsOrColumns(self: win32more.Microsoft.UI.Xaml.Controls.IUniformGridLayout) -> Int32: ...
    @winrt_mixinmethod
    def put_MaximumRowsOrColumns(self: win32more.Microsoft.UI.Xaml.Controls.IUniformGridLayout, value: Int32) -> Void: ...
    @winrt_classmethod
    def get_OrientationProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IUniformGridLayoutStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MinItemWidthProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IUniformGridLayoutStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MinItemHeightProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IUniformGridLayoutStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MinRowSpacingProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IUniformGridLayoutStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MinColumnSpacingProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IUniformGridLayoutStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ItemsJustificationProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IUniformGridLayoutStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ItemsStretchProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IUniformGridLayoutStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MaximumRowsOrColumnsProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IUniformGridLayoutStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    ItemsJustification = property(get_ItemsJustification, put_ItemsJustification)
    ItemsStretch = property(get_ItemsStretch, put_ItemsStretch)
    MaximumRowsOrColumns = property(get_MaximumRowsOrColumns, put_MaximumRowsOrColumns)
    MinColumnSpacing = property(get_MinColumnSpacing, put_MinColumnSpacing)
    MinItemHeight = property(get_MinItemHeight, put_MinItemHeight)
    MinItemWidth = property(get_MinItemWidth, put_MinItemWidth)
    MinRowSpacing = property(get_MinRowSpacing, put_MinRowSpacing)
    Orientation = property(get_Orientation, put_Orientation)
    _UniformGridLayout_Meta_.ItemsJustificationProperty = property(get_ItemsJustificationProperty, None)
    _UniformGridLayout_Meta_.ItemsStretchProperty = property(get_ItemsStretchProperty, None)
    _UniformGridLayout_Meta_.MaximumRowsOrColumnsProperty = property(get_MaximumRowsOrColumnsProperty, None)
    _UniformGridLayout_Meta_.MinColumnSpacingProperty = property(get_MinColumnSpacingProperty, None)
    _UniformGridLayout_Meta_.MinItemHeightProperty = property(get_MinItemHeightProperty, None)
    _UniformGridLayout_Meta_.MinItemWidthProperty = property(get_MinItemWidthProperty, None)
    _UniformGridLayout_Meta_.MinRowSpacingProperty = property(get_MinRowSpacingProperty, None)
    _UniformGridLayout_Meta_.OrientationProperty = property(get_OrientationProperty, None)
class UniformGridLayoutItemsJustification(Enum, Int32):
    Start = 0
    Center = 1
    End = 2
    SpaceAround = 3
    SpaceBetween = 4
    SpaceEvenly = 5
class UniformGridLayoutItemsStretch(Enum, Int32):
    None_ = 0
    Fill = 1
    Uniform = 2
class _UserControl_Meta_(ComPtr.__class__):
    pass
class UserControl(ComPtr, metaclass=_UserControl_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.Control
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IUserControl
    _classid_ = 'Microsoft.UI.Xaml.Controls.UserControl'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.UserControl.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IUserControlFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.UserControl: ...
    @winrt_mixinmethod
    def get_Content(self: win32more.Microsoft.UI.Xaml.Controls.IUserControl) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_mixinmethod
    def put_Content(self: win32more.Microsoft.UI.Xaml.Controls.IUserControl, value: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    @winrt_classmethod
    def get_ContentProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IUserControlStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    Content = property(get_Content, put_Content)
    _UserControl_Meta_.ContentProperty = property(get_ContentProperty, None)
class _VariableSizedWrapGrid_Meta_(ComPtr.__class__):
    pass
class VariableSizedWrapGrid(ComPtr, metaclass=_VariableSizedWrapGrid_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.Panel
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IVariableSizedWrapGrid
    _classid_ = 'Microsoft.UI.Xaml.Controls.VariableSizedWrapGrid'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.VariableSizedWrapGrid.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Controls.VariableSizedWrapGrid: ...
    @winrt_mixinmethod
    def get_ItemHeight(self: win32more.Microsoft.UI.Xaml.Controls.IVariableSizedWrapGrid) -> Double: ...
    @winrt_mixinmethod
    def put_ItemHeight(self: win32more.Microsoft.UI.Xaml.Controls.IVariableSizedWrapGrid, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_ItemWidth(self: win32more.Microsoft.UI.Xaml.Controls.IVariableSizedWrapGrid) -> Double: ...
    @winrt_mixinmethod
    def put_ItemWidth(self: win32more.Microsoft.UI.Xaml.Controls.IVariableSizedWrapGrid, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_Orientation(self: win32more.Microsoft.UI.Xaml.Controls.IVariableSizedWrapGrid) -> win32more.Microsoft.UI.Xaml.Controls.Orientation: ...
    @winrt_mixinmethod
    def put_Orientation(self: win32more.Microsoft.UI.Xaml.Controls.IVariableSizedWrapGrid, value: win32more.Microsoft.UI.Xaml.Controls.Orientation) -> Void: ...
    @winrt_mixinmethod
    def get_HorizontalChildrenAlignment(self: win32more.Microsoft.UI.Xaml.Controls.IVariableSizedWrapGrid) -> win32more.Microsoft.UI.Xaml.HorizontalAlignment: ...
    @winrt_mixinmethod
    def put_HorizontalChildrenAlignment(self: win32more.Microsoft.UI.Xaml.Controls.IVariableSizedWrapGrid, value: win32more.Microsoft.UI.Xaml.HorizontalAlignment) -> Void: ...
    @winrt_mixinmethod
    def get_VerticalChildrenAlignment(self: win32more.Microsoft.UI.Xaml.Controls.IVariableSizedWrapGrid) -> win32more.Microsoft.UI.Xaml.VerticalAlignment: ...
    @winrt_mixinmethod
    def put_VerticalChildrenAlignment(self: win32more.Microsoft.UI.Xaml.Controls.IVariableSizedWrapGrid, value: win32more.Microsoft.UI.Xaml.VerticalAlignment) -> Void: ...
    @winrt_mixinmethod
    def get_MaximumRowsOrColumns(self: win32more.Microsoft.UI.Xaml.Controls.IVariableSizedWrapGrid) -> Int32: ...
    @winrt_mixinmethod
    def put_MaximumRowsOrColumns(self: win32more.Microsoft.UI.Xaml.Controls.IVariableSizedWrapGrid, value: Int32) -> Void: ...
    @winrt_classmethod
    def get_ItemHeightProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IVariableSizedWrapGridStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ItemWidthProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IVariableSizedWrapGridStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_OrientationProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IVariableSizedWrapGridStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HorizontalChildrenAlignmentProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IVariableSizedWrapGridStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_VerticalChildrenAlignmentProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IVariableSizedWrapGridStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MaximumRowsOrColumnsProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IVariableSizedWrapGridStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_RowSpanProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IVariableSizedWrapGridStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetRowSpan(cls: win32more.Microsoft.UI.Xaml.Controls.IVariableSizedWrapGridStatics, element: win32more.Microsoft.UI.Xaml.UIElement) -> Int32: ...
    @winrt_classmethod
    def SetRowSpan(cls: win32more.Microsoft.UI.Xaml.Controls.IVariableSizedWrapGridStatics, element: win32more.Microsoft.UI.Xaml.UIElement, value: Int32) -> Void: ...
    @winrt_classmethod
    def get_ColumnSpanProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IVariableSizedWrapGridStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetColumnSpan(cls: win32more.Microsoft.UI.Xaml.Controls.IVariableSizedWrapGridStatics, element: win32more.Microsoft.UI.Xaml.UIElement) -> Int32: ...
    @winrt_classmethod
    def SetColumnSpan(cls: win32more.Microsoft.UI.Xaml.Controls.IVariableSizedWrapGridStatics, element: win32more.Microsoft.UI.Xaml.UIElement, value: Int32) -> Void: ...
    HorizontalChildrenAlignment = property(get_HorizontalChildrenAlignment, put_HorizontalChildrenAlignment)
    ItemHeight = property(get_ItemHeight, put_ItemHeight)
    ItemWidth = property(get_ItemWidth, put_ItemWidth)
    MaximumRowsOrColumns = property(get_MaximumRowsOrColumns, put_MaximumRowsOrColumns)
    Orientation = property(get_Orientation, put_Orientation)
    VerticalChildrenAlignment = property(get_VerticalChildrenAlignment, put_VerticalChildrenAlignment)
    _VariableSizedWrapGrid_Meta_.ColumnSpanProperty = property(get_ColumnSpanProperty, None)
    _VariableSizedWrapGrid_Meta_.HorizontalChildrenAlignmentProperty = property(get_HorizontalChildrenAlignmentProperty, None)
    _VariableSizedWrapGrid_Meta_.ItemHeightProperty = property(get_ItemHeightProperty, None)
    _VariableSizedWrapGrid_Meta_.ItemWidthProperty = property(get_ItemWidthProperty, None)
    _VariableSizedWrapGrid_Meta_.MaximumRowsOrColumnsProperty = property(get_MaximumRowsOrColumnsProperty, None)
    _VariableSizedWrapGrid_Meta_.OrientationProperty = property(get_OrientationProperty, None)
    _VariableSizedWrapGrid_Meta_.RowSpanProperty = property(get_RowSpanProperty, None)
    _VariableSizedWrapGrid_Meta_.VerticalChildrenAlignmentProperty = property(get_VerticalChildrenAlignmentProperty, None)
class _Viewbox_Meta_(ComPtr.__class__):
    pass
class Viewbox(ComPtr, metaclass=_Viewbox_Meta_):
    extends: win32more.Microsoft.UI.Xaml.FrameworkElement
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IViewbox
    _classid_ = 'Microsoft.UI.Xaml.Controls.Viewbox'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.Viewbox.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Controls.Viewbox: ...
    @winrt_mixinmethod
    def get_Child(self: win32more.Microsoft.UI.Xaml.Controls.IViewbox) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_mixinmethod
    def put_Child(self: win32more.Microsoft.UI.Xaml.Controls.IViewbox, value: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    @winrt_mixinmethod
    def get_Stretch(self: win32more.Microsoft.UI.Xaml.Controls.IViewbox) -> win32more.Microsoft.UI.Xaml.Media.Stretch: ...
    @winrt_mixinmethod
    def put_Stretch(self: win32more.Microsoft.UI.Xaml.Controls.IViewbox, value: win32more.Microsoft.UI.Xaml.Media.Stretch) -> Void: ...
    @winrt_mixinmethod
    def get_StretchDirection(self: win32more.Microsoft.UI.Xaml.Controls.IViewbox) -> win32more.Microsoft.UI.Xaml.Controls.StretchDirection: ...
    @winrt_mixinmethod
    def put_StretchDirection(self: win32more.Microsoft.UI.Xaml.Controls.IViewbox, value: win32more.Microsoft.UI.Xaml.Controls.StretchDirection) -> Void: ...
    @winrt_classmethod
    def get_StretchProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IViewboxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_StretchDirectionProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IViewboxStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    Child = property(get_Child, put_Child)
    Stretch = property(get_Stretch, put_Stretch)
    StretchDirection = property(get_StretchDirection, put_StretchDirection)
    _Viewbox_Meta_.StretchDirectionProperty = property(get_StretchDirectionProperty, None)
    _Viewbox_Meta_.StretchProperty = property(get_StretchProperty, None)
class VirtualizationMode(Enum, Int32):
    Standard = 0
    Recycling = 1
class VirtualizingLayout(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.Controls.Layout
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IVirtualizingLayout
    _classid_ = 'Microsoft.UI.Xaml.Controls.VirtualizingLayout'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.VirtualizingLayout.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IVirtualizingLayoutFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.VirtualizingLayout: ...
    @winrt_mixinmethod
    def InitializeForContextCore(self: win32more.Microsoft.UI.Xaml.Controls.IVirtualizingLayoutOverrides, context: win32more.Microsoft.UI.Xaml.Controls.VirtualizingLayoutContext) -> Void: ...
    @winrt_mixinmethod
    def UninitializeForContextCore(self: win32more.Microsoft.UI.Xaml.Controls.IVirtualizingLayoutOverrides, context: win32more.Microsoft.UI.Xaml.Controls.VirtualizingLayoutContext) -> Void: ...
    @winrt_mixinmethod
    def MeasureOverride(self: win32more.Microsoft.UI.Xaml.Controls.IVirtualizingLayoutOverrides, context: win32more.Microsoft.UI.Xaml.Controls.VirtualizingLayoutContext, availableSize: win32more.Windows.Foundation.Size) -> win32more.Windows.Foundation.Size: ...
    @winrt_mixinmethod
    def ArrangeOverride(self: win32more.Microsoft.UI.Xaml.Controls.IVirtualizingLayoutOverrides, context: win32more.Microsoft.UI.Xaml.Controls.VirtualizingLayoutContext, finalSize: win32more.Windows.Foundation.Size) -> win32more.Windows.Foundation.Size: ...
    @winrt_mixinmethod
    def OnItemsChangedCore(self: win32more.Microsoft.UI.Xaml.Controls.IVirtualizingLayoutOverrides, context: win32more.Microsoft.UI.Xaml.Controls.VirtualizingLayoutContext, source: IInspectable, args: win32more.Microsoft.UI.Xaml.Interop.NotifyCollectionChangedEventArgs) -> Void: ...
class VirtualizingLayoutContext(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.Controls.LayoutContext
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IVirtualizingLayoutContext
    _classid_ = 'Microsoft.UI.Xaml.Controls.VirtualizingLayoutContext'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.VirtualizingLayoutContext.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IVirtualizingLayoutContextFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.VirtualizingLayoutContext: ...
    @winrt_mixinmethod
    def get_ItemCount(self: win32more.Microsoft.UI.Xaml.Controls.IVirtualizingLayoutContext) -> Int32: ...
    @winrt_mixinmethod
    def GetItemAt(self: win32more.Microsoft.UI.Xaml.Controls.IVirtualizingLayoutContext, index: Int32) -> IInspectable: ...
    @winrt_mixinmethod
    def get_RealizationRect(self: win32more.Microsoft.UI.Xaml.Controls.IVirtualizingLayoutContext) -> win32more.Windows.Foundation.Rect: ...
    @winrt_mixinmethod
    def GetOrCreateElementAt(self: win32more.Microsoft.UI.Xaml.Controls.IVirtualizingLayoutContext, index: Int32) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_mixinmethod
    def GetOrCreateElementAt2(self: win32more.Microsoft.UI.Xaml.Controls.IVirtualizingLayoutContext, index: Int32, options: win32more.Microsoft.UI.Xaml.Controls.ElementRealizationOptions) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_mixinmethod
    def RecycleElement(self: win32more.Microsoft.UI.Xaml.Controls.IVirtualizingLayoutContext, element: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    @winrt_mixinmethod
    def get_RecommendedAnchorIndex(self: win32more.Microsoft.UI.Xaml.Controls.IVirtualizingLayoutContext) -> Int32: ...
    @winrt_mixinmethod
    def get_LayoutOrigin(self: win32more.Microsoft.UI.Xaml.Controls.IVirtualizingLayoutContext) -> win32more.Windows.Foundation.Point: ...
    @winrt_mixinmethod
    def put_LayoutOrigin(self: win32more.Microsoft.UI.Xaml.Controls.IVirtualizingLayoutContext, value: win32more.Windows.Foundation.Point) -> Void: ...
    @winrt_mixinmethod
    def get_VisibleRect(self: win32more.Microsoft.UI.Xaml.Controls.IVirtualizingLayoutContext2) -> win32more.Windows.Foundation.Rect: ...
    @winrt_mixinmethod
    def ItemCountCore(self: win32more.Microsoft.UI.Xaml.Controls.IVirtualizingLayoutContextOverrides) -> Int32: ...
    @winrt_mixinmethod
    def GetItemAtCore(self: win32more.Microsoft.UI.Xaml.Controls.IVirtualizingLayoutContextOverrides, index: Int32) -> IInspectable: ...
    @winrt_mixinmethod
    def RealizationRectCore(self: win32more.Microsoft.UI.Xaml.Controls.IVirtualizingLayoutContextOverrides) -> win32more.Windows.Foundation.Rect: ...
    @winrt_mixinmethod
    def GetOrCreateElementAtCore(self: win32more.Microsoft.UI.Xaml.Controls.IVirtualizingLayoutContextOverrides, index: Int32, options: win32more.Microsoft.UI.Xaml.Controls.ElementRealizationOptions) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_mixinmethod
    def RecycleElementCore(self: win32more.Microsoft.UI.Xaml.Controls.IVirtualizingLayoutContextOverrides, element: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    @winrt_mixinmethod
    def get_RecommendedAnchorIndexCore(self: win32more.Microsoft.UI.Xaml.Controls.IVirtualizingLayoutContextOverrides) -> Int32: ...
    @winrt_mixinmethod
    def get_LayoutOriginCore(self: win32more.Microsoft.UI.Xaml.Controls.IVirtualizingLayoutContextOverrides) -> win32more.Windows.Foundation.Point: ...
    @winrt_mixinmethod
    def put_LayoutOriginCore(self: win32more.Microsoft.UI.Xaml.Controls.IVirtualizingLayoutContextOverrides, value: win32more.Windows.Foundation.Point) -> Void: ...
    @winrt_mixinmethod
    def VisibleRectCore(self: win32more.Microsoft.UI.Xaml.Controls.IVirtualizingLayoutContextOverrides2) -> win32more.Windows.Foundation.Rect: ...
    ItemCount = property(get_ItemCount, None)
    LayoutOrigin = property(get_LayoutOrigin, put_LayoutOrigin)
    LayoutOriginCore = property(get_LayoutOriginCore, put_LayoutOriginCore)
    RealizationRect = property(get_RealizationRect, None)
    RecommendedAnchorIndex = property(get_RecommendedAnchorIndex, None)
    RecommendedAnchorIndexCore = property(get_RecommendedAnchorIndexCore, None)
    VisibleRect = property(get_VisibleRect, None)
class VirtualizingPanel(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.Controls.Panel
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IVirtualizingPanel
    _classid_ = 'Microsoft.UI.Xaml.Controls.VirtualizingPanel'
    @winrt_mixinmethod
    def get_ItemContainerGenerator(self: win32more.Microsoft.UI.Xaml.Controls.IVirtualizingPanel) -> win32more.Microsoft.UI.Xaml.Controls.ItemContainerGenerator: ...
    @winrt_mixinmethod
    def AddInternalChild(self: win32more.Microsoft.UI.Xaml.Controls.IVirtualizingPanelProtected, child: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    @winrt_mixinmethod
    def InsertInternalChild(self: win32more.Microsoft.UI.Xaml.Controls.IVirtualizingPanelProtected, index: Int32, child: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    @winrt_mixinmethod
    def RemoveInternalChildRange(self: win32more.Microsoft.UI.Xaml.Controls.IVirtualizingPanelProtected, index: Int32, range: Int32) -> Void: ...
    @winrt_mixinmethod
    def OnItemsChanged(self: win32more.Microsoft.UI.Xaml.Controls.IVirtualizingPanelOverrides, sender: IInspectable, args: win32more.Microsoft.UI.Xaml.Controls.Primitives.ItemsChangedEventArgs) -> Void: ...
    @winrt_mixinmethod
    def OnClearChildren(self: win32more.Microsoft.UI.Xaml.Controls.IVirtualizingPanelOverrides) -> Void: ...
    @winrt_mixinmethod
    def BringIndexIntoView(self: win32more.Microsoft.UI.Xaml.Controls.IVirtualizingPanelOverrides, index: Int32) -> Void: ...
    ItemContainerGenerator = property(get_ItemContainerGenerator, None)
class _VirtualizingStackPanel_Meta_(ComPtr.__class__):
    pass
class VirtualizingStackPanel(ComPtr, metaclass=_VirtualizingStackPanel_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.Primitives.OrientedVirtualizingPanel
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IVirtualizingStackPanel
    _classid_ = 'Microsoft.UI.Xaml.Controls.VirtualizingStackPanel'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.VirtualizingStackPanel.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Controls.VirtualizingStackPanel: ...
    @winrt_mixinmethod
    def get_AreScrollSnapPointsRegular(self: win32more.Microsoft.UI.Xaml.Controls.IVirtualizingStackPanel) -> Boolean: ...
    @winrt_mixinmethod
    def put_AreScrollSnapPointsRegular(self: win32more.Microsoft.UI.Xaml.Controls.IVirtualizingStackPanel, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_Orientation(self: win32more.Microsoft.UI.Xaml.Controls.IVirtualizingStackPanel) -> win32more.Microsoft.UI.Xaml.Controls.Orientation: ...
    @winrt_mixinmethod
    def put_Orientation(self: win32more.Microsoft.UI.Xaml.Controls.IVirtualizingStackPanel, value: win32more.Microsoft.UI.Xaml.Controls.Orientation) -> Void: ...
    @winrt_mixinmethod
    def add_CleanUpVirtualizedItemEvent(self: win32more.Microsoft.UI.Xaml.Controls.IVirtualizingStackPanel, handler: win32more.Microsoft.UI.Xaml.Controls.CleanUpVirtualizedItemEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_CleanUpVirtualizedItemEvent(self: win32more.Microsoft.UI.Xaml.Controls.IVirtualizingStackPanel, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def OnCleanUpVirtualizedItem(self: win32more.Microsoft.UI.Xaml.Controls.IVirtualizingStackPanelOverrides, e: win32more.Microsoft.UI.Xaml.Controls.CleanUpVirtualizedItemEventArgs) -> Void: ...
    @winrt_classmethod
    def get_AreScrollSnapPointsRegularProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IVirtualizingStackPanelStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_OrientationProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IVirtualizingStackPanelStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_VirtualizationModeProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IVirtualizingStackPanelStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetVirtualizationMode(cls: win32more.Microsoft.UI.Xaml.Controls.IVirtualizingStackPanelStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject) -> win32more.Microsoft.UI.Xaml.Controls.VirtualizationMode: ...
    @winrt_classmethod
    def SetVirtualizationMode(cls: win32more.Microsoft.UI.Xaml.Controls.IVirtualizingStackPanelStatics, element: win32more.Microsoft.UI.Xaml.DependencyObject, value: win32more.Microsoft.UI.Xaml.Controls.VirtualizationMode) -> Void: ...
    @winrt_classmethod
    def get_IsVirtualizingProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IVirtualizingStackPanelStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def GetIsVirtualizing(cls: win32more.Microsoft.UI.Xaml.Controls.IVirtualizingStackPanelStatics, o: win32more.Microsoft.UI.Xaml.DependencyObject) -> Boolean: ...
    AreScrollSnapPointsRegular = property(get_AreScrollSnapPointsRegular, put_AreScrollSnapPointsRegular)
    Orientation = property(get_Orientation, put_Orientation)
    _VirtualizingStackPanel_Meta_.AreScrollSnapPointsRegularProperty = property(get_AreScrollSnapPointsRegularProperty, None)
    _VirtualizingStackPanel_Meta_.IsVirtualizingProperty = property(get_IsVirtualizingProperty, None)
    _VirtualizingStackPanel_Meta_.OrientationProperty = property(get_OrientationProperty, None)
    _VirtualizingStackPanel_Meta_.VirtualizationModeProperty = property(get_VirtualizationModeProperty, None)
    CleanUpVirtualizedItemEvent = event(add_CleanUpVirtualizedItemEvent, remove_CleanUpVirtualizedItemEvent)
class _WebView2_Meta_(ComPtr.__class__):
    pass
class WebView2(ComPtr, metaclass=_WebView2_Meta_):
    extends: win32more.Microsoft.UI.Xaml.FrameworkElement
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IWebView2
    _classid_ = 'Microsoft.UI.Xaml.Controls.WebView2'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.WebView2.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Controls.IWebView2Factory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.WebView2: ...
    @winrt_mixinmethod
    def get_CoreWebView2(self: win32more.Microsoft.UI.Xaml.Controls.IWebView2) -> win32more.Microsoft.Web.WebView2.Core.CoreWebView2: ...
    @winrt_mixinmethod
    def EnsureCoreWebView2Async(self: win32more.Microsoft.UI.Xaml.Controls.IWebView2) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def ExecuteScriptAsync(self: win32more.Microsoft.UI.Xaml.Controls.IWebView2, javascriptCode: hstr) -> win32more.Windows.Foundation.IAsyncOperation[hstr]: ...
    @winrt_mixinmethod
    def get_Source(self: win32more.Microsoft.UI.Xaml.Controls.IWebView2) -> win32more.Windows.Foundation.Uri: ...
    @winrt_mixinmethod
    def put_Source(self: win32more.Microsoft.UI.Xaml.Controls.IWebView2, value: win32more.Windows.Foundation.Uri) -> Void: ...
    @winrt_mixinmethod
    def get_CanGoForward(self: win32more.Microsoft.UI.Xaml.Controls.IWebView2) -> Boolean: ...
    @winrt_mixinmethod
    def put_CanGoForward(self: win32more.Microsoft.UI.Xaml.Controls.IWebView2, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_CanGoBack(self: win32more.Microsoft.UI.Xaml.Controls.IWebView2) -> Boolean: ...
    @winrt_mixinmethod
    def put_CanGoBack(self: win32more.Microsoft.UI.Xaml.Controls.IWebView2, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_DefaultBackgroundColor(self: win32more.Microsoft.UI.Xaml.Controls.IWebView2) -> win32more.Windows.UI.Color: ...
    @winrt_mixinmethod
    def put_DefaultBackgroundColor(self: win32more.Microsoft.UI.Xaml.Controls.IWebView2, value: win32more.Windows.UI.Color) -> Void: ...
    @winrt_mixinmethod
    def Reload(self: win32more.Microsoft.UI.Xaml.Controls.IWebView2) -> Void: ...
    @winrt_mixinmethod
    def GoForward(self: win32more.Microsoft.UI.Xaml.Controls.IWebView2) -> Void: ...
    @winrt_mixinmethod
    def GoBack(self: win32more.Microsoft.UI.Xaml.Controls.IWebView2) -> Void: ...
    @winrt_mixinmethod
    def NavigateToString(self: win32more.Microsoft.UI.Xaml.Controls.IWebView2, htmlContent: hstr) -> Void: ...
    @winrt_mixinmethod
    def Close(self: win32more.Microsoft.UI.Xaml.Controls.IWebView2) -> Void: ...
    @winrt_mixinmethod
    def add_NavigationCompleted(self: win32more.Microsoft.UI.Xaml.Controls.IWebView2, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.WebView2, win32more.Microsoft.Web.WebView2.Core.CoreWebView2NavigationCompletedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_NavigationCompleted(self: win32more.Microsoft.UI.Xaml.Controls.IWebView2, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_WebMessageReceived(self: win32more.Microsoft.UI.Xaml.Controls.IWebView2, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.WebView2, win32more.Microsoft.Web.WebView2.Core.CoreWebView2WebMessageReceivedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_WebMessageReceived(self: win32more.Microsoft.UI.Xaml.Controls.IWebView2, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_NavigationStarting(self: win32more.Microsoft.UI.Xaml.Controls.IWebView2, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.WebView2, win32more.Microsoft.Web.WebView2.Core.CoreWebView2NavigationStartingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_NavigationStarting(self: win32more.Microsoft.UI.Xaml.Controls.IWebView2, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_CoreProcessFailed(self: win32more.Microsoft.UI.Xaml.Controls.IWebView2, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.WebView2, win32more.Microsoft.Web.WebView2.Core.CoreWebView2ProcessFailedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_CoreProcessFailed(self: win32more.Microsoft.UI.Xaml.Controls.IWebView2, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_CoreWebView2Initialized(self: win32more.Microsoft.UI.Xaml.Controls.IWebView2, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Controls.WebView2, win32more.Microsoft.UI.Xaml.Controls.CoreWebView2InitializedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_CoreWebView2Initialized(self: win32more.Microsoft.UI.Xaml.Controls.IWebView2, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def EnsureCoreWebView2WithEnvironmentAsync(self: win32more.Microsoft.UI.Xaml.Controls.IWebView22, environment: win32more.Microsoft.Web.WebView2.Core.CoreWebView2Environment) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def EnsureCoreWebView2WithEnvironmentAndOptionsAsync(self: win32more.Microsoft.UI.Xaml.Controls.IWebView22, environment: win32more.Microsoft.Web.WebView2.Core.CoreWebView2Environment, controllerOptions: win32more.Microsoft.Web.WebView2.Core.CoreWebView2ControllerOptions) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_classmethod
    def get_SourceProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IWebView2Statics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CanGoForwardProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IWebView2Statics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_CanGoBackProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IWebView2Statics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_DefaultBackgroundColorProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IWebView2Statics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    CanGoBack = property(get_CanGoBack, put_CanGoBack)
    CanGoForward = property(get_CanGoForward, put_CanGoForward)
    CoreWebView2 = property(get_CoreWebView2, None)
    DefaultBackgroundColor = property(get_DefaultBackgroundColor, put_DefaultBackgroundColor)
    Source = property(get_Source, put_Source)
    _WebView2_Meta_.CanGoBackProperty = property(get_CanGoBackProperty, None)
    _WebView2_Meta_.CanGoForwardProperty = property(get_CanGoForwardProperty, None)
    _WebView2_Meta_.DefaultBackgroundColorProperty = property(get_DefaultBackgroundColorProperty, None)
    _WebView2_Meta_.SourceProperty = property(get_SourceProperty, None)
    CoreProcessFailed = event(add_CoreProcessFailed, remove_CoreProcessFailed)
    CoreWebView2Initialized = event(add_CoreWebView2Initialized, remove_CoreWebView2Initialized)
    NavigationCompleted = event(add_NavigationCompleted, remove_NavigationCompleted)
    NavigationStarting = event(add_NavigationStarting, remove_NavigationStarting)
    WebMessageReceived = event(add_WebMessageReceived, remove_WebMessageReceived)
class _WrapGrid_Meta_(ComPtr.__class__):
    pass
class WrapGrid(ComPtr, metaclass=_WrapGrid_Meta_):
    extends: win32more.Microsoft.UI.Xaml.Controls.Primitives.OrientedVirtualizingPanel
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IWrapGrid
    _classid_ = 'Microsoft.UI.Xaml.Controls.WrapGrid'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.WrapGrid.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Controls.WrapGrid: ...
    @winrt_mixinmethod
    def get_ItemWidth(self: win32more.Microsoft.UI.Xaml.Controls.IWrapGrid) -> Double: ...
    @winrt_mixinmethod
    def put_ItemWidth(self: win32more.Microsoft.UI.Xaml.Controls.IWrapGrid, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_ItemHeight(self: win32more.Microsoft.UI.Xaml.Controls.IWrapGrid) -> Double: ...
    @winrt_mixinmethod
    def put_ItemHeight(self: win32more.Microsoft.UI.Xaml.Controls.IWrapGrid, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_Orientation(self: win32more.Microsoft.UI.Xaml.Controls.IWrapGrid) -> win32more.Microsoft.UI.Xaml.Controls.Orientation: ...
    @winrt_mixinmethod
    def put_Orientation(self: win32more.Microsoft.UI.Xaml.Controls.IWrapGrid, value: win32more.Microsoft.UI.Xaml.Controls.Orientation) -> Void: ...
    @winrt_mixinmethod
    def get_HorizontalChildrenAlignment(self: win32more.Microsoft.UI.Xaml.Controls.IWrapGrid) -> win32more.Microsoft.UI.Xaml.HorizontalAlignment: ...
    @winrt_mixinmethod
    def put_HorizontalChildrenAlignment(self: win32more.Microsoft.UI.Xaml.Controls.IWrapGrid, value: win32more.Microsoft.UI.Xaml.HorizontalAlignment) -> Void: ...
    @winrt_mixinmethod
    def get_VerticalChildrenAlignment(self: win32more.Microsoft.UI.Xaml.Controls.IWrapGrid) -> win32more.Microsoft.UI.Xaml.VerticalAlignment: ...
    @winrt_mixinmethod
    def put_VerticalChildrenAlignment(self: win32more.Microsoft.UI.Xaml.Controls.IWrapGrid, value: win32more.Microsoft.UI.Xaml.VerticalAlignment) -> Void: ...
    @winrt_mixinmethod
    def get_MaximumRowsOrColumns(self: win32more.Microsoft.UI.Xaml.Controls.IWrapGrid) -> Int32: ...
    @winrt_mixinmethod
    def put_MaximumRowsOrColumns(self: win32more.Microsoft.UI.Xaml.Controls.IWrapGrid, value: Int32) -> Void: ...
    @winrt_classmethod
    def get_ItemWidthProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IWrapGridStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ItemHeightProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IWrapGridStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_OrientationProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IWrapGridStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_HorizontalChildrenAlignmentProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IWrapGridStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_VerticalChildrenAlignmentProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IWrapGridStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_MaximumRowsOrColumnsProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IWrapGridStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    HorizontalChildrenAlignment = property(get_HorizontalChildrenAlignment, put_HorizontalChildrenAlignment)
    ItemHeight = property(get_ItemHeight, put_ItemHeight)
    ItemWidth = property(get_ItemWidth, put_ItemWidth)
    MaximumRowsOrColumns = property(get_MaximumRowsOrColumns, put_MaximumRowsOrColumns)
    Orientation = property(get_Orientation, put_Orientation)
    VerticalChildrenAlignment = property(get_VerticalChildrenAlignment, put_VerticalChildrenAlignment)
    _WrapGrid_Meta_.HorizontalChildrenAlignmentProperty = property(get_HorizontalChildrenAlignmentProperty, None)
    _WrapGrid_Meta_.ItemHeightProperty = property(get_ItemHeightProperty, None)
    _WrapGrid_Meta_.ItemWidthProperty = property(get_ItemWidthProperty, None)
    _WrapGrid_Meta_.MaximumRowsOrColumnsProperty = property(get_MaximumRowsOrColumnsProperty, None)
    _WrapGrid_Meta_.OrientationProperty = property(get_OrientationProperty, None)
    _WrapGrid_Meta_.VerticalChildrenAlignmentProperty = property(get_VerticalChildrenAlignmentProperty, None)
class _XamlControlsResources_Meta_(ComPtr.__class__):
    pass
class XamlControlsResources(ComPtr, metaclass=_XamlControlsResources_Meta_):
    extends: win32more.Microsoft.UI.Xaml.ResourceDictionary
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IXamlControlsResources
    _classid_ = 'Microsoft.UI.Xaml.Controls.XamlControlsResources'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.XamlControlsResources.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Controls.XamlControlsResources: ...
    @winrt_mixinmethod
    def get_UseCompactResources(self: win32more.Microsoft.UI.Xaml.Controls.IXamlControlsResources) -> Boolean: ...
    @winrt_mixinmethod
    def put_UseCompactResources(self: win32more.Microsoft.UI.Xaml.Controls.IXamlControlsResources, value: Boolean) -> Void: ...
    @winrt_classmethod
    def EnsureRevealLights(cls: win32more.Microsoft.UI.Xaml.Controls.IXamlControlsResourcesStatics, element: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    @winrt_classmethod
    def get_UseCompactResourcesProperty(cls: win32more.Microsoft.UI.Xaml.Controls.IXamlControlsResourcesStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    UseCompactResources = property(get_UseCompactResources, put_UseCompactResources)
    _XamlControlsResources_Meta_.UseCompactResourcesProperty = property(get_UseCompactResourcesProperty, None)
class ZoomMode(Enum, Int32):
    Disabled = 0
    Enabled = 1


make_ready(__name__)
